oshi-core 7.3.0 API
Packages
Package
Description
[oshi-core API] Provides a cross-platform implementation to retrieve Operating System and Hardware Information, such
as OS version, memory, CPU, disk, devices, sensors, etc.
Provides useful annotation for oshi project.
Provides annotations to document thread safety
Provides functions to query Mac info
Shared GPU-related driver classes for Windows, containing POJOs and utility methods with no native dependencies.
Provides common Windows performance monitor constants and definitions shared between JNA and FFM implementations.
Provides common Windows registry performance data POJOs shared between JNA and FFM implementations.
Provides common WMI driver constants and property enums shared between JNA and FFM implementations.
Provides functions to query Linux information
Provides functions to query statistics in the Linux /proc pseudo-filesystem
Provides functions to query Mac info
Provides functions to query Mac disk info
Provides functions to query Mac network info
Provides functions to query information on AIX
Provides functions to query information on AIX using the libperfstat api
Provides parsing utilities for commands shared by BSD-derived platforms (e.g.
Provides parsing utilities for BSD disk-related commands (e.g.
Provides functions to query FreeBSD information
Provides functions to query FreeBSD disk information
Provides functions to query Solaris information
Provides functions to query Solaris disk information.
Provides functions to query Solaris kstat information
Provides functions to query information in windows
Provides functions to query counters in windows performance monitor (or WMI counter tables)
Provides functions to query data in Windows Registry
Provides functions to query properties in WMI classes
[oshi-common API] Provides cross-platform implementation to retrieve hardware information such as CPU, Memory,
Display, Disks, Network Interfaces, Power Sources, Sensors, and USB Devices
Provides abstract classes for common code
Provides common Linux hardware implementations shared by JNA and FFM modules.
Native-free Linux hardware implementations using only procfs, sysfs, and command-line utilities.
Provides information about hardware such as Memory, Power Sources, and Processor on Mac systems
Provides common Unix hardware implementations shared by JNA and FFM modules.
Provides abstract base classes and pure-Java implementations for FreeBSD hardware, shared by the JNA and FFM modules.
Provides abstract base classes and pure-Java implementations for OpenBSD hardware, shared by the JNA and FFM modules.
Provides abstract base classes and pure-Java implementations for Solaris/illumos hardware, shared by the JNA and FFM
modules.
Provides common implementations for Windows hardware information shared between JNA and FFM implementations.
Provides information about hardware such as Memory, Power Sources, and Processor on Linux systems
Provides information about hardware such as Memory, Power Sources, and Processor on Mac systems
Provides mappings for Unix-based operating systems
Provides information about hardware such as Memory, Power Sources, and Processor on AIX systems
Provides information about hardware such as Memory, Power Sources, and Processor on DragonFly BSD systems
Provides information about hardware such as Memory, Power Sources, and Processor on FreeBSD systems
Provides information about hardware such as Memory, Power Sources, and Processor on NetBSD systems
Provides information about hardware such as Memory, Power Sources, and Processor on OpenBSD systems
Provides information about hardware such as Memory, Power Sources, and Processor on Solaris systems
Provides information about hardware such as Memory, Power Sources, and Processor on Windows systems
Provides wrapper functions to proactively close native memory allocations.
Provides JNA library bindings that are not platform-specific.
Provides extensions of JNA libraries for Linux.
Provides extensions of JNA libraries for macOS.
Provides extensions of JNA libraries for Unix.
Provides extensions of JNA libraries for Windows.
JNA-dependent utility methods extracted from common utilities.
Native-free OSHI entry point for Linux.
Provides abstract classes for common code
Provides common (native-free) Linux operating system implementations shared by JNA and FFM modules.
Native-free Linux operating system implementations using only procfs, sysfs, and command-line utilities.
Provides information about Software and OS on macOS
Provides abstract base classes and pure-Java implementations for the FreeBSD operating system, shared by the JNA and
FFM modules.
Provides abstract base classes and pure-Java implementations for the OpenBSD operating system, shared by the JNA and
FFM modules.
Provides abstract base classes and pure-Java implementations for Solaris/illumos software, shared by the JNA and FFM
modules.
Provides common implementations for Windows operating system information shared between JNA and FFM implementations.
[oshi-common API] Provides cross-platform common API to retrieve OS, FileSystem, and Process information
Provides information about Software and OS on Linux
Provides information about Software and OS on macOS
Provides information about Software and OS on AIX
Provides information about Software and OS on DragonFly BSD
Provides information about Software and OS on FreeBSD
Provides information about Software and OS on NetBSD
Provides information about Software and OS on OpenBSD
Provides information about Software and OS on Solaris
Provides information about Software and OS on Windows
Service Provider Interface for OSHI's SystemInfo entry points.
Provides utilities for parsing, formatting, and other access
Shared, native-free FreeBSD utility classes (procstat parsing, etc.) used by both JNA and FFM implementations.
Provides pure-Java utility classes for OpenBSD, shared by the JNA and FFM modules.
Provides non-native Linux driver utilities for querying system information.
Provides non-native Linux driver utilities for querying the
/proc filesystem.Provides driver utilities common to unix systems that do not require native access
Utility classes for optional vendor GPU library integration (NVML, ADL).
Provides constants for Linux filesystem paths (
/proc, /dev, /sys).Provides utilities for macOS.
Provides utilities for DragonFly BSD
Provides utilities for FreeBSD
Provides utilities for NetBSD
Provides utilities for OpenBSD
Provides utilities for Solaris
Provides utilities for Windows.
Provides classes encapsulating multiple objects, intended as return types from methods