All Classes and Interfaces

Class
Description
Baseboard data
Abstract base class for BluetoothDevice implementations.
A CPU.
Computer System data.
A Display
Common methods for filesystem implementations
Firmware data.
Memory info.
An abstract Graphics Card
Common fields or methods used by platform-specific implementations of HardwareAbstractionLayer
Common methods for platform HWDiskStore classes
Common implementations for IP Stats
Common implementations for LogicalVolumeGroup.
Network interfaces implementation.
Common NetworkParams implementation.
Common methods for OperatingSystem implementations
Common implementations for OSFileStore
A process is an instance of a computer program that is being executed.
Common methods for OSThread implementation
A Power Source
Abstract base class for Printer implementations.
Sensors from WMI or Open Hardware Monitor
An abstract Sound Card
A USB device
Virtual Memory info.
JNA bindings for the AMD Display Library (ADL) on Windows.
 
 
ADL malloc callback: allocates memory and returns a pointer.
 
 
Optional runtime binding to the AMD Display Library (ADL) on Windows.
The AIX File System contains OSFileStores which are a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage.
AIXHardwareAbstractionLayer class.
AIX hard disk implementation.
 
Internet Protocol Stats implementation
C library.
 
 
64-bit timestruc required for psinfo structure
AIXNetworks class.
AIX (Advanced Interactive eXecutive) is a series of proprietary Unix operating systems developed and sold by IBM for several of its computer platforms.
OSFileStore implementation
OSProcess implementation
OSThread implementation
A Power Source
AIX Usb Device
Represents common information about an installed application across different operating systems.
Constants and shared logic for the Linux auxiliary vector (/proc/self/auxv).
Reads a native-long value from a ByteBuffer and returns it as a Java long.
JNA-based utility to read the auxiliary vector from /proc/self/auxv.
The Baseboard represents the system board, also called motherboard, logic board, etc.
Represents a Bluetooth device (paired or connected) known to the system, analogous to UsbDevice for USB peripherals.
BsdNetworkIF applicable to FreeBSD and OpenBSD.
Provides access to sysctl calls on FreeBSD
Wrapper classes for JNA clases which extend ByReference intended for use in try-with-resources blocks.
 
 
 
 
 
 
 
 
 
This class represents the entire Central Processing Unit (CPU) of a computer system, which may contain one or more physical packages (sockets), one or more physical processors (cores), and one or more logical processors (what the Operating System sees, which may include hyperthreaded cores.)
A class representing a Logical Processor and its replationship to physical processors, physical packages, and logical groupings such as NUMA Nodes and Processor groups, useful for identifying processor topology.
A class representing a Physical Processor (a core) providing per-core statistics that may vary, particularly in hybrid/modular processors.
A class representing CPU Cache Memory.
The type of cache.
A class encapsulating ghe CPU's identifier strings ,including name, vendor, stepping, model, and family information (also called the signature of a CPU)
CF String retrieving
Represents cgroup (control group) information for containerized environments.
C library with code common to all *nix-based operating systems.
 
 
 
 
 
 
 
 
The ComputerSystem represents the physical hardware, of a computer system/product and includes BIOS/firmware and a motherboard, logic board, etc.
General constants used in multiple classes
Utility to read CPU info from /proc/cpuinfo
Utility to read CPU statistics from /proc/stat
CUPS-based printer implementation with shared lpstat fallback logic.
Factory interface for creating concrete printer instances.
CUPS-based printer implementation using JNA.
Utility to read info from the devicetree
Utility to query device interfaces via Config Manager Device Tree functions
Provides constants for paths in the /dev filesystem on Linux.
Utility class parsing partition information from the BSD disklabel command.
Utility to read disk statistics from /proc/diskstats
Enum corresponding to the fields in the output of /proc/diskstats
Display refers to the information regarding a video source and monitor identified by the EDID standard.
Utility to read info from dmidecode
DragonFly BSD Central Processor.
DragonFlyBsdHardwareAbstractionLayer class.
DragonFly BSD C library.
DragonFly BSD is a free and open-source Unix-like operating system forked from FreeBSD 4.8 in 2003.
OSProcess implementation
OSThread implementation
Utility to read EDID data from the Linux DRM (Direct Rendering Manager) subsystem.
Minimal JNA binding to dxgi.dll for enumerating display adapters and reading DXGI_ADAPTER_DESC.DedicatedVideoMemory.
Maps to the Windows DXGI_ADAPTER_DESC structure.
Immutable snapshot of a DXGI adapter's identity and dedicated video memory.
Shared utility methods for DXGI adapter matching and related parsing.
Utility methods for DXGI adapter enumeration and matching on Windows.
EDID parsing utility.
Utility to query Desktop windows
Utility methods for reducing repetitive exception handling boilerplate, particularly around FFM (Foreign Function and Memory) native calls that require catching Throwable.
A boolean-returning supplier that may throw any Throwable.
A double-returning supplier that may throw any Throwable.
An int-returning supplier that may throw any Throwable.
A long-returning supplier that may throw any Throwable.
A runnable that may throw any Throwable.
A supplier that may throw any Throwable, including checked exceptions.
A class for executing on the command line and returning the result of execution.
The File System is a logical arrangement, usually in a hierarchial tree, where files are placed for storage and retrieval.
Utility class for common filesystem code
File reading methods
JNA-specific extensions to FileUtil for reading native types from buffers and freeing native memory.
The Firmware represents the low level BIOS or equivalent.
Formatting utility for appending units or converting between number types.
 
A CPU
 
JNA-backed FreeBSD computer system.
 
JNA-backed FreeBSD file system.
Firmware information from dmidecode
 
JNA-backed FreeBSD global memory.
Graphics Card info obtained from pciconf
FreeBsdHardwareAbstractionLayerJNA class.
 
FreeBSD hard disk implementation.
 
Internet Protocol Stats implementation
C library.
CPU Ticks
Connection info
Return type for BSD sysctl kern.boottime
 
JNA-backed FreeBSD network params.
FreeBSD is a free and open-source Unix-like operating system descended from the Berkeley Software Distribution (BSD), which was based on Research Unix.
OSFileStore implementation.
 
Columns requested from ps -awwxo when enumerating threads.
OSProcess implementation
OSThread implementation
 
A Power Source
 
JNA-backed FreeBSD sensors.
FreeBSD soundcard.
FreeBsd Usb Device
 
Utility to query fsstat
Reads from fstat.
Reads from fstat and related utilities on NetBSD.
Utility to query geom part list
Utility to query geom part list
The global configuration utility.
Indicates that a configuration value is invalid.
The GlobalMemory class tracks information about the use of a computer's physical memory (RAM) as well as any available virtual memory.
GPU performance counter enums.
GPU Adapter Memory counter properties.
GPU Engine running time counter properties.
Utility to query GPU performance counter
A session handle for sampling dynamic GPU metrics.
An immutable snapshot of cumulative GPU active and idle tick counters in opaque, platform-native units.
Represents a graphics card (GPU) installed in the system.
The field or method to which this annotation is applied can only be accessed when holding a particular lock, which may be a built-in (synchronization) lock, or may be an explicit java.util.concurrent.Lock.
A hardware abstraction layer.
Base class for HKEY_PERFORMANCE_DATA utilities.
Utility to read HKEY_PERFORMANCE_DATA information.
Utility to read session data from HKEY_USERS
A storage mechanism where data are recorded by various electronic, magnetic, optical, or mechanical changes to a surface layer of one or more rotating disks or or flash storage such as a removable or solid state drive.
A region on a hard disk or other secondary storage, so that an operating system can manage information in each region separately.
The presence of this annotation indicates that the author believes the class to be immutable and hence inherently thread-safe.
 
Provides key statistics for TCP and UDP network protocols, including aggregate counters and per-connection details.
Encapsulates information associated with an IP connection.
The TCP connection state as described in RFC 793.
Encapsulates statistics associated with a TCP connection.
Encapsulates statistics associated with a UDP connection.
The I/O Kit framework implements non-kernel access to I/O Kit objects (drivers and nubs) through the device-interface mechanism.
Holds the return value of SMC query.
Holds the return value of SMC KeyInfo query.
Holds the return value of SMC pLimit query.
Holds the return value of SMC version query.
Holds an SMC value
Abstracts IOKit registry operations so that iteration logic can be shared between JNA and FFM implementations.
A handle to an IORegistry entry, providing property access.
IOReport is a private Apple framework that provides access to hardware performance counters, including GPU residency and energy metrics on Apple Silicon.
Manages a single IOReport subscription for GPU Stats and Energy Model channels, providing per-instance sampling of GPU active ticks, utilization, and power draw.
Utility to query iostat
Kernel32.
 
Provides access to kstat information on Solaris
A copy of the Kstat chain, encapsulating a kstat_ctl_t object.
Constants, property enums, and WHERE clause builders for LibreHardwareMonitor WMI sensor data.
LHM Hardware properties.
Sensor properties returned by LHM WMI queries.
 
Linux Bluetooth device enumeration via BlueZ filesystem paths.
A CPU as defined in Linux /proc.
Native-free Linux central processor implementation.
Linux implementation of CgroupInfo supporting both cgroup v2 and v1.
The Linux File System contains OSFileStores which are a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage.
JNA-based Linux file system implementation.
Native-free Linux file system implementation.
Memory obtained by /proc/meminfo and sysinfo.totalram
Linux GpuStats session.
Graphics card info obtained by lshw, with dynamic metrics from sysfs DRM driver files.
Parsed graphics card attributes used to construct concrete subclass instances.
LinuxHardwareAbstractionLayer class.
JNA-based Linux hardware abstraction layer.
Native-free hardware abstraction layer for Linux.
Linux hard disk implementation.
Field ordering in udev stat output.
JNA-based Linux hard disk implementation.
Native-free Linux disk store implementation.
Utility class for querying installed applications on Linux.
Internet Protocol Stats implementation
Linux C Library.
Part of utmpx structure
Return type for getutxent()
 
32-bit timeval required for utmpx structure
Linux implementation of LogicalVolumeGroup.
LinuxNetworks class.
JNA-based Linux network interface implementation.
Native-free Linux network interface implementation.
Linux network parameters.
Native-free Linux network parameters implementation.
Linux is a family of open source Unix-like operating systems based on the Linux kernel, an operating system kernel first released on September 17, 1991, by Linus Torvalds.
JNA-based Linux operating system implementation.
Native-free Linux operating system implementation.
OSFileStore implementation
OSProcess implementation
JNA-based Linux OS process.
Native-free Linux OS process implementation.
OSThread implementation
A Power Source
Power supply uevent properties from sysfs.
JNA-based Linux power source implementation.
Linux USB device base class.
Linux USB device helper using JNA/udev.
Native-free Linux USB device enumeration from /sys/bus/usb/devices/.
Utility to calculate a load average equivalent metric on Windows.
JNA implementation of LoadAverage using JNA-based perfmon drivers.
Utility to query Logical Processor Information
A logical volume group implemented as part of logical volume management, combining the space on one or more storage devices such as disks or partitions (physical volumes) into a storage pool, and subsequently allocating that space to virtual partitions (logical volumes) as block devices accessible to the file system.
Utility to parse printer information from lpstat and lpoptions commands.
Utility to query ls
Utility to query lscfg
Utility to query lshal
Utility to read info from lshal
Utility to read info from lshw
Utility to query lspv
Utility to query lssrad
Baseboard data obtained from ioreg
macOS Bluetooth device enumeration via system_profiler SPBluetoothDataType.
Base class for macOS CentralProcessor implementations.
Hardware data obtained from ioreg.
Common constants and configuration for macOS file system implementations.
The Mac File System contains OSFileStores which are a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage.
Firmware data obtained from ioreg.
Memory obtained by host_statistics (vm_stat) and sysctl.
Graphics card info obtained by system_profiler SPDisplaysDataType.
Factory for creating GraphicsCard instances.
Functional interface for sysctl long queries.
MacHardwareAbstractionLayer class.
MacHardwareAbstractionLayer JNA implementation.
Base class for macOS HWDiskStore implementations.
Strings to convert to CFStringRef for pointer lookups.
Mac hard disk implementation.
Utility class for querying installed applications on macOS.
Internet Protocol Stats implementation
MacLogicalVolumeGroup class.
Base class for macOS NetworkIF implementations.
MacNetworks JNA implementation.
macOS, previously Mac OS X and later OS X) is a series of proprietary graphical operating systems developed and marketed by Apple Inc. since 2001.
macOS, previously Mac OS X and later OS X) is a series of proprietary graphical operating systems developed and marketed by Apple Inc. since 2001.
Common base class for macOS OSFileStore implementations.
OSFileStore implementation
OSProcess implementation
OSThread implementation
A Power Source
A Power Source
Sound card data obtained via AppleHDA kext
Mac USB device base class.
Mac USB device helper using JNA/IOKit.
Memory obtained by host_statistics (vm_stat) and sysctl.
A memoized function stores the output corresponding to some set of specific inputs.
Memory performance counter enums
For pages in/out
Utility to query Memory performance counter
Utility to query mount
Constants and property enum for WMI class MSAcpi_ThermalZoneTemperature.
Current temperature property.
 
Constants and property enums for WMI classes in the Storage namespace associated with Storage Pools.
Properties for a physical disk.
Properties to identify the storage pool.
Properties to link a storage pool with a physical disk.
Properties for a virtual disk.
 
NetBSD Central Processor implementation
NetBSD ComputerSystem implementation
The NetBSD File System contains OSFileStores which are a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage.
NetBSD Firmware implementation
NetBsdHardwareAbstractionLayer class.
NetBSD hard disk implementation.
Internet Protocol Stats implementation
C library.
Return type for BSD sysctl kern.boottime
NetBSD-specific NetworkIF implementation.
NetBsdNetworkParams class.
NetBsd is a free and open-source Unix-like operating system descended from the Berkeley Software Distribution (BSD), which was based on Research Unix.
OSFileStore implementation
OSProcess implementation
OSThread implementation
A Power Source
Provides access to sysctl calls on NetBSD via command-line execution.
NetBsd Usb Device
Utility to read process data from HKEY_PERFORMANCE_DATA information with backup from Performance Counters or WMI
Utility to query NetStat.
Utility to query TCP connections
Class to encapsulate IF data for method return
A network interface in the machine, including statistics.
The current operational state of a network interface.
Provides network parameters of the running operating system, including the hostname, domain name, DNS server addresses, and default gateways for IPv4 and IPv6.
A no-op GpuStats implementation returned by platforms that do not support a native stats session.
The presence of this annotation indicates that the author believes the class is not thread-safe.
 
 
 
 
 
 
 
 
JNA bindings for the NVIDIA Management Library (NVML).
 
 
 
 
Optional runtime binding to the NVIDIA Management Library (NVML).
Constants, property enum, and WHERE clause builder for Open Hardware Monitor WMI Hardware data.
HW Identifier Property.
 
Constants, property enum, and WHERE clause builder for Open Hardware Monitor WMI Sensor data.
Sensor value property.
 
OpenBSD Central Processor implementation
OpenBSD ComputerSystem implementation
 
The OpenBSD File System contains OSFileStores which are a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage.
OpenBSD Firmware implementation
 
Graphics Card info obtained from pcidump
OpenBsdHardwareAbstractionLayer class.
OpenBSD hard disk implementation.
Internet Protocol Stats implementation
C library.
OpenBSD Cache stats for memory
Return type for BSD sysctl kern.boottime
OpenBsdNetworkParams class.
OpenBsd is a free and open-source Unix-like operating system descended from the Berkeley Software Distribution (BSD), which was based on Research Unix.
OSFileStore implementation.
 
OSProcess implementation
Columns requested from ps -aHwwxo when enumerating threads.
OSThread implementation
A Power Source
Sensors
OpenBSD soundcard.
Provides access to sysctl calls on OpenBSD
OpenBsd Usb Device
Memory info on OpenBSD
An operating system (OS) is the software on a computer that manages the way different programs use its hardware, and regulates the ways that a user controls the computer.
A class representing the Operating System version details.
This class encapsulates information about a window on the operating system's GUI desktop.
A FileStore represents a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage.
Represents a Process on the operating system, which may contain multiple threads.
Process and Thread Execution States
Operating system services are responsible for the management of platform resources, including the processor, memory, files, and input and output.
Service Execution States
This class encapsulates information about users who are currently logged in to an operating system.
Represents a Thread/Task on the operating system.
Constants which may be used to filter Thread lists
Paging File performance counter enums
For swap file usage
Utility to query PagingFile performance counter
Convenience class for returning multiple objects from methods.
String parsing utility.
Contract for Counter Property Enums.
Contract for Wildcard Counter Property Enums.
Encapsulates the three string components of a PDH performance counter path, plus whether it refers to the base (SecondValue) of a multi-value counter.
Enables queries of Performance Counters using wild cards to filter instances
Common interface for querying Windows performance counters, abstracting JNA and FFM implementations.
JNA-based PerfCounterQueryExecutor implementation.
Utility to handle Performance Counter Queries
Enables queries of Performance Counters using wild cards to filter instances
Helper class to centralize the boilerplate portions of PDH counter setup and allow applications to easily add, query, and remove counters.
Constants used in Perfmon driver classes
Tests whether performance counters are disabled
Utility to query partition config
Utility to query performance stats for cpu
Utility to query performance stats for disk_stats
Utility to query performance stats for memory
Utility to query performance stats for network interfaces
Utility to query performance stats for processes
Utility to query performance stats for network interfaces
Physical Disk performance counter enums
Physical Disk performance counters.
Utility to query PhysicalDisk performance counter
The PhysicalMemory class represents a physical memory device located on a computer system and available to the operating system.
An enumeration of supported operating systems.
A Power Source represents a battery or UPS device with some capacity and charge/discharge state.
Units of Battery Capacity
Power profile stats.
 
 
 
 
 
 
Contains information about a processor.
Contains information about the current state of the system battery.
Represents a printer device available to the operating system, including its name, driver, status, and connection type (local or network).
Printer status enumeration.
Utility class for privileged command execution and file reading.
Process performance counter enums
Handle performance counters
Processor performance counters
Process performance counters
Utility to query Process performance counter
Processor performance counter enums
System interrupts counters
Processor Frequency counters.
Processor Performance counters from the WMI Formatted Data table.
Processor performance counters
Processor performance counters including utility counters
System performance counters
Utility to query Processor performance counter
Encapsulates process performance data from the registry performance counter block.
Common logic for building process performance data maps from registry or performance counter results.
Utility to read process data from HKEY_PERFORMANCE_DATA information with backup from Performance Counters or WMI
Utility to read process statistics from /proc/[pid]/stat
Enum corresponding to the fields in the output of /proc/[pid]/stat
Enum corresponding to the fields in the output of /proc/[pid]/statm
Utility to read process data from HKEY_PERFORMANCE_DATA information with backup from Performance Counters or WMI
Provides constants for paths in the /proc filesystem on Linux.
Reads from procstat into a map
Provides process information on DragonFlyBSD using /proc and fstat
Utility class for parsing /proc filesystem statistics.
Utility to query iostat
Utility to query /proc/psinfo
Utility to query /proc/psinfo
Indicates that the annotated type is part of the OSHI public API.
Convenience class for returning multiple objects from methods.
Convenience class for returning multiple objects from methods.
Utility for reading values from the Windows Registry.
Sensors include hardware sensors to monitor temperature, fan speed, and other information.
Utility to read process data from HKEY_PERFORMANCE_DATA information with backup from Performance Counters or WMI
Provides access to SMC calls on macOS
Hardware data obtained from smbios.
 
The Solaris File System contains OSFileStores which are a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage.
Firmware data.
Memory obtained by kstat.
Graphics Card info obtained from prtconf
SolarisHardwareAbstractionLayer class.
Solaris hard disk implementation.
Internet Protocol Stats implementation
C library.
Part of utmpx structure
Nested Structure for psinfo file
Structure for usage file
Structure for psinfo file
Connection info
32/64-bit timestruc required for psinfo and lwpsinfo structures
32/64-bit timeval required for utmpx structure
SolarisNetworks class.
Solaris is a non-free Unix operating system originally developed by Sun Microsystems.
OSFileStore implementation
OSProcess implementation
OSThread implementation
A Power Source
Sensors from prtpicl
Solaris Sound Card.
Solaris Usb Device
Memory obtained by kstat and swap
Represents a sound card (audio adapter) installed in the system, providing the card name, driver version, and codec information.
Wrapper classes for JNA clases which extend Structure intended for use in try-with-resources blocks.
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
This annotation exists to permit suppression in the Forbidden APIs check and also indicate to consumers of these classes that they may need to handle these differently in their production code.
Abstracts sysctl operations so that Mac base classes can query sysctl values without depending on JNA or FFM directly.
Provides access to sysctl calls on macOS
Utility to read info from sysfs
Provides constants for paths in the /sys filesystem on Linux.
Utility class parsing output from the BSD systat -ab sensors command, shared by OpenBSD and NetBSD which produce the same output format.
Immutable holder for battery sensor readings parsed from systat -ab sensors.
System class.
Mac connection info
 
Allow applications to access a device’s network configuration settings.
 
JNA bindings for libsystemd.
Native-free SystemInfoProvider for Linux.
System information.
Factory that uses ServiceLoader to discover and select the best available SystemInfoProvider.
Static helper methods for printing OSHI system information, shared across test modules.
Service Provider Interface for OSHI's SystemInfo entry points.
System performance counter enums
Context switch property
Processor Queue Length property
Utility to query System performance counter
Utility to query geom part list
Utility to query threads for a process
Class to encapsulate mach thread info
Thread performance counter enums
Thread performance counters
Utility to query Thread performance counter
Encapsulates thread performance data from the registry performance counter block.
Common logic for building thread performance data maps from registry or performance counter results.
Utility to read thread data from HKEY_PERFORMANCE_DATA information with backup from Performance Counters or WMI
The presence of this annotation indicates that the author believes the class to be thread-safe.
Convenience class for returning multiple objects from methods.
Baseboard data obtained by a calling class
A Display
Utility to query up time.
Utility to read system uptime from /proc/uptime
A USB device is a device connected via a USB port, possibly internally/permanently.
Utility class to temporarily cache the userID and group maps in *nix, for parsing process ownership.
General utility methods
The VirtualMemory class tracks information about the use of a computer's virtual memory (swap file) which temporarily moves rarely accessed information to a disk or other storage device.
Utility to query logged in users.
Utility to query logged in users.
Utility to query logged in users.
Utility to query logged in users.
Utility to query logged in users using the who command with Linux date format parsing, falling back to Unix format.
Utility to query logged in users using the who command with Unix date format parsing.
Utility to query logged in users.
Constants and property enum for WMI class Win32_BaseBoard.
Baseboard description properties.
 
Constants and property enums for WMI class Win32_BIOS.
BIOS description properties.
Serial number property.
 
Constants and property enum for WMI class Win32_ComputerSystem.
Computer System properties.
 
Constants and property enum for WMI class Win32_ComputerSystemProduct.
Computer System ID number.
 
Constants and property enum for WMI class Win32_DiskDrive.
Disk drive properties.
 
Constants and property enum for WMI class Win32_DiskDriveToDiskPartition.
Links disk drives to partitions.
 
Constants and property enum for WMI class Win32_DiskPartition.
Disk partition properties.
 
Constants and property enum for WMI class Win32_Fan.
Fan speed property.
 
Constants and property enum for WMI class Win32_LogicalDisk.
Logical disk properties.
 
Constants and property enum for WMI class Win32_LogicalDiskToPartition.
Links disk drives to partitions.
 
Constants and property enum for WMI class Win32_OperatingSystem.
Operating System properties.
 
Constants and property enums for WMI class Win32_PhysicalMemory.
Physical Memory properties for Win10 and later.
Physical Memory properties for Win8 and earlier.
 
Constants and property enum for WMI class Win32_Printer.
Printer properties from WMI.
 
Constants, property enums, and WHERE clause builder for WMI class Win32_Process.
Process command lines.
Process properties accessible from WTSEnumerateProcesses in Vista+.
Utility to query WMI class Win32_Process using cache (JNA).
 
Constants and property enums for WMI class Win32_Processor.
Processor bitness property.
Processor ID property.
Processor voltage properties.
 
Constants and property enum for WMI class Win32_VideoController.
Video Controller properties.
 
Utility to query desktop windows
Baseboard data obtained from WMI.
Windows Bluetooth device enumeration via the Bluetooth API (bthprops.cpl).
Common non-native logic for Windows Central Processor implementations.
Hardware data obtained from WMI.
The Windows File System contains OSFileStores which are a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage.
Firmware data obtained from WMI.
Common Windows global memory logic shared between JNA and FFM implementations.
Common Windows GpuStats implementation.
WindowsHardwareAbstractionLayer class.
Common Windows hard disk implementation shared between JNA and FFM.
Maps to store read/write bytes per drive index
Maps for the partition structure
Windows hard disk implementation using JNA.
 
Internet Protocol Stats implementation
WindowsNetworks class.
Common base class for Windows operating system implementations.
Microsoft Windows, commonly referred to as Windows, is a group of several proprietary graphical operating system families, all of which are developed and marketed by Microsoft.
Common base class for Windows OSFileStore implementations.
JNA-based Windows OSFileStore implementation.
Common base class for Windows OS process implementations, containing shared fields, getters, and non-native methods.
JNA-based Windows OS process implementation.
Common base class for Windows OS thread implementations.
JNA-based Windows OS thread implementation.
A Power Source
JNA-based Windows power source implementation.
Common Windows printer logic shared between JNA and FFM implementations.
Windows Usb Device
WMI type constants used for interpreting WmiResult values.
Encapsulates a WMI query with a namespace, class name, and property enum.
Common interface for executing WMI queries, abstracting JNA and FFM implementations.
Adapts the JNA WmiQueryHandler to the common WmiQueryExecutor interface.
Utility to handle WMI Queries.
Common interface for WMI query results, abstracting JNA and FFM implementations.
Helper class for extracting typed values from WmiResult objects.
Helper class for WMI
Data holder for Windows Terminal Services (WTS) process information.
Utility to query xrandr
Utility to query X11 windows