Uses of Annotation Interface
oshi.annotation.concurrent.Immutable

Packages that use Immutable
Package
Description
Provides functions to query Mac info
Provides common Windows performance monitor constants and definitions shared between JNA and FFM implementations.
Provides common Windows registry performance data POJOs shared between JNA and FFM implementations.
Provides functions to query Mac network info
[oshi-common API] Provides cross-platform implementation to retrieve hardware information such as CPU, Memory, Display, Disks, Network Interfaces, Power Sources, Sensors, and USB Devices
Provides abstract classes for common code
Provides common Linux hardware implementations shared by JNA and FFM modules.
Provides information about hardware such as Memory, Power Sources, and Processor on Mac systems
Provides common Unix hardware implementations shared by JNA and FFM modules.
Provides common implementations for Windows hardware information shared between JNA and FFM implementations.
Provides mappings for Unix-based operating systems
Provides information about hardware such as Memory, Power Sources, and Processor on AIX systems
Provides information about hardware such as Memory, Power Sources, and Processor on FreeBSD systems
Provides information about hardware such as Memory, Power Sources, and Processor on OpenBSD systems
Provides information about hardware such as Memory, Power Sources, and Processor on Solaris systems
Provides information about hardware such as Memory, Power Sources, and Processor on Windows systems
[oshi-common API] Provides cross-platform common API to retrieve OS, FileSystem, and Process information