Uses of Class
oshi.annotation.concurrent.NotThreadSafe
| Package | Description |
|---|---|
| oshi.hardware |
[oshi-core API] Provides cross-platform implementation to retrieve hardware
information such as CPU, Memory, Display, Disks, Network Interfaces, Power
Sources, Sensors, and USB Devices
|
| oshi.software.os |
[oshi-core API] Provides cross-platform implementation to retrieve OS,
FileSystem, and Process information
|
| oshi.util |
Provides utilities for parsing, formatting, and other access
|
| oshi.util.platform.windows |
Provides utilities for Windows.
|
-
Uses of NotThreadSafe in oshi.hardware
Classes in oshi.hardware with annotations of type NotThreadSafe Modifier and Type Class Description classHWDiskStoreA storage mechanism where data are recorded by various electronic, magnetic, optical, or mechanical changes to a surface layer of one or more rotating disks or or flash storage such as a removable or solid state drive.classHWPartitionA region on a hard disk or other secondary storage, so that an operating system can manage information in each region separately.classNetworkIFA network interface in the machine, including statistics -
Uses of NotThreadSafe in oshi.software.os
Classes in oshi.software.os with annotations of type NotThreadSafe Modifier and Type Interface Description interfaceOperatingSystemVersionDeprecated.classOSFileStoreA File Store is a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage.classOSProcessA process is an instance of a computer program that is being executed. -
Uses of NotThreadSafe in oshi.util
Classes in oshi.util with annotations of type NotThreadSafe Modifier and Type Class Description classGlobalConfigThe global configuration utility. -
Uses of NotThreadSafe in oshi.util.platform.windows
Classes in oshi.util.platform.windows with annotations of type NotThreadSafe Modifier and Type Class Description classPerfCounterQuery<T extends java.lang.Enum<T>>Encapsulates information for a Performance Counter query.classPerfCounterWildcardQuery<T extends java.lang.Enum<T>>Encapsulates information for a Performance Counter query.