Uses of Package
oshi.annotation.concurrent
Packages that use oshi.annotation.concurrent
Package
Description
Provides functions to query Mac info
Shared GPU-related driver classes for Windows, containing POJOs and utility methods with no native dependencies.
Provides common Windows performance monitor constants and definitions shared between JNA and FFM implementations.
Provides common Windows registry performance data POJOs shared between JNA and FFM implementations.
Provides common WMI driver constants and property enums shared between JNA and FFM implementations.
Provides functions to query Linux information
Provides functions to query statistics in the Linux /proc pseudo-filesystem
Provides functions to query Mac info
Provides functions to query Mac disk info
Provides functions to query Mac network info
Provides functions to query information on AIX
Provides functions to query information on AIX using the libperfstat api
Provides functions to query FreeBSD information
Provides functions to query FreeBSD disk information
Provides functions to query OpenBSD information
Provides functions to query Solaris information
Provides functions to query Solaris disk information
Provides functions to query Solaris kstat information
Provides functions to query information in windows
Provides functions to query counters in windows performance monitor (or WMI counter tables)
Provides functions to query data in Windows Registry
Provides functions to query properties in WMI classes
[oshi-common API] Provides cross-platform implementation to retrieve hardware information such as CPU, Memory,
Display, Disks, Network Interfaces, Power Sources, Sensors, and USB Devices
Provides abstract classes for common code
Provides common Linux hardware implementations shared by JNA and FFM modules.
Native-free Linux hardware implementations using only procfs, sysfs, and command-line utilities.
Provides information about hardware such as Memory, Power Sources, and Processor on Mac systems
Provides common Unix hardware implementations shared by JNA and FFM modules.
Provides common implementations for Windows hardware information shared between JNA and FFM implementations.
Provides information about hardware such as Memory, Power Sources, and Processor on Linux systems
Provides information about hardware such as Memory, Power Sources, and Processor on Mac systems
Provides mappings for Unix-based operating systems
Provides information about hardware such as Memory, Power Sources, and Processor on AIX systems
Provides information about hardware such as Memory, Power Sources, and Processor on FreeBSD systems
Provides information about hardware such as Memory, Power Sources, and Processor on OpenBSD systems
Provides information about hardware such as Memory, Power Sources, and Processor on Solaris systems
Provides information about hardware such as Memory, Power Sources, and Processor on Windows systems
Provides extensions of JNA libraries for Linux.
JNA-dependent utility methods extracted from common utilities.
Provides abstract classes for common code
Provides common (native-free) Linux operating system implementations shared by JNA and FFM modules.
Native-free Linux operating system implementations using only procfs, sysfs, and command-line utilities.
Provides information about Software and OS on macOS
Provides common implementations for Windows operating system information shared between JNA and FFM implementations.
[oshi-common API] Provides cross-platform common API to retrieve OS, FileSystem, and Process information
Provides information about Software and OS on Linux
Provides information about Software and OS on macOS
Provides information about Software and OS on AIX
Provides information about Software and OS on FreeBSD
Provides information about Software and OS on OpenBSD
Provides information about Software and OS on Solaris
Provides information about Software and OS on Windows
Provides utilities for parsing, formatting, and other access
Provides non-native Linux driver utilities for querying system information.
Provides non-native Linux driver utilities for querying the
/proc filesystem.Provides driver utilities common to unix systems that do not require native access
Utility classes for optional vendor GPU library integration (NVML, ADL).
Provides constants for Linux filesystem paths (
/proc, /dev, /sys).Provides utilities for macOS.
Provides utilities for FreeBSD
Provides utilities for OpenBSD
Provides utilities for Solaris
Provides utilities for Windows.
Provides classes encapsulating multiple objects, intended as return types from methods
-
Classes in oshi.annotation.concurrent used by oshi.driver.common.macClassDescriptionThe presence of this annotation indicates that the author believes the class to be immutable and hence inherently thread-safe.The presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.driver.common.windows.gpuClassDescriptionThe presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.driver.common.windows.perfmonClassDescriptionThe presence of this annotation indicates that the author believes the class to be immutable and hence inherently thread-safe.The presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.driver.common.windows.registryClassDescriptionThe presence of this annotation indicates that the author believes the class to be immutable and hence inherently thread-safe.The presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.driver.common.windows.wmiClassDescriptionThe presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.driver.linuxClassDescriptionThe presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.driver.linux.procClassDescriptionThe presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.driver.macClassDescriptionThe presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.driver.mac.diskClassDescriptionThe presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.driver.mac.netClassDescriptionThe presence of this annotation indicates that the author believes the class to be immutable and hence inherently thread-safe.The presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.driver.unix.aixClassDescriptionThe presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.driver.unix.aix.perfstatClassDescriptionThe presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.driver.unix.freebsdClassDescriptionThe presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.driver.unix.freebsd.diskClassDescriptionThe presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.driver.unix.openbsd.diskClassDescriptionThe presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.driver.unix.solarisClassDescriptionThe presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.driver.unix.solaris.diskClassDescriptionThe presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.driver.unix.solaris.kstatClassDescriptionThe presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.driver.windowsClassDescriptionThe presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.driver.windows.perfmonClassDescriptionThe presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.driver.windows.registryClassDescriptionThe presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.driver.windows.wmiClassDescriptionThe presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.hardwareClassDescriptionThe presence of this annotation indicates that the author believes the class to be immutable and hence inherently thread-safe.The presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.hardware.commonClassDescriptionThe presence of this annotation indicates that the author believes the class to be immutable and hence inherently thread-safe.The presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.hardware.common.platform.linuxClassDescriptionThe presence of this annotation indicates that the author believes the class to be immutable and hence inherently thread-safe.The presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.hardware.common.platform.linux.nativefreeClassDescriptionThe presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.hardware.common.platform.macClassDescriptionThe presence of this annotation indicates that the author believes the class to be immutable and hence inherently thread-safe.The presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.hardware.common.platform.unixClassDescriptionThe presence of this annotation indicates that the author believes the class to be immutable and hence inherently thread-safe.The presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.hardware.common.platform.windowsClassDescriptionThe presence of this annotation indicates that the author believes the class to be immutable and hence inherently thread-safe.The presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.hardware.platform.linuxClassDescriptionThe presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.hardware.platform.macClassDescriptionThe presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.hardware.platform.unixClassDescriptionThe presence of this annotation indicates that the author believes the class to be immutable and hence inherently thread-safe.The presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.hardware.platform.unix.aixClassDescriptionThe presence of this annotation indicates that the author believes the class to be immutable and hence inherently thread-safe.The presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.hardware.platform.unix.freebsdClassDescriptionThe presence of this annotation indicates that the author believes the class to be immutable and hence inherently thread-safe.The presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.hardware.platform.unix.openbsdClassDescriptionThe presence of this annotation indicates that the author believes the class to be immutable and hence inherently thread-safe.The presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.hardware.platform.unix.solarisClassDescriptionThe presence of this annotation indicates that the author believes the class to be immutable and hence inherently thread-safe.The presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.hardware.platform.windowsClassDescriptionThe presence of this annotation indicates that the author believes the class to be immutable and hence inherently thread-safe.The presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.jna.platform.linuxClassDescriptionThe presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.jna.utilClassDescriptionThe presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.software.commonClassDescriptionThe presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.software.common.os.linuxClassDescriptionThe presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.software.common.os.linux.nativefreeClassDescriptionThe presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.software.common.os.macClassDescriptionThe presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.software.common.os.windowsClassDescriptionThe presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.software.osClassDescriptionThe presence of this annotation indicates that the author believes the class to be immutable and hence inherently thread-safe.The presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.software.os.linuxClassDescriptionThe presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.software.os.macClassDescriptionThe presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.software.os.unix.aixClassDescriptionThe presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.software.os.unix.freebsdClassDescriptionThe presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.software.os.unix.openbsdClassDescriptionThe presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.software.os.unix.solarisClassDescriptionThe presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.software.os.windowsClassDescriptionThe presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.utilClassDescriptionThe presence of this annotation indicates that the author believes the class is not thread-safe.The presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.util.driver.linuxClassDescriptionThe presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.util.driver.linux.procClassDescriptionThe presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.util.driver.unixClassDescriptionThe presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.util.gpuClassDescriptionThe presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.util.linuxClassDescriptionThe presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.util.platform.macClassDescriptionThe presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.util.platform.unix.freebsdClassDescriptionThe presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.util.platform.unix.openbsdClassDescriptionThe presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.util.platform.unix.solarisClassDescriptionThe field or method to which this annotation is applied can only be accessed when holding a particular lock, which may be a built-in (synchronization) lock, or may be an explicit
java.util.concurrent.Lock.The presence of this annotation indicates that the author believes the class to be thread-safe. -
Classes in oshi.annotation.concurrent used by oshi.util.platform.windowsClassDescriptionThe presence of this annotation indicates that the author believes the class is not thread-safe.The presence of this annotation indicates that the author believes the class to be thread-safe.
-
Classes in oshi.annotation.concurrent used by oshi.util.tuplesClassDescriptionThe presence of this annotation indicates that the author believes the class to be thread-safe.