Uses of Class
oshi.driver.common.mac.IFdata
Packages that use IFdata
Package
Description
Provides functions to query Mac network info
Provides information about hardware such as Memory, Power Sources, and Processor on Mac systems
-
Uses of IFdata in oshi.driver.mac.net
Methods in oshi.driver.mac.net that return types with arguments of type IFdataModifier and TypeMethodDescriptionNetStat.queryIFdata(int index) Map data for network interfaces. -
Uses of IFdata in oshi.hardware.platform.mac
Constructor parameters in oshi.hardware.platform.mac with type arguments of type IFdata