Class ProcessPerformanceData
java.lang.Object
oshi.driver.common.windows.registry.ProcessPerformanceData
Common logic for building process performance data maps from registry or performance counter results. Callers
(JNA/FFM variants) supply the platform-specific pre-fetched registry or performance-counter data.
-
Field Summary
Fields -
Method Summary
Modifier and TypeMethodDescriptionstatic Map<Integer, ProcessPerfCounterBlock> buildProcessMapFromPerfCounters(Collection<Integer> pids, Pair<List<String>, Map<ProcessInformation.ProcessPerformanceProperty, List<Long>>> instanceValues) Builds a process map from performance counter query results.static Map<Integer, ProcessPerfCounterBlock> buildProcessMapFromRegistry(Collection<Integer> pids, Triplet<List<Map<ProcessInformation.ProcessPerformanceProperty, Object>>, Long, Long> processData) Builds a process map from registry performance data that has already been read.
-
Field Details
-
PROCESS
-
-
Method Details
-
buildProcessMapFromRegistry
public static Map<Integer, ProcessPerfCounterBlock> buildProcessMapFromRegistry(Collection<Integer> pids, Triplet<List<Map<ProcessInformation.ProcessPerformanceProperty, Object>>, Long, Long> processData) Builds a process map from registry performance data that has already been read.- Parameters:
pids- An optional collection of process IDs to filter the list to. May be null for no filtering.processData- The raw registry data triplet (instance maps, perfTime100nSec, now in ms)- Returns:
- A map with Process ID as the key and a
ProcessPerfCounterBlockobject populated with performance counter information, or null if processData is null.
-
buildProcessMapFromPerfCounters
public static Map<Integer, ProcessPerfCounterBlock> buildProcessMapFromPerfCounters(Collection<Integer> pids, Pair<List<String>, Map<ProcessInformation.ProcessPerformanceProperty, List<Long>>> instanceValues) Builds a process map from performance counter query results.- Parameters:
pids- An optional collection of process IDs to filter the list to. May be null for no filtering.instanceValues- The query results as a pair of (instances, valueMap)- Returns:
- A map with Process ID as the key and a
ProcessPerfCounterBlockobject populated with performance counter information, or null if instanceValues is null.
-