Uses of Class
oshi.driver.common.windows.registry.ProcessPerfCounterBlock
Packages that use ProcessPerfCounterBlock
Package
Description
Provides common Windows registry performance data POJOs shared between JNA and FFM implementations.
Provides functions to query data in Windows Registry
Provides common implementations for Windows operating system information shared between JNA and FFM implementations.
Provides information about Software and OS on Windows
-
Uses of ProcessPerfCounterBlock in oshi.driver.common.windows.registry
Methods in oshi.driver.common.windows.registry that return types with arguments of type ProcessPerfCounterBlockModifier and TypeMethodDescriptionstatic Map<Integer, ProcessPerfCounterBlock> ProcessPerformanceData.buildProcessMapFromPerfCounters(Collection<Integer> pids, Pair<List<String>, Map<ProcessInformation.ProcessPerformanceProperty, List<Long>>> instanceValues) Builds a process map from performance counter query results.static Map<Integer, ProcessPerfCounterBlock> ProcessPerformanceData.buildProcessMapFromRegistry(Collection<Integer> pids, Triplet<List<Map<ProcessInformation.ProcessPerformanceProperty, Object>>, Long, Long> processData) Builds a process map from registry performance data that has already been read. -
Uses of ProcessPerfCounterBlock in oshi.driver.windows.registry
Methods in oshi.driver.windows.registry that return types with arguments of type ProcessPerfCounterBlockModifier and TypeMethodDescriptionstatic Map<Integer, ProcessPerfCounterBlock> ProcessPerformanceDataJNA.buildProcessMapFromPerfCounters(Collection<Integer> pids) Query PerfMon for process performance countersstatic Map<Integer, ProcessPerfCounterBlock> ProcessPerformanceDataJNA.buildProcessMapFromRegistry(Collection<Integer> pids) Query the registry for process performance counters -
Uses of ProcessPerfCounterBlock in oshi.software.common.os.windows
Methods in oshi.software.common.os.windows with parameters of type ProcessPerfCounterBlockModifier and TypeMethodDescriptionprotected booleanWindowsOSProcess.updateAttributes(ProcessPerfCounterBlock pcb, WtsInfo wts) Updates process attributes from performance counter and WTS data, then performs native-specific updates.Constructor parameters in oshi.software.common.os.windows with type arguments of type ProcessPerfCounterBlockModifierConstructorDescriptionprotectedWindowsOSProcess(int pid, OperatingSystem os, Map<Integer, ProcessPerfCounterBlock> processMap, Map<Integer, WtsInfo> processWtsMap, Map<Integer, ThreadPerfCounterBlock> threadMap) Constructor. -
Uses of ProcessPerfCounterBlock in oshi.software.os.windows
Methods in oshi.software.os.windows with parameters of type ProcessPerfCounterBlockModifier and TypeMethodDescriptionprotected booleanWindowsOSProcessJNA.updateAttributes(ProcessPerfCounterBlock pcb, WtsInfo wts) Constructor parameters in oshi.software.os.windows with type arguments of type ProcessPerfCounterBlockModifierConstructorDescriptionWindowsOSProcessJNA(int pid, WindowsOperatingSystemJNA os, Map<Integer, ProcessPerfCounterBlock> processMap, Map<Integer, WtsInfo> processWtsMap, Map<Integer, ThreadPerfCounterBlock> threadMap)