Uses of Enum Class
oshi.driver.common.windows.wmi.Win32ComputerSystem.ComputerSystemProperty
Packages that use Win32ComputerSystem.ComputerSystemProperty
Package
Description
Provides common WMI driver constants and property enums shared between JNA and FFM implementations.
Provides functions to query properties in WMI classes
-
Uses of Win32ComputerSystem.ComputerSystemProperty in oshi.driver.common.windows.wmi
Subclasses with type arguments of type Win32ComputerSystem.ComputerSystemProperty in oshi.driver.common.windows.wmiModifier and TypeClassDescriptionstatic enumComputer System properties.Methods in oshi.driver.common.windows.wmi that return Win32ComputerSystem.ComputerSystemPropertyModifier and TypeMethodDescriptionReturns the enum constant of this class with the specified name.Win32ComputerSystem.ComputerSystemProperty.values()Returns an array containing the constants of this enum class, in the order they are declared.Methods in oshi.driver.common.windows.wmi that return types with arguments of type Win32ComputerSystem.ComputerSystemPropertyModifier and TypeMethodDescriptionWin32ComputerSystem.queryComputerSystem(WmiQueryExecutor h) Queries computer system information. -
Uses of Win32ComputerSystem.ComputerSystemProperty in oshi.driver.windows.wmi
Methods in oshi.driver.windows.wmi that return types with arguments of type Win32ComputerSystem.ComputerSystemProperty