Uses of Enum Class
oshi.driver.common.windows.wmi.Win32Process.ProcessXPProperty
Packages that use Win32Process.ProcessXPProperty
Package
Description
Provides common WMI driver constants and property enums shared between JNA and FFM implementations.
Provides functions to query properties in WMI classes
-
Uses of Win32Process.ProcessXPProperty in oshi.driver.common.windows.wmi
Subclasses with type arguments of type Win32Process.ProcessXPProperty in oshi.driver.common.windows.wmiModifier and TypeClassDescriptionstatic enumProcess properties accessible from WTSEnumerateProcesses in Vista+.Methods in oshi.driver.common.windows.wmi that return Win32Process.ProcessXPPropertyModifier and TypeMethodDescriptionReturns the enum constant of this class with the specified name.static Win32Process.ProcessXPProperty[]Win32Process.ProcessXPProperty.values()Returns an array containing the constants of this enum class, in the order they are declared.Methods in oshi.driver.common.windows.wmi that return types with arguments of type Win32Process.ProcessXPPropertyModifier and TypeMethodDescriptionWin32Process.queryProcesses(WmiQueryExecutor h, Collection<Integer> pids) Returns process info. -
Uses of Win32Process.ProcessXPProperty in oshi.driver.windows.wmi
Methods in oshi.driver.windows.wmi that return types with arguments of type Win32Process.ProcessXPProperty