Uses of Enum Class
oshi.driver.common.windows.wmi.Win32VideoController.VideoControllerProperty
Packages that use Win32VideoController.VideoControllerProperty
Package
Description
Provides common WMI driver constants and property enums shared between JNA and FFM implementations.
Provides functions to query properties in WMI classes
-
Uses of Win32VideoController.VideoControllerProperty in oshi.driver.common.windows.wmi
Subclasses with type arguments of type Win32VideoController.VideoControllerProperty in oshi.driver.common.windows.wmiModifier and TypeClassDescriptionstatic enumVideo Controller properties.Methods in oshi.driver.common.windows.wmi that return Win32VideoController.VideoControllerPropertyModifier and TypeMethodDescriptionReturns the enum constant of this class with the specified name.Win32VideoController.VideoControllerProperty.values()Returns an array containing the constants of this enum class, in the order they are declared.Methods in oshi.driver.common.windows.wmi that return types with arguments of type Win32VideoController.VideoControllerPropertyModifier and TypeMethodDescriptionWin32VideoController.queryVideoController(WmiQueryExecutor h) Queries video controller information. -
Uses of Win32VideoController.VideoControllerProperty in oshi.driver.windows.wmi
Methods in oshi.driver.windows.wmi that return types with arguments of type Win32VideoController.VideoControllerProperty