Package oshi.driver.linux.proc
Provides functions to query statistics in the Linux /proc pseudo-filesystem
-
Class Summary Class Description CpuStat DiskStats ProcessStat UpTime -
Enum Summary Enum Description DiskStats.IoStat Enum corresponding to the fields in the output of/proc/diskstatsProcessStat.PidStat Enum corresponding to the fields in the output of/proc/[pid]/stat