Class NetStat
java.lang.Object
oshi.driver.mac.net.NetStat
Utility to query NetStat.
-
Method Summary
-
Method Details
-
queryIFdata
Map data for network interfaces.- Parameters:
index- If positive, limit the map to only return data for this interface index. If negative, returns data for all indices.- Returns:
- a map of
IFdataobject indexed by the interface index, encapsulating the stats
-