Package oshi.driver.perfmon
Class SystemInformation
java.lang.Object
oshi.driver.perfmon.SystemInformation
public class SystemInformation
extends java.lang.Object
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classSystemInformation.ContextSwitchProperty -
Constructor Summary
Constructors Constructor Description SystemInformation() -
Method Summary
Modifier and Type Method Description java.util.Map<SystemInformation.ContextSwitchProperty,java.lang.Long>queryContextSwitchCounters()Returns system context switch counters.
-
Constructor Details
-
SystemInformation
public SystemInformation()
-
-
Method Details
-
queryContextSwitchCounters
public java.util.Map<SystemInformation.ContextSwitchProperty,java.lang.Long> queryContextSwitchCounters()Returns system context switch counters.- Returns:
- Context switches counter for the total of all processors.
-