Class OhmSensor

java.lang.Object
oshi.driver.wmi.OhmSensor

public class OhmSensor
extends java.lang.Object
  • Nested Class Summary

    Nested Classes 
    Modifier and Type Class Description
    static class  OhmSensor.ValueProperty
    Sensor value property
  • Constructor Summary

    Constructors 
    Constructor Description
    OhmSensor()  
  • Method Summary

    Modifier and Type Method Description
    com.sun.jna.platform.win32.COM.WbemcliUtil.WmiResult<OhmSensor.ValueProperty> querySensorValue​(java.lang.String identifier, java.lang.String sensorType)
    Queries the sensor value of an hardware identifier and sensor type.

    Methods inherited from class java.lang.Object

    clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
  • Constructor Details

  • Method Details

    • querySensorValue

      public com.sun.jna.platform.win32.COM.WbemcliUtil.WmiResult<OhmSensor.ValueProperty> querySensorValue​(java.lang.String identifier, java.lang.String sensorType)
      Queries the sensor value of an hardware identifier and sensor type.
      Parameters:
      identifier - The identifier whose value to query.
      sensorType - The type of sensor to query.
      Returns:
      The sensor value.