Interface Baseboard

All Known Implementing Classes:
AbstractBaseboard, MacBaseboard, UnixBaseboard, WindowsBaseboard

@PublicApi @Immutable public interface Baseboard
The Baseboard represents the system board, also called motherboard, logic board, etc.

Obtained from ComputerSystem.getBaseboard().

Platform notes: On Linux, reading the serial number requires root access because /sys/class/dmi/id/board_serial is root-owned and read-only (mode 0400) by default.

See Also:
  • Method Details

    • getManufacturer

      String getManufacturer()
      Get the baseboard manufacturer.
      Returns:
      The manufacturer.
    • getModel

      String getModel()
      Get the baseboard model.
      Returns:
      The model.
    • getVersion

      String getVersion()
      Get the baseboard version.
      Returns:
      The version.
    • getSerialNumber

      String getSerialNumber()
      Get the baseboard serial number.
      Returns:
      The serial number.