Enum Class NetworkIF.IfOperStatus

java.lang.Object
java.lang.Enum<NetworkIF.IfOperStatus>
oshi.hardware.NetworkIF.IfOperStatus
All Implemented Interfaces:
Serializable, Comparable<NetworkIF.IfOperStatus>, Constable
Enclosing interface:
NetworkIF

@PublicApi public static enum NetworkIF.IfOperStatus extends Enum<NetworkIF.IfOperStatus>
The current operational state of a network interface.

As described in RFC 2863.

  • Enum Constant Details

  • Method Details

    • values

      public static NetworkIF.IfOperStatus[] values()
      Returns an array containing the constants of this enum class, in the order they are declared.
      Returns:
      an array containing the constants of this enum class, in the order they are declared
    • valueOf

      public static NetworkIF.IfOperStatus valueOf(String name)
      Returns the enum constant of this class with the specified name. The string must match exactly an identifier used to declare an enum constant in this class. (Extraneous whitespace characters are not permitted.)
      Parameters:
      name - the name of the enum constant to be returned.
      Returns:
      the enum constant with the specified name
      Throws:
      IllegalArgumentException - if this enum class has no constant with the specified name
      NullPointerException - if the argument is null
    • getValue

      public int getValue()
      Gets the RFC 2863 integer value for this operational status.
      Returns:
      the integer value specified in RFC 2863 for this operational status.
    • byValue

      public static NetworkIF.IfOperStatus byValue(int value)
      Find IfOperStatus by the integer value.
      Parameters:
      value - Integer value specified in RFC 2863
      Returns:
      the matching IfOperStatu or UNKNOWN if no matching IfOperStatus can be found