Uses of Interface
oshi.hardware.CentralProcessor
Packages that use CentralProcessor
Package
Description
[oshi-common API] Provides cross-platform implementation to retrieve hardware information such as CPU, Memory,
Display, Disks, Network Interfaces, Power Sources, Sensors, and USB Devices
Provides abstract classes for common code
Provides common Linux hardware implementations shared by JNA and FFM modules.
Native-free Linux hardware implementations using only procfs, sysfs, and command-line utilities.
Provides information about hardware such as Memory, Power Sources, and Processor on Mac systems
Provides common Unix hardware implementations shared by JNA and FFM modules.
Provides information about hardware such as Memory, Power Sources, and Processor on AIX systems
Provides abstract base classes and pure-Java implementations for FreeBSD hardware, shared by the JNA and FFM modules.
Provides information about hardware such as Memory, Power Sources, and Processor on NetBSD systems
Provides abstract base classes and pure-Java implementations for OpenBSD hardware, shared by the JNA and FFM modules.
Provides abstract base classes and pure-Java implementations for Solaris/illumos hardware, shared by the JNA and FFM
modules.
Provides common implementations for Windows hardware information shared between JNA and FFM implementations.
Provides information about hardware such as Memory, Power Sources, and Processor on Linux systems
Provides information about hardware such as Memory, Power Sources, and Processor on Mac systems
Provides JNA-backed hardware implementations for AIX.
Provides information about hardware such as Memory, Power Sources, and Processor on DragonFly BSD systems
Provides information about hardware such as Memory, Power Sources, and Processor on FreeBSD systems
Provides information about hardware such as Memory, Power Sources, and Processor on OpenBSD systems
Provides information about hardware such as Memory, Power Sources, and Processor on Solaris systems
Provides information about hardware such as Memory, Power Sources, and Processor on Windows systems
Provides utilities for parsing, formatting, and other access
-
Uses of CentralProcessor in oshi.hardware
Methods in oshi.hardware that return CentralProcessorModifier and TypeMethodDescriptionHardwareAbstractionLayer.getProcessor()Instantiates aCentralProcessorobject. -
Uses of CentralProcessor in oshi.hardware.common
Classes in oshi.hardware.common that implement CentralProcessorMethods in oshi.hardware.common that return CentralProcessorModifier and TypeMethodDescriptionprotected abstract CentralProcessorAbstractHardwareAbstractionLayer.createProcessor()Instantiates the platform-specificCentralProcessorobjectAbstractHardwareAbstractionLayer.getProcessor() -
Uses of CentralProcessor in oshi.hardware.common.platform.linux
Classes in oshi.hardware.common.platform.linux that implement CentralProcessorMethods in oshi.hardware.common.platform.linux that return CentralProcessorModifier and TypeMethodDescriptionabstract CentralProcessorLinuxHardwareAbstractionLayer.createProcessor() -
Uses of CentralProcessor in oshi.hardware.common.platform.linux.nativefree
Classes in oshi.hardware.common.platform.linux.nativefree that implement CentralProcessorModifier and TypeClassDescriptionfinal classNative-free Linux central processor implementation.Methods in oshi.hardware.common.platform.linux.nativefree that return CentralProcessor -
Uses of CentralProcessor in oshi.hardware.common.platform.mac
Classes in oshi.hardware.common.platform.mac that implement CentralProcessorModifier and TypeClassDescriptionclassBase class for macOS CentralProcessor implementations. -
Uses of CentralProcessor in oshi.hardware.common.platform.unix
Classes in oshi.hardware.common.platform.unix that implement CentralProcessorModifier and TypeClassDescriptionclassShared CentralProcessor logic for thedmesg-parsing BSDs (OpenBSD and NetBSD). -
Uses of CentralProcessor in oshi.hardware.common.platform.unix.aix
Classes in oshi.hardware.common.platform.unix.aix that implement CentralProcessorModifier and TypeClassDescriptionclassAbstract base for AIX CentralProcessor. -
Uses of CentralProcessor in oshi.hardware.common.platform.unix.freebsd
Classes in oshi.hardware.common.platform.unix.freebsd that implement CentralProcessorModifier and TypeClassDescriptionclassShared FreeBSD CentralProcessor logic. -
Uses of CentralProcessor in oshi.hardware.common.platform.unix.netbsd
Classes in oshi.hardware.common.platform.unix.netbsd that implement CentralProcessorModifier and TypeClassDescriptionclassNetBSD Central Processor implementation.Methods in oshi.hardware.common.platform.unix.netbsd that return CentralProcessor -
Uses of CentralProcessor in oshi.hardware.common.platform.unix.openbsd
Classes in oshi.hardware.common.platform.unix.openbsd that implement CentralProcessorModifier and TypeClassDescriptionclassShared OpenBSD CentralProcessor logic. -
Uses of CentralProcessor in oshi.hardware.common.platform.unix.solaris
Classes in oshi.hardware.common.platform.unix.solaris that implement CentralProcessorModifier and TypeClassDescriptionclassAbstract base for the Solaris CPU. -
Uses of CentralProcessor in oshi.hardware.common.platform.windows
Classes in oshi.hardware.common.platform.windows that implement CentralProcessorModifier and TypeClassDescriptionclassCommon non-native logic for Windows Central Processor implementations. -
Uses of CentralProcessor in oshi.hardware.platform.linux
Methods in oshi.hardware.platform.linux that return CentralProcessor -
Uses of CentralProcessor in oshi.hardware.platform.mac
Methods in oshi.hardware.platform.mac that return CentralProcessor -
Uses of CentralProcessor in oshi.hardware.platform.unix.aix
Methods in oshi.hardware.platform.unix.aix that return CentralProcessor -
Uses of CentralProcessor in oshi.hardware.platform.unix.dragonflybsd
Classes in oshi.hardware.platform.unix.dragonflybsd that implement CentralProcessorModifier and TypeClassDescriptionclassDragonFly BSD Central Processor.Methods in oshi.hardware.platform.unix.dragonflybsd that return CentralProcessor -
Uses of CentralProcessor in oshi.hardware.platform.unix.freebsd
Classes in oshi.hardware.platform.unix.freebsd that implement CentralProcessorMethods in oshi.hardware.platform.unix.freebsd that return CentralProcessor -
Uses of CentralProcessor in oshi.hardware.platform.unix.openbsd
Classes in oshi.hardware.platform.unix.openbsd that implement CentralProcessorModifier and TypeClassDescriptionclassOpenBSD Central Processor implementation, backed by JNA sysctl and native library calls.Methods in oshi.hardware.platform.unix.openbsd that return CentralProcessor -
Uses of CentralProcessor in oshi.hardware.platform.unix.solaris
Methods in oshi.hardware.platform.unix.solaris that return CentralProcessor -
Uses of CentralProcessor in oshi.hardware.platform.windows
Methods in oshi.hardware.platform.windows that return CentralProcessor -
Uses of CentralProcessor in oshi.util
Methods in oshi.util with parameters of type CentralProcessorModifier and TypeMethodDescriptionstatic voidSystemInfoHelper.printCpu(List<String> lines, CentralProcessor processor) Prints Cpu information to the output lines.static voidSystemInfoHelper.printProcessor(List<String> lines, CentralProcessor processor) Prints Processor information to the output lines.