Uses of Class
oshi.hardware.CentralProcessor.PhysicalProcessor
Packages that use CentralProcessor.PhysicalProcessor
Package
Description
Provides functions to query information in windows
[oshi-common API] Provides cross-platform implementation to retrieve hardware information such as CPU, Memory,
Display, Disks, Network Interfaces, Power Sources, Sensors, and USB Devices
Provides abstract classes for common code
Provides common Linux hardware implementations shared by JNA and FFM modules.
Provides information about hardware such as Memory, Power Sources, and Processor on Mac systems
Provides information about hardware such as Memory, Power Sources, and Processor on OpenBSD systems
-
Uses of CentralProcessor.PhysicalProcessor in oshi.driver.windows
Methods in oshi.driver.windows that return types with arguments of type CentralProcessor.PhysicalProcessorModifier and TypeMethodDescriptionstatic Triplet<List<CentralProcessor.LogicalProcessor>, List<CentralProcessor.PhysicalProcessor>, List<CentralProcessor.ProcessorCache>> LogicalProcessorInformation.getLogicalProcessorInformation()Get a list of logical processors on this machinestatic Triplet<List<CentralProcessor.LogicalProcessor>, List<CentralProcessor.PhysicalProcessor>, List<CentralProcessor.ProcessorCache>> LogicalProcessorInformation.getLogicalProcessorInformationEx()Get a list of logical processors on this machine. -
Uses of CentralProcessor.PhysicalProcessor in oshi.hardware
Methods in oshi.hardware that return types with arguments of type CentralProcessor.PhysicalProcessorModifier and TypeMethodDescriptionCentralProcessor.getPhysicalProcessors()Returns anUnmodifiableListof the CPU's physical processors. -
Uses of CentralProcessor.PhysicalProcessor in oshi.hardware.common
Methods in oshi.hardware.common that return types with arguments of type CentralProcessor.PhysicalProcessorModifier and TypeMethodDescriptionprotected List<CentralProcessor.PhysicalProcessor> AbstractCentralProcessor.createProcListFromDmesg(List<CentralProcessor.LogicalProcessor> logProcs, Map<Integer, String> dmesg) Creates a list of physical processors from dmesg output.AbstractCentralProcessor.getPhysicalProcessors()protected abstract Quartet<List<CentralProcessor.LogicalProcessor>, List<CentralProcessor.PhysicalProcessor>, List<CentralProcessor.ProcessorCache>, List<String>> AbstractCentralProcessor.initProcessorCounts()Initializes logical and physical processor lists and feature flags. -
Uses of CentralProcessor.PhysicalProcessor in oshi.hardware.common.platform.linux
Methods in oshi.hardware.common.platform.linux that return types with arguments of type CentralProcessor.PhysicalProcessorModifier and TypeMethodDescriptionprotected Quartet<List<CentralProcessor.LogicalProcessor>, List<CentralProcessor.PhysicalProcessor>, List<CentralProcessor.ProcessorCache>, List<String>> LinuxCentralProcessor.initProcessorCounts() -
Uses of CentralProcessor.PhysicalProcessor in oshi.hardware.common.platform.mac
Methods in oshi.hardware.common.platform.mac that return types with arguments of type CentralProcessor.PhysicalProcessorModifier and TypeMethodDescriptionprotected Quartet<List<CentralProcessor.LogicalProcessor>, List<CentralProcessor.PhysicalProcessor>, List<CentralProcessor.ProcessorCache>, List<String>> MacCentralProcessor.initProcessorCounts() -
Uses of CentralProcessor.PhysicalProcessor in oshi.hardware.platform.unix.openbsd
Methods in oshi.hardware.platform.unix.openbsd that return types with arguments of type CentralProcessor.PhysicalProcessorModifier and TypeMethodDescriptionprotected Quartet<List<CentralProcessor.LogicalProcessor>, List<CentralProcessor.PhysicalProcessor>, List<CentralProcessor.ProcessorCache>, List<String>> OpenBsdCentralProcessor.initProcessorCounts()