| Package | Description |
|---|---|
| oshi.hardware |
[oshi-core API] Provides cross-platform implementation to retrieve hardware
information such as CPU, Memory, Display, Disks, Network Interfaces, Power
Sources, Sensors, and USB Devices
|
| oshi.hardware.common |
Provides abstract classes for common code
|
| oshi.hardware.platform.linux |
Provides information about hardware such as Memory, Power Sources, and
Processor on Linux systems
|
| oshi.hardware.platform.mac |
Provides information about hardware such as Memory, Power Sources, and
Processor on Mac systems
|
| oshi.hardware.platform.unix.freebsd |
Provides information about hardware such as Memory, Power Sources, and
Processor on FreeBSD systems
|
| oshi.hardware.platform.unix.solaris |
Provides information about hardware such as Memory, Power Sources, and
Processor on Solaris systems
|
| oshi.hardware.platform.windows |
Provides information about hardware such as Memory, Power Sources, and
Processor on Windows systems
|
| Modifier and Type | Method and Description |
|---|---|
CentralProcessor.ProcessorIdentifier |
CentralProcessor.getProcessorIdentifier()
The CPU's identifier strings ,including name, vendor, stepping, model, and
family information (also called the signature of a CPU)
|
| Modifier and Type | Method and Description |
|---|---|
CentralProcessor.ProcessorIdentifier |
AbstractCentralProcessor.getProcessorIdentifier() |
protected abstract CentralProcessor.ProcessorIdentifier |
AbstractCentralProcessor.queryProcessorId()
Updates logical and physical processor counts and arrays
|
| Modifier and Type | Method and Description |
|---|---|
protected CentralProcessor.ProcessorIdentifier |
LinuxCentralProcessor.queryProcessorId() |
| Modifier and Type | Method and Description |
|---|---|
protected CentralProcessor.ProcessorIdentifier |
MacCentralProcessor.queryProcessorId() |
| Modifier and Type | Method and Description |
|---|---|
protected CentralProcessor.ProcessorIdentifier |
FreeBsdCentralProcessor.queryProcessorId() |
| Modifier and Type | Method and Description |
|---|---|
protected CentralProcessor.ProcessorIdentifier |
SolarisCentralProcessor.queryProcessorId() |
| Modifier and Type | Method and Description |
|---|---|
protected CentralProcessor.ProcessorIdentifier |
WindowsCentralProcessor.queryProcessorId()
Initializes Class variables
|
Copyright © 2010–2020 oshi. All rights reserved.