| Package | Description |
|---|---|
| oshi.hardware |
[oshi-core API] Provides cross-platform implementation to retrieve hardware
information such as CPU, Memory, Display, Disks, Network Interfaces, Power
Sources, Sensors, and USB Devices
|
| oshi.hardware.common |
Provides abstract classes for common code
|
| oshi.hardware.platform.linux |
Provides information about hardware such as Memory, Power Sources, and
Processor on Linux systems
|
| oshi.hardware.platform.mac |
Provides information about hardware such as Memory, Power Sources, and
Processor on Mac systems
|
| oshi.hardware.platform.unix.freebsd |
Provides information about hardware such as Memory, Power Sources, and
Processor on FreeBSD systems
|
| oshi.hardware.platform.unix.solaris |
Provides information about hardware such as Memory, Power Sources, and
Processor on Solaris systems
|
| oshi.hardware.platform.windows |
Provides information about hardware such as Memory, Power Sources, and
Processor on Windows systems
|
| Modifier and Type | Method and Description |
|---|---|
ComputerSystem |
HardwareAbstractionLayer.getComputerSystem()
Instantiates a
ComputerSystem object. |
| Modifier and Type | Class and Description |
|---|---|
class |
AbstractComputerSystem
Computer System data.
|
| Modifier and Type | Method and Description |
|---|---|
protected abstract ComputerSystem |
AbstractHardwareAbstractionLayer.createComputerSystem()
Instantiates the platform-specific
ComputerSystem object |
ComputerSystem |
AbstractHardwareAbstractionLayer.getComputerSystem() |
| Modifier and Type | Method and Description |
|---|---|
ComputerSystem |
LinuxHardwareAbstractionLayer.createComputerSystem()
Instantiates the platform-specific
ComputerSystem object |
| Modifier and Type | Method and Description |
|---|---|
ComputerSystem |
MacHardwareAbstractionLayer.createComputerSystem()
Instantiates the platform-specific
ComputerSystem object |
| Modifier and Type | Method and Description |
|---|---|
ComputerSystem |
FreeBsdHardwareAbstractionLayer.createComputerSystem()
Instantiates the platform-specific
ComputerSystem object |
| Modifier and Type | Method and Description |
|---|---|
ComputerSystem |
SolarisHardwareAbstractionLayer.createComputerSystem()
Instantiates the platform-specific
ComputerSystem object |
| Modifier and Type | Method and Description |
|---|---|
ComputerSystem |
WindowsHardwareAbstractionLayer.createComputerSystem()
Instantiates the platform-specific
ComputerSystem object |
Copyright © 2010–2020 oshi. All rights reserved.