Uses of Interface
oshi.hardware.Display
| Package | Description |
|---|---|
| oshi.hardware |
[oshi-core API] Provides cross-platform implementation to retrieve hardware
information such as CPU, Memory, Display, Disks, Network Interfaces, Power
Sources, Sensors, and USB Devices
|
| oshi.hardware.common |
Provides abstract classes for common code
|
| oshi.hardware.platform.linux |
Provides information about hardware such as Memory, Power Sources, and
Processor on Linux systems
|
| oshi.hardware.platform.mac |
Provides information about hardware such as Memory, Power Sources, and
Processor on Mac systems
|
| oshi.hardware.platform.unix.freebsd |
Provides information about hardware such as Memory, Power Sources, and
Processor on FreeBSD systems
|
| oshi.hardware.platform.unix.solaris |
Provides information about hardware such as Memory, Power Sources, and
Processor on Solaris systems
|
| oshi.hardware.platform.windows |
Provides information about hardware such as Memory, Power Sources, and
Processor on Windows systems
|
-
Uses of Display in oshi.hardware
Methods in oshi.hardware that return Display Modifier and Type Method Description Display[]HardwareAbstractionLayer. getDisplays()Instantiates an array ofDisplayobjects, representing monitors or other video output devices. -
Uses of Display in oshi.hardware.common
Classes in oshi.hardware.common that implement Display Modifier and Type Class Description classAbstractDisplayA Display -
Uses of Display in oshi.hardware.platform.linux
Classes in oshi.hardware.platform.linux that implement Display Modifier and Type Class Description classLinuxDisplayA DisplayMethods in oshi.hardware.platform.linux that return Display Modifier and Type Method Description static Display[]LinuxDisplay. getDisplays()Gets Display InformationDisplay[]LinuxHardwareAbstractionLayer. getDisplays()Instantiates an array ofDisplayobjects, representing monitors or other video output devices. -
Uses of Display in oshi.hardware.platform.mac
Classes in oshi.hardware.platform.mac that implement Display Modifier and Type Class Description classMacDisplayA DisplayMethods in oshi.hardware.platform.mac that return Display Modifier and Type Method Description static Display[]MacDisplay. getDisplays()Gets Display InformationDisplay[]MacHardwareAbstractionLayer. getDisplays()Instantiates an array ofDisplayobjects, representing monitors or other video output devices. -
Uses of Display in oshi.hardware.platform.unix.freebsd
Classes in oshi.hardware.platform.unix.freebsd that implement Display Modifier and Type Class Description classFreeBsdDisplayA DisplayMethods in oshi.hardware.platform.unix.freebsd that return Display Modifier and Type Method Description static Display[]FreeBsdDisplay. getDisplays()Gets Display InformationDisplay[]FreeBsdHardwareAbstractionLayer. getDisplays()Instantiates an array ofDisplayobjects, representing monitors or other video output devices. -
Uses of Display in oshi.hardware.platform.unix.solaris
Classes in oshi.hardware.platform.unix.solaris that implement Display Modifier and Type Class Description classSolarisDisplayA DisplayMethods in oshi.hardware.platform.unix.solaris that return Display Modifier and Type Method Description static Display[]SolarisDisplay. getDisplays()Gets Display InformationDisplay[]SolarisHardwareAbstractionLayer. getDisplays()Instantiates an array ofDisplayobjects, representing monitors or other video output devices. -
Uses of Display in oshi.hardware.platform.windows
Classes in oshi.hardware.platform.windows that implement Display Modifier and Type Class Description classWindowsDisplayA DisplayMethods in oshi.hardware.platform.windows that return Display Modifier and Type Method Description static Display[]WindowsDisplay. getDisplays()Gets Display InformationDisplay[]WindowsHardwareAbstractionLayer. getDisplays()Instantiates an array ofDisplayobjects, representing monitors or other video output devices.