Uses of Interface
oshi.hardware.Firmware
Packages that use Firmware
Package
Description
[oshi-common API] Provides cross-platform implementation to retrieve hardware information such as CPU, Memory,
Display, Disks, Network Interfaces, Power Sources, Sensors, and USB Devices
Provides abstract classes for common code
Provides information about hardware such as Memory, Power Sources, and Processor on Mac systems
Provides common implementations for Windows hardware information shared between JNA and FFM implementations.
Provides information about hardware such as Memory, Power Sources, and Processor on OpenBSD systems
-
Uses of Firmware in oshi.hardware
Methods in oshi.hardware that return FirmwareModifier and TypeMethodDescriptionComputerSystem.getFirmware()Get the computer system firmware/BIOS. -
Uses of Firmware in oshi.hardware.common
Classes in oshi.hardware.common that implement FirmwareMethods in oshi.hardware.common that return FirmwareModifier and TypeMethodDescriptionprotected abstract FirmwareAbstractComputerSystem.createFirmware()Instantiates the platform-specificFirmwareobjectAbstractComputerSystem.getFirmware() -
Uses of Firmware in oshi.hardware.common.platform.mac
Classes in oshi.hardware.common.platform.mac that implement Firmware -
Uses of Firmware in oshi.hardware.common.platform.windows
Classes in oshi.hardware.common.platform.windows that implement Firmware -
Uses of Firmware in oshi.hardware.platform.unix.openbsd
Classes in oshi.hardware.platform.unix.openbsd that implement FirmwareMethods in oshi.hardware.platform.unix.openbsd that return Firmware