Uses of Interface
oshi.hardware.GlobalMemory
Packages that use GlobalMemory
Package
Description
[oshi-common API] Provides cross-platform implementation to retrieve hardware information such as CPU, Memory,
Display, Disks, Network Interfaces, Power Sources, Sensors, and USB Devices
Provides abstract classes for common code
Provides common Linux hardware implementations shared by JNA and FFM modules.
Native-free Linux hardware implementations using only procfs, sysfs, and command-line utilities.
Provides information about hardware such as Memory, Power Sources, and Processor on Mac systems
Provides common implementations for Windows hardware information shared between JNA and FFM implementations.
Provides information about hardware such as Memory, Power Sources, and Processor on Linux systems
Provides information about hardware such as Memory, Power Sources, and Processor on Mac systems
Provides information about hardware such as Memory, Power Sources, and Processor on AIX systems
Provides information about hardware such as Memory, Power Sources, and Processor on FreeBSD systems
Provides information about hardware such as Memory, Power Sources, and Processor on OpenBSD systems
Provides information about hardware such as Memory, Power Sources, and Processor on Solaris systems
Provides information about hardware such as Memory, Power Sources, and Processor on Windows systems
Provides utilities for parsing, formatting, and other access
-
Uses of GlobalMemory in oshi.hardware
Methods in oshi.hardware that return GlobalMemoryModifier and TypeMethodDescriptionHardwareAbstractionLayer.getMemory()Instantiates aGlobalMemoryobject. -
Uses of GlobalMemory in oshi.hardware.common
Classes in oshi.hardware.common that implement GlobalMemoryMethods in oshi.hardware.common that return GlobalMemoryModifier and TypeMethodDescriptionprotected abstract GlobalMemoryAbstractHardwareAbstractionLayer.createMemory()Instantiates the platform-specificGlobalMemoryobjectAbstractHardwareAbstractionLayer.getMemory() -
Uses of GlobalMemory in oshi.hardware.common.platform.linux
Classes in oshi.hardware.common.platform.linux that implement GlobalMemoryModifier and TypeClassDescriptionfinal classMemory obtained by /proc/meminfo and sysinfo.totalramMethods in oshi.hardware.common.platform.linux that return GlobalMemoryModifier and TypeMethodDescriptionabstract GlobalMemoryLinuxHardwareAbstractionLayer.createMemory() -
Uses of GlobalMemory in oshi.hardware.common.platform.linux.nativefree
Methods in oshi.hardware.common.platform.linux.nativefree that return GlobalMemory -
Uses of GlobalMemory in oshi.hardware.common.platform.mac
Classes in oshi.hardware.common.platform.mac that implement GlobalMemoryModifier and TypeClassDescriptionclassMemory obtained by host_statistics (vm_stat) and sysctl. -
Uses of GlobalMemory in oshi.hardware.common.platform.windows
Classes in oshi.hardware.common.platform.windows that implement GlobalMemoryModifier and TypeClassDescriptionclassCommon Windows global memory logic shared between JNA and FFM implementations. -
Uses of GlobalMemory in oshi.hardware.platform.linux
Methods in oshi.hardware.platform.linux that return GlobalMemory -
Uses of GlobalMemory in oshi.hardware.platform.mac
Methods in oshi.hardware.platform.mac that return GlobalMemory -
Uses of GlobalMemory in oshi.hardware.platform.unix.aix
Methods in oshi.hardware.platform.unix.aix that return GlobalMemory -
Uses of GlobalMemory in oshi.hardware.platform.unix.freebsd
Methods in oshi.hardware.platform.unix.freebsd that return GlobalMemory -
Uses of GlobalMemory in oshi.hardware.platform.unix.openbsd
Methods in oshi.hardware.platform.unix.openbsd that return GlobalMemory -
Uses of GlobalMemory in oshi.hardware.platform.unix.solaris
Methods in oshi.hardware.platform.unix.solaris that return GlobalMemory -
Uses of GlobalMemory in oshi.hardware.platform.windows
Methods in oshi.hardware.platform.windows that return GlobalMemory -
Uses of GlobalMemory in oshi.util
Methods in oshi.util with parameters of type GlobalMemoryModifier and TypeMethodDescriptionstatic voidSystemInfoHelper.printMemory(List<String> lines, GlobalMemory memory) Prints Memory information to the output lines.static voidSystemInfoHelper.printProcesses(List<String> lines, OperatingSystem os, GlobalMemory memory) Prints Processes information to the output lines.