Uses of Interface
oshi.hardware.GraphicsCard
Packages that use GraphicsCard
Package
Description
[oshi-common API] Provides cross-platform implementation to retrieve hardware information such as CPU, Memory,
Display, Disks, Network Interfaces, Power Sources, Sensors, and USB Devices
Provides abstract classes for common code
Provides common Linux hardware implementations shared by JNA and FFM modules.
Provides information about hardware such as Memory, Power Sources, and Processor on Mac systems
Provides information about hardware such as Memory, Power Sources, and Processor on Linux systems
Provides information about hardware such as Memory, Power Sources, and Processor on Mac systems
Provides information about hardware such as Memory, Power Sources, and Processor on AIX systems
Provides information about hardware such as Memory, Power Sources, and Processor on FreeBSD systems
Provides information about hardware such as Memory, Power Sources, and Processor on OpenBSD systems
Provides information about hardware such as Memory, Power Sources, and Processor on Solaris systems
Provides information about hardware such as Memory, Power Sources, and Processor on Windows systems
-
Uses of GraphicsCard in oshi.hardware
Methods in oshi.hardware that return types with arguments of type GraphicsCardModifier and TypeMethodDescriptionHardwareAbstractionLayer.getGraphicsCards()Instantiates a list ofGraphicsCardobjects, representing the Graphics cards. -
Uses of GraphicsCard in oshi.hardware.common
Classes in oshi.hardware.common that implement GraphicsCard -
Uses of GraphicsCard in oshi.hardware.common.platform.linux
Classes in oshi.hardware.common.platform.linux that implement GraphicsCardModifier and TypeClassDescriptionclassGraphics card info obtained by lshw, with dynamic metrics from sysfs DRM driver files.Methods in oshi.hardware.common.platform.linux that return types with arguments of type GraphicsCardModifier and TypeMethodDescriptionstatic List<GraphicsCard> LinuxGraphicsCard.getGraphicsCards(Function<LinuxGraphicsCard.Attrs, GraphicsCard> factory) Queries graphics cards from lspci/lshw and constructs instances using the provided factory.abstract List<GraphicsCard> LinuxHardwareAbstractionLayer.getGraphicsCards()Method parameters in oshi.hardware.common.platform.linux with type arguments of type GraphicsCardModifier and TypeMethodDescriptionstatic List<GraphicsCard> LinuxGraphicsCard.getGraphicsCards(Function<LinuxGraphicsCard.Attrs, GraphicsCard> factory) Queries graphics cards from lspci/lshw and constructs instances using the provided factory. -
Uses of GraphicsCard in oshi.hardware.common.platform.mac
Classes in oshi.hardware.common.platform.mac that implement GraphicsCardModifier and TypeClassDescriptionclassGraphics card info obtained by system_profiler SPDisplaysDataType.Methods in oshi.hardware.common.platform.mac that return GraphicsCardModifier and TypeMethodDescriptionMacGraphicsCard.GraphicsCardFactory.create(String name, String deviceId, String vendor, String versionInfo, long vram) Methods in oshi.hardware.common.platform.mac that return types with arguments of type GraphicsCardModifier and TypeMethodDescriptionprotected static List<GraphicsCard> MacGraphicsCard.parseGraphicsCards(MacGraphicsCard.GraphicsCardFactory factory, MacGraphicsCard.SysctlLong sysctl) -
Uses of GraphicsCard in oshi.hardware.platform.linux
Methods in oshi.hardware.platform.linux that return types with arguments of type GraphicsCard -
Uses of GraphicsCard in oshi.hardware.platform.mac
Methods in oshi.hardware.platform.mac that return types with arguments of type GraphicsCard -
Uses of GraphicsCard in oshi.hardware.platform.unix.aix
Methods in oshi.hardware.platform.unix.aix that return types with arguments of type GraphicsCard -
Uses of GraphicsCard in oshi.hardware.platform.unix.freebsd
Methods in oshi.hardware.platform.unix.freebsd that return types with arguments of type GraphicsCard -
Uses of GraphicsCard in oshi.hardware.platform.unix.openbsd
Methods in oshi.hardware.platform.unix.openbsd that return types with arguments of type GraphicsCard -
Uses of GraphicsCard in oshi.hardware.platform.unix.solaris
Methods in oshi.hardware.platform.unix.solaris that return types with arguments of type GraphicsCard -
Uses of GraphicsCard in oshi.hardware.platform.windows
Methods in oshi.hardware.platform.windows that return types with arguments of type GraphicsCard