Uses of Interface
oshi.hardware.LogicalVolumeGroup
Packages that use LogicalVolumeGroup
Package
Description
[oshi-common API] Provides cross-platform implementation to retrieve hardware information such as CPU, Memory,
Display, Disks, Network Interfaces, Power Sources, Sensors, and USB Devices
Provides abstract classes for common code
Provides common Linux hardware implementations shared by JNA and FFM modules.
Provides information about hardware such as Memory, Power Sources, and Processor on Mac systems
Provides information about hardware such as Memory, Power Sources, and Processor on Linux systems
Provides information about hardware such as Memory, Power Sources, and Processor on Windows systems
-
Uses of LogicalVolumeGroup in oshi.hardware
Methods in oshi.hardware that return types with arguments of type LogicalVolumeGroupModifier and TypeMethodDescriptiondefault List<LogicalVolumeGroup> HardwareAbstractionLayer.getLogicalVolumeGroups()Instantiates a list ofLogicalVolumeGroupobjects, representing a storage pool or group of devices, partitions, volumes, or other implementation specific means of file storage. -
Uses of LogicalVolumeGroup in oshi.hardware.common
Classes in oshi.hardware.common that implement LogicalVolumeGroupModifier and TypeClassDescriptionclassCommon implementations for LogicalVolumeGroup. -
Uses of LogicalVolumeGroup in oshi.hardware.common.platform.linux
Classes in oshi.hardware.common.platform.linux that implement LogicalVolumeGroupModifier and TypeClassDescriptionclassLinux implementation of LogicalVolumeGroup. -
Uses of LogicalVolumeGroup in oshi.hardware.common.platform.mac
Classes in oshi.hardware.common.platform.mac that implement LogicalVolumeGroupMethods in oshi.hardware.common.platform.mac that return types with arguments of type LogicalVolumeGroup -
Uses of LogicalVolumeGroup in oshi.hardware.platform.linux
Methods in oshi.hardware.platform.linux that return types with arguments of type LogicalVolumeGroup -
Uses of LogicalVolumeGroup in oshi.hardware.platform.windows
Methods in oshi.hardware.platform.windows that return types with arguments of type LogicalVolumeGroup