Uses of Interface
oshi.hardware.NetworkIF
Packages that use NetworkIF
Package
Description
[oshi-common API] Provides cross-platform implementation to retrieve hardware information such as CPU, Memory,
Display, Disks, Network Interfaces, Power Sources, Sensors, and USB Devices
Provides abstract classes for common code
Provides common Linux hardware implementations shared by JNA and FFM modules.
Native-free Linux hardware implementations using only procfs, sysfs, and command-line utilities.
Provides information about hardware such as Memory, Power Sources, and Processor on Mac systems
Provides common Unix hardware implementations shared by JNA and FFM modules.
Provides information about hardware such as Memory, Power Sources, and Processor on AIX systems
Provides information about hardware such as Memory, Power Sources, and Processor on NetBSD systems
Provides abstract base classes and pure-Java implementations for Solaris/illumos hardware, shared by the JNA and FFM
modules.
Provides information about hardware such as Memory, Power Sources, and Processor on Linux systems
Provides information about hardware such as Memory, Power Sources, and Processor on Mac systems
Provides JNA-backed hardware implementations for AIX.
Provides information about hardware such as Memory, Power Sources, and Processor on DragonFly BSD systems
Provides information about hardware such as Memory, Power Sources, and Processor on FreeBSD systems
Provides information about hardware such as Memory, Power Sources, and Processor on OpenBSD systems
Provides information about hardware such as Memory, Power Sources, and Processor on Solaris systems
Provides information about hardware such as Memory, Power Sources, and Processor on Windows systems
-
Uses of NetworkIF in oshi.hardware
Methods in oshi.hardware that return types with arguments of type NetworkIFModifier and TypeMethodDescriptionHardwareAbstractionLayer.getNetworkIFs()Gets a list of non-localNetworkIFobjects, representing a network interface.HardwareAbstractionLayer.getNetworkIFs(boolean includeLocalInterfaces) Gets a listNetworkIFobjects, representing a network interface. -
Uses of NetworkIF in oshi.hardware.common
Classes in oshi.hardware.common that implement NetworkIFMethods in oshi.hardware.common that return types with arguments of type NetworkIF -
Uses of NetworkIF in oshi.hardware.common.platform.linux
Classes in oshi.hardware.common.platform.linux that implement NetworkIF -
Uses of NetworkIF in oshi.hardware.common.platform.linux.nativefree
Classes in oshi.hardware.common.platform.linux.nativefree that implement NetworkIFModifier and TypeClassDescriptionfinal classNative-free Linux network interface implementation.Methods in oshi.hardware.common.platform.linux.nativefree that return types with arguments of type NetworkIFModifier and TypeMethodDescriptionLinuxHardwareAbstractionLayerNF.getNetworkIFs(boolean includeLocalInterfaces) LinuxNetworkIfNF.getNetworks(boolean includeLocalInterfaces) Gets network interfaces on this machine. -
Uses of NetworkIF in oshi.hardware.common.platform.mac
Classes in oshi.hardware.common.platform.mac that implement NetworkIFModifier and TypeClassDescriptionclassBase class for macOS NetworkIF implementations. -
Uses of NetworkIF in oshi.hardware.common.platform.unix
Classes in oshi.hardware.common.platform.unix that implement NetworkIFModifier and TypeClassDescriptionfinal classBsdNetworkIF applicable to FreeBSD and OpenBSD.Methods in oshi.hardware.common.platform.unix that return types with arguments of type NetworkIFModifier and TypeMethodDescriptionBsdNetworkIF.getNetworks(boolean includeLocalInterfaces) Gets all network interfaces on this machine -
Uses of NetworkIF in oshi.hardware.common.platform.unix.aix
Classes in oshi.hardware.common.platform.unix.aix that implement NetworkIF -
Uses of NetworkIF in oshi.hardware.common.platform.unix.netbsd
Classes in oshi.hardware.common.platform.unix.netbsd that implement NetworkIFModifier and TypeClassDescriptionfinal classNetBSD-specific NetworkIF implementation.Methods in oshi.hardware.common.platform.unix.netbsd that return types with arguments of type NetworkIFModifier and TypeMethodDescriptionNetBsdHardwareAbstractionLayer.getNetworkIFs(boolean includeLocalInterfaces) NetBsdNetworkIF.getNetworks(boolean includeLocalInterfaces) Gets all network interfaces on this machine -
Uses of NetworkIF in oshi.hardware.common.platform.unix.solaris
Classes in oshi.hardware.common.platform.unix.solaris that implement NetworkIFMethods in oshi.hardware.common.platform.unix.solaris that return types with arguments of type NetworkIFModifier and TypeMethodDescriptionSolarisNetworkIF.getNetworks(boolean includeLocalInterfaces, SolarisNetworkIF.NetworkIFFactory factory) Gets all network interfaces on this machine, building each with the given concrete factory. -
Uses of NetworkIF in oshi.hardware.platform.linux
Classes in oshi.hardware.platform.linux that implement NetworkIFModifier and TypeClassDescriptionfinal classJNA-based Linux network interface implementation.Methods in oshi.hardware.platform.linux that return types with arguments of type NetworkIFModifier and TypeMethodDescriptionLinuxHardwareAbstractionLayerJNA.getNetworkIFs(boolean includeLocalInterfaces) LinuxNetworkIFJNA.getNetworks(boolean includeLocalInterfaces) Gets network interfaces on this machine -
Uses of NetworkIF in oshi.hardware.platform.mac
Classes in oshi.hardware.platform.mac that implement NetworkIFMethods in oshi.hardware.platform.mac that return types with arguments of type NetworkIFModifier and TypeMethodDescriptionMacHardwareAbstractionLayerJNA.getNetworkIFs(boolean includeLocalInterfaces) MacNetworkIfJNA.getNetworks(boolean includeLocalInterfaces) Gets all network interfaces on this machine -
Uses of NetworkIF in oshi.hardware.platform.unix.aix
Classes in oshi.hardware.platform.unix.aix that implement NetworkIFMethods in oshi.hardware.platform.unix.aix that return types with arguments of type NetworkIFModifier and TypeMethodDescriptionAixHardwareAbstractionLayerJNA.getNetworkIFs(boolean includeLocalInterfaces) AixNetworkIFJNA.getNetworks(boolean includeLocalInterfaces) Gets all network interfaces on this machine. -
Uses of NetworkIF in oshi.hardware.platform.unix.dragonflybsd
Methods in oshi.hardware.platform.unix.dragonflybsd that return types with arguments of type NetworkIFModifier and TypeMethodDescriptionDragonFlyBsdHardwareAbstractionLayerJNA.getNetworkIFs(boolean includeLocalInterfaces) -
Uses of NetworkIF in oshi.hardware.platform.unix.freebsd
Methods in oshi.hardware.platform.unix.freebsd that return types with arguments of type NetworkIFModifier and TypeMethodDescriptionFreeBsdHardwareAbstractionLayerJNA.getNetworkIFs(boolean includeLocalInterfaces) -
Uses of NetworkIF in oshi.hardware.platform.unix.openbsd
Methods in oshi.hardware.platform.unix.openbsd that return types with arguments of type NetworkIFModifier and TypeMethodDescriptionOpenBsdHardwareAbstractionLayerJNA.getNetworkIFs(boolean includeLocalInterfaces) -
Uses of NetworkIF in oshi.hardware.platform.unix.solaris
Classes in oshi.hardware.platform.unix.solaris that implement NetworkIFMethods in oshi.hardware.platform.unix.solaris that return types with arguments of type NetworkIFModifier and TypeMethodDescriptionSolarisHardwareAbstractionLayerJNA.getNetworkIFs(boolean includeLocalInterfaces) SolarisNetworkIFJNA.getNetworks(boolean includeLocalInterfaces) Gets all network interfaces on this machine. -
Uses of NetworkIF in oshi.hardware.platform.windows
Classes in oshi.hardware.platform.windows that implement NetworkIFMethods in oshi.hardware.platform.windows that return types with arguments of type NetworkIFModifier and TypeMethodDescriptionWindowsHardwareAbstractionLayerJNA.getNetworkIFs(boolean includeLocalInterfaces) WindowsNetworkIfJNA.getNetworks(boolean includeLocalInterfaces) Gets all network interfaces on this machine