Uses of Enum Class
oshi.hardware.NetworkIF.IfOperStatus

Packages that use NetworkIF.IfOperStatus
Package
Description
[oshi-common API] Provides cross-platform implementation to retrieve hardware information such as CPU, Memory, Display, Disks, Network Interfaces, Power Sources, Sensors, and USB Devices
Provides common Linux hardware implementations shared by JNA and FFM modules.
Provides information about hardware such as Memory, Power Sources, and Processor on Windows systems