Uses of Interface
oshi.hardware.Networks
| Package | Description |
|---|---|
| oshi.hardware.common |
Provides abstract classes for common code
|
| oshi.hardware.platform.linux |
Provides information about hardware such as Memory, Power Sources, and
Processor on Linux systems
|
| oshi.hardware.platform.mac |
Provides information about hardware such as Memory, Power Sources, and
Processor on Mac systems
|
| oshi.hardware.platform.unix.freebsd |
Provides information about hardware such as Memory, Power Sources, and
Processor on FreeBSD systems
|
| oshi.hardware.platform.unix.solaris |
Provides information about hardware such as Memory, Power Sources, and
Processor on Solaris systems
|
| oshi.hardware.platform.windows |
Provides information about hardware such as Memory, Power Sources, and
Processor on Windows systems
|
-
Uses of Networks in oshi.hardware.common
Classes in oshi.hardware.common that implement Networks Modifier and Type Class Description classAbstractNetworksNetwork interfaces implementation. -
Uses of Networks in oshi.hardware.platform.linux
Classes in oshi.hardware.platform.linux that implement Networks Modifier and Type Class Description classLinuxNetworksLinuxNetworks class. -
Uses of Networks in oshi.hardware.platform.mac
Classes in oshi.hardware.platform.mac that implement Networks Modifier and Type Class Description classMacNetworksMacNetworks class. -
Uses of Networks in oshi.hardware.platform.unix.freebsd
Classes in oshi.hardware.platform.unix.freebsd that implement Networks Modifier and Type Class Description classFreeBsdNetworksFreeBsdNetworks class. -
Uses of Networks in oshi.hardware.platform.unix.solaris
Classes in oshi.hardware.platform.unix.solaris that implement Networks Modifier and Type Class Description classSolarisNetworksSolarisNetworks class. -
Uses of Networks in oshi.hardware.platform.windows
Classes in oshi.hardware.platform.windows that implement Networks Modifier and Type Class Description classWindowsNetworksWindowsNetworks class.