Uses of Class
oshi.hardware.PhysicalMemory
| Package | Description |
|---|---|
| oshi.hardware |
[oshi-core API] Provides cross-platform implementation to retrieve hardware
information such as CPU, Memory, Display, Disks, Network Interfaces, Power
Sources, Sensors, and USB Devices
|
| oshi.hardware.common |
Provides abstract classes for common code
|
| oshi.hardware.platform.mac |
Provides information about hardware such as Memory, Power Sources, and
Processor on Mac systems
|
| oshi.hardware.platform.windows |
Provides information about hardware such as Memory, Power Sources, and
Processor on Windows systems
|
-
Uses of PhysicalMemory in oshi.hardware
Methods in oshi.hardware that return PhysicalMemory Modifier and Type Method Description PhysicalMemory[]GlobalMemory. getPhysicalMemory()Physical memory, such as banks of memory. -
Uses of PhysicalMemory in oshi.hardware.common
Methods in oshi.hardware.common that return PhysicalMemory Modifier and Type Method Description PhysicalMemory[]AbstractGlobalMemory. getPhysicalMemory() -
Uses of PhysicalMemory in oshi.hardware.platform.mac
Methods in oshi.hardware.platform.mac that return PhysicalMemory Modifier and Type Method Description PhysicalMemory[]MacGlobalMemory. getPhysicalMemory() -
Uses of PhysicalMemory in oshi.hardware.platform.windows
Methods in oshi.hardware.platform.windows that return PhysicalMemory Modifier and Type Method Description PhysicalMemory[]WindowsGlobalMemory. getPhysicalMemory()