| Package | Description |
|---|---|
| oshi.hardware |
[oshi-core API] Provides cross-platform implementation to retrieve hardware
information such as CPU, Memory, Display, Disks, Network Interfaces, Power
Sources, Sensors, and USB Devices
|
| oshi.hardware.common |
Provides abstract classes for common code
|
| oshi.hardware.platform.linux |
Provides information about hardware such as Memory, Power Sources, and
Processor on Linux systems
|
| oshi.hardware.platform.mac |
Provides information about hardware such as Memory, Power Sources, and
Processor on Mac systems
|
| oshi.hardware.platform.unix.freebsd |
Provides information about hardware such as Memory, Power Sources, and
Processor on FreeBSD systems
|
| oshi.hardware.platform.unix.solaris |
Provides information about hardware such as Memory, Power Sources, and
Processor on Solaris systems
|
| oshi.hardware.platform.windows |
Provides information about hardware such as Memory, Power Sources, and
Processor on Windows systems
|
| Modifier and Type | Method and Description |
|---|---|
PowerSource.CapacityUnits |
PowerSource.getCapacityUnits()
Reports =the units of
PowerSource.getCurrentCapacity(),
PowerSource.getMaxCapacity(), and PowerSource.getDesignCapacity() |
static PowerSource.CapacityUnits |
PowerSource.CapacityUnits.valueOf(String name)
Returns the enum constant of this type with the specified name.
|
static PowerSource.CapacityUnits[] |
PowerSource.CapacityUnits.values()
Returns an array containing the constants of this enum type, in
the order they are declared.
|
| Modifier and Type | Method and Description |
|---|---|
PowerSource.CapacityUnits |
AbstractPowerSource.getCapacityUnits() |
| Constructor and Description |
|---|
AbstractPowerSource(String name,
String deviceName,
double remainingCapacityPercent,
double timeRemainingEstimated,
double timeRemainingInstant,
double powerUsageRate,
double voltage,
double amperage,
boolean powerOnLine,
boolean charging,
boolean discharging,
PowerSource.CapacityUnits capacityUnits,
int currentCapacity,
int maxCapacity,
int designCapacity,
int cycleCount,
String chemistry,
LocalDate manufactureDate,
String manufacturer,
String serialNumber,
double temperature) |
| Constructor and Description |
|---|
LinuxPowerSource(String psName,
String psDeviceName,
double psRemainingCapacityPercent,
double psTimeRemainingEstimated,
double psTimeRemainingInstant,
double psPowerUsageRate,
double psVoltage,
double psAmperage,
boolean psPowerOnLine,
boolean psCharging,
boolean psDischarging,
PowerSource.CapacityUnits psCapacityUnits,
int psCurrentCapacity,
int psMaxCapacity,
int psDesignCapacity,
int psCycleCount,
String psChemistry,
LocalDate psManufactureDate,
String psManufacturer,
String psSerialNumber,
double psTemperature) |
| Constructor and Description |
|---|
MacPowerSource(String psName,
String psDeviceName,
double psRemainingCapacityPercent,
double psTimeRemainingEstimated,
double psTimeRemainingInstant,
double psPowerUsageRate,
double psVoltage,
double psAmperage,
boolean psPowerOnLine,
boolean psCharging,
boolean psDischarging,
PowerSource.CapacityUnits psCapacityUnits,
int psCurrentCapacity,
int psMaxCapacity,
int psDesignCapacity,
int psCycleCount,
String psChemistry,
LocalDate psManufactureDate,
String psManufacturer,
String psSerialNumber,
double psTemperature) |
| Constructor and Description |
|---|
FreeBsdPowerSource(String psName,
String psDeviceName,
double psRemainingCapacityPercent,
double psTimeRemainingEstimated,
double psTimeRemainingInstant,
double psPowerUsageRate,
double psVoltage,
double psAmperage,
boolean psPowerOnLine,
boolean psCharging,
boolean psDischarging,
PowerSource.CapacityUnits psCapacityUnits,
int psCurrentCapacity,
int psMaxCapacity,
int psDesignCapacity,
int psCycleCount,
String psChemistry,
LocalDate psManufactureDate,
String psManufacturer,
String psSerialNumber,
double psTemperature) |
| Constructor and Description |
|---|
SolarisPowerSource(String psName,
String psDeviceName,
double psRemainingCapacityPercent,
double psTimeRemainingEstimated,
double psTimeRemainingInstant,
double psPowerUsageRate,
double psVoltage,
double psAmperage,
boolean psPowerOnLine,
boolean psCharging,
boolean psDischarging,
PowerSource.CapacityUnits psCapacityUnits,
int psCurrentCapacity,
int psMaxCapacity,
int psDesignCapacity,
int psCycleCount,
String psChemistry,
LocalDate psManufactureDate,
String psManufacturer,
String psSerialNumber,
double psTemperature) |
| Constructor and Description |
|---|
WindowsPowerSource(String psName,
String psDeviceName,
double psRemainingCapacityPercent,
double psTimeRemainingEstimated,
double psTimeRemainingInstant,
double psPowerUsageRate,
double psVoltage,
double psAmperage,
boolean psPowerOnLine,
boolean psCharging,
boolean psDischarging,
PowerSource.CapacityUnits psCapacityUnits,
int psCurrentCapacity,
int psMaxCapacity,
int psDesignCapacity,
int psCycleCount,
String psChemistry,
LocalDate psManufactureDate,
String psManufacturer,
String psSerialNumber,
double psTemperature) |
Copyright © 2010–2020 oshi. All rights reserved.