Uses of Interface
oshi.hardware.SoundCard
| Package | Description |
|---|---|
| oshi.hardware |
[oshi-core API] Provides cross-platform implementation to retrieve hardware
information such as CPU, Memory, Display, Disks, Network Interfaces, Power
Sources, Sensors, and USB Devices
|
| oshi.hardware.common |
Provides abstract classes for common code
|
| oshi.hardware.platform.linux |
Provides information about hardware such as Memory, Power Sources, and
Processor on Linux systems
|
| oshi.hardware.platform.mac |
Provides information about hardware such as Memory, Power Sources, and
Processor on Mac systems
|
| oshi.hardware.platform.unix.freebsd |
Provides information about hardware such as Memory, Power Sources, and
Processor on FreeBSD systems
|
| oshi.hardware.platform.unix.solaris |
Provides information about hardware such as Memory, Power Sources, and
Processor on Solaris systems
|
| oshi.hardware.platform.windows |
Provides information about hardware such as Memory, Power Sources, and
Processor on Windows systems
|
-
Uses of SoundCard in oshi.hardware
Methods in oshi.hardware that return SoundCard Modifier and Type Method Description SoundCard[]HardwareAbstractionLayer. getSoundCards()Instantiates an array ofSoundCardobjects, representing the Sound cards. -
Uses of SoundCard in oshi.hardware.common
Classes in oshi.hardware.common that implement SoundCard Modifier and Type Class Description classAbstractSoundCardAn abstract Sound Card -
Uses of SoundCard in oshi.hardware.platform.linux
Methods in oshi.hardware.platform.linux that return SoundCard Modifier and Type Method Description SoundCard[]LinuxHardwareAbstractionLayer. getSoundCards() -
Uses of SoundCard in oshi.hardware.platform.mac
Methods in oshi.hardware.platform.mac that return SoundCard Modifier and Type Method Description SoundCard[]MacHardwareAbstractionLayer. getSoundCards() -
Uses of SoundCard in oshi.hardware.platform.unix.freebsd
Methods in oshi.hardware.platform.unix.freebsd that return SoundCard Modifier and Type Method Description SoundCard[]FreeBsdHardwareAbstractionLayer. getSoundCards() -
Uses of SoundCard in oshi.hardware.platform.unix.solaris
Methods in oshi.hardware.platform.unix.solaris that return SoundCard Modifier and Type Method Description SoundCard[]SolarisHardwareAbstractionLayer. getSoundCards() -
Uses of SoundCard in oshi.hardware.platform.windows
Methods in oshi.hardware.platform.windows that return SoundCard Modifier and Type Method Description SoundCard[]WindowsHardwareAbstractionLayer. getSoundCards()