Uses of Interface
oshi.hardware.UsbDevice
Packages that use UsbDevice
Package
Description
[oshi-common API] Provides cross-platform implementation to retrieve hardware information such as CPU, Memory,
Display, Disks, Network Interfaces, Power Sources, Sensors, and USB Devices
Provides abstract classes for common code
Provides common Linux hardware implementations shared by JNA and FFM modules.
Native-free Linux hardware implementations using only procfs, sysfs, and command-line utilities.
Provides information about hardware such as Memory, Power Sources, and Processor on Mac systems
Provides common Unix hardware implementations shared by JNA and FFM modules.
Provides information about hardware such as Memory, Power Sources, and Processor on AIX systems
Provides abstract base classes and pure-Java implementations for FreeBSD hardware, shared by the JNA and FFM modules.
Provides information about hardware such as Memory, Power Sources, and Processor on NetBSD systems
Provides abstract base classes and pure-Java implementations for Solaris/illumos hardware, shared by the JNA and FFM
modules.
Provides information about hardware such as Memory, Power Sources, and Processor on Linux systems
Provides information about hardware such as Memory, Power Sources, and Processor on Mac systems
Provides JNA-backed hardware implementations for AIX.
Provides information about hardware such as Memory, Power Sources, and Processor on DragonFly BSD systems
Provides information about hardware such as Memory, Power Sources, and Processor on FreeBSD systems
Provides information about hardware such as Memory, Power Sources, and Processor on OpenBSD systems
Provides information about hardware such as Memory, Power Sources, and Processor on Solaris systems
Provides information about hardware such as Memory, Power Sources, and Processor on Windows systems
-
Uses of UsbDevice in oshi.hardware
Subinterfaces with type arguments of type UsbDevice in oshi.hardwareModifier and TypeInterfaceDescriptioninterfaceA USB device is a device connected via a USB port, possibly internally/permanently.Methods in oshi.hardware that return types with arguments of type UsbDeviceModifier and TypeMethodDescriptionUsbDevice.getConnectedDevices()Other devices connected to this hubHardwareAbstractionLayer.getUsbDevices(boolean tree) Instantiates a list ofUsbDeviceobjects, representing devices connected via a usb port (including internal devices). -
Uses of UsbDevice in oshi.hardware.common
Classes in oshi.hardware.common that implement UsbDeviceMethods in oshi.hardware.common that return types with arguments of type UsbDeviceMethods in oshi.hardware.common with parameters of type UsbDeviceMethod parameters in oshi.hardware.common with type arguments of type UsbDeviceModifier and TypeMethodDescriptionprotected static voidAbstractUsbDevice.addDevicesToList(List<UsbDevice> deviceList, List<UsbDevice> list) Recursively adds USB devices fromlisttodeviceList, depth-first.Constructor parameters in oshi.hardware.common with type arguments of type UsbDevice -
Uses of UsbDevice in oshi.hardware.common.platform.linux
Classes in oshi.hardware.common.platform.linux that implement UsbDeviceConstructor parameters in oshi.hardware.common.platform.linux with type arguments of type UsbDevice -
Uses of UsbDevice in oshi.hardware.common.platform.linux.nativefree
Classes in oshi.hardware.common.platform.linux.nativefree that implement UsbDeviceModifier and TypeClassDescriptionfinal classNative-free Linux USB device enumeration from/sys/bus/usb/devices/.Methods in oshi.hardware.common.platform.linux.nativefree that return types with arguments of type UsbDeviceModifier and TypeMethodDescriptionLinuxHardwareAbstractionLayerNF.getUsbDevices(boolean tree) LinuxUsbDeviceNF.getUsbDevices(boolean tree) Gets USB devices on this machine. -
Uses of UsbDevice in oshi.hardware.common.platform.mac
Classes in oshi.hardware.common.platform.mac that implement UsbDeviceConstructor parameters in oshi.hardware.common.platform.mac with type arguments of type UsbDevice -
Uses of UsbDevice in oshi.hardware.common.platform.unix
Classes in oshi.hardware.common.platform.unix that implement UsbDeviceModifier and TypeClassDescriptionfinal classShared USB device implementation for BSDs that useusbdevs -vto enumerate devices (NetBSD, OpenBSD).Methods in oshi.hardware.common.platform.unix that return types with arguments of type UsbDeviceModifier and TypeMethodDescriptionBsdUsbDevice.getUsbDevices(boolean tree) Instantiates a list ofUsbDeviceobjects, representing devices connected via a usb port (including internal devices).Constructor parameters in oshi.hardware.common.platform.unix with type arguments of type UsbDevice -
Uses of UsbDevice in oshi.hardware.common.platform.unix.aix
Classes in oshi.hardware.common.platform.unix.aix that implement UsbDeviceMethods in oshi.hardware.common.platform.unix.aix that return types with arguments of type UsbDeviceModifier and TypeMethodDescriptionAixUsbDevice.getUsbDevices(boolean tree, Supplier<List<String>> lscfg) Instantiates a list ofUsbDeviceobjects, representing devices connected via a usb port (including internal devices).Constructor parameters in oshi.hardware.common.platform.unix.aix with type arguments of type UsbDevice -
Uses of UsbDevice in oshi.hardware.common.platform.unix.freebsd
Classes in oshi.hardware.common.platform.unix.freebsd that implement UsbDeviceMethods in oshi.hardware.common.platform.unix.freebsd that return types with arguments of type UsbDeviceModifier and TypeMethodDescriptionFreeBsdUsbDevice.getUsbDevices(boolean tree) Instantiates a list ofUsbDeviceobjects, representing devices connected via a usb port (including internal devices).Constructor parameters in oshi.hardware.common.platform.unix.freebsd with type arguments of type UsbDevice -
Uses of UsbDevice in oshi.hardware.common.platform.unix.netbsd
Methods in oshi.hardware.common.platform.unix.netbsd that return types with arguments of type UsbDevice -
Uses of UsbDevice in oshi.hardware.common.platform.unix.solaris
Classes in oshi.hardware.common.platform.unix.solaris that implement UsbDeviceMethods in oshi.hardware.common.platform.unix.solaris that return types with arguments of type UsbDeviceModifier and TypeMethodDescriptionSolarisUsbDevice.getUsbDevices(boolean tree) Instantiates a list ofUsbDeviceobjects, representing devices connected via a usb port (including internal devices).Constructor parameters in oshi.hardware.common.platform.unix.solaris with type arguments of type UsbDevice -
Uses of UsbDevice in oshi.hardware.platform.linux
Classes in oshi.hardware.platform.linux that implement UsbDeviceModifier and TypeClassDescriptionfinal classLinux USB device helper using JNA/udev.Methods in oshi.hardware.platform.linux that return types with arguments of type UsbDeviceModifier and TypeMethodDescriptionLinuxHardwareAbstractionLayerJNA.getUsbDevices(boolean tree) LinuxUsbDeviceJNA.getUsbDevices(boolean tree) Instantiates a list ofUsbDeviceobjects, representing devices connected via a usb port (including internal devices). -
Uses of UsbDevice in oshi.hardware.platform.mac
Classes in oshi.hardware.platform.mac that implement UsbDeviceModifier and TypeClassDescriptionfinal classMac USB device helper using JNA/IOKit.Methods in oshi.hardware.platform.mac that return types with arguments of type UsbDeviceModifier and TypeMethodDescriptionMacHardwareAbstractionLayerJNA.getUsbDevices(boolean tree) MacUsbDeviceJNA.getUsbDevices(boolean tree) Instantiates a list ofUsbDeviceobjects, representing devices connected via a usb port (including internal devices). -
Uses of UsbDevice in oshi.hardware.platform.unix.aix
Methods in oshi.hardware.platform.unix.aix that return types with arguments of type UsbDevice -
Uses of UsbDevice in oshi.hardware.platform.unix.dragonflybsd
Methods in oshi.hardware.platform.unix.dragonflybsd that return types with arguments of type UsbDeviceModifier and TypeMethodDescriptionDragonFlyBsdHardwareAbstractionLayerJNA.getUsbDevices(boolean tree) -
Uses of UsbDevice in oshi.hardware.platform.unix.freebsd
Methods in oshi.hardware.platform.unix.freebsd that return types with arguments of type UsbDevice -
Uses of UsbDevice in oshi.hardware.platform.unix.openbsd
Methods in oshi.hardware.platform.unix.openbsd that return types with arguments of type UsbDevice -
Uses of UsbDevice in oshi.hardware.platform.unix.solaris
Methods in oshi.hardware.platform.unix.solaris that return types with arguments of type UsbDevice -
Uses of UsbDevice in oshi.hardware.platform.windows
Classes in oshi.hardware.platform.windows that implement UsbDeviceMethods in oshi.hardware.platform.windows that return types with arguments of type UsbDeviceModifier and TypeMethodDescriptionWindowsHardwareAbstractionLayerJNA.getUsbDevices(boolean tree) WindowsUsbDeviceJNA.getUsbDevices(boolean tree) Instantiates a list ofUsbDeviceobjects, representing devices connected via a usb port (including internal devices).Constructor parameters in oshi.hardware.platform.windows with type arguments of type UsbDevice