Uses of Interface
oshi.hardware.VirtualMemory
Packages that use VirtualMemory
Package
Description
[oshi-common API] Provides cross-platform implementation to retrieve hardware information such as CPU, Memory,
Display, Disks, Network Interfaces, Power Sources, Sensors, and USB Devices
Provides abstract classes for common code
Provides common Linux hardware implementations shared by JNA and FFM modules.
Provides information about hardware such as Memory, Power Sources, and Processor on Mac systems
Provides abstract base classes and pure-Java implementations for FreeBSD hardware, shared by the JNA and FFM modules.
Provides abstract base classes and pure-Java implementations for OpenBSD hardware, shared by the JNA and FFM modules.
Provides abstract base classes and pure-Java implementations for Solaris/illumos hardware, shared by the JNA and FFM
modules.
Provides information about hardware such as Memory, Power Sources, and Processor on FreeBSD systems
-
Uses of VirtualMemory in oshi.hardware
Methods in oshi.hardware that return VirtualMemoryModifier and TypeMethodDescriptionGlobalMemory.getVirtualMemory()Virtual memory, such as a swap file. -
Uses of VirtualMemory in oshi.hardware.common
Classes in oshi.hardware.common that implement VirtualMemory -
Uses of VirtualMemory in oshi.hardware.common.platform.linux
Methods in oshi.hardware.common.platform.linux that return VirtualMemory -
Uses of VirtualMemory in oshi.hardware.common.platform.mac
Classes in oshi.hardware.common.platform.mac that implement VirtualMemoryModifier and TypeClassDescriptionclassMemory obtained by host_statistics (vm_stat) and sysctl.Methods in oshi.hardware.common.platform.mac that return VirtualMemoryModifier and TypeMethodDescriptionprotected abstract VirtualMemoryMacGlobalMemory.createVirtualMemory()Creates the virtual memory instance.MacGlobalMemory.getVirtualMemory() -
Uses of VirtualMemory in oshi.hardware.common.platform.unix.freebsd
Classes in oshi.hardware.common.platform.unix.freebsd that implement VirtualMemoryMethods in oshi.hardware.common.platform.unix.freebsd that return VirtualMemoryModifier and TypeMethodDescriptionprotected abstract VirtualMemoryFreeBsdGlobalMemory.createVirtualMemory()Constructs the matching FreeBsdVirtualMemory concrete (JNA or FFM) for this instance.FreeBsdGlobalMemory.getVirtualMemory() -
Uses of VirtualMemory in oshi.hardware.common.platform.unix.openbsd
Classes in oshi.hardware.common.platform.unix.openbsd that implement VirtualMemoryMethods in oshi.hardware.common.platform.unix.openbsd that return VirtualMemoryModifier and TypeMethodDescriptionprotected abstract VirtualMemoryOpenBsdGlobalMemory.createVirtualMemory()Constructs the matching OpenBsdVirtualMemory concrete (JNA or FFM) for this instance.OpenBsdGlobalMemory.getVirtualMemory() -
Uses of VirtualMemory in oshi.hardware.common.platform.unix.solaris
Classes in oshi.hardware.common.platform.unix.solaris that implement VirtualMemoryMethods in oshi.hardware.common.platform.unix.solaris that return VirtualMemoryModifier and TypeMethodDescriptionprotected VirtualMemorySolarisGlobalMemory.createVirtualMemory()Constructs theSolarisVirtualMemorypaired with this GlobalMemory instance.SolarisGlobalMemory.getVirtualMemory() -
Uses of VirtualMemory in oshi.hardware.platform.unix.freebsd
Methods in oshi.hardware.platform.unix.freebsd that return VirtualMemoryModifier and TypeMethodDescriptionprotected VirtualMemoryFreeBsdGlobalMemoryJNA.createVirtualMemory()