Class AbstractSoundCard

java.lang.Object
oshi.hardware.common.AbstractSoundCard
All Implemented Interfaces:
SoundCard
Direct Known Subclasses:
FreeBsdSoundCard, LinuxSoundCard, MacSoundCard, SolarisSoundCard, WindowsSoundCard

public abstract class AbstractSoundCard
extends java.lang.Object
implements SoundCard
An abstract Sound Card
  • Constructor Summary

    Constructors 
    Constructor Description
    AbstractSoundCard​(java.lang.String kernelVersion, java.lang.String name, java.lang.String codec)
    Constructor for AbstractSoundCard.
  • Method Summary

    Modifier and Type Method Description
    java.lang.String getCodec()
    Retrieves the codec of the Sound card
    java.lang.String getDriverVersion()
    Retrieves the driver version currently in use in machine
    java.lang.String getName()
    Retrieves the full name of the card.
    void setCodec​(java.lang.String codec)
    Setter for the field codec.
    void setKernelVersion​(java.lang.String kernelVersion)
    Setter for the field kernelVersion.
    void setName​(java.lang.String name)
    Setter for the field name.
    java.lang.String toString()

    Methods inherited from class java.lang.Object

    clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, wait
  • Constructor Details

    • AbstractSoundCard

      public AbstractSoundCard​(java.lang.String kernelVersion, java.lang.String name, java.lang.String codec)

      Constructor for AbstractSoundCard.

      Parameters:
      kernelVersion - a String object.
      name - a String object.
      codec - a String object.
  • Method Details

    • getDriverVersion

      public java.lang.String getDriverVersion()
      Retrieves the driver version currently in use in machine
      Specified by:
      getDriverVersion in interface SoundCard
      Returns:
      The current and complete name of the driver version
    • setKernelVersion

      public void setKernelVersion​(java.lang.String kernelVersion)

      Setter for the field kernelVersion.

      Parameters:
      kernelVersion - a String object.
    • getName

      public java.lang.String getName()
      Retrieves the full name of the card.
      Specified by:
      getName in interface SoundCard
      Returns:
      The name of the card.
    • setName

      public void setName​(java.lang.String name)

      Setter for the field name.

      Parameters:
      name - a String object.
    • getCodec

      public java.lang.String getCodec()
      Retrieves the codec of the Sound card
      Specified by:
      getCodec in interface SoundCard
      Returns:
      The name of the codec of the sound card
    • setCodec

      public void setCodec​(java.lang.String codec)

      Setter for the field codec.

      Parameters:
      codec - a String object.
    • toString

      public java.lang.String toString()
      Overrides:
      toString in class java.lang.Object