Class AbstractVirtualMemory
java.lang.Object
oshi.hardware.common.AbstractVirtualMemory
- All Implemented Interfaces:
VirtualMemory
- Direct Known Subclasses:
FreeBsdVirtualMemory, MacVirtualMemory, OpenBsdVirtualMemory, SolarisVirtualMemory
Virtual Memory info.
-
Constructor Summary
Constructors -
Method Summary
Methods inherited from class Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface VirtualMemory
getSwapPagesIn, getSwapPagesOut, getSwapTotal, getSwapUsed, getVirtualInUse, getVirtualMaxModifier and TypeMethodDescriptionlongNumber of pages read from paging/swap file(s) to resolve hard page faults.longNumber of pages written to paging/swap file(s) to free up space in physical memory.longThe current size of the paging/swap file(s), in bytes.longThe current memory committed to the paging/swap file(s), in byteslongThe memory currently committed by the system, in bytes.longThe maximum memory that can be committed by the system without extending the paging file(s), in bytes.
-
Constructor Details
-
AbstractVirtualMemory
protected AbstractVirtualMemory()Default constructor.
-
-
Method Details
-
toString
-