Uses of Class
oshi.hardware.common.AbstractBaseboard

Packages that use AbstractBaseboard
Package
Description
Provides information about hardware such as Memory, Power Sources, and Processor on Mac systems
Provides common Unix hardware implementations shared by JNA and FFM modules.
Provides common implementations for Windows hardware information shared between JNA and FFM implementations.