Uses of Class
oshi.hardware.common.AbstractGlobalMemory
Packages that use AbstractGlobalMemory
Package
Description
Provides common Linux hardware implementations shared by JNA and FFM modules.
Provides information about hardware such as Memory, Power Sources, and Processor on Mac systems
Provides abstract base classes and pure-Java implementations for FreeBSD hardware, shared by the JNA and FFM modules.
Provides abstract base classes and pure-Java implementations for OpenBSD hardware, shared by the JNA and FFM modules.
Provides abstract base classes and pure-Java implementations for Solaris/illumos hardware, shared by the JNA and FFM
modules.
Provides common implementations for Windows hardware information shared between JNA and FFM implementations.
Provides information about hardware such as Memory, Power Sources, and Processor on FreeBSD systems
-
Uses of AbstractGlobalMemory in oshi.hardware.common.platform.linux
Subclasses of AbstractGlobalMemory in oshi.hardware.common.platform.linuxModifier and TypeClassDescriptionfinal classMemory obtained by /proc/meminfo and sysinfo.totalram -
Uses of AbstractGlobalMemory in oshi.hardware.common.platform.mac
Subclasses of AbstractGlobalMemory in oshi.hardware.common.platform.macModifier and TypeClassDescriptionclassMemory obtained by host_statistics (vm_stat) and sysctl. -
Uses of AbstractGlobalMemory in oshi.hardware.common.platform.unix.freebsd
Subclasses of AbstractGlobalMemory in oshi.hardware.common.platform.unix.freebsd -
Uses of AbstractGlobalMemory in oshi.hardware.common.platform.unix.openbsd
Subclasses of AbstractGlobalMemory in oshi.hardware.common.platform.unix.openbsd -
Uses of AbstractGlobalMemory in oshi.hardware.common.platform.unix.solaris
Subclasses of AbstractGlobalMemory in oshi.hardware.common.platform.unix.solaris -
Uses of AbstractGlobalMemory in oshi.hardware.common.platform.windows
Subclasses of AbstractGlobalMemory in oshi.hardware.common.platform.windowsModifier and TypeClassDescriptionclassCommon Windows global memory logic shared between JNA and FFM implementations. -
Uses of AbstractGlobalMemory in oshi.hardware.platform.unix.freebsd
Subclasses of AbstractGlobalMemory in oshi.hardware.platform.unix.freebsd