Uses of Class
oshi.hardware.common.AbstractGraphicsCard
Packages that use AbstractGraphicsCard
Package
Description
Provides common Linux hardware implementations shared by JNA and FFM modules.
Provides information about hardware such as Memory, Power Sources, and Processor on Mac systems
-
Uses of AbstractGraphicsCard in oshi.hardware.common.platform.linux
Subclasses of AbstractGraphicsCard in oshi.hardware.common.platform.linuxModifier and TypeClassDescriptionclassGraphics card info obtained by lshw, with dynamic metrics from sysfs DRM driver files. -
Uses of AbstractGraphicsCard in oshi.hardware.common.platform.mac
Subclasses of AbstractGraphicsCard in oshi.hardware.common.platform.macModifier and TypeClassDescriptionclassGraphics card info obtained by system_profiler SPDisplaysDataType.