Uses of Class
oshi.hardware.common.AbstractHWDiskStore
Packages that use AbstractHWDiskStore
Package
Description
Provides common Linux hardware implementations shared by JNA and FFM modules.
Native-free Linux hardware implementations using only procfs, sysfs, and command-line utilities.
Provides information about hardware such as Memory, Power Sources, and Processor on Mac systems
Provides information about hardware such as Memory, Power Sources, and Processor on AIX systems
Provides abstract base classes and pure-Java implementations for FreeBSD hardware, shared by the JNA and FFM modules.
Provides information about hardware such as Memory, Power Sources, and Processor on NetBSD systems
Provides abstract base classes and pure-Java implementations for OpenBSD hardware, shared by the JNA and FFM modules.
Provides abstract base classes and pure-Java implementations for Solaris/illumos hardware, shared by the JNA and FFM
modules.
Provides common implementations for Windows hardware information shared between JNA and FFM implementations.
Provides information about hardware such as Memory, Power Sources, and Processor on Linux systems
Provides information about hardware such as Memory, Power Sources, and Processor on Mac systems
Provides JNA-backed hardware implementations for AIX.
Provides information about hardware such as Memory, Power Sources, and Processor on FreeBSD systems
Provides information about hardware such as Memory, Power Sources, and Processor on OpenBSD systems
Provides information about hardware such as Memory, Power Sources, and Processor on Solaris systems
Provides information about hardware such as Memory, Power Sources, and Processor on Windows systems
-
Uses of AbstractHWDiskStore in oshi.hardware.common.platform.linux
Subclasses of AbstractHWDiskStore in oshi.hardware.common.platform.linux -
Uses of AbstractHWDiskStore in oshi.hardware.common.platform.linux.nativefree
Subclasses of AbstractHWDiskStore in oshi.hardware.common.platform.linux.nativefreeModifier and TypeClassDescriptionfinal classNative-free Linux disk store implementation. -
Uses of AbstractHWDiskStore in oshi.hardware.common.platform.mac
Subclasses of AbstractHWDiskStore in oshi.hardware.common.platform.macModifier and TypeClassDescriptionclassBase class for macOS HWDiskStore implementations. -
Uses of AbstractHWDiskStore in oshi.hardware.common.platform.unix.aix
Subclasses of AbstractHWDiskStore in oshi.hardware.common.platform.unix.aix -
Uses of AbstractHWDiskStore in oshi.hardware.common.platform.unix.freebsd
Subclasses of AbstractHWDiskStore in oshi.hardware.common.platform.unix.freebsd -
Uses of AbstractHWDiskStore in oshi.hardware.common.platform.unix.netbsd
Subclasses of AbstractHWDiskStore in oshi.hardware.common.platform.unix.netbsd -
Uses of AbstractHWDiskStore in oshi.hardware.common.platform.unix.openbsd
Subclasses of AbstractHWDiskStore in oshi.hardware.common.platform.unix.openbsd -
Uses of AbstractHWDiskStore in oshi.hardware.common.platform.unix.solaris
Subclasses of AbstractHWDiskStore in oshi.hardware.common.platform.unix.solaris -
Uses of AbstractHWDiskStore in oshi.hardware.common.platform.windows
Subclasses of AbstractHWDiskStore in oshi.hardware.common.platform.windowsModifier and TypeClassDescriptionclassCommon Windows hard disk implementation shared between JNA and FFM. -
Uses of AbstractHWDiskStore in oshi.hardware.platform.linux
Subclasses of AbstractHWDiskStore in oshi.hardware.platform.linuxModifier and TypeClassDescriptionfinal classJNA-based Linux hard disk implementation. -
Uses of AbstractHWDiskStore in oshi.hardware.platform.mac
Subclasses of AbstractHWDiskStore in oshi.hardware.platform.mac -
Uses of AbstractHWDiskStore in oshi.hardware.platform.unix.aix
Subclasses of AbstractHWDiskStore in oshi.hardware.platform.unix.aix -
Uses of AbstractHWDiskStore in oshi.hardware.platform.unix.freebsd
Subclasses of AbstractHWDiskStore in oshi.hardware.platform.unix.freebsdModifier and TypeClassDescriptionfinal classFreeBSD hard disk implementation. -
Uses of AbstractHWDiskStore in oshi.hardware.platform.unix.openbsd
Subclasses of AbstractHWDiskStore in oshi.hardware.platform.unix.openbsdModifier and TypeClassDescriptionfinal classOpenBSD hard disk implementation. -
Uses of AbstractHWDiskStore in oshi.hardware.platform.unix.solaris
Subclasses of AbstractHWDiskStore in oshi.hardware.platform.unix.solarisModifier and TypeClassDescriptionfinal classJNA-backed Solaris HWDiskStore. -
Uses of AbstractHWDiskStore in oshi.hardware.platform.windows
Subclasses of AbstractHWDiskStore in oshi.hardware.platform.windowsModifier and TypeClassDescriptionfinal classWindows hard disk implementation using JNA.