Uses of Class
oshi.hardware.common.AbstractPowerSource
Packages that use AbstractPowerSource
Package
Description
Provides common Linux hardware implementations shared by JNA and FFM modules.
Provides information about hardware such as Memory, Power Sources, and Processor on Mac systems
Provides abstract base classes and pure-Java implementations for FreeBSD hardware, shared by the JNA and FFM modules.
Provides abstract base classes and pure-Java implementations for OpenBSD hardware, shared by the JNA and FFM modules.
Provides common implementations for Windows hardware information shared between JNA and FFM implementations.
Provides information about hardware such as Memory, Power Sources, and Processor on Linux systems
Provides information about hardware such as Memory, Power Sources, and Processor on Mac systems
Provides information about hardware such as Memory, Power Sources, and Processor on AIX systems
Provides information about hardware such as Memory, Power Sources, and Processor on FreeBSD systems
Provides information about hardware such as Memory, Power Sources, and Processor on NetBSD systems
Provides information about hardware such as Memory, Power Sources, and Processor on Solaris systems
Provides information about hardware such as Memory, Power Sources, and Processor on Windows systems
-
Uses of AbstractPowerSource in oshi.hardware.common.platform.linux
Subclasses of AbstractPowerSource in oshi.hardware.common.platform.linux -
Uses of AbstractPowerSource in oshi.hardware.common.platform.mac
Subclasses of AbstractPowerSource in oshi.hardware.common.platform.mac -
Uses of AbstractPowerSource in oshi.hardware.common.platform.unix.freebsd
Subclasses of AbstractPowerSource in oshi.hardware.common.platform.unix.freebsd -
Uses of AbstractPowerSource in oshi.hardware.common.platform.unix.openbsd
Subclasses of AbstractPowerSource in oshi.hardware.common.platform.unix.openbsd -
Uses of AbstractPowerSource in oshi.hardware.common.platform.windows
Subclasses of AbstractPowerSource in oshi.hardware.common.platform.windows -
Uses of AbstractPowerSource in oshi.hardware.platform.linux
Subclasses of AbstractPowerSource in oshi.hardware.platform.linuxModifier and TypeClassDescriptionfinal classJNA-based Linux power source implementation. -
Uses of AbstractPowerSource in oshi.hardware.platform.mac
Subclasses of AbstractPowerSource in oshi.hardware.platform.mac -
Uses of AbstractPowerSource in oshi.hardware.platform.unix.aix
Subclasses of AbstractPowerSource in oshi.hardware.platform.unix.aix -
Uses of AbstractPowerSource in oshi.hardware.platform.unix.freebsd
Subclasses of AbstractPowerSource in oshi.hardware.platform.unix.freebsd -
Uses of AbstractPowerSource in oshi.hardware.platform.unix.netbsd
Subclasses of AbstractPowerSource in oshi.hardware.platform.unix.netbsd -
Uses of AbstractPowerSource in oshi.hardware.platform.unix.solaris
Subclasses of AbstractPowerSource in oshi.hardware.platform.unix.solaris -
Uses of AbstractPowerSource in oshi.hardware.platform.windows
Subclasses of AbstractPowerSource in oshi.hardware.platform.windowsModifier and TypeClassDescriptionfinal classJNA-based Windows power source implementation.