Uses of Class
oshi.hardware.common.AbstractSoundCard
| Package | Description |
|---|---|
| oshi.hardware.platform.linux |
Provides information about hardware such as Memory, Power Sources, and
Processor on Linux systems
|
| oshi.hardware.platform.mac |
Provides information about hardware such as Memory, Power Sources, and
Processor on Mac systems
|
| oshi.hardware.platform.unix.freebsd |
Provides information about hardware such as Memory, Power Sources, and
Processor on FreeBSD systems
|
| oshi.hardware.platform.unix.solaris |
Provides information about hardware such as Memory, Power Sources, and
Processor on Solaris systems
|
| oshi.hardware.platform.windows |
Provides information about hardware such as Memory, Power Sources, and
Processor on Windows systems
|
-
Uses of AbstractSoundCard in oshi.hardware.platform.linux
Subclasses of AbstractSoundCard in oshi.hardware.platform.linux Modifier and Type Class Description classLinuxSoundCardSound card data obtained via /proc/asound directory -
Uses of AbstractSoundCard in oshi.hardware.platform.mac
Subclasses of AbstractSoundCard in oshi.hardware.platform.mac Modifier and Type Class Description classMacSoundCardSound card data obtained via system_profiler -
Uses of AbstractSoundCard in oshi.hardware.platform.unix.freebsd
Subclasses of AbstractSoundCard in oshi.hardware.platform.unix.freebsd Modifier and Type Class Description classFreeBsdSoundCardFreeBSD soundcard. -
Uses of AbstractSoundCard in oshi.hardware.platform.unix.solaris
Subclasses of AbstractSoundCard in oshi.hardware.platform.unix.solaris Modifier and Type Class Description classSolarisSoundCardSolaris Sound Card. -
Uses of AbstractSoundCard in oshi.hardware.platform.windows
Subclasses of AbstractSoundCard in oshi.hardware.platform.windows Modifier and Type Class Description classWindowsSoundCardSound Card data obtained from registry