Uses of Class
oshi.hardware.common.AbstractVirtualMemory
Packages that use AbstractVirtualMemory
Package
Description
Provides information about hardware such as Memory, Power Sources, and Processor on Mac systems
Provides information about hardware such as Memory, Power Sources, and Processor on AIX systems
Provides abstract base classes and pure-Java implementations for FreeBSD hardware, shared by the JNA and FFM modules.
Provides abstract base classes and pure-Java implementations for OpenBSD hardware, shared by the JNA and FFM modules.
Provides abstract base classes and pure-Java implementations for Solaris/illumos hardware, shared by the JNA and FFM
modules.
-
Uses of AbstractVirtualMemory in oshi.hardware.common.platform.mac
Subclasses of AbstractVirtualMemory in oshi.hardware.common.platform.macModifier and TypeClassDescriptionclassMemory obtained by host_statistics (vm_stat) and sysctl. -
Uses of AbstractVirtualMemory in oshi.hardware.common.platform.unix.aix
Subclasses of AbstractVirtualMemory in oshi.hardware.common.platform.unix.aix -
Uses of AbstractVirtualMemory in oshi.hardware.common.platform.unix.freebsd
Subclasses of AbstractVirtualMemory in oshi.hardware.common.platform.unix.freebsd -
Uses of AbstractVirtualMemory in oshi.hardware.common.platform.unix.openbsd
Subclasses of AbstractVirtualMemory in oshi.hardware.common.platform.unix.openbsd -
Uses of AbstractVirtualMemory in oshi.hardware.common.platform.unix.solaris
Subclasses of AbstractVirtualMemory in oshi.hardware.common.platform.unix.solaris