Class LinuxHardwareAbstractionLayer
java.lang.Object
oshi.hardware.common.AbstractHardwareAbstractionLayer
oshi.hardware.common.platform.linux.LinuxHardwareAbstractionLayer
- All Implemented Interfaces:
HardwareAbstractionLayer
- Direct Known Subclasses:
LinuxHardwareAbstractionLayerJNA, LinuxHardwareAbstractionLayerNF
@ThreadSafe
public abstract class LinuxHardwareAbstractionLayer
extends AbstractHardwareAbstractionLayer
LinuxHardwareAbstractionLayer class.
-
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionInstantiates the platform-specificComputerSystemobjectabstract GlobalMemoryInstantiates the platform-specificGlobalMemoryobjectabstract CentralProcessorInstantiates the platform-specificCentralProcessorobjectInstantiates the platform-specificSensorsobjectInstantiates a list ofBluetoothDeviceobjects, representing Bluetooth devices (paired or connected) known to the system.Instantiates a list ofDisplayobjects, representing monitors or other video output devices.abstract List<GraphicsCard> Instantiates a list ofGraphicsCardobjects, representing the Graphics cards.Instantiates a list ofSoundCardobjects, representing the Sound cards.Methods inherited from class AbstractHardwareAbstractionLayer
getComputerSystem, getMemory, getNetworkIFs, getProcessor, getSensorsModifier and TypeMethodDescriptionInstantiates aComputerSystemobject.Instantiates aGlobalMemoryobject.Gets a list of non-localNetworkIFobjects, representing a network interface.Instantiates aCentralProcessorobject.Instantiates aSensorsobject, representing CPU temperature and fan speed.Methods inherited from class Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, waitMethods inherited from interface HardwareAbstractionLayer
getDiskStores, getLogicalVolumeGroups, getNetworkIFs, getPowerSources, getPrinters, getUsbDevicesModifier and TypeMethodDescriptionInstantiates a list ofHWDiskStoreobjects, representing physical hard disks or other similar storage devices.default List<LogicalVolumeGroup> Instantiates a list ofLogicalVolumeGroupobjects, representing a storage pool or group of devices, partitions, volumes, or other implementation specific means of file storage.getNetworkIFs(boolean includeLocalInterfaces) Gets a listNetworkIFobjects, representing a network interface.Instantiates a list ofPowerSourceobjects, representing batteries, etc.Instantiates a list ofPrinterobjects, representing printers.getUsbDevices(boolean tree) Instantiates a list ofUsbDeviceobjects, representing devices connected via a usb port (including internal devices).
-
Constructor Details
-
LinuxHardwareAbstractionLayer
protected LinuxHardwareAbstractionLayer()Default constructor.
-
-
Method Details
-
createComputerSystem
Description copied from class:AbstractHardwareAbstractionLayerInstantiates the platform-specificComputerSystemobject- Specified by:
createComputerSystemin classAbstractHardwareAbstractionLayer- Returns:
- platform-specific
ComputerSystemobject
-
createMemory
Description copied from class:AbstractHardwareAbstractionLayerInstantiates the platform-specificGlobalMemoryobject- Specified by:
createMemoryin classAbstractHardwareAbstractionLayer- Returns:
- platform-specific
GlobalMemoryobject
-
createProcessor
Description copied from class:AbstractHardwareAbstractionLayerInstantiates the platform-specificCentralProcessorobject- Specified by:
createProcessorin classAbstractHardwareAbstractionLayer- Returns:
- platform-specific
CentralProcessorobject
-
createSensors
Description copied from class:AbstractHardwareAbstractionLayerInstantiates the platform-specificSensorsobject- Specified by:
createSensorsin classAbstractHardwareAbstractionLayer- Returns:
- platform-specific
Sensorsobject
-
getDisplays
Description copied from interface:HardwareAbstractionLayerInstantiates a list ofDisplayobjects, representing monitors or other video output devices.- Returns:
- A list of Display objects or an empty list if none are present.
-
getSoundCards
Description copied from interface:HardwareAbstractionLayerInstantiates a list ofSoundCardobjects, representing the Sound cards.- Returns:
- A list of SoundCard objects or an empty list if none are present.
-
getBluetoothDevices
Description copied from interface:HardwareAbstractionLayerInstantiates a list ofBluetoothDeviceobjects, representing Bluetooth devices (paired or connected) known to the system.- Returns:
- A list of BluetoothDevice objects or an empty list if none are present.
-
getGraphicsCards
Description copied from interface:HardwareAbstractionLayerInstantiates a list ofGraphicsCardobjects, representing the Graphics cards.- Returns:
- A list of objects or an empty list if none are present.
-