Enum Class LinuxPowerSource.Prop

java.lang.Object
java.lang.Enum<LinuxPowerSource.Prop>
oshi.hardware.common.platform.linux.LinuxPowerSource.Prop
All Implemented Interfaces:
Serializable, Comparable<LinuxPowerSource.Prop>, Constable
Enclosing class:
LinuxPowerSource

protected static enum LinuxPowerSource.Prop extends Enum<LinuxPowerSource.Prop>
Power supply uevent properties from sysfs.
  • Enum Constant Details

    • POWER_SUPPLY_NAME

      public static final LinuxPowerSource.Prop POWER_SUPPLY_NAME
      Power supply name.
    • POWER_SUPPLY_STATUS

      public static final LinuxPowerSource.Prop POWER_SUPPLY_STATUS
      Power supply status (Charging, Discharging, etc.).
    • POWER_SUPPLY_CAPACITY

      public static final LinuxPowerSource.Prop POWER_SUPPLY_CAPACITY
      Remaining capacity percentage.
    • POWER_SUPPLY_PRESENT

      public static final LinuxPowerSource.Prop POWER_SUPPLY_PRESENT
      Whether the power supply is present.
    • POWER_SUPPLY_ONLINE

      public static final LinuxPowerSource.Prop POWER_SUPPLY_ONLINE
      Whether the power supply is online.
    • POWER_SUPPLY_ENERGY_NOW

      public static final LinuxPowerSource.Prop POWER_SUPPLY_ENERGY_NOW
      Current energy in microwatt-hours.
    • POWER_SUPPLY_CHARGE_NOW

      public static final LinuxPowerSource.Prop POWER_SUPPLY_CHARGE_NOW
      Current charge in microamp-hours.
    • POWER_SUPPLY_ENERGY_FULL

      public static final LinuxPowerSource.Prop POWER_SUPPLY_ENERGY_FULL
      Full energy capacity in microwatt-hours.
    • POWER_SUPPLY_CHARGE_FULL

      public static final LinuxPowerSource.Prop POWER_SUPPLY_CHARGE_FULL
      Full charge capacity in microamp-hours.
    • POWER_SUPPLY_ENERGY_FULL_DESIGN

      public static final LinuxPowerSource.Prop POWER_SUPPLY_ENERGY_FULL_DESIGN
      Design energy capacity in microwatt-hours.
    • POWER_SUPPLY_CHARGE_FULL_DESIGN

      public static final LinuxPowerSource.Prop POWER_SUPPLY_CHARGE_FULL_DESIGN
      Design charge capacity in microamp-hours.
    • POWER_SUPPLY_VOLTAGE_NOW

      public static final LinuxPowerSource.Prop POWER_SUPPLY_VOLTAGE_NOW
      Current voltage in microvolts.
    • POWER_SUPPLY_POWER_NOW

      public static final LinuxPowerSource.Prop POWER_SUPPLY_POWER_NOW
      Current power draw in microwatts.
    • POWER_SUPPLY_CURRENT_NOW

      public static final LinuxPowerSource.Prop POWER_SUPPLY_CURRENT_NOW
      Current draw in microamps.
    • POWER_SUPPLY_CYCLE_COUNT

      public static final LinuxPowerSource.Prop POWER_SUPPLY_CYCLE_COUNT
      Battery cycle count.
    • POWER_SUPPLY_TECHNOLOGY

      public static final LinuxPowerSource.Prop POWER_SUPPLY_TECHNOLOGY
      Battery technology/chemistry.
    • POWER_SUPPLY_MODEL_NAME

      public static final LinuxPowerSource.Prop POWER_SUPPLY_MODEL_NAME
      Model name.
    • POWER_SUPPLY_MANUFACTURER

      public static final LinuxPowerSource.Prop POWER_SUPPLY_MANUFACTURER
      Manufacturer name.
    • POWER_SUPPLY_SERIAL_NUMBER

      public static final LinuxPowerSource.Prop POWER_SUPPLY_SERIAL_NUMBER
      Serial number.
    • POWER_SUPPLY_TEMP

      public static final LinuxPowerSource.Prop POWER_SUPPLY_TEMP
      Temperature in tenths of degrees Celsius.
    • POWER_SUPPLY_TIME_TO_EMPTY_NOW

      public static final LinuxPowerSource.Prop POWER_SUPPLY_TIME_TO_EMPTY_NOW
      Estimated time to empty in seconds.
    • POWER_SUPPLY_TIME_TO_FULL_NOW

      public static final LinuxPowerSource.Prop POWER_SUPPLY_TIME_TO_FULL_NOW
      Estimated time to full in seconds.
    • POWER_SUPPLY_MANUFACTURE_YEAR

      public static final LinuxPowerSource.Prop POWER_SUPPLY_MANUFACTURE_YEAR
      Manufacture year.
    • POWER_SUPPLY_MANUFACTURE_MONTH

      public static final LinuxPowerSource.Prop POWER_SUPPLY_MANUFACTURE_MONTH
      Manufacture month.
    • POWER_SUPPLY_MANUFACTURE_DAY

      public static final LinuxPowerSource.Prop POWER_SUPPLY_MANUFACTURE_DAY
      Manufacture day.
  • Method Details

    • values

      public static LinuxPowerSource.Prop[] values()
      Returns an array containing the constants of this enum class, in the order they are declared.
      Returns:
      an array containing the constants of this enum class, in the order they are declared
    • valueOf

      public static LinuxPowerSource.Prop valueOf(String name)
      Returns the enum constant of this class with the specified name. The string must match exactly an identifier used to declare an enum constant in this class. (Extraneous whitespace characters are not permitted.)
      Parameters:
      name - the name of the enum constant to be returned.
      Returns:
      the enum constant with the specified name
      Throws:
      IllegalArgumentException - if this enum class has no constant with the specified name
      NullPointerException - if the argument is null