Class LinuxPowerSourceJNA

All Implemented Interfaces:
PowerSource

@ThreadSafe public final class LinuxPowerSourceJNA extends LinuxPowerSource
JNA-based Linux power source implementation.
  • Method Details

    • queryPowerSources

      protected List<PowerSource> queryPowerSources()
      Description copied from class: AbstractPowerSource
      Returns a fresh list of power sources for this platform, used by AbstractPowerSource.updateAttributes(). Each concrete subclass implements this by delegating to its own static getPowerSources() factory method.
      Overrides:
      queryPowerSources in class LinuxPowerSource
      Returns:
      A list of PowerSource objects representing batteries, etc.
    • getPowerSources

      public static List<PowerSource> getPowerSources()
      Gets Battery Information
      Returns:
      A list of PowerSource objects representing batteries, etc.