Uses of Class
oshi.hardware.platform.linux.LinuxSoundCard
| Package | Description |
|---|---|
| oshi.hardware.platform.linux |
Provides information about hardware such as Memory, Power Sources, and
Processor on Linux systems
|
-
Uses of LinuxSoundCard in oshi.hardware.platform.linux
Methods in oshi.hardware.platform.linux that return types with arguments of type LinuxSoundCard Modifier and Type Method Description static java.util.List<LinuxSoundCard>LinuxSoundCard. getSoundCards()public method used byAbstractHardwareAbstractionLayerto access the sound cards.