Class WindowsPowerSourceJNA
java.lang.Object
oshi.hardware.common.AbstractPowerSource
oshi.hardware.common.platform.windows.WindowsPowerSource
oshi.hardware.platform.windows.WindowsPowerSourceJNA
- All Implemented Interfaces:
PowerSource
JNA-based Windows power source implementation.
-
Nested Class Summary
Nested classes/interfaces inherited from interface PowerSource
PowerSource.CapacityUnitsModifier and TypeInterfaceDescriptionstatic enumUnits of Battery Capacity -
Field Summary
Fields inherited from class WindowsPowerSource
BATTERY_CAPACITY_RELATIVE, BATTERY_CHARGING, BATTERY_DEVICE_NAME_LEVEL, BATTERY_DISCHARGING, BATTERY_ESTIMATED_TIME_LEVEL, BATTERY_INFORMATION_LEVEL, BATTERY_IS_SHORT_TERM, BATTERY_MANUFACTURE_DATE_LEVEL, BATTERY_MANUFACTURE_NAME_LEVEL, BATTERY_POWER_ON_LINE, BATTERY_SERIAL_NUMBER_LEVEL, BATTERY_SYSTEM_BATTERY, BATTERY_TEMPERATURE_LEVEL, IOCTL_BATTERY_QUERY_INFORMATION, IOCTL_BATTERY_QUERY_STATUS, IOCTL_BATTERY_QUERY_TAGModifier and TypeFieldDescriptionprotected static final intBattery capability flag: capacity is relative (percent).protected static final intBattery power state flag: charging.protected static final intQuery information level: device name.protected static final intBattery power state flag: discharging.protected static final intQuery information level: estimated time remaining.protected static final intQuery information level: battery information.protected static final intBattery capability flag: short-term (UPS).protected static final intQuery information level: manufacture date.protected static final intQuery information level: manufacturer name.protected static final intBattery power state flag: AC power online.protected static final intQuery information level: serial number.protected static final intBattery capability flag: system battery.protected static final intQuery information level: temperature.protected static final intIOCTL code to query battery information.protected static final intIOCTL code to query battery status.protected static final intIOCTL code to query battery tag. -
Constructor Summary
ConstructorsConstructorDescriptionWindowsPowerSourceJNA(String psName, String psDeviceName, double psRemainingCapacityPercent, double psTimeRemainingEstimated, double psTimeRemainingInstant, double psPowerUsageRate, double psVoltage, double psAmperage, boolean psPowerOnLine, boolean psCharging, boolean psDischarging, PowerSource.CapacityUnits psCapacityUnits, int psCurrentCapacity, int psMaxCapacity, int psDesignCapacity, int psCycleCount, String psChemistry, LocalDate psManufactureDate, String psManufacturer, String psSerialNumber, double psTemperature) -
Method Summary
Modifier and TypeMethodDescriptionstatic List<PowerSource> Gets Battery Information.protected List<PowerSource> Returns a fresh list of power sources for this platform, used byAbstractPowerSource.updateAttributes().Methods inherited from class AbstractPowerSource
getAmperage, getCapacityUnits, getChemistry, getCurrentCapacity, getCycleCount, getDesignCapacity, getDeviceName, getManufactureDate, getManufacturer, getMaxCapacity, getName, getPowerUsageRate, getRemainingCapacityPercent, getSerialNumber, getTemperature, getTimeRemainingEstimated, getTimeRemainingInstant, getVoltage, isCharging, isDischarging, isPowerOnLine, toString, updateAttributesModifier and TypeMethodDescriptiondoubleAmperage of the battery, in milliAmperes (mA).Reports =the units ofPowerSource.getCurrentCapacity(),PowerSource.getMaxCapacity(), andPowerSource.getDesignCapacity()The battery chemistry (e.g., Lithium Ion).intThe current (remaining) capacity of the battery.intThe cycle count of the battery, if known.intThe design (original) capacity of the battery.Name of the power source at the device level.The battery's date of manufacture.The name of the battery's manufacturer.intThe maximum capacity of the battery.getName()Name of the power source at the Operating System level.doublePower Usage Rate of the battery, in milliWatts (mW).doubleEstimated remaining capacity as a fraction of max capacity.The battery's serial number.doubleThe battery's temperature, in degrees Celsius.doubleEstimated time remaining on the power source, in seconds, as reported by the operating system.doubleEstimated time remaining on the power source, in seconds, as reported by the battery.doubleVoltage of the battery, in Volts.booleanReports whether the battery is charging.booleanReports whether the battery is discharging.booleanReports whether the device is plugged in to an external power source.toString()booleanUpdates statistics on this battery.
-
Constructor Details
-
WindowsPowerSourceJNA
public WindowsPowerSourceJNA(String psName, String psDeviceName, double psRemainingCapacityPercent, double psTimeRemainingEstimated, double psTimeRemainingInstant, double psPowerUsageRate, double psVoltage, double psAmperage, boolean psPowerOnLine, boolean psCharging, boolean psDischarging, PowerSource.CapacityUnits psCapacityUnits, int psCurrentCapacity, int psMaxCapacity, int psDesignCapacity, int psCycleCount, String psChemistry, LocalDate psManufactureDate, String psManufacturer, String psSerialNumber, double psTemperature)
-
-
Method Details
-
queryPowerSources
Description copied from class:AbstractPowerSourceReturns a fresh list of power sources for this platform, used byAbstractPowerSource.updateAttributes(). Each concrete subclass implements this by delegating to its own staticgetPowerSources()factory method.- Specified by:
queryPowerSourcesin classAbstractPowerSource- Returns:
- A list of PowerSource objects representing batteries, etc.
-
getPowerSources
Gets Battery Information.- Returns:
- A list of PowerSource objects representing batteries, etc.
-