Class WindowsSoundCard

java.lang.Object
oshi.hardware.common.AbstractSoundCard
oshi.hardware.platform.windows.WindowsSoundCard
All Implemented Interfaces:
SoundCard

public class WindowsSoundCard
extends AbstractSoundCard
Sound Card data obtained from registry
  • Constructor Summary

    Constructors 
    Constructor Description
    WindowsSoundCard​(java.lang.String kernelVersion, java.lang.String name, java.lang.String codec)
    Constructor for WindowsSoundCard.
  • Method Summary

    Modifier and Type Method Description
    static java.util.List<WindowsSoundCard> getSoundCards()
    Returns Windows audio device driver information, which represents the closest proxy we have to sound cards.

    Methods inherited from class oshi.hardware.common.AbstractSoundCard

    getCodec, getDriverVersion, getName, setCodec, setKernelVersion, setName, toString

    Methods inherited from class java.lang.Object

    clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, wait
  • Constructor Details

    • WindowsSoundCard

      public WindowsSoundCard​(java.lang.String kernelVersion, java.lang.String name, java.lang.String codec)

      Constructor for WindowsSoundCard.

      Parameters:
      kernelVersion - a String object.
      name - a String object.
      codec - a String object.
  • Method Details

    • getSoundCards

      public static java.util.List<WindowsSoundCard> getSoundCards()
      Returns Windows audio device driver information, which represents the closest proxy we have to sound cards.

      NOTE : The reason why the codec name is same as the card name is because windows does not provide the name of the codec chip but sometimes the name of the card returned is infact the name of the codec chip also. Example : Realtek ALC887 HD Audio Device

      Returns:
      List of sound cards