Uses of Class
oshi.hardware.platform.windows.WindowsSoundCard
| Package | Description |
|---|---|
| oshi.hardware.platform.windows |
Provides information about hardware such as Memory, Power Sources, and
Processor on Windows systems
|
-
Uses of WindowsSoundCard in oshi.hardware.platform.windows
Methods in oshi.hardware.platform.windows that return types with arguments of type WindowsSoundCard Modifier and Type Method Description static java.util.List<WindowsSoundCard>WindowsSoundCard. getSoundCards()Returns Windows audio device driver information, which represents the closest proxy we have to sound cards.