Interface CoreGraphicsExt
- All Superinterfaces:
CoreGraphics, Library
Extensions to JNA's
CoreGraphics for functions not yet bound upstream. This class should be considered
non-API as it may be removed if/when its code is incorporated into the JNA project.-
Nested Class Summary
Nested ClassesModifier and TypeInterfaceDescriptionstatic classACGSizereturned by value from native functions.Nested classes/interfaces inherited from interface CoreGraphics
CoreGraphics.CGPoint, CoreGraphics.CGRect, CoreGraphics.CGSizeNested classes/interfaces inherited from interface Library
Library.Handler -
Field Summary
FieldsFields inherited from interface CoreGraphics
kCGBackingStoreBuffered, kCGBackingStoreNonretained, kCGBackingStoreRetained, kCGNullWindowID, kCGWindowAlpha, kCGWindowBackingLocationVideoMemory, kCGWindowBounds, kCGWindowImageBestResolution, kCGWindowImageBoundsIgnoreFraming, kCGWindowImageDefault, kCGWindowImageNominalResolution, kCGWindowImageOnlyShadows, kCGWindowImageShouldBeOpaque, kCGWindowIsOnscreen, kCGWindowLayer, kCGWindowListExcludeDesktopElements, kCGWindowListOptionAll, kCGWindowListOptionIncludingWindow, kCGWindowListOptionOnScreenAboveWindow, kCGWindowListOptionOnScreenBelowWindow, kCGWindowListOptionOnScreenOnly, kCGWindowMemoryUsage, kCGWindowName, kCGWindowNumber, kCGWindowOwnerName, kCGWindowOwnerPID, kCGWindowSharingNone, kCGWindowSharingReadOnly, kCGWindowSharingReadWrite, kCGWindowSharingState, kCGWindowStoreType -
Method Summary
Modifier and TypeMethodDescriptionCGDisplayScreenSize(int display) Returns the physical size of the display in millimeters.Methods inherited from interface CoreGraphics
CGDisplayBounds, CGDisplayIsActive, CGDisplayIsBuiltin, CGDisplayIsMain, CGDisplayModelNumber, CGDisplayPixelsHigh, CGDisplayPixelsWide, CGDisplayRotation, CGDisplaySerialNumber, CGDisplayVendorNumber, CGGetActiveDisplayList, CGGetOnlineDisplayList, CGMainDisplayID, CGRectMakeWithDictionaryRepresentation, CGWindowListCopyWindowInfo
-
Field Details
-
INSTANCE
-
-
Method Details
-
CGDisplayScreenSize
Returns the physical size of the display in millimeters.- Parameters:
display- The display identifier.- Returns:
- A
CoreGraphicsExt.CGSizeByValuecontaining the width and height in millimeters.
-