public abstract class AbstractFileSystem extends Object implements FileSystem
| Modifier and Type | Field and Description |
|---|---|
protected static List<String> |
NETWORK_FS_TYPES
FileSystem types which are network-based and should be excluded from local-only lists
|
| Constructor and Description |
|---|
AbstractFileSystem() |
| Modifier and Type | Method and Description |
|---|---|
OSFileStore[] |
getFileStores()
Get file stores on this machine
Instantiates an array of
OSFileStore objects,
representing a storage pool, device, partition, volume, concrete file system
or other implementation specific means of file storage. |
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, waitgetFileStores, getMaxFileDescriptors, getOpenFileDescriptorspublic OSFileStore[] getFileStores()
FileSystemOSFileStore objects,
representing a storage pool, device, partition, volume, concrete file system
or other implementation specific means of file storage.getFileStores in interface FileSystemCopyright © 2010–2020 oshi. All rights reserved.