Uses of Class
oshi.software.common.AbstractFileSystem
Packages that use AbstractFileSystem
Package
Description
Provides common (native-free) Linux operating system implementations shared by JNA and FFM modules.
Native-free Linux operating system implementations using only procfs, sysfs, and command-line utilities.
Provides information about Software and OS on macOS
Provides abstract base classes and pure-Java implementations for the FreeBSD operating system, shared by the JNA and
FFM modules.
Provides abstract base classes and pure-Java implementations for the OpenBSD operating system, shared by the JNA and
FFM modules.
Provides information about Software and OS on Linux
Provides information about Software and OS on macOS
Provides information about Software and OS on AIX
Provides information about Software and OS on FreeBSD
Provides information about Software and OS on NetBSD
Provides information about Software and OS on OpenBSD
Provides information about Software and OS on Solaris
Provides information about Software and OS on Windows
-
Uses of AbstractFileSystem in oshi.software.common.os.linux
Subclasses of AbstractFileSystem in oshi.software.common.os.linuxModifier and TypeClassDescriptionclassThe Linux File System containsOSFileStores which are a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage. -
Uses of AbstractFileSystem in oshi.software.common.os.linux.nativefree
Subclasses of AbstractFileSystem in oshi.software.common.os.linux.nativefreeModifier and TypeClassDescriptionclassNative-free Linux file system implementation. -
Uses of AbstractFileSystem in oshi.software.common.os.mac
Subclasses of AbstractFileSystem in oshi.software.common.os.macModifier and TypeClassDescriptionclassCommon constants and configuration for macOS file system implementations. -
Uses of AbstractFileSystem in oshi.software.common.os.unix.freebsd
Subclasses of AbstractFileSystem in oshi.software.common.os.unix.freebsd -
Uses of AbstractFileSystem in oshi.software.common.os.unix.openbsd
Subclasses of AbstractFileSystem in oshi.software.common.os.unix.openbsd -
Uses of AbstractFileSystem in oshi.software.os.linux
Subclasses of AbstractFileSystem in oshi.software.os.linuxModifier and TypeClassDescriptionclassJNA-based Linux file system implementation. -
Uses of AbstractFileSystem in oshi.software.os.mac
Subclasses of AbstractFileSystem in oshi.software.os.macModifier and TypeClassDescriptionclassThe Mac File System containsOSFileStores which are a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage. -
Uses of AbstractFileSystem in oshi.software.os.unix.aix
Subclasses of AbstractFileSystem in oshi.software.os.unix.aixModifier and TypeClassDescriptionclassThe AIX File System containsOSFileStores which are a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage. -
Uses of AbstractFileSystem in oshi.software.os.unix.freebsd
Subclasses of AbstractFileSystem in oshi.software.os.unix.freebsdModifier and TypeClassDescriptionfinal classJNA-backed FreeBSD file system. -
Uses of AbstractFileSystem in oshi.software.os.unix.netbsd
Subclasses of AbstractFileSystem in oshi.software.os.unix.netbsdModifier and TypeClassDescriptionclassThe NetBSD File System containsOSFileStores which are a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage. -
Uses of AbstractFileSystem in oshi.software.os.unix.openbsd
Subclasses of AbstractFileSystem in oshi.software.os.unix.openbsdModifier and TypeClassDescriptionclassThe OpenBSD File System containsOSFileStores which are a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage. -
Uses of AbstractFileSystem in oshi.software.os.unix.solaris
Subclasses of AbstractFileSystem in oshi.software.os.unix.solarisModifier and TypeClassDescriptionclassThe Solaris File System containsOSFileStores which are a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage. -
Uses of AbstractFileSystem in oshi.software.os.windows
Subclasses of AbstractFileSystem in oshi.software.os.windowsModifier and TypeClassDescriptionclassThe Windows File System containsOSFileStores which are a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage.