Uses of Class
oshi.software.common.AbstractOSProcess

Packages that use AbstractOSProcess
Package
Description
Provides common (native-free) Linux operating system implementations shared by JNA and FFM modules.
Native-free Linux operating system implementations using only procfs, sysfs, and command-line utilities.
Provides abstract base classes and pure-Java implementations for AIX software, shared by the JNA and FFM modules.
Provides shared abstract base classes for the BSD-family operating systems
Provides DragonFly BSD-specific shared software OS classes (abstract bases and no-native concrete implementations).
Provides abstract base classes and pure-Java implementations for the FreeBSD operating system, shared by the JNA and FFM modules.
Provides information about Software and OS on NetBSD
Provides abstract base classes and pure-Java implementations for the OpenBSD operating system, shared by the JNA and FFM modules.
Provides abstract base classes and pure-Java implementations for Solaris/illumos software, shared by the JNA and FFM modules.
Provides common implementations for Windows operating system information shared between JNA and FFM implementations.
Provides information about Software and OS on Linux
Provides information about Software and OS on macOS
Provides information about Software and OS on AIX
Provides information about Software and OS on DragonFly BSD
Provides information about Software and OS on FreeBSD
Provides information about Software and OS on OpenBSD
Provides information about Software and OS on Solaris
Provides information about Software and OS on Windows