Class LinuxOSFileStore

java.lang.Object
oshi.software.common.AbstractOSFileStore
oshi.software.common.os.linux.LinuxOSFileStore
All Implemented Interfaces:
OSFileStore

@ThreadSafe public class LinuxOSFileStore extends AbstractOSFileStore
OSFileStore implementation
  • Constructor Details

    • LinuxOSFileStore

      public LinuxOSFileStore(String name, String volume, String label, String mount, String options, String uuid, boolean local, String logicalVolume, String description, String fsType, long freeSpace, long usableSpace, long totalSpace, long freeInodes, long totalInodes, LinuxFileSystem fs)
      Creates a LinuxOSFileStore.
      Parameters:
      name - the name
      volume - the volume
      label - the label
      mount - the mount point
      options - the mount options
      uuid - the UUID
      local - whether local
      logicalVolume - the logical volume
      description - the description
      fsType - the filesystem type
      freeSpace - free space in bytes
      usableSpace - usable space in bytes
      totalSpace - total space in bytes
      freeInodes - free inodes
      totalInodes - total inodes
      fs - the parent filesystem
  • Method Details

    • updateAttributes

      public boolean updateAttributes()
      Description copied from interface: OSFileStore
      Make a best effort to update all the statistics about the file store without needing to recreate the file store list. This method provides for more frequent periodic updates of file store statistics.
      Returns:
      True if the update was (probably) successful, false if the disk was not found