Class LinuxOperatingSystemNF

All Implemented Interfaces:
OperatingSystem

@ThreadSafe public class LinuxOperatingSystemNF extends LinuxOperatingSystem
Native-free Linux operating system implementation. Extends LinuxOperatingSystem, providing implementations that require no native access.
  • Constructor Details

    • LinuxOperatingSystemNF

      public LinuxOperatingSystemNF()
  • Method Details

    • hz

      public static long hz()
      Gets Jiffies per second.
      Returns:
      Jiffies per second.
    • pageSize

      public static long pageSize()
      Gets Page Size in bytes.
      Returns:
      Page Size in bytes.
    • getHz

      public long getHz()
      Description copied from class: LinuxOperatingSystem
      Gets Jiffies per second, useful for converting ticks to milliseconds and vice versa.
      Specified by:
      getHz in class LinuxOperatingSystem
      Returns:
      Jiffies per second.
    • getPageSize

      public long getPageSize()
      Description copied from class: LinuxOperatingSystem
      Gets Page Size, for converting memory stats from pages to bytes
      Specified by:
      getPageSize in class LinuxOperatingSystem
      Returns:
      Page Size
    • getFileSystem

      public FileSystem getFileSystem()
      Description copied from interface: OperatingSystem
      Instantiates a FileSystem object.
      Returns:
      A FileSystem object.
    • getNetworkParams

      public NetworkParams getNetworkParams()
      Description copied from interface: OperatingSystem
      Instantiates a NetworkParams object.
      Returns:
      A NetworkParams object.
    • getProcess

      public OSProcess getProcess(int pid)
      Description copied from interface: OperatingSystem
      Gets information on a currently running process
      Parameters:
      pid - A process ID
      Returns:
      An OSProcess object for the specified process id if it is running; null otherwise
    • createOSProcess

      protected OSProcess createOSProcess(int pid)
      Description copied from class: LinuxOperatingSystem
      Creates an OS process for the given PID.
      Specified by:
      createOSProcess in class LinuxOperatingSystem
      Parameters:
      pid - the process ID
      Returns:
      the OS process
    • getProcessId

      public int getProcessId()
      Description copied from interface: OperatingSystem
      Gets the current process ID (PID).
      Returns:
      the Process ID of the current process
    • getThreadId

      public int getThreadId()
      Description copied from interface: OperatingSystem
      Makes a best effort to get the current thread ID (TID). May not be useful in a multithreaded environment. The thread ID returned may have been short lived and no longer exist.

      Thread IDs on macOS are not correlated with any other Operating System output.

      Returns:
      the Thread ID of the current thread if known, 0 otherwise.
    • getThreadCount

      public int getThreadCount()
      Description copied from interface: OperatingSystem
      Get the number of threads currently running
      Returns:
      The number of threads running