Package oshi.software.common.os.linux
package oshi.software.common.os.linux
Provides common (native-free) Linux operating system implementations shared by JNA and FFM modules.
-
ClassesClassDescriptionLinux implementation of
CgroupInfosupporting both cgroup v2 and v1.The Linux File System containsOSFileStores which are a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage.Utility class for querying installed applications on Linux.Internet Protocol Stats implementationLinux network parameters.Linux is a family of open source Unix-like operating systems based on the Linux kernel, an operating system kernel first released on September 17, 1991, by Linus Torvalds.OSFileStore implementationOSProcess implementationOSThread implementation