Uses of Package
oshi.software.common.os.linux
Packages that use oshi.software.common.os.linux
Package
Description
Provides common (native-free) Linux operating system implementations shared by JNA and FFM modules.
Native-free Linux operating system implementations using only procfs, sysfs, and command-line utilities.
Provides information about Software and OS on Linux
-
Classes in oshi.software.common.os.linux used by oshi.software.common.os.linuxClassDescriptionThe Linux File System contains
OSFileStores which are a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage.Linux is a family of open source Unix-like operating systems based on the Linux kernel, an operating system kernel first released on September 17, 1991, by Linus Torvalds. -
Classes in oshi.software.common.os.linux used by oshi.software.common.os.linux.nativefreeClassDescriptionThe Linux File System contains
OSFileStores which are a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage.Linux network parameters.Linux is a family of open source Unix-like operating systems based on the Linux kernel, an operating system kernel first released on September 17, 1991, by Linus Torvalds.OSProcess implementation -
Classes in oshi.software.common.os.linux used by oshi.software.os.linuxClassDescriptionThe Linux File System contains
OSFileStores which are a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage.Linux is a family of open source Unix-like operating systems based on the Linux kernel, an operating system kernel first released on September 17, 1991, by Linus Torvalds.OSProcess implementation