Class MacFileSystem
java.lang.Object
oshi.software.common.AbstractFileSystem
oshi.software.common.os.mac.MacFileSystem
- All Implemented Interfaces:
FileSystem
- Direct Known Subclasses:
MacFileSystemJNA
Common constants and configuration for macOS file system implementations.
-
Field Summary
FieldsModifier and TypeFieldDescriptionprotected static final List<PathMatcher> File system path exclude matchers.protected static final List<PathMatcher> File system path include matchers.protected static final List<PathMatcher> File system volume exclude matchers.protected static final List<PathMatcher> File system volume include matchers.protected static final PatternPattern matching local disk device paths.protected static final intMount flag: asynchronous.protected static final intMount flag: automounted.protected static final intMount flag: content protection.protected static final intMount flag: deferred writes.protected static final intMount flag: don't browse.protected static final intMount flag: volfs.protected static final intMount flag: exported.protected static final intMount flag: ignore ownership.protected static final intMount flag: journaled.protected static final intMount flag: local.protected static final intMount flag: multilabel MAC.protected static final intMount flag: no access time.protected static final intMount flag: no device access.protected static final intMount flag: no exec.protected static final intMount flag: no setuid.protected static final intMount flag: no user extended attributes.protected static final intMount flag: quarantined.protected static final intMount flag: quotas.protected static final intMount flag: read-only.protected static final intMount flag: root filesystem.protected static final intMount flag: synchronous.protected static final intMount flag: union.Map of mount flags to option strings.static final StringConfiguration key for path excludes.static final StringConfiguration key for path includes.static final StringConfiguration key for volume excludes.static final StringConfiguration key for volume includes.Fields inherited from class AbstractFileSystem
NETWORK_FS_TYPES, PSEUDO_FS_TYPESModifier and TypeFieldDescriptionFileSystem types which are network-based and should be excluded from local-only listsFileSystem types which are pseudo-filesystems and should be excluded from local-only lists -
Constructor Summary
Constructors -
Method Summary
Methods inherited from class AbstractFileSystem
getFileStoresModifier and TypeMethodDescriptionGet file stores on this machine Instantiates a list ofOSFileStoreobjects, representing a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage.Methods inherited from class Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, waitMethods inherited from interface FileSystem
getFileStores, getMaxFileDescriptors, getMaxFileDescriptorsPerProcess, getOpenFileDescriptorsModifier and TypeMethodDescriptiongetFileStores(boolean localOnly) Get file stores on this machine Instantiates a list ofOSFileStoreobjects, representing a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage.longThe maximum number of open file descriptors.longThe maximum number of open file descriptors per process.longThe current number of open file descriptors.
-
Field Details
-
OSHI_MAC_FS_PATH_EXCLUDES
-
OSHI_MAC_FS_PATH_INCLUDES
-
OSHI_MAC_FS_VOLUME_EXCLUDES
Configuration key for volume excludes.- See Also:
-
OSHI_MAC_FS_VOLUME_INCLUDES
Configuration key for volume includes.- See Also:
-
FS_PATH_EXCLUDES
File system path exclude matchers. -
FS_PATH_INCLUDES
File system path include matchers. -
FS_VOLUME_EXCLUDES
File system volume exclude matchers. -
FS_VOLUME_INCLUDES
File system volume include matchers. -
LOCAL_DISK
Pattern matching local disk device paths. -
MNT_RDONLY
protected static final int MNT_RDONLYMount flag: read-only.- See Also:
-
MNT_SYNCHRONOUS
protected static final int MNT_SYNCHRONOUSMount flag: synchronous.- See Also:
-
MNT_NOEXEC
protected static final int MNT_NOEXECMount flag: no exec.- See Also:
-
MNT_NOSUID
protected static final int MNT_NOSUIDMount flag: no setuid.- See Also:
-
MNT_NODEV
protected static final int MNT_NODEVMount flag: no device access.- See Also:
-
MNT_UNION
protected static final int MNT_UNIONMount flag: union.- See Also:
-
MNT_ASYNC
protected static final int MNT_ASYNCMount flag: asynchronous.- See Also:
-
MNT_CPROTECT
protected static final int MNT_CPROTECTMount flag: content protection.- See Also:
-
MNT_EXPORTED
protected static final int MNT_EXPORTEDMount flag: exported.- See Also:
-
MNT_QUARANTINE
protected static final int MNT_QUARANTINEMount flag: quarantined.- See Also:
-
MNT_LOCAL
protected static final int MNT_LOCALMount flag: local.- See Also:
-
MNT_QUOTA
protected static final int MNT_QUOTAMount flag: quotas.- See Also:
-
MNT_ROOTFS
protected static final int MNT_ROOTFSMount flag: root filesystem.- See Also:
-
MNT_DOVOLFS
protected static final int MNT_DOVOLFSMount flag: volfs.- See Also:
-
MNT_DONTBROWSE
protected static final int MNT_DONTBROWSEMount flag: don't browse.- See Also:
-
MNT_IGNORE_OWNERSHIP
protected static final int MNT_IGNORE_OWNERSHIPMount flag: ignore ownership.- See Also:
-
MNT_AUTOMOUNTED
protected static final int MNT_AUTOMOUNTEDMount flag: automounted.- See Also:
-
MNT_JOURNALED
protected static final int MNT_JOURNALEDMount flag: journaled.- See Also:
-
MNT_NOUSERXATTR
protected static final int MNT_NOUSERXATTRMount flag: no user extended attributes.- See Also:
-
MNT_DEFWRITE
protected static final int MNT_DEFWRITEMount flag: deferred writes.- See Also:
-
MNT_MULTILABEL
protected static final int MNT_MULTILABELMount flag: multilabel MAC.- See Also:
-
MNT_NOATIME
protected static final int MNT_NOATIMEMount flag: no access time.- See Also:
-
OPTIONS_MAP
-
-
Constructor Details
-
MacFileSystem
protected MacFileSystem()Default constructor.
-