Class OpenBsdFileSystem
java.lang.Object
oshi.software.common.AbstractFileSystem
oshi.software.common.os.unix.openbsd.OpenBsdFileSystem
- All Implemented Interfaces:
FileSystem
- Direct Known Subclasses:
OpenBsdFileSystem
-
Field Summary
FieldsModifier and TypeFieldDescriptionstatic final Stringstatic final Stringstatic final Stringstatic final StringFields inherited from class AbstractFileSystem
NETWORK_FS_TYPES, PSEUDO_FS_TYPESModifier and TypeFieldDescriptionFileSystem types which are network-based and should be excluded from local-only listsFileSystem types which are pseudo-filesystems and should be excluded from local-only lists -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptiongetFileStoreMatching(String nameToMatch, boolean localOnly) Gets file stores matching the given name (or all if null).getFileStores(boolean localOnly) Get file stores on this machine Instantiates a list ofOSFileStoreobjects, representing a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage.Methods inherited from class AbstractFileSystem
getFileStoresModifier and TypeMethodDescriptionGet file stores on this machine Instantiates a list ofOSFileStoreobjects, representing a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage.Methods inherited from class Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, waitMethods inherited from interface FileSystem
getMaxFileDescriptors, getMaxFileDescriptorsPerProcess, getOpenFileDescriptorsModifier and TypeMethodDescriptionlongThe maximum number of open file descriptors.longThe maximum number of open file descriptors per process.longThe current number of open file descriptors.
-
Field Details
-
OSHI_OPENBSD_FS_PATH_EXCLUDES
- See Also:
-
OSHI_OPENBSD_FS_PATH_INCLUDES
- See Also:
-
OSHI_OPENBSD_FS_VOLUME_EXCLUDES
- See Also:
-
OSHI_OPENBSD_FS_VOLUME_INCLUDES
- See Also:
-
-
Constructor Details
-
OpenBsdFileSystem
public OpenBsdFileSystem()
-
-
Method Details
-
getFileStores
Description copied from interface:FileSystemGet file stores on this machine Instantiates a list ofOSFileStoreobjects, representing a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage.- Parameters:
localOnly- If true, filters the list to only local file stores. On Windows, also excluded CD-ROM drives.- Returns:
- A list of
OSFileStoreobjects or an empty array if none are present.
-
getFileStoreMatching
Gets file stores matching the given name (or all if null).- Parameters:
nameToMatch- name to filter on, or null for alllocalOnly- if true, only return local file systems- Returns:
- list of matching file stores
-