Class SolarisFileSystem

java.lang.Object
oshi.software.common.AbstractFileSystem
oshi.software.common.os.unix.solaris.SolarisFileSystem
All Implemented Interfaces:
FileSystem
Direct Known Subclasses:
SolarisFileSystemJNA

@ThreadSafe public abstract class SolarisFileSystem extends AbstractFileSystem
The Solaris File System contains OSFileStores which are a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage. In Solaris, these are found in the /proc/mount filesystem, excluding temporary and kernel mounts.

The mount-table and inode parsing is shared; the kstat-based file-descriptor counts (getOpenFile..., getMaxFile...) are native and implemented by the JNA and FFM subclasses.

  • Field Details

  • Constructor Details

    • SolarisFileSystem

      public SolarisFileSystem()
  • Method Details

    • getFileStores

      public List<OSFileStore> getFileStores(boolean localOnly)
      Description copied from interface: FileSystem
      Get file stores on this machine Instantiates a list of OSFileStore objects, representing a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage.
      Parameters:
      localOnly - If true, filters the list to only local file stores. On Windows, also excluded CD-ROM drives.
      Returns:
      A list of OSFileStore objects or an empty array if none are present.
    • getMaxFileDescriptorsPerProcess

      public long getMaxFileDescriptorsPerProcess()
      Description copied from interface: FileSystem
      The maximum number of open file descriptors per process. This returns the upper limit which applies to each process. The actual limit of a process may be lower if configured.
      Returns:
      The maximum number of file descriptors of each process if available, 0 otherwise.