Class WindowsOperatingSystem
java.lang.Object
oshi.software.common.AbstractOperatingSystem
oshi.software.common.os.windows.WindowsOperatingSystem
- All Implemented Interfaces:
OperatingSystem
- Direct Known Subclasses:
WindowsOperatingSystemJNA
Common base class for Windows operating system implementations.
-
Nested Class Summary
Nested classes/interfaces inherited from interface OperatingSystem
OperatingSystem.OSVersionInfo, OperatingSystem.ProcessFiltering, OperatingSystem.ProcessSortingModifier and TypeInterfaceDescriptionstatic classA class representing the Operating System version details.static final classConstants which may be used to filter Process lists inOperatingSystem.getProcesses(Predicate, Comparator, int),OperatingSystem.getChildProcesses(int, Predicate, Comparator, int), andOperatingSystem.getDescendantProcesses(int, Predicate, Comparator, int).static final classConstants which may be used to sort Process lists inOperatingSystem.getProcesses(Predicate, Comparator, int),OperatingSystem.getChildProcesses(int, Predicate, Comparator, int), andOperatingSystem.getDescendantProcesses(int, Predicate, Comparator, int). -
Field Summary
FieldsModifier and TypeFieldDescriptionprotected static final booleanWhether to check thread states to determine if a process is suspended.Fields inherited from class AbstractOperatingSystem
USE_WHO_COMMANDModifier and TypeFieldDescriptionprotected static final booleanWhether to use the 'who' command for session queries. -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionprotected static StringparseCodeName(int suiteMask) Gets suites available on the system and return as a codename.protected StringQueries the OS manufacturer.Methods inherited from class AbstractOperatingSystem
getBitness, getChildProcesses, getChildrenOrDescendants, getChildrenOrDescendants, getDescendantProcesses, getDesktopWindows, getFamily, getManufacturer, getProcesses, getSessions, getVersionInfo, isElevated, queryAllProcesses, queryBitness, queryChildProcesses, queryDescendantProcesses, queryFamilyVersionInfo, toStringModifier and TypeMethodDescriptionintGets the bitness (32 or 64) of the operating system.getChildProcesses(int parentPid, Predicate<OSProcess> filter, Comparator<OSProcess> sort, int limit) Gets currently running child processes of provided parent PID, optionally filtering, sorting, and limited to the top "N".getChildrenOrDescendants(Collection<OSProcess> allProcs, int parentPid, boolean allDescendants) Utility method for subclasses to take a full process list as input and return the children or descendants of a particular process.getChildrenOrDescendants(Map<Integer, Integer> parentPidMap, int parentPid, boolean allDescendants) Utility method for subclasses to take a map of pid to parent as input and return the children or descendants of a particular process.getDescendantProcesses(int parentPid, Predicate<OSProcess> filter, Comparator<OSProcess> sort, int limit) Gets currently running processes of provided parent PID's descendants, including their children, the children's children, etc., optionally filtering, sorting, and limited to the top "N".getDesktopWindows(boolean visibleOnly) Gets windows on the operating system's GUI desktop.Get the Operating System family.Get the Operating System manufacturer.getProcesses(Predicate<OSProcess> filter, Comparator<OSProcess> sort, int limit) Gets currently running processes, optionally filtering, sorting, and limited to the top "N".Gets currently logged in users.Get Operating System version information.booleanDetermine whether the current process has elevated permissions such as sudo / AdministratorQueries all processes on the system.protected abstract intqueryBitness(int jvmBitness) Backup OS-specific query to determine bitness if previous checks failqueryChildProcesses(int parentPid) Queries the children of a process.queryDescendantProcesses(int parentPid) Queries the descendants of a process.protected abstract Pair<String, OperatingSystem.OSVersionInfo> Queries the OS family and version info.toString()Methods inherited from class Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface OperatingSystem
getCgroupInfo, getCurrentProcess, getCurrentThread, getFileSystem, getInstalledApplications, getInternetProtocolStats, getNetworkParams, getProcess, getProcessCount, getProcesses, getProcesses, getProcessId, getServices, getSystemBootTime, getSystemUptime, getThreadCount, getThreadIdModifier and TypeMethodDescriptiondefault CgroupInfoRetrieves cgroup information for the current process.default OSProcessGets the current process.Makes a best effort to get the current thread.Instantiates aFileSystemobject.default List<ApplicationInfo> Retrieves a list of installed applications on the system.Instantiates aInternetProtocolStatsobject.Instantiates aNetworkParamsobject.getProcess(int pid) Gets information on a currently running processintGet the number of processes currently runningGets currently running processes.getProcesses(Collection<Integer> pids) Gets information on aCollectionof currently running processes.intGets the current process ID (PID).Gets the all services on the system.longGet Unix time of boot.longGet the System up time (time since boot).intGet the number of threads currently runningintMakes a best effort to get the current thread ID (TID).
-
Field Details
-
USE_PROCSTATE_SUSPENDED
protected static final boolean USE_PROCSTATE_SUSPENDEDWhether to check thread states to determine if a process is suspended.
-
-
Constructor Details
-
WindowsOperatingSystem
protected WindowsOperatingSystem()Default constructor.
-
-
Method Details
-
queryManufacturer
Description copied from class:AbstractOperatingSystemQueries the OS manufacturer.- Specified by:
queryManufacturerin classAbstractOperatingSystem- Returns:
- the manufacturer string
-
parseCodeName
Gets suites available on the system and return as a codename.- Parameters:
suiteMask- The suite mask bitmask- Returns:
- Suites
-