Enum Class OSService.State

java.lang.Object
java.lang.Enum<OSService.State>
oshi.software.os.OSService.State
All Implemented Interfaces:
Serializable, Comparable<OSService.State>, Constable
Enclosing class:
OSService

@PublicApi public static enum OSService.State extends Enum<OSService.State>
Service Execution States
  • Enum Constant Details

    • RUNNING

      public static final OSService.State RUNNING
      Service is running.
    • STOPPED

      public static final OSService.State STOPPED
      Service is stopped.
    • OTHER

      public static final OSService.State OTHER
      Service is in another state.
  • Method Details

    • values

      public static OSService.State[] values()
      Returns an array containing the constants of this enum class, in the order they are declared.
      Returns:
      an array containing the constants of this enum class, in the order they are declared
    • valueOf

      public static OSService.State valueOf(String name)
      Returns the enum constant of this class with the specified name. The string must match exactly an identifier used to declare an enum constant in this class. (Extraneous whitespace characters are not permitted.)
      Parameters:
      name - the name of the enum constant to be returned.
      Returns:
      the enum constant with the specified name
      Throws:
      IllegalArgumentException - if this enum class has no constant with the specified name
      NullPointerException - if the argument is null