Uses of Interface
oshi.software.os.FileSystem
Packages that use FileSystem
Package
Description
Provides abstract classes for common code
Provides common (native-free) Linux operating system implementations shared by JNA and FFM modules.
Native-free Linux operating system implementations using only procfs, sysfs, and command-line utilities.
Provides information about Software and OS on macOS
Provides abstract base classes and pure-Java implementations for AIX software, shared by the JNA and FFM modules.
Provides abstract base classes and pure-Java implementations for the FreeBSD operating system, shared by the JNA and
FFM modules.
Provides information about Software and OS on NetBSD
Provides abstract base classes and pure-Java implementations for the OpenBSD operating system, shared by the JNA and
FFM modules.
Provides abstract base classes and pure-Java implementations for Solaris/illumos software, shared by the JNA and FFM
modules.
[oshi-common API] Provides cross-platform common API to retrieve OS, FileSystem, and Process information
Provides information about Software and OS on Linux
Provides information about Software and OS on macOS
Provides information about Software and OS on AIX
Provides information about Software and OS on DragonFly BSD
Provides information about Software and OS on FreeBSD
Provides information about Software and OS on OpenBSD
Provides information about Software and OS on Solaris
Provides information about Software and OS on Windows
Provides utilities for parsing, formatting, and other access
-
Uses of FileSystem in oshi.software.common
Classes in oshi.software.common that implement FileSystemModifier and TypeClassDescriptionclassCommon methods for filesystem implementations -
Uses of FileSystem in oshi.software.common.os.linux
Classes in oshi.software.common.os.linux that implement FileSystemModifier and TypeClassDescriptionclassThe Linux File System containsOSFileStores which are a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage. -
Uses of FileSystem in oshi.software.common.os.linux.nativefree
Classes in oshi.software.common.os.linux.nativefree that implement FileSystemModifier and TypeClassDescriptionclassNative-free Linux file system implementation.Methods in oshi.software.common.os.linux.nativefree that return FileSystem -
Uses of FileSystem in oshi.software.common.os.mac
Classes in oshi.software.common.os.mac that implement FileSystemModifier and TypeClassDescriptionclassCommon constants and configuration for macOS file system implementations. -
Uses of FileSystem in oshi.software.common.os.unix.aix
Classes in oshi.software.common.os.unix.aix that implement FileSystemModifier and TypeClassDescriptionclassThe AIX File System containsOSFileStores which are a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage. -
Uses of FileSystem in oshi.software.common.os.unix.freebsd
Classes in oshi.software.common.os.unix.freebsd that implement FileSystem -
Uses of FileSystem in oshi.software.common.os.unix.netbsd
Classes in oshi.software.common.os.unix.netbsd that implement FileSystemModifier and TypeClassDescriptionclassThe NetBSD File System containsOSFileStores which are a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage.Methods in oshi.software.common.os.unix.netbsd that return FileSystem -
Uses of FileSystem in oshi.software.common.os.unix.openbsd
Classes in oshi.software.common.os.unix.openbsd that implement FileSystem -
Uses of FileSystem in oshi.software.common.os.unix.solaris
Classes in oshi.software.common.os.unix.solaris that implement FileSystemModifier and TypeClassDescriptionclassThe Solaris File System containsOSFileStores which are a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage. -
Uses of FileSystem in oshi.software.os
Methods in oshi.software.os that return FileSystemModifier and TypeMethodDescriptionOperatingSystem.getFileSystem()Instantiates aFileSystemobject. -
Uses of FileSystem in oshi.software.os.linux
Classes in oshi.software.os.linux that implement FileSystemModifier and TypeClassDescriptionclassJNA-based Linux file system implementation.Methods in oshi.software.os.linux that return FileSystem -
Uses of FileSystem in oshi.software.os.mac
Classes in oshi.software.os.mac that implement FileSystemModifier and TypeClassDescriptionclassThe Mac File System containsOSFileStores which are a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage.Methods in oshi.software.os.mac that return FileSystem -
Uses of FileSystem in oshi.software.os.unix.aix
Methods in oshi.software.os.unix.aix that return FileSystem -
Uses of FileSystem in oshi.software.os.unix.dragonflybsd
Methods in oshi.software.os.unix.dragonflybsd that return FileSystem -
Uses of FileSystem in oshi.software.os.unix.freebsd
Classes in oshi.software.os.unix.freebsd that implement FileSystemModifier and TypeClassDescriptionfinal classJNA-backed FreeBSD file system.Methods in oshi.software.os.unix.freebsd that return FileSystem -
Uses of FileSystem in oshi.software.os.unix.openbsd
Classes in oshi.software.os.unix.openbsd that implement FileSystemModifier and TypeClassDescriptionclassThe OpenBSD File System containsOSFileStores which are a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage.Methods in oshi.software.os.unix.openbsd that return FileSystem -
Uses of FileSystem in oshi.software.os.unix.solaris
Classes in oshi.software.os.unix.solaris that implement FileSystemModifier and TypeClassDescriptionfinal classJNA-backed Solaris File System.Methods in oshi.software.os.unix.solaris that return FileSystem -
Uses of FileSystem in oshi.software.os.windows
Classes in oshi.software.os.windows that implement FileSystemModifier and TypeClassDescriptionclassThe Windows File System containsOSFileStores which are a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage.Methods in oshi.software.os.windows that return FileSystem -
Uses of FileSystem in oshi.util
Methods in oshi.util with parameters of type FileSystemModifier and TypeMethodDescriptionstatic voidSystemInfoHelper.printFileSystem(List<String> lines, FileSystem fileSystem) Prints File System information to the output lines.