Uses of Class
oshi.software.os.InternetProtocolStats.IPConnection
Packages that use InternetProtocolStats.IPConnection
Package
Description
Provides abstract classes for common code
Provides common (native-free) Linux operating system implementations shared by JNA and FFM modules.
[oshi-common API] Provides cross-platform common API to retrieve OS, FileSystem, and Process information
Provides information about Software and OS on macOS
Provides information about Software and OS on Windows
Provides driver utilities common to unix systems that do not require native access
-
Uses of InternetProtocolStats.IPConnection in oshi.software.common
Methods in oshi.software.common that return types with arguments of type InternetProtocolStats.IPConnection -
Uses of InternetProtocolStats.IPConnection in oshi.software.common.os.linux
Methods in oshi.software.common.os.linux that return types with arguments of type InternetProtocolStats.IPConnection -
Uses of InternetProtocolStats.IPConnection in oshi.software.os
Methods in oshi.software.os that return types with arguments of type InternetProtocolStats.IPConnectionModifier and TypeMethodDescriptionInternetProtocolStats.getConnections()Gets a list of TCP and UDP connections. -
Uses of InternetProtocolStats.IPConnection in oshi.software.os.mac
Methods in oshi.software.os.mac that return types with arguments of type InternetProtocolStats.IPConnection -
Uses of InternetProtocolStats.IPConnection in oshi.software.os.windows
Methods in oshi.software.os.windows that return types with arguments of type InternetProtocolStats.IPConnection -
Uses of InternetProtocolStats.IPConnection in oshi.util.driver.unix
Methods in oshi.util.driver.unix that return types with arguments of type InternetProtocolStats.IPConnectionModifier and TypeMethodDescriptionNetStat.queryNetstat()Query netstat to all TCP and UDP connections