Uses of Interface
oshi.software.os.OSFileStore
Packages that use OSFileStore
Package
Description
Provides abstract classes for common code
Provides common (native-free) Linux operating system implementations shared by JNA and FFM modules.
Provides information about Software and OS on macOS
Provides abstract base classes and pure-Java implementations for the FreeBSD operating system, shared by the JNA and
FFM modules.
Provides abstract base classes and pure-Java implementations for the OpenBSD operating system, shared by the JNA and
FFM modules.
Provides common implementations for Windows operating system information shared between JNA and FFM implementations.
[oshi-common API] Provides cross-platform common API to retrieve OS, FileSystem, and Process information
Provides information about Software and OS on macOS
Provides information about Software and OS on AIX
Provides information about Software and OS on NetBSD
Provides information about Software and OS on Solaris
Provides information about Software and OS on Windows
-
Uses of OSFileStore in oshi.software.common
Classes in oshi.software.common that implement OSFileStoreModifier and TypeClassDescriptionclassCommon implementations for OSFileStoreMethods in oshi.software.common that return types with arguments of type OSFileStoreMethods in oshi.software.common with parameters of type OSFileStoreModifier and TypeMethodDescriptionprotected voidAbstractOSFileStore.updateFrom(OSFileStore fileStore) Copies mutable attributes from another file store into this one. -
Uses of OSFileStore in oshi.software.common.os.linux
Classes in oshi.software.common.os.linux that implement OSFileStoreMethods in oshi.software.common.os.linux that return types with arguments of type OSFileStore -
Uses of OSFileStore in oshi.software.common.os.mac
Classes in oshi.software.common.os.mac that implement OSFileStoreModifier and TypeClassDescriptionclassCommon base class for macOS OSFileStore implementations. -
Uses of OSFileStore in oshi.software.common.os.unix.freebsd
Classes in oshi.software.common.os.unix.freebsd that implement OSFileStoreMethods in oshi.software.common.os.unix.freebsd that return types with arguments of type OSFileStore -
Uses of OSFileStore in oshi.software.common.os.unix.openbsd
Classes in oshi.software.common.os.unix.openbsd that implement OSFileStoreMethods in oshi.software.common.os.unix.openbsd that return types with arguments of type OSFileStoreModifier and TypeMethodDescriptionOpenBsdFileSystem.getFileStoreMatching(String nameToMatch, boolean localOnly) Gets file stores matching the given name (or all if null).OpenBsdFileSystem.getFileStores(boolean localOnly) -
Uses of OSFileStore in oshi.software.common.os.windows
Classes in oshi.software.common.os.windows that implement OSFileStoreModifier and TypeClassDescriptionclassCommon base class for Windows OSFileStore implementations. -
Uses of OSFileStore in oshi.software.os
Methods in oshi.software.os that return types with arguments of type OSFileStoreModifier and TypeMethodDescriptionFileSystem.getFileStores()Get file stores on this machine Instantiates a list ofOSFileStoreobjects, representing a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage.FileSystem.getFileStores(boolean localOnly) Get file stores on this machine Instantiates a list ofOSFileStoreobjects, representing a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage. -
Uses of OSFileStore in oshi.software.os.mac
Classes in oshi.software.os.mac that implement OSFileStoreMethods in oshi.software.os.mac that return types with arguments of type OSFileStore -
Uses of OSFileStore in oshi.software.os.unix.aix
Classes in oshi.software.os.unix.aix that implement OSFileStoreMethods in oshi.software.os.unix.aix that return types with arguments of type OSFileStore -
Uses of OSFileStore in oshi.software.os.unix.netbsd
Classes in oshi.software.os.unix.netbsd that implement OSFileStoreMethods in oshi.software.os.unix.netbsd that return types with arguments of type OSFileStore -
Uses of OSFileStore in oshi.software.os.unix.solaris
Classes in oshi.software.os.unix.solaris that implement OSFileStoreMethods in oshi.software.os.unix.solaris that return types with arguments of type OSFileStore -
Uses of OSFileStore in oshi.software.os.windows
Classes in oshi.software.os.windows that implement OSFileStoreModifier and TypeClassDescriptionclassJNA-based Windows OSFileStore implementation.Methods in oshi.software.os.windows that return types with arguments of type OSFileStore