Uses of Interface
oshi.software.os.OSProcess

Packages that use OSProcess
Package
Description
Provides abstract classes for common code
Provides common (native-free) Linux operating system implementations shared by JNA and FFM modules.
Native-free Linux operating system implementations using only procfs, sysfs, and command-line utilities.
Provides information about Software and OS on macOS
Provides abstract base classes and pure-Java implementations for the FreeBSD operating system, shared by the JNA and FFM modules.
Provides abstract base classes and pure-Java implementations for the OpenBSD operating system, shared by the JNA and FFM modules.
Provides common implementations for Windows operating system information shared between JNA and FFM implementations.
[oshi-common API] Provides cross-platform common API to retrieve OS, FileSystem, and Process information
Provides information about Software and OS on Linux
Provides information about Software and OS on macOS
Provides information about Software and OS on AIX
Provides information about Software and OS on DragonFly BSD
Provides information about Software and OS on FreeBSD
Provides information about Software and OS on NetBSD
Provides information about Software and OS on OpenBSD
Provides information about Software and OS on Solaris
Provides information about Software and OS on Windows