Uses of Class
oshi.software.os.OSService
Packages that use OSService
Package
Description
Provides common (native-free) Linux operating system implementations shared by JNA and FFM modules.
Provides information about Software and OS on macOS
Provides information about Software and OS on NetBSD
Provides abstract base classes and pure-Java implementations for Solaris/illumos software, shared by the JNA and FFM
modules.
[oshi-common API] Provides cross-platform common API to retrieve OS, FileSystem, and Process information
Provides information about Software and OS on AIX
Provides information about Software and OS on DragonFly BSD
Provides information about Software and OS on FreeBSD
Provides information about Software and OS on OpenBSD
Provides information about Software and OS on Windows
-
Uses of OSService in oshi.software.common.os.linux
Methods in oshi.software.common.os.linux that return types with arguments of type OSService -
Uses of OSService in oshi.software.common.os.mac
Methods in oshi.software.common.os.mac that return types with arguments of type OSService -
Uses of OSService in oshi.software.common.os.unix.netbsd
Methods in oshi.software.common.os.unix.netbsd that return types with arguments of type OSService -
Uses of OSService in oshi.software.common.os.unix.solaris
Methods in oshi.software.common.os.unix.solaris that return types with arguments of type OSService -
Uses of OSService in oshi.software.os
Methods in oshi.software.os that return types with arguments of type OSServiceModifier and TypeMethodDescriptionOperatingSystem.getServices()Gets the all services on the system. -
Uses of OSService in oshi.software.os.unix.aix
Methods in oshi.software.os.unix.aix that return types with arguments of type OSService -
Uses of OSService in oshi.software.os.unix.dragonflybsd
Methods in oshi.software.os.unix.dragonflybsd that return types with arguments of type OSService -
Uses of OSService in oshi.software.os.unix.freebsd
Methods in oshi.software.os.unix.freebsd that return types with arguments of type OSService -
Uses of OSService in oshi.software.os.unix.openbsd
Methods in oshi.software.os.unix.openbsd that return types with arguments of type OSService -
Uses of OSService in oshi.software.os.windows
Methods in oshi.software.os.windows that return types with arguments of type OSService