Uses of Class
oshi.software.os.OSSession
Packages that use OSSession
Package
Description
Provides functions to query Linux information
Provides functions to query Mac info
Provides functions to query FreeBSD information
Provides functions to query Solaris information
Provides functions to query data in Windows Registry
Provides abstract classes for common code
[oshi-common API] Provides cross-platform common API to retrieve OS, FileSystem, and Process information
Provides information about Software and OS on Linux
Provides information about Software and OS on macOS
Provides information about Software and OS on DragonFly BSD
Provides information about Software and OS on FreeBSD
Provides information about Software and OS on Solaris
Provides information about Software and OS on Windows
Provides non-native Linux driver utilities for querying system information.
Provides driver utilities common to unix systems that do not require native access
-
Uses of OSSession in oshi.driver.linux
Methods in oshi.driver.linux that return types with arguments of type OSSession -
Uses of OSSession in oshi.driver.mac
Methods in oshi.driver.mac that return types with arguments of type OSSession -
Uses of OSSession in oshi.driver.unix.freebsd
Methods in oshi.driver.unix.freebsd that return types with arguments of type OSSession -
Uses of OSSession in oshi.driver.unix.solaris
Methods in oshi.driver.unix.solaris that return types with arguments of type OSSession -
Uses of OSSession in oshi.driver.windows.registry
Methods in oshi.driver.windows.registry that return types with arguments of type OSSessionModifier and TypeMethodDescriptionHkeyUserData.queryUserSessions()NetSessionData.queryUserSessions()SessionWtsData.queryUserSessions() -
Uses of OSSession in oshi.software.common
Methods in oshi.software.common that return types with arguments of type OSSession -
Uses of OSSession in oshi.software.os
Methods in oshi.software.os that return types with arguments of type OSSession -
Uses of OSSession in oshi.software.os.linux
Methods in oshi.software.os.linux that return types with arguments of type OSSession -
Uses of OSSession in oshi.software.os.mac
Methods in oshi.software.os.mac that return types with arguments of type OSSession -
Uses of OSSession in oshi.software.os.unix.dragonflybsd
Methods in oshi.software.os.unix.dragonflybsd that return types with arguments of type OSSession -
Uses of OSSession in oshi.software.os.unix.freebsd
Methods in oshi.software.os.unix.freebsd that return types with arguments of type OSSession -
Uses of OSSession in oshi.software.os.unix.solaris
Methods in oshi.software.os.unix.solaris that return types with arguments of type OSSession -
Uses of OSSession in oshi.software.os.windows
Methods in oshi.software.os.windows that return types with arguments of type OSSession -
Uses of OSSession in oshi.util.driver.linux
Methods in oshi.util.driver.linux that return types with arguments of type OSSession -
Uses of OSSession in oshi.util.driver.unix
Methods in oshi.util.driver.unix that return types with arguments of type OSSessionModifier and TypeMethodDescriptionWho.queryWho()Querywhoto get logged in users, parsing Unix date format.Method parameters in oshi.util.driver.unix with type arguments of type OSSession