Class LinuxFileSystemJNA
java.lang.Object
oshi.software.common.AbstractFileSystem
oshi.software.common.os.linux.LinuxFileSystem
oshi.software.os.linux.LinuxFileSystemJNA
- All Implemented Interfaces:
FileSystem
JNA-based Linux file system implementation. Implements
statvfs via JNA.-
Field Summary
Fields inherited from class LinuxFileSystem
OSHI_LINUX_FS_PATH_EXCLUDES, OSHI_LINUX_FS_PATH_INCLUDES, OSHI_LINUX_FS_VOLUME_EXCLUDES, OSHI_LINUX_FS_VOLUME_INCLUDESFields inherited from class AbstractFileSystem
NETWORK_FS_TYPES, PSEUDO_FS_TYPESModifier and TypeFieldDescriptionFileSystem types which are network-based and should be excluded from local-only listsFileSystem types which are pseudo-filesystems and should be excluded from local-only lists -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionprotected long[]queryStatvfs(String path) Queries filesystem statistics for the given mount path.Methods inherited from class LinuxFileSystem
buildUuidMap, getFileStores, getMaxFileDescriptors, getMaxFileDescriptorsPerProcess, getOpenFileDescriptorsModifier and TypeMethodDescriptionBuilds a map of filesystem UUIDs to device paths.getFileStores(boolean localOnly) Get file stores on this machine Instantiates a list ofOSFileStoreobjects, representing a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage.longThe maximum number of open file descriptors.longThe maximum number of open file descriptors per process.longThe current number of open file descriptors.Methods inherited from class AbstractFileSystem
getFileStoresModifier and TypeMethodDescriptionGet file stores on this machine Instantiates a list ofOSFileStoreobjects, representing a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage.
-
Constructor Details
-
LinuxFileSystemJNA
public LinuxFileSystemJNA()
-
-
Method Details
-
queryStatvfs
Description copied from class:LinuxFileSystemQueries filesystem statistics for the given mount path.Returns an array of [totalInodes, freeInodes, totalSpace, usableSpace, freeSpace], or
nullon failure (the caller will fall back toFilemethods for space values).- Specified by:
queryStatvfsin classLinuxFileSystem- Parameters:
path- the mount path to query- Returns:
- array of [totalInodes, freeInodes, totalSpace, usableSpace, freeSpace], or
nullon failure
-