public class MacFileSystem extends AbstractFileSystem
OSFileStores which are
a storage pool, device, partition, volume, concrete file system or other
implementation specific means of file storage. In Mac OS X, these are found
in the /Volumes directory.NETWORK_FS_TYPES| Constructor and Description |
|---|
MacFileSystem() |
| Modifier and Type | Method and Description |
|---|---|
OSFileStore[] |
getFileStores(boolean localOnly)
Get file stores on this machine
Instantiates an array of
OSFileStore objects,
representing a storage pool, device, partition, volume, concrete file system
or other implementation specific means of file storage. |
long |
getMaxFileDescriptors()
The maximum number of open file descriptors.
|
long |
getOpenFileDescriptors()
The current number of open file descriptors.
|
static boolean |
updateFileStoreStats(OSFileStore osFileStore)
updateFileStoreStats.
|
getFileStorespublic OSFileStore[] getFileStores(boolean localOnly)
FileSystemOSFileStore objects,
representing a storage pool, device, partition, volume, concrete file system
or other implementation specific means of file storage.localOnly - If true, filters the list to only local file stores.public long getOpenFileDescriptors()
public long getMaxFileDescriptors()
public static boolean updateFileStoreStats(OSFileStore osFileStore)
updateFileStoreStats.
osFileStore - a OSFileStore object.Copyright © 2010–2020 oshi. All rights reserved.