Class MacFileSystemJNA
java.lang.Object
oshi.software.common.AbstractFileSystem
oshi.software.common.os.mac.MacFileSystem
oshi.software.os.mac.MacFileSystemJNA
- All Implemented Interfaces:
FileSystem
The Mac File System contains
OSFileStores which are a storage pool, device, partition,
volume, concrete file system or other implementation specific means of file storage. In macOS, these are found in the
/Volumes directory.-
Field Summary
Fields inherited from class MacFileSystem
FS_PATH_EXCLUDES, FS_PATH_INCLUDES, FS_VOLUME_EXCLUDES, FS_VOLUME_INCLUDES, LOCAL_DISK, MNT_ASYNC, MNT_AUTOMOUNTED, MNT_CPROTECT, MNT_DEFWRITE, MNT_DONTBROWSE, MNT_DOVOLFS, MNT_EXPORTED, MNT_IGNORE_OWNERSHIP, MNT_JOURNALED, MNT_LOCAL, MNT_MULTILABEL, MNT_NOATIME, MNT_NODEV, MNT_NOEXEC, MNT_NOSUID, MNT_NOUSERXATTR, MNT_QUARANTINE, MNT_QUOTA, MNT_RDONLY, MNT_ROOTFS, MNT_SYNCHRONOUS, MNT_UNION, OPTIONS_MAP, OSHI_MAC_FS_PATH_EXCLUDES, OSHI_MAC_FS_PATH_INCLUDES, OSHI_MAC_FS_VOLUME_EXCLUDES, OSHI_MAC_FS_VOLUME_INCLUDESModifier and TypeFieldDescriptionprotected static final List<PathMatcher> File system path exclude matchers.protected static final List<PathMatcher> File system path include matchers.protected static final List<PathMatcher> File system volume exclude matchers.protected static final List<PathMatcher> File system volume include matchers.protected static final PatternPattern matching local disk device paths.protected static final intMount flag: asynchronous.protected static final intMount flag: automounted.protected static final intMount flag: content protection.protected static final intMount flag: deferred writes.protected static final intMount flag: don't browse.protected static final intMount flag: volfs.protected static final intMount flag: exported.protected static final intMount flag: ignore ownership.protected static final intMount flag: journaled.protected static final intMount flag: local.protected static final intMount flag: multilabel MAC.protected static final intMount flag: no access time.protected static final intMount flag: no device access.protected static final intMount flag: no exec.protected static final intMount flag: no setuid.protected static final intMount flag: no user extended attributes.protected static final intMount flag: quarantined.protected static final intMount flag: quotas.protected static final intMount flag: read-only.protected static final intMount flag: root filesystem.protected static final intMount flag: synchronous.protected static final intMount flag: union.Map of mount flags to option strings.static final StringConfiguration key for path excludes.static final StringConfiguration key for path includes.static final StringConfiguration key for volume excludes.static final StringConfiguration key for volume includes.Fields inherited from class AbstractFileSystem
NETWORK_FS_TYPES, PSEUDO_FS_TYPESModifier and TypeFieldDescriptionFileSystem types which are network-based and should be excluded from local-only listsFileSystem types which are pseudo-filesystems and should be excluded from local-only lists -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptiongetFileStores(boolean localOnly) Get file stores on this machine Instantiates a list ofOSFileStoreobjects, representing a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage.longThe maximum number of open file descriptors.longThe maximum number of open file descriptors per process.longThe current number of open file descriptors.Methods inherited from class AbstractFileSystem
getFileStoresModifier and TypeMethodDescriptionGet file stores on this machine Instantiates a list ofOSFileStoreobjects, representing a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage.
-
Constructor Details
-
MacFileSystemJNA
public MacFileSystemJNA()
-
-
Method Details
-
getFileStores
Description copied from interface:FileSystemGet file stores on this machine Instantiates a list ofOSFileStoreobjects, representing a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage.- Parameters:
localOnly- If true, filters the list to only local file stores. On Windows, also excluded CD-ROM drives.- Returns:
- A list of
OSFileStoreobjects or an empty array if none are present.
-
getOpenFileDescriptors
public long getOpenFileDescriptors()Description copied from interface:FileSystemThe current number of open file descriptors. A file descriptor is an abstract handle used to access I/O resources such as files and network connections. On UNIX-based systems there is a system-wide limit on the number of open file descriptors. On Windows systems, this method returns the total number of handles held by Processes. While Windows handles are conceptually similar to file descriptors, they may also refer to a number of non-I/O related objects.- Returns:
- The number of open file descriptors if available, 0 otherwise.
-
getMaxFileDescriptors
public long getMaxFileDescriptors()Description copied from interface:FileSystemThe maximum number of open file descriptors. A file descriptor is an abstract handle used to access I/O resources such as files and network connections. On UNIX-based systems there is a system-wide limit on the number of open file descriptors. On Windows systems, this method returns the theoretical max number of handles (2^24-2^15 on 32-bit, 2^24-2^16 on 64-bit). There may be a lower per-process limit. While Windows handles are conceptually similar to file descriptors, they may also refer to a number of non-I/O related objects.- Returns:
- The maximum number of file descriptors if available, 0 otherwise.
-
getMaxFileDescriptorsPerProcess
public long getMaxFileDescriptorsPerProcess()Description copied from interface:FileSystemThe maximum number of open file descriptors per process. This returns the upper limit which applies to each process. The actual limit of a process may be lower if configured.- Returns:
- The maximum number of file descriptors of each process if available, 0 otherwise.
-