Class MacOSFileStoreJNA

All Implemented Interfaces:
OSFileStore

@ThreadSafe public class MacOSFileStoreJNA extends MacOSFileStore
OSFileStore implementation
  • Constructor Details

    • MacOSFileStoreJNA

      public MacOSFileStoreJNA(String name, String volume, String label, String mount, String options, String uuid, boolean local, String logicalVolume, String description, String fsType, long freeSpace, long usableSpace, long totalSpace, long freeInodes, long totalInodes)
  • Method Details

    • updateAttributes

      public boolean updateAttributes()
      Description copied from interface: OSFileStore
      Make a best effort to update all the statistics about the file store without needing to recreate the file store list. This method provides for more frequent periodic updates of file store statistics.
      Returns:
      True if the update was (probably) successful, false if the disk was not found