Class MacOperatingSystem
- All Implemented Interfaces:
OperatingSystem
@ThreadSafe public class MacOperatingSystem extends AbstractOperatingSystem
-
Nested Class Summary
Nested classes/interfaces inherited from class oshi.software.common.AbstractOperatingSystem
AbstractOperatingSystem.FamilyVersionInfoNested classes/interfaces inherited from interface oshi.software.os.OperatingSystem
OperatingSystem.OSVersionInfo, OperatingSystem.ProcessSort -
Field Summary
Fields Modifier and Type Field Description static java.lang.StringMACOS_VERSIONS_PROPERTIESFields inherited from class oshi.software.common.AbstractOperatingSystem
OSHI_OS_UNIX_WHOCOMMAND, USE_WHO_COMMAND -
Constructor Summary
Constructors Constructor Description MacOperatingSystem() -
Method Summary
Modifier and Type Method Description java.util.List<OSProcess>getChildProcesses(int parentPid, int limit, OperatingSystem.ProcessSort sort)Gets currently running child processes of provided parent PID, optionally limited to the top "N" for a particular sorting order.java.util.List<OSDesktopWindow>getDesktopWindows(boolean visibleOnly)Gets windows on the operating system's GUI desktop.FileSystemgetFileSystem()Instantiates aFileSystemobject.InternetProtocolStatsgetInternetProtocolStats()Instantiates aInternetProtocolStatsobject.NetworkParamsgetNetworkParams()Instantiates aNetworkParamsobject.OSProcessgetProcess(int pid)Gets information on a currently running processintgetProcessCount()Get the number of processes currently runningjava.util.List<OSProcess>getProcesses(int limit, OperatingSystem.ProcessSort sort)Gets currently running processes, optionally limited to the top "N" for a particular sorting order.intgetProcessId()Gets the current process IDOSService[]getServices()Gets the all services on the system.java.util.List<OSSession>getSessions()Gets currently logged in users.longgetSystemBootTime()Get Unix time of boot.longgetSystemUptime()Get the System up time (time since boot).intgetThreadCount()Get the number of threads currently runningprotected intqueryBitness(int jvmBitness)Backup OS-specific query to determine bitness if previous checks failAbstractOperatingSystem.FamilyVersionInfoqueryFamilyVersionInfo()java.lang.StringqueryManufacturer()Methods inherited from class oshi.software.common.AbstractOperatingSystem
getBitness, getFamily, getManufacturer, getProcesses, getProcesses, getVersionInfo, isElevated, processSort, toStringMethods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, wait
-
Field Details
-
MACOS_VERSIONS_PROPERTIES
public static final java.lang.String MACOS_VERSIONS_PROPERTIES- See Also:
- Constant Field Values
-
-
Constructor Details
-
MacOperatingSystem
public MacOperatingSystem()
-
-
Method Details
-
queryManufacturer
public java.lang.String queryManufacturer()- Specified by:
queryManufacturerin classAbstractOperatingSystem
-
queryFamilyVersionInfo
- Specified by:
queryFamilyVersionInfoin classAbstractOperatingSystem
-
queryBitness
protected int queryBitness(int jvmBitness)Description copied from class:AbstractOperatingSystemBackup OS-specific query to determine bitness if previous checks fail- Specified by:
queryBitnessin classAbstractOperatingSystem- Parameters:
jvmBitness- The bitness of the JVM- Returns:
- The operating system bitness
-
getFileSystem
Description copied from interface:OperatingSystemInstantiates aFileSystemobject.- Returns:
- A
FileSystemobject.
-
getInternetProtocolStats
Description copied from interface:OperatingSystemInstantiates aInternetProtocolStatsobject.- Returns:
- a
InternetProtocolStatsobject.
-
getSessions
Description copied from interface:OperatingSystemGets currently logged in users.On macOS, Linux, and Unix systems, the default implementation uses native code (see
man getutxent) that is not thread safe. OSHI's use of this code is synchronized and may be used in a multi-threaded environment without introducing any additional conflicts. Users should note, however, that other operating system code may access the same native code.The
Who.queryWho()method produces similar output parsing the output of the Posix-standardwhocommand, and may internally employ reentrant code on some platforms. Users may opt to use this command-line variant by default using theoshi.os.unix.whoCommandconfiguration property.- Specified by:
getSessionsin interfaceOperatingSystem- Overrides:
getSessionsin classAbstractOperatingSystem- Returns:
- A list of
OSSessionobjects representing logged-in users
-
getProcesses
Description copied from interface:OperatingSystemGets currently running processes, optionally limited to the top "N" for a particular sorting order. If a positive limit is specified, returns only that number of processes; zero will return all processes. The order may be specified by the sort parameter, for example, to return the top cpu or memory consuming processes; if the sort isnull, no order is guaranteed.- Parameters:
limit- Max number of results to return, or 0 to return all resultssort- If not null, determines sorting of results- Returns:
- A list of
OSProcessobjects for the specified number (or all) of currently running processes, sorted as specified. The list may contain null elements or processes with a state ofOSProcess.State.INVALIDif a process terminates during iteration.
-
getProcess
Description copied from interface:OperatingSystemGets information on a currently running process- Parameters:
pid- A process ID- Returns:
- An
OSProcessobject for the specified process id if it is running; null otherwise
-
getChildProcesses
public java.util.List<OSProcess> getChildProcesses(int parentPid, int limit, OperatingSystem.ProcessSort sort)Description copied from interface:OperatingSystemGets currently running child processes of provided parent PID, optionally limited to the top "N" for a particular sorting order. If a positive limit is specified, returns only that number of processes; zero will return all processes. The order may be specified by the sort parameter, for example, to return the top cpu or memory consuming processes; if the sort isnull, no order is guaranteed.- Specified by:
getChildProcessesin interfaceOperatingSystem- Overrides:
getChildProcessesin classAbstractOperatingSystem- Parameters:
parentPid- A process IDlimit- Max number of results to return, or 0 to return all resultssort- If not null, determines sorting of results- Returns:
- A list of
OSProcessobjects representing the specified number (or all) of currently running child processes of the provided PID, sorted as specified. The list may contain null elements or processes with a state ofOSProcess.State.INVALIDif a process terminates during iteration.
-
getProcessId
public int getProcessId()Description copied from interface:OperatingSystemGets the current process ID- Returns:
- the Process ID of the current process
-
getProcessCount
public int getProcessCount()Description copied from interface:OperatingSystemGet the number of processes currently running- Returns:
- The number of processes running
-
getThreadCount
public int getThreadCount()Description copied from interface:OperatingSystemGet the number of threads currently running- Returns:
- The number of threads running
-
getSystemUptime
public long getSystemUptime()Description copied from interface:OperatingSystemGet the System up time (time since boot).- Returns:
- Number of seconds since boot.
-
getSystemBootTime
public long getSystemBootTime()Description copied from interface:OperatingSystemGet Unix time of boot.- Returns:
- The approximate time at which the system booted, in seconds since the Unix epoch.
-
getNetworkParams
Description copied from interface:OperatingSystemInstantiates aNetworkParamsobject.- Returns:
- A
NetworkParamsobject.
-
getServices
Description copied from interface:OperatingSystemGets the all services on the system. The definition of what is a service is platform-dependent.- Specified by:
getServicesin interfaceOperatingSystem- Overrides:
getServicesin classAbstractOperatingSystem- Returns:
- An array of
OSServiceobjects
-
getDesktopWindows
Description copied from interface:OperatingSystemGets windows on the operating system's GUI desktop.On Unix-like systems, reports X11 windows only, which may be limited to the current display and will not report windows used by other window managers.
While not a guarantee, a best effort is made to return windows in foreground-to-background order. This ordering may be used along with
OSDesktopWindow.getOrder()to (probably) determine the frontmost window.- Specified by:
getDesktopWindowsin interfaceOperatingSystem- Overrides:
getDesktopWindowsin classAbstractOperatingSystem- Parameters:
visibleOnly- Whether to restrict the list to only windows visible to the user.This is a best effort attempt at a reasonable definition of visibility. Visible windows may be completely transparent.
- Returns:
- A list of
OSDesktopWindowobjects representing the desktop windows.
-