Class MacOperatingSystemJNA
- All Implemented Interfaces:
OperatingSystem
-
Nested Class Summary
Nested classes/interfaces inherited from interface OperatingSystem
OperatingSystem.OSVersionInfo, OperatingSystem.ProcessFiltering, OperatingSystem.ProcessSortingModifier and TypeInterfaceDescriptionstatic classA class representing the Operating System version details.static final classConstants which may be used to filter Process lists inOperatingSystem.getProcesses(Predicate, Comparator, int),OperatingSystem.getChildProcesses(int, Predicate, Comparator, int), andOperatingSystem.getDescendantProcesses(int, Predicate, Comparator, int).static final classConstants which may be used to sort Process lists inOperatingSystem.getProcesses(Predicate, Comparator, int),OperatingSystem.getChildProcesses(int, Predicate, Comparator, int), andOperatingSystem.getDescendantProcesses(int, Predicate, Comparator, int). -
Field Summary
Fields inherited from class MacOperatingSystem
MACOS_VERSIONS_PROPERTIES, major, maxProc, minor, osXVersionFields inherited from class AbstractOperatingSystem
USE_WHO_COMMANDModifier and TypeFieldDescriptionprotected static final booleanWhether to use the 'who' command for session queries. -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptiongetDesktopWindows(boolean visibleOnly) Gets windows on the operating system's GUI desktop.Instantiates aFileSystemobject.Instantiates aInternetProtocolStatsobject.Instantiates aNetworkParamsobject.getProcess(int pid) Gets information on a currently running processintGet the number of processes currently runningintGets the current process ID (PID).Gets currently logged in users.longGet Unix time of boot.intGet the number of threads currently runningQueries all processes on the system.Queries the OS family and version info.Methods inherited from class MacOperatingSystem
getCurrentThread, getInstalledApplications, getServices, getSystemUptime, getThreadId, parseCodeName, queryBitness, queryChildProcesses, queryDescendantProcesses, queryManufacturerModifier and TypeMethodDescriptionMakes a best effort to get the current thread.Retrieves a list of installed applications on the system.Gets the all services on the system.longGet the System up time (time since boot).intMakes a best effort to get the current thread ID (TID).protected StringParses the macOS code name from the version.protected intqueryBitness(int jvmBitness) Backup OS-specific query to determine bitness if previous checks failqueryChildProcesses(int parentPid) Queries the children of a process.queryDescendantProcesses(int parentPid) Queries the descendants of a process.Queries the OS manufacturer.Methods inherited from class AbstractOperatingSystem
getBitness, getChildProcesses, getChildrenOrDescendants, getChildrenOrDescendants, getDescendantProcesses, getFamily, getManufacturer, getProcesses, getVersionInfo, isElevated, toStringModifier and TypeMethodDescriptionintGets the bitness (32 or 64) of the operating system.getChildProcesses(int parentPid, Predicate<OSProcess> filter, Comparator<OSProcess> sort, int limit) Gets currently running child processes of provided parent PID, optionally filtering, sorting, and limited to the top "N".getChildrenOrDescendants(Collection<OSProcess> allProcs, int parentPid, boolean allDescendants) Utility method for subclasses to take a full process list as input and return the children or descendants of a particular process.getChildrenOrDescendants(Map<Integer, Integer> parentPidMap, int parentPid, boolean allDescendants) Utility method for subclasses to take a map of pid to parent as input and return the children or descendants of a particular process.getDescendantProcesses(int parentPid, Predicate<OSProcess> filter, Comparator<OSProcess> sort, int limit) Gets currently running processes of provided parent PID's descendants, including their children, the children's children, etc., optionally filtering, sorting, and limited to the top "N".Get the Operating System family.Get the Operating System manufacturer.getProcesses(Predicate<OSProcess> filter, Comparator<OSProcess> sort, int limit) Gets currently running processes, optionally filtering, sorting, and limited to the top "N".Get Operating System version information.booleanDetermine whether the current process has elevated permissions such as sudo / AdministratortoString()Methods inherited from class Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface OperatingSystem
getCgroupInfo, getCurrentProcess, getProcesses, getProcessesModifier and TypeMethodDescriptiondefault CgroupInfoRetrieves cgroup information for the current process.default OSProcessGets the current process.Gets currently running processes.getProcesses(Collection<Integer> pids) Gets information on aCollectionof currently running processes.
-
Constructor Details
-
MacOperatingSystemJNA
public MacOperatingSystemJNA() -
MacOperatingSystemJNA
protected MacOperatingSystemJNA(int maxproc)
-
-
Method Details
-
getSystemBootTime
public long getSystemBootTime()Description copied from interface:OperatingSystemGet Unix time of boot.- Returns:
- The approximate time at which the system booted, in seconds since the Unix epoch.
-
getFileSystem
Description copied from interface:OperatingSystemInstantiates aFileSystemobject.- Returns:
- A
FileSystemobject.
-
getInternetProtocolStats
Description copied from interface:OperatingSystemInstantiates aInternetProtocolStatsobject.- Returns:
- a
InternetProtocolStatsobject.
-
queryFamilyVersionInfo
Description copied from class:AbstractOperatingSystemQueries the OS family and version info.- Specified by:
queryFamilyVersionInfoin classAbstractOperatingSystem- Returns:
- a pair of family string and OS version info
-
getSessions
Description copied from interface:OperatingSystemGets currently logged in users.On macOS, Linux, and Unix systems, the default implementation uses native code (see
man getutxent) that is not thread safe. OSHI's use of this code is synchronized and may be used in a multi-threaded environment without introducing any additional conflicts. Users should note, however, that other operating system code may access the same native code.The
Who#queryWho()method produces similar output parsing the output of the Posix-standardwhocommand, and may internally employ reentrant code on some platforms. Users may opt to use this command-line variant by default using theoshi.os.unix.whocommandconfiguration property.- Specified by:
getSessionsin interfaceOperatingSystem- Overrides:
getSessionsin classAbstractOperatingSystem- Returns:
- A list of
OSSessionobjects representing logged-in users
-
queryAllProcesses
Description copied from class:AbstractOperatingSystemQueries all processes on the system.- Specified by:
queryAllProcessesin classAbstractOperatingSystem- Returns:
- a list of all OS processes
-
getProcess
Description copied from interface:OperatingSystemGets information on a currently running process- Parameters:
pid- A process ID- Returns:
- An
OSProcessobject for the specified process id if it is running; null otherwise
-
getProcessId
public int getProcessId()Description copied from interface:OperatingSystemGets the current process ID (PID).- Returns:
- the Process ID of the current process
-
getProcessCount
public int getProcessCount()Description copied from interface:OperatingSystemGet the number of processes currently running- Returns:
- The number of processes running
-
getThreadCount
public int getThreadCount()Description copied from interface:OperatingSystemGet the number of threads currently running- Returns:
- The number of threads running
-
getNetworkParams
Description copied from interface:OperatingSystemInstantiates aNetworkParamsobject.- Returns:
- A
NetworkParamsobject.
-
getDesktopWindows
Description copied from interface:OperatingSystemGets windows on the operating system's GUI desktop.On Unix-like systems, reports X11 windows only, which may be limited to the current display and will not report windows used by other window managers.
While not a guarantee, a best effort is made to return windows in foreground-to-background order. This ordering may be used along with
OSDesktopWindow.getOrder()to (probably) determine the frontmost window.- Specified by:
getDesktopWindowsin interfaceOperatingSystem- Overrides:
getDesktopWindowsin classAbstractOperatingSystem- Parameters:
visibleOnly- Whether to restrict the list to only windows visible to the user.This is a best effort attempt at a reasonable definition of visibility. Visible windows may be completely transparent.
- Returns:
- A list of
OSDesktopWindowobjects representing the desktop windows.
-