Package oshi.software.os

[oshi-core API] Provides cross-platform implementation to retrieve OS, FileSystem, and Process information
  • Interface Summary
    Interface Description
    FileSystem
    The File System is a logical arrangement, usually in a hierarchial tree, where files are placed for storage and retrieval.
    InternetProtocolStats
    Includes key statistics of TCP and UDP protocols
    NetworkParams
    NetworkParams presents network parameters of running OS, such as DNS, host name etc.
    OperatingSystem
    An operating system (OS) is the software on a computer that manages the way different programs use its hardware, and regulates the ways that a user controls the computer.
    OSFileStore
    A FileStore represents a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage.
    OSProcess
    Represents a Process on the operating system, which may contain multiple threads.
    OSThread
    Represents a Thread/Task on the operating system.
  • Class Summary
    Class Description
    InternetProtocolStats.IPConnection
    Encapsulates information associated with an IP connection.
    InternetProtocolStats.TcpStats
    Encapsulates statistics associated with a TCP connection.
    InternetProtocolStats.UdpStats
    Encapsulates statistics associated with a UDP connection.
    OperatingSystem.OSVersionInfo
    A class representing the Operating System version details.
    OSDesktopWindow
    This class encapsulates information about a window on the operating system's GUI desktop
    OSService
    Operating system services are responsible for the management of platform resources, including the processor, memory, files, and input and output.
    OSSession
    This class encapsulates information about users who are currently logged in to an operating system.
  • Enum Summary
    Enum Description
    InternetProtocolStats.TcpState
    The TCP connection state as described in RFC 793.
    OperatingSystem.ProcessSort
    Controls sorting of Process output
    OSProcess.State
    Process Execution States
    OSService.State
    Service Execution States