Uses of Package
oshi.software.os
| Package | Description |
|---|---|
| oshi |
[oshi-core API] Provides a cross-platform implementation to retrieve
Operating System and Hardware Information, such as OS version, memory, CPU,
disk, devices, sensors, etc.
|
| oshi.driver.windows.registry |
Provides functions to query data in Windows Registry
|
| oshi.software.common |
Provides abstract classes for common code
|
| oshi.software.os |
[oshi-core API] Provides cross-platform implementation to retrieve OS,
FileSystem, and Process information
|
| oshi.software.os.linux |
Provides information about Software and OS on Linux
|
| oshi.software.os.mac |
Provides information about Software and OS on Mac OS X
|
| oshi.software.os.unix.freebsd |
Provides information about Software and OS on FreeBSD
|
| oshi.software.os.unix.solaris |
Provides information about Software and OS on Solaris
|
| oshi.software.os.windows |
Provides information about Software and OS on Windows
|
-
Classes in oshi.software.os used by oshi Class Description OperatingSystem An operating system (OS) is the software on a computer that manages the way different programs use its hardware, and regulates the ways that a user controls the computer. -
Classes in oshi.software.os used by oshi.driver.windows.registry Class Description OperatingSystem An operating system (OS) is the software on a computer that manages the way different programs use its hardware, and regulates the ways that a user controls the computer.OSProcess A process is an instance of a computer program that is being executed. -
Classes in oshi.software.os used by oshi.software.common Class Description FileSystem The File System is a logical arrangement, usually in a hierarchial tree, where files are placed for storage and retrieval.NetworkParams NetworkParams presents network parameters of running OS, such as DNS, host name etc.OperatingSystem An operating system (OS) is the software on a computer that manages the way different programs use its hardware, and regulates the ways that a user controls the computer.OperatingSystem.OSVersionInfo OperatingSystem.ProcessSort Controls sorting of Process outputOperatingSystemVersion Deprecated.OSFileStore A File Store is a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage.OSProcess A process is an instance of a computer program that is being executed.OSService Operating system services are responsible for the management of platform resources, including the processor, memory, files, and input and output. -
Classes in oshi.software.os used by oshi.software.os Class Description FileSystem The File System is a logical arrangement, usually in a hierarchial tree, where files are placed for storage and retrieval.InternetProtocolStats Includes key statistics of TCP and UDP protocolsInternetProtocolStats.TcpStats InternetProtocolStats.UdpStats NetworkParams NetworkParams presents network parameters of running OS, such as DNS, host name etc.OperatingSystem An operating system (OS) is the software on a computer that manages the way different programs use its hardware, and regulates the ways that a user controls the computer.OperatingSystem.OSVersionInfo OperatingSystem.ProcessSort Controls sorting of Process outputOperatingSystemVersion Deprecated.OSFileStore A File Store is a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage.OSProcess A process is an instance of a computer program that is being executed.OSProcess.State Process Execution StatesOSService Operating system services are responsible for the management of platform resources, including the processor, memory, files, and input and output.OSService.State Service Execution States -
Classes in oshi.software.os used by oshi.software.os.linux Class Description FileSystem The File System is a logical arrangement, usually in a hierarchial tree, where files are placed for storage and retrieval.InternetProtocolStats Includes key statistics of TCP and UDP protocolsInternetProtocolStats.TcpStats InternetProtocolStats.UdpStats NetworkParams NetworkParams presents network parameters of running OS, such as DNS, host name etc.OperatingSystem An operating system (OS) is the software on a computer that manages the way different programs use its hardware, and regulates the ways that a user controls the computer.OperatingSystem.ProcessSort Controls sorting of Process outputOperatingSystemVersion Deprecated.OSFileStore A File Store is a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage.OSProcess A process is an instance of a computer program that is being executed.OSService Operating system services are responsible for the management of platform resources, including the processor, memory, files, and input and output. -
Classes in oshi.software.os used by oshi.software.os.mac Class Description FileSystem The File System is a logical arrangement, usually in a hierarchial tree, where files are placed for storage and retrieval.InternetProtocolStats Includes key statistics of TCP and UDP protocolsInternetProtocolStats.TcpStats InternetProtocolStats.UdpStats NetworkParams NetworkParams presents network parameters of running OS, such as DNS, host name etc.OperatingSystem An operating system (OS) is the software on a computer that manages the way different programs use its hardware, and regulates the ways that a user controls the computer.OperatingSystem.ProcessSort Controls sorting of Process outputOperatingSystemVersion Deprecated.OSFileStore A File Store is a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage.OSProcess A process is an instance of a computer program that is being executed.OSService Operating system services are responsible for the management of platform resources, including the processor, memory, files, and input and output. -
Classes in oshi.software.os used by oshi.software.os.unix.freebsd Class Description FileSystem The File System is a logical arrangement, usually in a hierarchial tree, where files are placed for storage and retrieval.InternetProtocolStats Includes key statistics of TCP and UDP protocolsInternetProtocolStats.TcpStats InternetProtocolStats.UdpStats NetworkParams NetworkParams presents network parameters of running OS, such as DNS, host name etc.OperatingSystem An operating system (OS) is the software on a computer that manages the way different programs use its hardware, and regulates the ways that a user controls the computer.OperatingSystem.ProcessSort Controls sorting of Process outputOperatingSystemVersion Deprecated.OSFileStore A File Store is a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage.OSProcess A process is an instance of a computer program that is being executed.OSService Operating system services are responsible for the management of platform resources, including the processor, memory, files, and input and output. -
Classes in oshi.software.os used by oshi.software.os.unix.solaris Class Description FileSystem The File System is a logical arrangement, usually in a hierarchial tree, where files are placed for storage and retrieval.InternetProtocolStats Includes key statistics of TCP and UDP protocolsInternetProtocolStats.TcpStats InternetProtocolStats.UdpStats NetworkParams NetworkParams presents network parameters of running OS, such as DNS, host name etc.OperatingSystem An operating system (OS) is the software on a computer that manages the way different programs use its hardware, and regulates the ways that a user controls the computer.OperatingSystem.ProcessSort Controls sorting of Process outputOperatingSystemVersion Deprecated.OSFileStore A File Store is a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage.OSProcess A process is an instance of a computer program that is being executed.OSService Operating system services are responsible for the management of platform resources, including the processor, memory, files, and input and output. -
Classes in oshi.software.os used by oshi.software.os.windows Class Description FileSystem The File System is a logical arrangement, usually in a hierarchial tree, where files are placed for storage and retrieval.InternetProtocolStats Includes key statistics of TCP and UDP protocolsInternetProtocolStats.TcpStats InternetProtocolStats.UdpStats NetworkParams NetworkParams presents network parameters of running OS, such as DNS, host name etc.OperatingSystem An operating system (OS) is the software on a computer that manages the way different programs use its hardware, and regulates the ways that a user controls the computer.OperatingSystem.ProcessSort Controls sorting of Process outputOperatingSystemVersion Deprecated.OSFileStore A File Store is a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage.OSProcess A process is an instance of a computer program that is being executed.OSService Operating system services are responsible for the management of platform resources, including the processor, memory, files, and input and output.