Class AixOperatingSystem

java.lang.Object
oshi.software.common.AbstractOperatingSystem
oshi.software.os.unix.aix.AixOperatingSystem
All Implemented Interfaces:
OperatingSystem

@ThreadSafe
public class AixOperatingSystem
extends AbstractOperatingSystem
AIX (Advanced Interactive eXecutive) is a series of proprietary Unix operating systems developed and sold by IBM for several of its computer platforms.
  • Constructor Details

    • AixOperatingSystem

      public AixOperatingSystem()
  • Method Details

    • queryManufacturer

      public java.lang.String queryManufacturer()
      Specified by:
      queryManufacturer in class AbstractOperatingSystem
    • queryFamilyVersionInfo

      public AbstractOperatingSystem.FamilyVersionInfo queryFamilyVersionInfo()
      Specified by:
      queryFamilyVersionInfo in class AbstractOperatingSystem
    • queryBitness

      protected int queryBitness​(int jvmBitness)
      Description copied from class: AbstractOperatingSystem
      Backup OS-specific query to determine bitness if previous checks fail
      Specified by:
      queryBitness in class AbstractOperatingSystem
      Parameters:
      jvmBitness - The bitness of the JVM
      Returns:
      The operating system bitness
    • getFileSystem

      public FileSystem getFileSystem()
      Description copied from interface: OperatingSystem
      Instantiates a FileSystem object.
      Returns:
      A FileSystem object.
    • getInternetProtocolStats

      public InternetProtocolStats getInternetProtocolStats()
      Description copied from interface: OperatingSystem
      Instantiates a InternetProtocolStats object.
      Returns:
      a InternetProtocolStats object.
    • getProcesses

      public java.util.List<OSProcess> getProcesses​(int limit, OperatingSystem.ProcessSort sort)
      Description copied from interface: OperatingSystem
      Gets currently running processes, optionally limited to the top "N" for a particular sorting order. If a positive limit is specified, returns only that number of processes; zero will return all processes. The order may be specified by the sort parameter, for example, to return the top cpu or memory consuming processes; if the sort is null, no order is guaranteed.
      Parameters:
      limit - Max number of results to return, or 0 to return all results
      sort - If not null, determines sorting of results
      Returns:
      A list of OSProcess objects for the specified number (or all) of currently running processes, sorted as specified. The list may contain null elements or processes with a state of OSProcess.State.INVALID if a process terminates during iteration.
    • getProcess

      public OSProcess getProcess​(int pid)
      Description copied from interface: OperatingSystem
      Gets information on a currently running process
      Parameters:
      pid - A process ID
      Returns:
      An OSProcess object for the specified process id if it is running; null otherwise
    • getProcessId

      public int getProcessId()
      Description copied from interface: OperatingSystem
      Gets the current process ID
      Returns:
      the Process ID of the current process
    • getProcessCount

      public int getProcessCount()
      Description copied from interface: OperatingSystem
      Get the number of processes currently running
      Returns:
      The number of processes running
    • getThreadCount

      public int getThreadCount()
      Description copied from interface: OperatingSystem
      Get the number of threads currently running
      Returns:
      The number of threads running
    • getSystemUptime

      public long getSystemUptime()
      Description copied from interface: OperatingSystem
      Get the System up time (time since boot).
      Returns:
      Number of seconds since boot.
    • getSystemBootTime

      public long getSystemBootTime()
      Description copied from interface: OperatingSystem
      Get Unix time of boot.
      Returns:
      The approximate time at which the system booted, in seconds since the Unix epoch.
    • getNetworkParams

      public NetworkParams getNetworkParams()
      Description copied from interface: OperatingSystem
      Instantiates a NetworkParams object.
      Returns:
      A NetworkParams object.
    • getServices

      public OSService[] getServices()
      Description copied from interface: OperatingSystem
      Gets the all services on the system. The definition of what is a service is platform-dependent.
      Specified by:
      getServices in interface OperatingSystem
      Overrides:
      getServices in class AbstractOperatingSystem
      Returns:
      An array of OSService objects