Class OpenBsdFileSystem
java.lang.Object
oshi.software.common.AbstractFileSystem
oshi.software.common.os.unix.openbsd.OpenBsdFileSystem
oshi.software.os.unix.openbsd.OpenBsdFileSystem
- All Implemented Interfaces:
FileSystem
The OpenBSD File System contains
OSFileStores which are a storage pool, device, partition,
volume, concrete file system or other implementation specific means of file storage.-
Field Summary
Fields inherited from class OpenBsdFileSystem
OSHI_OPENBSD_FS_PATH_EXCLUDES, OSHI_OPENBSD_FS_PATH_INCLUDES, OSHI_OPENBSD_FS_VOLUME_EXCLUDES, OSHI_OPENBSD_FS_VOLUME_INCLUDESFields inherited from class AbstractFileSystem
NETWORK_FS_TYPES, PSEUDO_FS_TYPESModifier and TypeFieldDescriptionFileSystem types which are network-based and should be excluded from local-only listsFileSystem types which are pseudo-filesystems and should be excluded from local-only lists -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionlongThe maximum number of open file descriptors.longThe maximum number of open file descriptors per process.longThe current number of open file descriptors.Methods inherited from class OpenBsdFileSystem
getFileStoreMatching, getFileStoresModifier and TypeMethodDescriptiongetFileStoreMatching(String nameToMatch, boolean localOnly) Gets file stores matching the given name (or all if null).getFileStores(boolean localOnly) Get file stores on this machine Instantiates a list ofOSFileStoreobjects, representing a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage.Methods inherited from class AbstractFileSystem
getFileStoresModifier and TypeMethodDescriptionGet file stores on this machine Instantiates a list ofOSFileStoreobjects, representing a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage.
-
Constructor Details
-
OpenBsdFileSystem
public OpenBsdFileSystem()
-
-
Method Details
-
getOpenFileDescriptors
public long getOpenFileDescriptors()Description copied from interface:FileSystemThe current number of open file descriptors. A file descriptor is an abstract handle used to access I/O resources such as files and network connections. On UNIX-based systems there is a system-wide limit on the number of open file descriptors. On Windows systems, this method returns the total number of handles held by Processes. While Windows handles are conceptually similar to file descriptors, they may also refer to a number of non-I/O related objects.- Returns:
- The number of open file descriptors if available, 0 otherwise.
-
getMaxFileDescriptors
public long getMaxFileDescriptors()Description copied from interface:FileSystemThe maximum number of open file descriptors. A file descriptor is an abstract handle used to access I/O resources such as files and network connections. On UNIX-based systems there is a system-wide limit on the number of open file descriptors. On Windows systems, this method returns the theoretical max number of handles (2^24-2^15 on 32-bit, 2^24-2^16 on 64-bit). There may be a lower per-process limit. While Windows handles are conceptually similar to file descriptors, they may also refer to a number of non-I/O related objects.- Returns:
- The maximum number of file descriptors if available, 0 otherwise.
-
getMaxFileDescriptorsPerProcess
public long getMaxFileDescriptorsPerProcess()Description copied from interface:FileSystemThe maximum number of open file descriptors per process. This returns the upper limit which applies to each process. The actual limit of a process may be lower if configured.- Returns:
- The maximum number of file descriptors of each process if available, 0 otherwise.
-