Class WindowsOSThreadJNA

All Implemented Interfaces:
OSThread

@ThreadSafe public class WindowsOSThreadJNA extends WindowsOSThread
JNA-based Windows OS thread implementation.
  • Constructor Details

  • Method Details

    • updateAttributes

      public boolean updateAttributes()
      Description copied from interface: OSThread
      Attempts to updates process attributes. Returns false if the update fails, which will occur if the process no longer exists. Not implemented for macOS, as thread ID is simply an index and not unique.
      Returns:
      true if the update was successful, false if the update failed. In addition, on a failed update the thread state will be changed to OSProcess.State.INVALID.