Class WindowsOperatingSystemJNA
- All Implemented Interfaces:
OperatingSystem
-
Nested Class Summary
Nested classes/interfaces inherited from interface OperatingSystem
OperatingSystem.OSVersionInfo, OperatingSystem.ProcessFiltering, OperatingSystem.ProcessSortingModifier and TypeInterfaceDescriptionstatic classA class representing the Operating System version details.static final classConstants which may be used to filter Process lists inOperatingSystem.getProcesses(Predicate, Comparator, int),OperatingSystem.getChildProcesses(int, Predicate, Comparator, int), andOperatingSystem.getDescendantProcesses(int, Predicate, Comparator, int).static final classConstants which may be used to sort Process lists inOperatingSystem.getProcesses(Predicate, Comparator, int),OperatingSystem.getChildProcesses(int, Predicate, Comparator, int), andOperatingSystem.getDescendantProcesses(int, Predicate, Comparator, int). -
Field Summary
Fields inherited from class WindowsOperatingSystem
USE_PROCSTATE_SUSPENDEDModifier and TypeFieldDescriptionprotected static final booleanWhether to check thread states to determine if a process is suspended.Fields inherited from class AbstractOperatingSystem
USE_WHO_COMMANDModifier and TypeFieldDescriptionprotected static final booleanWhether to use the 'who' command for session queries. -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionMakes a best effort to get the current thread.getDesktopWindows(boolean visibleOnly) Gets windows on the operating system's GUI desktop.Instantiates aFileSystemobject.Retrieves a list of installed applications on the system.Instantiates aInternetProtocolStatsobject.Instantiates aNetworkParamsobject.getProcess(int pid) Gets information on a currently running processintGet the number of processes currently runninggetProcesses(Collection<Integer> pids) Gets information on aCollectionof currently running processes.intGets the current process ID (PID).Gets the all services on the system.Gets currently logged in users.longGet Unix time of boot.longGet the System up time (time since boot).intGet the number of threads currently runningintMakes a best effort to get the current thread ID (TID).booleanDetermine whether the current process has elevated permissions such as sudo / AdministratorQueries all processes on the system.protected intqueryBitness(int jvmBitness) Backup OS-specific query to determine bitness if previous checks failqueryChildProcesses(int parentPid) Queries the children of a process.queryDescendantProcesses(int parentPid) Queries the descendants of a process.Queries the OS family and version info.Methods inherited from class WindowsOperatingSystem
parseCodeName, queryManufacturerModifier and TypeMethodDescriptionprotected static StringparseCodeName(int suiteMask) Gets suites available on the system and return as a codename.protected StringQueries the OS manufacturer.Methods inherited from class AbstractOperatingSystem
getBitness, getChildProcesses, getChildrenOrDescendants, getChildrenOrDescendants, getDescendantProcesses, getFamily, getManufacturer, getProcesses, getVersionInfo, toStringModifier and TypeMethodDescriptionintGets the bitness (32 or 64) of the operating system.getChildProcesses(int parentPid, Predicate<OSProcess> filter, Comparator<OSProcess> sort, int limit) Gets currently running child processes of provided parent PID, optionally filtering, sorting, and limited to the top "N".getChildrenOrDescendants(Collection<OSProcess> allProcs, int parentPid, boolean allDescendants) Utility method for subclasses to take a full process list as input and return the children or descendants of a particular process.getChildrenOrDescendants(Map<Integer, Integer> parentPidMap, int parentPid, boolean allDescendants) Utility method for subclasses to take a map of pid to parent as input and return the children or descendants of a particular process.getDescendantProcesses(int parentPid, Predicate<OSProcess> filter, Comparator<OSProcess> sort, int limit) Gets currently running processes of provided parent PID's descendants, including their children, the children's children, etc., optionally filtering, sorting, and limited to the top "N".Get the Operating System family.Get the Operating System manufacturer.getProcesses(Predicate<OSProcess> filter, Comparator<OSProcess> sort, int limit) Gets currently running processes, optionally filtering, sorting, and limited to the top "N".Get Operating System version information.toString()Methods inherited from class Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface OperatingSystem
getCgroupInfo, getCurrentProcess, getProcessesModifier and TypeMethodDescriptiondefault CgroupInfoRetrieves cgroup information for the current process.default OSProcessGets the current process.Gets currently running processes.
-
Constructor Details
-
WindowsOperatingSystemJNA
public WindowsOperatingSystemJNA()
-
-
Method Details
-
queryFamilyVersionInfo
Description copied from class:AbstractOperatingSystemQueries the OS family and version info.- Specified by:
queryFamilyVersionInfoin classAbstractOperatingSystem- Returns:
- a pair of family string and OS version info
-
queryBitness
protected int queryBitness(int jvmBitness) Description copied from class:AbstractOperatingSystemBackup OS-specific query to determine bitness if previous checks fail- Specified by:
queryBitnessin classAbstractOperatingSystem- Parameters:
jvmBitness- The bitness of the JVM- Returns:
- The operating system bitness
-
isElevated
public boolean isElevated()Description copied from interface:OperatingSystemDetermine whether the current process has elevated permissions such as sudo / Administrator- Specified by:
isElevatedin interfaceOperatingSystem- Overrides:
isElevatedin classAbstractOperatingSystem- Returns:
- True if this process has elevated permissions
-
getFileSystem
Description copied from interface:OperatingSystemInstantiates aFileSystemobject.- Returns:
- A
FileSystemobject.
-
getInternetProtocolStats
Description copied from interface:OperatingSystemInstantiates aInternetProtocolStatsobject.- Returns:
- a
InternetProtocolStatsobject.
-
getSessions
Description copied from interface:OperatingSystemGets currently logged in users.On macOS, Linux, and Unix systems, the default implementation uses native code (see
man getutxent) that is not thread safe. OSHI's use of this code is synchronized and may be used in a multi-threaded environment without introducing any additional conflicts. Users should note, however, that other operating system code may access the same native code.The
Who#queryWho()method produces similar output parsing the output of the Posix-standardwhocommand, and may internally employ reentrant code on some platforms. Users may opt to use this command-line variant by default using theoshi.os.unix.whocommandconfiguration property.- Specified by:
getSessionsin interfaceOperatingSystem- Overrides:
getSessionsin classAbstractOperatingSystem- Returns:
- A list of
OSSessionobjects representing logged-in users
-
getProcesses
Description copied from interface:OperatingSystemGets information on aCollectionof currently running processes. This has potentially improved performance vs. iterating individual processes.- Parameters:
pids- A collection of process IDs- Returns:
- A list of
OSProcessobjects for the specified process ids if it is running
-
queryAllProcesses
Description copied from class:AbstractOperatingSystemQueries all processes on the system.- Specified by:
queryAllProcessesin classAbstractOperatingSystem- Returns:
- a list of all OS processes
-
queryChildProcesses
Description copied from class:AbstractOperatingSystemQueries the children of a process.- Specified by:
queryChildProcessesin classAbstractOperatingSystem- Parameters:
parentPid- the parent process ID- Returns:
- a list of child processes (including the parent itself)
-
queryDescendantProcesses
Description copied from class:AbstractOperatingSystemQueries the descendants of a process.- Specified by:
queryDescendantProcessesin classAbstractOperatingSystem- Parameters:
parentPid- the parent process ID- Returns:
- a list of descendant processes (including the parent itself)
-
getProcess
Description copied from interface:OperatingSystemGets information on a currently running process- Parameters:
pid- A process ID- Returns:
- An
OSProcessobject for the specified process id if it is running; null otherwise
-
getProcessId
public int getProcessId()Description copied from interface:OperatingSystemGets the current process ID (PID).- Returns:
- the Process ID of the current process
-
getProcessCount
public int getProcessCount()Description copied from interface:OperatingSystemGet the number of processes currently running- Returns:
- The number of processes running
-
getThreadId
public int getThreadId()Description copied from interface:OperatingSystemMakes a best effort to get the current thread ID (TID). May not be useful in a multithreaded environment. The thread ID returned may have been short lived and no longer exist.Thread IDs on macOS are not correlated with any other Operating System output.
- Returns:
- the Thread ID of the current thread if known, 0 otherwise.
-
getCurrentThread
Description copied from interface:OperatingSystemMakes a best effort to get the current thread. May not be useful in a multithreaded environment. The thread returned may have been short lived and no longer exist.On macOS, returns the oldest thread in the calling process.
- Returns:
- the current thread if known; an invalid thread otherwise.
-
getThreadCount
public int getThreadCount()Description copied from interface:OperatingSystemGet the number of threads currently running- Returns:
- The number of threads running
-
getSystemUptime
public long getSystemUptime()Description copied from interface:OperatingSystemGet the System up time (time since boot).- Returns:
- Number of seconds since boot.
-
getSystemBootTime
public long getSystemBootTime()Description copied from interface:OperatingSystemGet Unix time of boot.- Returns:
- The approximate time at which the system booted, in seconds since the Unix epoch.
-
getNetworkParams
Description copied from interface:OperatingSystemInstantiates aNetworkParamsobject.- Returns:
- A
NetworkParamsobject.
-
getServices
Description copied from interface:OperatingSystemGets the all services on the system. The definition of what is a service is platform-dependent.- Returns:
- An array of
OSServiceobjects
-
getDesktopWindows
Description copied from interface:OperatingSystemGets windows on the operating system's GUI desktop.On Unix-like systems, reports X11 windows only, which may be limited to the current display and will not report windows used by other window managers.
While not a guarantee, a best effort is made to return windows in foreground-to-background order. This ordering may be used along with
OSDesktopWindow.getOrder()to (probably) determine the frontmost window.- Specified by:
getDesktopWindowsin interfaceOperatingSystem- Overrides:
getDesktopWindowsin classAbstractOperatingSystem- Parameters:
visibleOnly- Whether to restrict the list to only windows visible to the user.This is a best effort attempt at a reasonable definition of visibility. Visible windows may be completely transparent.
- Returns:
- A list of
OSDesktopWindowobjects representing the desktop windows.
-
getInstalledApplications
Description copied from interface:OperatingSystemRetrieves a list of installed applications on the system.This method is implemented per OS. If the OS does not support this feature, it returns an empty list.
- Returns:
- A list of installed applications or an empty list if unsupported.
-