Interface ExceptionUtil.ThrowingBooleanSupplier

Enclosing class:
ExceptionUtil
Functional Interface:
This is a functional interface and can therefore be used as the assignment target for a lambda expression or method reference.

@FunctionalInterface public static interface ExceptionUtil.ThrowingBooleanSupplier
A boolean-returning supplier that may throw any Throwable.
  • Method Summary

    Modifier and Type
    Method
    Description
    boolean
    Gets a boolean result.
  • Method Details

    • getAsBoolean

      boolean getAsBoolean() throws Throwable
      Gets a boolean result.
      Returns:
      a boolean result
      Throws:
      Throwable - if unable to compute