Interface ExceptionUtil.ThrowingIntSupplier

Enclosing class:
ExceptionUtil
Functional Interface:
This is a functional interface and can therefore be used as the assignment target for a lambda expression or method reference.

@FunctionalInterface public static interface ExceptionUtil.ThrowingIntSupplier
An int-returning supplier that may throw any Throwable.
  • Method Summary

    Modifier and Type
    Method
    Description
    int
    Gets an int result.
  • Method Details

    • getAsInt

      int getAsInt() throws Throwable
      Gets an int result.
      Returns:
      an int result
      Throws:
      Throwable - if unable to compute