Class SystemInfoHelper
java.lang.Object
oshi.util.SystemInfoHelper
Static helper methods for printing OSHI system information, shared across test modules.
-
Method Summary
Modifier and TypeMethodDescriptionstatic voidprintBluetoothDevices(List<String> lines, List<BluetoothDevice> list) Prints Bluetooth Devices information to the output lines.static voidprintComputerSystem(List<String> lines, ComputerSystem computerSystem) Prints Computer System information to the output lines.static voidprintCpu(List<String> lines, CentralProcessor processor) Prints Cpu information to the output lines.static voidprintDisks(List<String> lines, List<HWDiskStore> list) Prints Disks information to the output lines.static voidprintDisplays(List<String> lines, List<Display> list) Prints Displays information to the output lines.static voidprintFileSystem(List<String> lines, FileSystem fileSystem) Prints File System information to the output lines.static voidprintGraphicsCards(List<String> lines, List<GraphicsCard> list) Prints Graphics Cards information to the output lines.static voidprintInstalledApps(List<String> lines, List<ApplicationInfo> installedApplications) Prints Installed Apps information to the output lines.static voidprintInternetProtocolStats(List<String> lines, InternetProtocolStats ip) Prints Internet Protocol Stats information to the output lines.static voidprintLVgroups(List<String> lines, List<LogicalVolumeGroup> list) Prints L Vgroups information to the output lines.static voidprintMemory(List<String> lines, GlobalMemory memory) Prints Memory information to the output lines.static voidprintNetworkInterfaces(List<String> lines, List<NetworkIF> list) Prints Network Interfaces information to the output lines.static voidprintNetworkParameters(List<String> lines, NetworkParams networkParams) Prints Network Parameters information to the output lines.static voidprintOperatingSystem(List<String> lines, OperatingSystem os) Prints Operating System information to the output lines.static voidprintPowerSources(List<String> lines, List<PowerSource> list) Prints Power Sources information to the output lines.static voidprintPrinters(List<String> lines, List<Printer> list) Prints Printers information to the output lines.static voidprintProcesses(List<String> lines, OperatingSystem os, GlobalMemory memory) Prints Processes information to the output lines.static voidprintProcessor(List<String> lines, CentralProcessor processor) Prints Processor information to the output lines.static voidprintSensors(List<String> lines, Sensors sensors) Prints Sensors information to the output lines.static voidprintServices(List<String> lines, OperatingSystem os) Prints Services information to the output lines.static voidprintSoundCards(List<String> lines, List<SoundCard> list) Prints Sound Cards information to the output lines.static voidprintUsbDevices(List<String> lines, List<UsbDevice> list) Prints Usb Devices information to the output lines.
-
Method Details
-
printOperatingSystem
Prints Operating System information to the output lines.- Parameters:
lines- the output listos- the os
-
printInstalledApps
public static void printInstalledApps(List<String> lines, List<ApplicationInfo> installedApplications) Prints Installed Apps information to the output lines.- Parameters:
lines- the output listinstalledApplications- the installedApplications
-
printComputerSystem
Prints Computer System information to the output lines.- Parameters:
lines- the output listcomputerSystem- the computerSystem
-
printProcessor
Prints Processor information to the output lines.- Parameters:
lines- the output listprocessor- the processor
-
printMemory
Prints Memory information to the output lines.- Parameters:
lines- the output listmemory- the memory
-
printCpu
Prints Cpu information to the output lines.- Parameters:
lines- the output listprocessor- the processor
-
printProcesses
Prints Processes information to the output lines.- Parameters:
lines- the output listos- the osmemory- the memory
-
printServices
Prints Services information to the output lines.- Parameters:
lines- the output listos- the os
-
printSensors
-
printPowerSources
Prints Power Sources information to the output lines.- Parameters:
lines- the output listlist- the list
-
printDisks
Prints Disks information to the output lines.- Parameters:
lines- the output listlist- the list
-
printLVgroups
Prints L Vgroups information to the output lines.- Parameters:
lines- the output listlist- the list
-
printFileSystem
Prints File System information to the output lines.- Parameters:
lines- the output listfileSystem- the fileSystem
-
printNetworkInterfaces
-
printNetworkParameters
Prints Network Parameters information to the output lines.- Parameters:
lines- the output listnetworkParams- the networkParams
-
printInternetProtocolStats
Prints Internet Protocol Stats information to the output lines.- Parameters:
lines- the output listip- the ip
-
printDisplays
-
printUsbDevices
-
printBluetoothDevices
Prints Bluetooth Devices information to the output lines.- Parameters:
lines- the output listlist- the list
-
printSoundCards
-
printGraphicsCards
Prints Graphics Cards information to the output lines.- Parameters:
lines- the output listlist- the list
-
printPrinters
-