Uses of Enum Class
oshi.util.PlatformEnum
Packages that use PlatformEnum
-
Uses of PlatformEnum in oshi.util
Subclasses with type arguments of type PlatformEnum in oshi.utilModifier and TypeClassDescriptionenumAn enumeration of supported operating systems.Methods in oshi.util that return PlatformEnumModifier and TypeMethodDescriptionstatic PlatformEnumPlatformEnum.getCurrentPlatform()Gets the current platform, detected from system properties without loading JNA.static PlatformEnumPlatformEnum.getValue(int osType) Gets the value corresponding to the specified JNA osType ordinal.static PlatformEnumReturns the enum constant of this class with the specified name.static PlatformEnum[]PlatformEnum.values()Returns an array containing the constants of this enum class, in the order they are declared.