Package oshi.util.driver.linux


package oshi.util.driver.linux
Provides non-native Linux driver utilities for querying system information.
  • Classes
    Class
    Description
    Utility to read info from the devicetree
    Utility to read info from dmidecode
    Utility to read EDID data from the Linux DRM (Direct Rendering Manager) subsystem.
    Utility to read info from lshal
    Utility to read info from lshw
    Utility to read info from sysfs
    Utility to query logged in users using the who command with Linux date format parsing, falling back to Unix format.