Package oshi.util.driver.linux.proc


package oshi.util.driver.linux.proc
Provides non-native Linux driver utilities for querying the /proc filesystem.
  • Class
    Description
    Constants and shared logic for the Linux auxiliary vector (/proc/self/auxv).
    Reads a native-long value from a ByteBuffer and returns it as a Java long.
    Utility to read CPU info from /proc/cpuinfo
    Utility to read CPU statistics from /proc/stat
    Utility to read disk statistics from /proc/diskstats
    Enum corresponding to the fields in the output of /proc/diskstats
    Utility to read process statistics from /proc/[pid]/stat
    Enum corresponding to the fields in the output of /proc/[pid]/stat
    Enum corresponding to the fields in the output of /proc/[pid]/statm
    Utility to read system uptime from /proc/uptime