Uses of Package
oshi.util.driver.linux.proc
Packages that use oshi.util.driver.linux.proc
Package
Description
Provides non-native Linux driver utilities for querying the
/proc filesystem.-
Classes in oshi.util.driver.linux.proc used by oshi.util.driver.linux.procClassDescriptionReads a native-long value from a
ByteBufferand returns it as a Javalong.Enum corresponding to the fields in the output of/proc/diskstatsEnum corresponding to the fields in the output of/proc/[pid]/statEnum corresponding to the fields in the output of/proc/[pid]/statm