Class DevPath

java.lang.Object
oshi.util.linux.DevPath

@ThreadSafe public final class DevPath extends Object
Provides constants for paths in the /dev filesystem on Linux.

If the user desires to configure a custom /dev path, it must be declared in the OSHI configuration file or updated in the GlobalConfig class prior to initializing this class.

  • Field Details

    • DEV

      public static final String DEV
      The /dev filesystem location.
    • DISK_BY_UUID

      public static final String DISK_BY_UUID
      Path to disk-by-uuid directory.
    • DM

      public static final String DM
      Path prefix for device-mapper devices.
    • LOOP

      public static final String LOOP
      Path prefix for loop devices.
    • MAPPER

      public static final String MAPPER
      Path prefix for device-mapper mapped names.
    • RAM

      public static final String RAM
      Path prefix for RAM disk devices.