Class SysPath

java.lang.Object
oshi.util.linux.SysPath

@ThreadSafe public final class SysPath extends Object
Provides constants for paths in the /sys filesystem on Linux.

If the user desires to configure a custom /sys path, it must be declared in the OSHI configuration file or updated in the GlobalConfig class prior to initializing this class.

  • Field Details

    • SYS

      public static final String SYS
      The /sys filesystem location.
    • CPU

      public static final String CPU
      Path to CPU devices.
    • DMI_ID

      public static final String DMI_ID
      Path to DMI identification.
    • NET

      public static final String NET
      Path to network interfaces.
    • MODEL

      public static final String MODEL
      Path to device tree model.
    • POWER_SUPPLY

      public static final String POWER_SUPPLY
      Path to power supply class.
    • HWMON

      public static final String HWMON
      Path to hardware monitoring.
    • THERMAL

      public static final String THERMAL
      Path to thermal class.
    • CGROUP

      public static final String CGROUP
      Path to cgroup filesystem.
    • DRM

      public static final String DRM
      Path to DRM (Direct Rendering Manager) class.