Package oshi.util
package oshi.util
Provides utilities for parsing, formatting, and other access
-
ClassDescriptionGeneral constants used in multiple classesEDID parsing utility.Utility methods for reducing repetitive exception handling boilerplate, particularly around FFM (Foreign Function and Memory) native calls that require catching
Throwable.A boolean-returning supplier that may throw anyThrowable.A double-returning supplier that may throw anyThrowable.An int-returning supplier that may throw anyThrowable.A long-returning supplier that may throw anyThrowable.A runnable that may throw anyThrowable.A supplier that may throw anyThrowable, including checked exceptions.A class for executing on the command line and returning the result of execution.Utility class for common filesystem codeFile reading methodsFormatting utility for appending units or converting between number types.The global configuration utility.Indicates that a configuration value is invalid.A memoized function stores the output corresponding to some set of specific inputs.String parsing utility.An enumeration of supported operating systems.Utility class for privileged command execution and file reading.Utility class for parsing /proc filesystem statistics.Static helper methods for printing OSHI system information, shared across test modules.Utility class to temporarily cache the userID and group maps in *nix, for parsing process ownership.General utility methods