Uses of Annotation Interface
oshi.annotation.concurrent.Immutable
Packages that use Immutable
Package
Description
Provides functions to query Mac info
Provides common Windows performance monitor constants and definitions shared between JNA and FFM implementations.
Provides common Windows registry performance data POJOs shared between JNA and FFM implementations.
Provides functions to query Mac network info
[oshi-common API] Provides cross-platform implementation to retrieve hardware information such as CPU, Memory,
Display, Disks, Network Interfaces, Power Sources, Sensors, and USB Devices
Provides abstract classes for common code
Provides common Linux hardware implementations shared by JNA and FFM modules.
Provides information about hardware such as Memory, Power Sources, and Processor on Mac systems
Provides common Unix hardware implementations shared by JNA and FFM modules.
Provides common implementations for Windows hardware information shared between JNA and FFM implementations.
Provides mappings for Unix-based operating systems
Provides information about hardware such as Memory, Power Sources, and Processor on AIX systems
Provides information about hardware such as Memory, Power Sources, and Processor on FreeBSD systems
Provides information about hardware such as Memory, Power Sources, and Processor on OpenBSD systems
Provides information about hardware such as Memory, Power Sources, and Processor on Solaris systems
Provides information about hardware such as Memory, Power Sources, and Processor on Windows systems
[oshi-common API] Provides cross-platform common API to retrieve OS, FileSystem, and Process information
-
Uses of Immutable in oshi.driver.common.mac
Classes in oshi.driver.common.mac with annotations of type ImmutableModifier and TypeClassDescriptionstatic classClass to encapsulate mach thread info -
Uses of Immutable in oshi.driver.common.windows.perfmon
Classes in oshi.driver.common.windows.perfmon with annotations of type ImmutableModifier and TypeClassDescriptionfinal classEncapsulates the three string components of a PDH performance counter path, plus whether it refers to the base (SecondValue) of a multi-value counter. -
Uses of Immutable in oshi.driver.common.windows.registry
Classes in oshi.driver.common.windows.registry with annotations of type ImmutableModifier and TypeClassDescriptionfinal classEncapsulates process performance data from the registry performance counter block.final classEncapsulates thread performance data from the registry performance counter block. -
Uses of Immutable in oshi.driver.mac.net
Classes in oshi.driver.mac.net with annotations of type ImmutableModifier and TypeClassDescriptionstatic classClass to encapsulate IF data for method return -
Uses of Immutable in oshi.hardware
Classes in oshi.hardware with annotations of type ImmutableModifier and TypeInterfaceDescriptioninterfaceThe Baseboard represents the system board, also called motherboard, logic board, etc.interfaceRepresents a Bluetooth device (paired or connected) known to the system, analogous toUsbDevicefor USB peripherals.static classA class representing a Logical Processor and its replationship to physical processors, physical packages, and logical groupings such as NUMA Nodes and Processor groups, useful for identifying processor topology.static classA class representing a Physical Processor (a core) providing per-core statistics that may vary, particularly in hybrid/modular processors.static classA class representing CPU Cache Memory.static final classA class encapsulating ghe CPU's identifier strings ,including name, vendor, stepping, model, and family information (also called the signature of a CPU)interfaceThe ComputerSystem represents the physical hardware, of a computer system/product and includes BIOS/firmware and a motherboard, logic board, etc.interfaceDisplay refers to the information regarding a video source and monitor identified by the EDID standard.interfaceThe Firmware represents the low level BIOS or equivalent.final classAn immutable snapshot of cumulative GPU active and idle tick counters in opaque, platform-native units.interfaceRepresents a graphics card (GPU) installed in the system.classA region on a hard disk or other secondary storage, so that an operating system can manage information in each region separately.interfaceA logical volume group implemented as part of logical volume management, combining the space on one or more storage devices such as disks or partitions (physical volumes) into a storage pool, and subsequently allocating that space to virtual partitions (logical volumes) as block devices accessible to the file system.classThe PhysicalMemory class represents a physical memory device located on a computer system and available to the operating system.interfaceRepresents a printer device available to the operating system, including its name, driver, status, and connection type (local or network).interfaceRepresents a sound card (audio adapter) installed in the system, providing the card name, driver version, and codec information.interfaceA USB device is a device connected via a USB port, possibly internally/permanently. -
Uses of Immutable in oshi.hardware.common
Classes in oshi.hardware.common with annotations of type ImmutableModifier and TypeClassDescriptionclassBaseboard dataclassAbstract base class for BluetoothDevice implementations.classComputer System data.classA DisplayclassFirmware data.classAn abstract Graphics CardclassAbstract base class for Printer implementations.classAn abstract Sound CardclassA USB device -
Uses of Immutable in oshi.hardware.common.platform.linux
Classes in oshi.hardware.common.platform.linux with annotations of type ImmutableModifier and TypeClassDescriptionfinal classLinux Bluetooth device enumeration via BlueZ filesystem paths.classLinux USB device base class. -
Uses of Immutable in oshi.hardware.common.platform.mac
Classes in oshi.hardware.common.platform.mac with annotations of type ImmutableModifier and TypeClassDescriptionclassBaseboard data obtained from ioregfinal classmacOS Bluetooth device enumeration viasystem_profiler SPBluetoothDataType.classHardware data obtained from ioreg.classFirmware data obtained from ioreg.final classSound card data obtained via AppleHDA kextclassMac USB device base class. -
Uses of Immutable in oshi.hardware.common.platform.unix
Classes in oshi.hardware.common.platform.unix with annotations of type ImmutableModifier and TypeClassDescriptionclassCUPS-based printer implementation with shared lpstat fallback logic. -
Uses of Immutable in oshi.hardware.common.platform.windows
Classes in oshi.hardware.common.platform.windows with annotations of type ImmutableModifier and TypeClassDescriptionclassBaseboard data obtained from WMI.classHardware data obtained from WMI.classFirmware data obtained from WMI.classCommon Windows printer logic shared between JNA and FFM implementations. -
Uses of Immutable in oshi.hardware.platform.unix
Classes in oshi.hardware.platform.unix with annotations of type ImmutableModifier and TypeClassDescriptionfinal classCUPS-based printer implementation using JNA.final classBaseboard data obtained by a calling class -
Uses of Immutable in oshi.hardware.platform.unix.aix
Classes in oshi.hardware.platform.unix.aix with annotations of type Immutable -
Uses of Immutable in oshi.hardware.platform.unix.freebsd
Classes in oshi.hardware.platform.unix.freebsd with annotations of type Immutable -
Uses of Immutable in oshi.hardware.platform.unix.openbsd
Classes in oshi.hardware.platform.unix.openbsd with annotations of type ImmutableModifier and TypeClassDescriptionclassOpenBSD ComputerSystem implementationclassOpenBSD Firmware implementationclassOpenBsd Usb Device -
Uses of Immutable in oshi.hardware.platform.unix.solaris
Classes in oshi.hardware.platform.unix.solaris with annotations of type Immutable -
Uses of Immutable in oshi.hardware.platform.windows
Classes in oshi.hardware.platform.windows with annotations of type ImmutableModifier and TypeClassDescriptionfinal classWindows Bluetooth device enumeration via the Bluetooth API (bthprops.cpl).classWindows Usb Device -
Uses of Immutable in oshi.software.os
Classes in oshi.software.os with annotations of type ImmutableModifier and TypeClassDescriptionstatic final classEncapsulates information associated with an IP connection.static final classEncapsulates statistics associated with a TCP connection.static final classEncapsulates statistics associated with a UDP connection.static classA class representing the Operating System version details.classThis class encapsulates information about a window on the operating system's GUI desktop.classOperating system services are responsible for the management of platform resources, including the processor, memory, files, and input and output.classThis class encapsulates information about users who are currently logged in to an operating system.