Uses of Class
oshi.annotation.concurrent.Immutable
| Package | Description |
|---|---|
| oshi.hardware |
[oshi-core API] Provides cross-platform implementation to retrieve hardware
information such as CPU, Memory, Display, Disks, Network Interfaces, Power
Sources, Sensors, and USB Devices
|
| oshi.hardware.common |
Provides abstract classes for common code
|
| oshi.hardware.platform.linux |
Provides information about hardware such as Memory, Power Sources, and
Processor on Linux systems
|
| oshi.hardware.platform.mac |
Provides information about hardware such as Memory, Power Sources, and
Processor on Mac systems
|
| oshi.hardware.platform.unix.freebsd |
Provides information about hardware such as Memory, Power Sources, and
Processor on FreeBSD systems
|
| oshi.hardware.platform.unix.solaris |
Provides information about hardware such as Memory, Power Sources, and
Processor on Solaris systems
|
| oshi.hardware.platform.windows |
Provides information about hardware such as Memory, Power Sources, and
Processor on Windows systems
|
| oshi.software.os |
[oshi-core API] Provides cross-platform implementation to retrieve OS,
FileSystem, and Process information
|
-
Uses of Immutable in oshi.hardware
Classes in oshi.hardware with annotations of type Immutable Modifier and Type Interface Description interfaceBaseboardThe Baseboard represents the system board, also called motherboard, logic board, etc.interfaceComputerSystemThe ComputerSystem represents the physical hardware, of a computer system/product and includes BIOS/firmware and a motherboard, logic board, etc.interfaceDisplayDisplay refers to the information regarding a video source and monitor identified by the EDID standard.interfaceFirmwareThe Firmware represents the low level BIOS or equivalent.interfaceGraphicsCardGraphicsCard interface.classPhysicalMemoryThe PhysicalMemory class represents a physical memory device located on a computer system and available to the operating system.interfaceSoundCardSoundCard interface.interfaceUsbDeviceA USB device is a device connected via a USB port, possibly internally/permanently. -
Uses of Immutable in oshi.hardware.common
Classes in oshi.hardware.common with annotations of type Immutable Modifier and Type Class Description classAbstractBaseboardBaseboard dataclassAbstractComputerSystemComputer System data.classAbstractDisplayA DisplayclassAbstractFirmwareFirmware data.classAbstractGraphicsCardAn abstract Sound CardclassAbstractSoundCardAn abstract Sound CardclassAbstractUsbDeviceA USB device -
Uses of Immutable in oshi.hardware.platform.linux
Classes in oshi.hardware.platform.linux with annotations of type Immutable Modifier and Type Class Description classLinuxUsbDeviceLinux Usb Device -
Uses of Immutable in oshi.hardware.platform.mac
Classes in oshi.hardware.platform.mac with annotations of type Immutable Modifier and Type Class Description classMacUsbDeviceMac Usb Device -
Uses of Immutable in oshi.hardware.platform.unix.freebsd
Classes in oshi.hardware.platform.unix.freebsd with annotations of type Immutable Modifier and Type Class Description classFreeBsdUsbDeviceFreeBsd Usb Device -
Uses of Immutable in oshi.hardware.platform.unix.solaris
Classes in oshi.hardware.platform.unix.solaris with annotations of type Immutable Modifier and Type Class Description classSolarisUsbDeviceSolaris Usb Device -
Uses of Immutable in oshi.hardware.platform.windows
Classes in oshi.hardware.platform.windows with annotations of type Immutable Modifier and Type Class Description classWindowsUsbDeviceWindows Usb Device -
Uses of Immutable in oshi.software.os
Classes in oshi.software.os with annotations of type Immutable Modifier and Type Class Description classOSServiceOperating system services are responsible for the management of platform resources, including the processor, memory, files, and input and output.