Uses of Annotation Interface
oshi.annotation.concurrent.ThreadSafe
Packages that use ThreadSafe
Package
Description
Provides functions to query Mac info
Shared GPU-related driver classes for Windows, containing POJOs and utility methods with no native dependencies.
Provides common Windows performance monitor constants and definitions shared between JNA and FFM implementations.
Provides common Windows registry performance data POJOs shared between JNA and FFM implementations.
Provides common WMI driver constants and property enums shared between JNA and FFM implementations.
Provides functions to query Linux information
Provides functions to query statistics in the Linux /proc pseudo-filesystem
Provides functions to query Mac info
Provides functions to query Mac disk info
Provides functions to query Mac network info
Provides functions to query information on AIX
Provides functions to query information on AIX using the libperfstat api
Provides functions to query FreeBSD information
Provides functions to query FreeBSD disk information
Provides functions to query OpenBSD information
Provides functions to query Solaris information
Provides functions to query Solaris disk information
Provides functions to query Solaris kstat information
Provides functions to query information in windows
Provides functions to query counters in windows performance monitor (or WMI counter tables)
Provides functions to query data in Windows Registry
Provides functions to query properties in WMI classes
[oshi-common API] Provides cross-platform implementation to retrieve hardware information such as CPU, Memory,
Display, Disks, Network Interfaces, Power Sources, Sensors, and USB Devices
Provides abstract classes for common code
Provides common Linux hardware implementations shared by JNA and FFM modules.
Provides information about hardware such as Memory, Power Sources, and Processor on Mac systems
Provides common Unix hardware implementations shared by JNA and FFM modules.
Provides common implementations for Windows hardware information shared between JNA and FFM implementations.
Provides information about hardware such as Memory, Power Sources, and Processor on Linux systems
Provides information about hardware such as Memory, Power Sources, and Processor on Mac systems
Provides mappings for Unix-based operating systems
Provides information about hardware such as Memory, Power Sources, and Processor on AIX systems
Provides information about hardware such as Memory, Power Sources, and Processor on FreeBSD systems
Provides information about hardware such as Memory, Power Sources, and Processor on OpenBSD systems
Provides information about hardware such as Memory, Power Sources, and Processor on Solaris systems
Provides information about hardware such as Memory, Power Sources, and Processor on Windows systems
Provides extensions of JNA libraries for Linux.
JNA-dependent utility methods extracted from common utilities.
Provides abstract classes for common code
Provides common (native-free) Linux operating system implementations shared by JNA and FFM modules.
Provides information about Software and OS on macOS
Provides common implementations for Windows operating system information shared between JNA and FFM implementations.
[oshi-common API] Provides cross-platform common API to retrieve OS, FileSystem, and Process information
Provides information about Software and OS on Linux
Provides information about Software and OS on macOS
Provides information about Software and OS on AIX
Provides information about Software and OS on FreeBSD
Provides information about Software and OS on OpenBSD
Provides information about Software and OS on Solaris
Provides information about Software and OS on Windows
Provides utilities for parsing, formatting, and other access
Provides non-native Linux driver utilities for querying system information.
Provides non-native Linux driver utilities for querying the
/proc filesystem.Provides driver utilities common to unix systems that do not require native access
Utility classes for optional vendor GPU library integration (NVML, ADL).
Provides constants for Linux filesystem paths (
/proc, /dev, /sys).Provides utilities for macOS.
Provides utilities for FreeBSD
Provides utilities for OpenBSD
Provides utilities for Solaris
Provides utilities for Windows.
Provides classes encapsulating multiple objects, intended as return types from methods
-
Uses of ThreadSafe in oshi.driver.common.mac
Classes in oshi.driver.common.mac with annotations of type ThreadSafe -
Uses of ThreadSafe in oshi.driver.common.windows.gpu
Classes in oshi.driver.common.windows.gpu with annotations of type ThreadSafeModifier and TypeClassDescriptionfinal classShared utility methods for DXGI adapter matching and related parsing. -
Uses of ThreadSafe in oshi.driver.common.windows.perfmon
Classes in oshi.driver.common.windows.perfmon with annotations of type ThreadSafeModifier and TypeClassDescriptionfinal classGPU performance counter enums.classUtility to calculate a load average equivalent metric on Windows.final classMemory performance counter enumsfinal classPaging File performance counter enumsfinal classConstants used in Perfmon driver classesfinal classPhysical Disk performance counter enumsfinal classProcess performance counter enumsfinal classProcessor performance counter enumsfinal classSystem performance counter enumsfinal classThread performance counter enums -
Uses of ThreadSafe in oshi.driver.common.windows.registry
Classes in oshi.driver.common.windows.registry with annotations of type ThreadSafeModifier and TypeClassDescriptionclassBase class for HKEY_PERFORMANCE_DATA utilities.final classCommon logic for building process performance data maps from registry or performance counter results.final classCommon logic for building thread performance data maps from registry or performance counter results. -
Uses of ThreadSafe in oshi.driver.common.windows.wmi
Classes in oshi.driver.common.windows.wmi with annotations of type ThreadSafeModifier and TypeClassDescriptionclassConstants, property enums, and WHERE clause builders for LibreHardwareMonitor WMI sensor data.classConstants and property enum for WMI classMSAcpi_ThermalZoneTemperature.classConstants and property enums for WMI classes in the Storage namespace associated with Storage Pools.classConstants, property enum, and WHERE clause builder for Open Hardware Monitor WMI Hardware data.classConstants, property enum, and WHERE clause builder for Open Hardware Monitor WMI Sensor data.classConstants and property enum for WMI classWin32_BaseBoard.classConstants and property enums for WMI classWin32_BIOS.classConstants and property enum for WMI classWin32_ComputerSystem.classConstants and property enum for WMI classWin32_ComputerSystemProduct.classConstants and property enum for WMI classWin32_DiskDrive.classConstants and property enum for WMI classWin32_DiskDriveToDiskPartition.classConstants and property enum for WMI classWin32_DiskPartition.classConstants and property enum for WMI classWin32_Fan.classConstants and property enum for WMI classWin32_LogicalDisk.classConstants and property enum for WMI classWin32_LogicalDiskToPartition.classConstants and property enum for WMI classWin32_OperatingSystem.classConstants and property enums for WMI classWin32_PhysicalMemory.classConstants and property enum for WMI classWin32_Printer.classConstants, property enums, and WHERE clause builder for WMI classWin32_Process.classConstants and property enums for WMI classWin32_Processor.classConstants and property enum for WMI classWin32_VideoController. -
Uses of ThreadSafe in oshi.driver.linux
Classes in oshi.driver.linux with annotations of type ThreadSafe -
Uses of ThreadSafe in oshi.driver.linux.proc
Classes in oshi.driver.linux.proc with annotations of type ThreadSafeModifier and TypeClassDescriptionfinal classJNA-based utility to read the auxiliary vector from/proc/self/auxv. -
Uses of ThreadSafe in oshi.driver.mac
Classes in oshi.driver.mac with annotations of type ThreadSafeModifier and TypeClassDescriptionfinal classUtility to query logged in users.final classUtility to query desktop windows -
Uses of ThreadSafe in oshi.driver.mac.disk
Classes in oshi.driver.mac.disk with annotations of type ThreadSafe -
Uses of ThreadSafe in oshi.driver.mac.net
Classes in oshi.driver.mac.net with annotations of type ThreadSafe -
Uses of ThreadSafe in oshi.driver.unix.aix
Classes in oshi.driver.unix.aix with annotations of type ThreadSafeModifier and TypeClassDescriptionfinal classUtility to query lsfinal classUtility to query lscfgfinal classUtility to query lspvfinal classUtility to query lssradfinal classUtility to query /proc/psinfofinal classUtility to query up time.final classUtility to query logged in users. -
Uses of ThreadSafe in oshi.driver.unix.aix.perfstat
Classes in oshi.driver.unix.aix.perfstat with annotations of type ThreadSafeModifier and TypeClassDescriptionfinal classUtility to query partition configfinal classUtility to query performance stats for cpufinal classUtility to query performance stats for disk_statsfinal classUtility to query performance stats for memoryfinal classUtility to query performance stats for network interfacesfinal classUtility to query performance stats for processesfinal classUtility to query performance stats for network interfaces -
Uses of ThreadSafe in oshi.driver.unix.freebsd
Classes in oshi.driver.unix.freebsd with annotations of type ThreadSafe -
Uses of ThreadSafe in oshi.driver.unix.freebsd.disk
Classes in oshi.driver.unix.freebsd.disk with annotations of type ThreadSafeModifier and TypeClassDescriptionfinal classUtility to query geom part listfinal classUtility to query geom part listfinal classUtility to query mount -
Uses of ThreadSafe in oshi.driver.unix.openbsd.disk
Classes in oshi.driver.unix.openbsd.disk with annotations of type ThreadSafeModifier and TypeClassDescriptionfinal classUtility class parsing partition information from disklabel command -
Uses of ThreadSafe in oshi.driver.unix.solaris
Classes in oshi.driver.unix.solaris with annotations of type ThreadSafe -
Uses of ThreadSafe in oshi.driver.unix.solaris.disk
Classes in oshi.driver.unix.solaris.disk with annotations of type ThreadSafe -
Uses of ThreadSafe in oshi.driver.unix.solaris.kstat
Classes in oshi.driver.unix.solaris.kstat with annotations of type ThreadSafe -
Uses of ThreadSafe in oshi.driver.windows
Classes in oshi.driver.windows with annotations of type ThreadSafeModifier and TypeClassDescriptionfinal classUtility to query device interfaces via Config Manager Device Tree functionsfinal classUtility to query Desktop windowsfinal classUtility to query Logical Processor Information -
Uses of ThreadSafe in oshi.driver.windows.perfmon
Classes in oshi.driver.windows.perfmon with annotations of type ThreadSafeModifier and TypeClassDescriptionfinal classUtility to query GPU Engine and GPU Adapter Memory performance counters.final classJNA implementation ofLoadAverageusing JNA-based perfmon drivers.final classUtility to query Memory performance counterfinal classUtility to query Paging File performance counterfinal classTests whether performance counters are disabledfinal classUtility to query PhysicalDisk performance counterfinal classUtility to query Process Information performance counterfinal classUtility to query Processor performance counterfinal classUtility to query System performance countersfinal classUtility to query Thread Information performance counter -
Uses of ThreadSafe in oshi.driver.windows.registry
Classes in oshi.driver.windows.registry with annotations of type ThreadSafeModifier and TypeClassDescriptionfinal classUtility to read HKEY_PERFORMANCE_DATA information.final classUtility to read session data from HKEY_USERSfinal classUtility to read process data from HKEY_PERFORMANCE_DATA information with backup from Performance Counters or WMIfinal classUtility to read process data from HKEY_PERFORMANCE_DATA information with backup from Performance Counters or WMIfinal classUtility to read process data from HKEY_PERFORMANCE_DATA information with backup from Performance Counters or WMIfinal classUtility to read process data from HKEY_PERFORMANCE_DATA information with backup from Performance Counters or WMIfinal classUtility to read thread data from HKEY_PERFORMANCE_DATA information with backup from Performance Counters or WMI -
Uses of ThreadSafe in oshi.driver.windows.wmi
Classes in oshi.driver.windows.wmi with annotations of type ThreadSafeModifier and TypeClassDescriptionfinal classUtility to query LibreHardwareMonitor WMI sensor data using JNA.final classUtility to query WMI classMSAcpi_ThermalZoneTemperatureusing JNA.final classUtility to query WMI classes in Storage namespace associated with Storage Pools using JNA.final classUtility to query Open Hardware Monitor WMI data for Hardware using JNA.final classUtility to query Open Hardware Monitor WMI data for Sensors using JNA.final classUtility to query WMI classWin32_BaseBoardusing JNA.final classUtility to query WMI classWin32_BIOSusing JNA.final classUtility to query WMI classWin32_ComputerSystemusing JNA.final classUtility to query WMI classWin32_ComputerSystemProductusing JNA.final classUtility to query WMI classWin32_DiskDriveusing JNA.final classUtility to query WMI classWin32_DiskDriveToDiskPartitionusing JNA.final classUtility to query WMI classWin32_DiskPartitionusing JNA.final classUtility to query WMI classWin32_Fanusing JNA.final classUtility to query WMI classWin32_LogicalDiskusing JNA.final classUtility to query WMI classWin32_LogicalDiskToPartitionusing JNA.final classUtility to query WMI classWin32_OperatingSystemusing JNA.final classUtility to query WMI classWin32_PhysicalMemoryusing JNA.final classUtility to query WMI classWin32_Printerusing JNA.final classUtility to query WMI classWin32_Processusing cache (JNA).final classUtility to query WMI classWin32_Processusing JNA.final classUtility to query WMI classWin32_Processorusing JNA.final classUtility to query WMI classWin32_VideoControllerusing JNA. -
Uses of ThreadSafe in oshi.hardware
Classes in oshi.hardware with annotations of type ThreadSafeModifier and TypeInterfaceDescriptioninterfaceThis class represents the entire Central Processing Unit (CPU) of a computer system, which may contain one or more physical packages (sockets), one or more physical processors (cores), and one or more logical processors (what the Operating System sees, which may include hyperthreaded cores.)interfaceThe GlobalMemory class tracks information about the use of a computer's physical memory (RAM) as well as any available virtual memory.interfaceA session handle for sampling dynamic GPU metrics.interfaceA hardware abstraction layer.interfaceA storage mechanism where data are recorded by various electronic, magnetic, optical, or mechanical changes to a surface layer of one or more rotating disks or or flash storage such as a removable or solid state drive.interfaceA network interface in the machine, including statistics.interfaceA Power Source represents a battery or UPS device with some capacity and charge/discharge state.interfaceSensors include hardware sensors to monitor temperature, fan speed, and other information.interfaceThe VirtualMemory class tracks information about the use of a computer's virtual memory (swap file) which temporarily moves rarely accessed information to a disk or other storage device. -
Uses of ThreadSafe in oshi.hardware.common
Classes in oshi.hardware.common with annotations of type ThreadSafeModifier and TypeClassDescriptionclassA CPU.classMemory info.classCommon fields or methods used by platform-specific implementations of HardwareAbstractionLayerclassCommon methods for platform HWDiskStore classesclassNetwork interfaces implementation.classA Power SourceclassSensors from WMI or Open Hardware MonitorclassVirtual Memory info.final classA no-opGpuStatsimplementation returned by platforms that do not support a native stats session. -
Uses of ThreadSafe in oshi.hardware.common.platform.linux
Classes in oshi.hardware.common.platform.linux with annotations of type ThreadSafeModifier and TypeClassDescriptionclassA CPU as defined in Linux /proc.final classMemory obtained by /proc/meminfo and sysinfo.totalramclassLinuxGpuStatssession.classGraphics card info obtained by lshw, with dynamic metrics from sysfs DRM driver files.classLinuxHardwareAbstractionLayer class.classLinux hard disk implementation.classLinuxNetworks class.classA Power Source -
Uses of ThreadSafe in oshi.hardware.common.platform.mac
Classes in oshi.hardware.common.platform.mac with annotations of type ThreadSafeModifier and TypeClassDescriptionclassBase class for macOS CentralProcessor implementations.classMemory obtained by host_statistics (vm_stat) and sysctl.classGraphics card info obtained by system_profiler SPDisplaysDataType.classMacHardwareAbstractionLayer class.classBase class for macOS HWDiskStore implementations.classBase class for macOS NetworkIF implementations.classA Power SourceclassMemory obtained by host_statistics (vm_stat) and sysctl. -
Uses of ThreadSafe in oshi.hardware.common.platform.unix
Classes in oshi.hardware.common.platform.unix with annotations of type ThreadSafe -
Uses of ThreadSafe in oshi.hardware.common.platform.windows
Classes in oshi.hardware.common.platform.windows with annotations of type ThreadSafeModifier and TypeClassDescriptionclassCommon non-native logic for Windows Central Processor implementations.classCommon Windows global memory logic shared between JNA and FFM implementations.classCommon Windows hard disk implementation shared between JNA and FFM.classA Power Source -
Uses of ThreadSafe in oshi.hardware.platform.linux
Classes in oshi.hardware.platform.linux with annotations of type ThreadSafeModifier and TypeClassDescriptionfinal classJNA-based Linux hardware abstraction layer.final classJNA-based Linux hard disk implementation.final classJNA-based Linux network interface implementation.final classJNA-based Linux power source implementation. -
Uses of ThreadSafe in oshi.hardware.platform.mac
Classes in oshi.hardware.platform.mac with annotations of type ThreadSafeModifier and TypeClassDescriptionfinal classMacHardwareAbstractionLayer JNA implementation.final classMac hard disk implementation.final classMacNetworks JNA implementation.final classA Power Source -
Uses of ThreadSafe in oshi.hardware.platform.unix
Classes in oshi.hardware.platform.unix with annotations of type ThreadSafeModifier and TypeClassDescriptionfinal classBsdNetworkIF applicable to FreeBSD and OpenBSD. -
Uses of ThreadSafe in oshi.hardware.platform.unix.aix
Classes in oshi.hardware.platform.unix.aix with annotations of type ThreadSafeModifier and TypeClassDescriptionfinal classAIXHardwareAbstractionLayer class.final classAIX hard disk implementation.final classAIXNetworks class.final classA Power Source -
Uses of ThreadSafe in oshi.hardware.platform.unix.freebsd
Classes in oshi.hardware.platform.unix.freebsd with annotations of type ThreadSafeModifier and TypeClassDescriptionfinal classFreeBsdHardwareAbstractionLayer class.final classFreeBSD hard disk implementation.final classA Power Source -
Uses of ThreadSafe in oshi.hardware.platform.unix.openbsd
Classes in oshi.hardware.platform.unix.openbsd with annotations of type ThreadSafeModifier and TypeClassDescriptionclassOpenBSD Central Processor implementationfinal classOpenBsdHardwareAbstractionLayer class.final classOpenBSD hard disk implementation.final classA Power Source -
Uses of ThreadSafe in oshi.hardware.platform.unix.solaris
Classes in oshi.hardware.platform.unix.solaris with annotations of type ThreadSafeModifier and TypeClassDescriptionfinal classSolarisHardwareAbstractionLayer class.final classSolaris hard disk implementation.final classSolarisNetworks class.final classA Power Source -
Uses of ThreadSafe in oshi.hardware.platform.windows
Classes in oshi.hardware.platform.windows with annotations of type ThreadSafeModifier and TypeClassDescriptionclassWindowsHardwareAbstractionLayer class.final classWindows hard disk implementation using JNA.final classWindowsNetworks class.final classJNA-based Windows power source implementation. -
Uses of ThreadSafe in oshi.jna.platform.linux
Classes in oshi.jna.platform.linux with annotations of type ThreadSafe -
Uses of ThreadSafe in oshi.jna.util
Classes in oshi.jna.util with annotations of type ThreadSafeModifier and TypeClassDescriptionfinal classJNA-specific extensions toFileUtilfor reading native types from buffers and freeing native memory. -
Uses of ThreadSafe in oshi.software.common
Classes in oshi.software.common with annotations of type ThreadSafeModifier and TypeClassDescriptionclassCommon methods for filesystem implementationsclassCommon NetworkParams implementation.classCommon implementations for OSFileStoreclassA process is an instance of a computer program that is being executed.classCommon methods for OSThread implementation -
Uses of ThreadSafe in oshi.software.common.os.linux
Classes in oshi.software.common.os.linux with annotations of type ThreadSafeModifier and TypeClassDescriptionclassLinux implementation ofCgroupInfosupporting both cgroup v2 and v1.classThe Linux File System containsOSFileStores which are a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage.classInternet Protocol Stats implementationclassLinux network parameters.classLinux is a family of open source Unix-like operating systems based on the Linux kernel, an operating system kernel first released on September 17, 1991, by Linus Torvalds.classOSFileStore implementationclassOSProcess implementationclassOSThread implementation -
Uses of ThreadSafe in oshi.software.common.os.mac
Classes in oshi.software.common.os.mac with annotations of type ThreadSafeModifier and TypeClassDescriptionclassCommon constants and configuration for macOS file system implementations.classmacOS, previously Mac OS X and later OS X) is a series of proprietary graphical operating systems developed and marketed by Apple Inc. since 2001.classCommon OSFileStore fields and getters for macOS implementations.classOSThread implementation -
Uses of ThreadSafe in oshi.software.common.os.windows
Classes in oshi.software.common.os.windows with annotations of type ThreadSafeModifier and TypeClassDescriptionclassCommon base class for Windows operating system implementations.classCommon base class for Windows OSFileStore implementations, containing shared fields and getters.classCommon base class for Windows OS process implementations, containing shared fields, getters, and non-native methods.classCommon base class for Windows OS thread implementations. -
Uses of ThreadSafe in oshi.software.os
Classes in oshi.software.os with annotations of type ThreadSafeModifier and TypeInterfaceDescriptioninterfaceRepresents cgroup (control group) information for containerized environments.interfaceThe File System is a logical arrangement, usually in a hierarchial tree, where files are placed for storage and retrieval.interfaceProvides key statistics for TCP and UDP network protocols, including aggregate counters and per-connection details.interfaceProvides network parameters of the running operating system, including the hostname, domain name, DNS server addresses, and default gateways for IPv4 and IPv6.interfaceAn operating system (OS) is the software on a computer that manages the way different programs use its hardware, and regulates the ways that a user controls the computer.interfaceA FileStore represents a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage.interfaceRepresents a Process on the operating system, which may contain multiple threads. -
Uses of ThreadSafe in oshi.software.os.linux
Classes in oshi.software.os.linux with annotations of type ThreadSafeModifier and TypeClassDescriptionclassJNA-based Linux file system implementation.classJNA-based Linux operating system implementation.classJNA-based Linux OS process. -
Uses of ThreadSafe in oshi.software.os.mac
Classes in oshi.software.os.mac with annotations of type ThreadSafeModifier and TypeClassDescriptionclassThe Mac File System containsOSFileStores which are a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage.classInternet Protocol Stats implementationclassmacOS, previously Mac OS X and later OS X) is a series of proprietary graphical operating systems developed and marketed by Apple Inc. since 2001.classOSFileStore implementationclassOSProcess implementation -
Uses of ThreadSafe in oshi.software.os.unix.aix
Classes in oshi.software.os.unix.aix with annotations of type ThreadSafeModifier and TypeClassDescriptionclassThe AIX File System containsOSFileStores which are a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage.classInternet Protocol Stats implementationclassAIX (Advanced Interactive eXecutive) is a series of proprietary Unix operating systems developed and sold by IBM for several of its computer platforms.classOSFileStore implementationclassOSProcess implementationclassOSThread implementation -
Uses of ThreadSafe in oshi.software.os.unix.freebsd
Classes in oshi.software.os.unix.freebsd with annotations of type ThreadSafeModifier and TypeClassDescriptionfinal classThe FreeBSD File System containsOSFileStores which are a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage.classInternet Protocol Stats implementationclassFreeBSD is a free and open-source Unix-like operating system descended from the Berkeley Software Distribution (BSD), which was based on Research Unix.classOSFileStore implementationclassOSProcess implementationclassOSThread implementation -
Uses of ThreadSafe in oshi.software.os.unix.openbsd
Classes in oshi.software.os.unix.openbsd with annotations of type ThreadSafeModifier and TypeClassDescriptionclassThe FreeBSD File System containsOSFileStores which are a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage.classInternet Protocol Stats implementationclassOpenBsdNetworkParams class.classOpenBsd is a free and open-source Unix-like operating system descended from the Berkeley Software Distribution (BSD), which was based on Research Unix.classOSFileStore implementationclassOSProcess implementationclassOSThread implementation -
Uses of ThreadSafe in oshi.software.os.unix.solaris
Classes in oshi.software.os.unix.solaris with annotations of type ThreadSafeModifier and TypeClassDescriptionclassThe Solaris File System containsOSFileStores which are a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage.classInternet Protocol Stats implementationclassSolaris is a non-free Unix operating system originally developed by Sun Microsystems.classOSFileStore implementationclassOSProcess implementationclassOSThread implementation -
Uses of ThreadSafe in oshi.software.os.windows
Classes in oshi.software.os.windows with annotations of type ThreadSafeModifier and TypeClassDescriptionclassThe Windows File System containsOSFileStores which are a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage.classInternet Protocol Stats implementationclassMicrosoft Windows, commonly referred to as Windows, is a group of several proprietary graphical operating system families, all of which are developed and marketed by Microsoft.classJNA-based Windows OSFileStore implementation.classJNA-based Windows OS process implementation.classJNA-based Windows OS thread implementation. -
Uses of ThreadSafe in oshi.util
Classes in oshi.util with annotations of type ThreadSafeModifier and TypeClassDescriptionfinal classGeneral constants used in multiple classesfinal classEDID parsing utility.final classA class for executing on the command line and returning the result of execution.final classUtility class for common filesystem codefinal classFile reading methodsfinal classFormatting utility for appending units or converting between number types.final classA memoized function stores the output corresponding to some set of specific inputs.final classString parsing utility.final classUtility class for privileged command execution and file reading.final classfinal classUtility class to temporarily cache the userID and group maps in *nix, for parsing process ownership.final classGeneral utility methods -
Uses of ThreadSafe in oshi.util.driver.linux
Classes in oshi.util.driver.linux with annotations of type ThreadSafeModifier and TypeClassDescriptionfinal classUtility to read info from the devicetreefinal classUtility to read info fromdmidecodefinal classUtility to read info fromlshalfinal classUtility to read info fromlshwfinal classUtility to read info fromsysfsfinal classUtility to query logged in users using thewhocommand with Linux date format parsing, falling back to Unix format. -
Uses of ThreadSafe in oshi.util.driver.linux.proc
Classes in oshi.util.driver.linux.proc with annotations of type ThreadSafeModifier and TypeClassDescriptionfinal classUtility to read CPU info from/proc/cpuinfofinal classUtility to read CPU statistics from/proc/statfinal classUtility to read disk statistics from/proc/diskstatsfinal classUtility to read process statistics from/proc/[pid]/statfinal classUtility to read system uptime from/proc/uptime -
Uses of ThreadSafe in oshi.util.driver.unix
Classes in oshi.util.driver.unix with annotations of type ThreadSafeModifier and TypeClassDescriptionfinal classUtility to parse printer information fromlpstatandlpoptionscommands.final classUtility to query TCP connectionsfinal classUtility to query logged in users using thewhocommand with Unix date format parsing.final classUtility to query xrandrfinal classUtility to query X11 windows -
Uses of ThreadSafe in oshi.util.gpu
Classes in oshi.util.gpu with annotations of type ThreadSafeModifier and TypeClassDescriptionfinal classOptional runtime binding to the AMD Display Library (ADL) on Windows.final classUtility methods for DXGI adapter enumeration and matching on Windows.final classOptional runtime binding to the NVIDIA Management Library (NVML). -
Uses of ThreadSafe in oshi.util.linux
Classes in oshi.util.linux with annotations of type ThreadSafe -
Uses of ThreadSafe in oshi.util.platform.mac
Classes in oshi.util.platform.mac with annotations of type ThreadSafeModifier and TypeClassDescriptionfinal classCF String retrievingfinal classProvides access to SMC calls on macOSfinal classProvides access to sysctl calls on macOS -
Uses of ThreadSafe in oshi.util.platform.unix.freebsd
Classes in oshi.util.platform.unix.freebsd with annotations of type ThreadSafeModifier and TypeClassDescriptionfinal classProvides access to sysctl calls on FreeBSDfinal classReads from procstat into a map -
Uses of ThreadSafe in oshi.util.platform.unix.openbsd
Classes in oshi.util.platform.unix.openbsd with annotations of type ThreadSafeModifier and TypeClassDescriptionfinal classReads from fstat.final classProvides access to sysctl calls on OpenBSD -
Uses of ThreadSafe in oshi.util.platform.unix.solaris
Classes in oshi.util.platform.unix.solaris with annotations of type ThreadSafeModifier and TypeClassDescriptionfinal classProvides access to kstat information on Solaris -
Uses of ThreadSafe in oshi.util.platform.windows
Classes in oshi.util.platform.windows with annotations of type ThreadSafeModifier and TypeClassDescriptionfinal classEnables queries of Performance Counters using wild cards to filter instancesfinal classEnables queries of Performance Counters using wild cards to filter instancesfinal classHelper class to centralize the boilerplate portions of PDH counter setup and allow applications to easily add, query, and remove counters.classUtility to handle WMI Queries.final classHelper class for WMI -
Uses of ThreadSafe in oshi.util.tuples
Classes in oshi.util.tuples with annotations of type ThreadSafeModifier and TypeClassDescriptionclassPair<A,B> Convenience class for returning multiple objects from methods.classQuartet<A,B, C, D> Convenience class for returning multiple objects from methods.classQuintet<A,B, C, D, E> Convenience class for returning multiple objects from methods.classTriplet<A,B, C> Convenience class for returning multiple objects from methods.