Interface Baseboard
- All Known Implementing Classes:
AbstractBaseboard, MacBaseboard, UnixBaseboard, WindowsBaseboard
The Baseboard represents the system board, also called motherboard, logic board, etc.
Obtained from ComputerSystem.getBaseboard().
Platform notes: On Linux, reading the serial number requires root access because
/sys/class/dmi/id/board_serial is root-owned and read-only (mode 0400) by default.
- See Also:
-
Method Summary
Modifier and TypeMethodDescriptionGet the baseboard manufacturer.getModel()Get the baseboard model.Get the baseboard serial number.Get the baseboard version.
-
Method Details
-
getManufacturer
-
getModel
-
getVersion
-
getSerialNumber
-