public class HWDiskStore extends Object implements Comparable<HWDiskStore>
| Constructor and Description |
|---|
HWDiskStore()
Create an object with empty/default values
|
HWDiskStore(HWDiskStore diskStore)
Copy constructor
|
| Modifier and Type | Method and Description |
|---|---|
int |
compareTo(HWDiskStore store) |
boolean |
equals(Object obj) |
long |
getCurrentQueueLength()
Getter for the field
currentQueueLength. |
String |
getModel()
Getter for the field
model. |
String |
getName()
Getter for the field
name. |
HWPartition[] |
getPartitions()
Getter for the field
partitions. |
long |
getReadBytes()
Getter for the field
readBytes. |
long |
getReads()
Getter for the field
reads. |
String |
getSerial()
Getter for the field
serial. |
long |
getSize()
Getter for the field
size. |
long |
getTimeStamp()
Getter for the field
timeStamp. |
long |
getTransferTime()
Getter for the field
transferTime. |
long |
getWriteBytes()
Getter for the field
writeBytes. |
long |
getWrites()
Getter for the field
writes. |
int |
hashCode() |
void |
setCurrentQueueLength(long currentQueueLength)
Setter for the field
currentQueueLength. |
void |
setModel(String model)
Setter for the field
model. |
void |
setName(String name)
Setter for the field
name. |
void |
setPartitions(HWPartition[] partitions)
Setter for the field
partitions. |
void |
setReadBytes(long readBytes)
Setter for the field
readBytes. |
void |
setReads(long reads)
Setter for the field
reads. |
void |
setSerial(String serial)
Setter for the field
serial. |
void |
setSize(long size)
Setter for the field
size. |
void |
setTimeStamp(long timeStamp)
Setter for the field
timeStamp. |
void |
setTransferTime(long transferTime)
Setter for the field
transferTime. |
void |
setWriteBytes(long writeBytes)
Setter for the field
writeBytes. |
void |
setWrites(long writes)
Setter for the field
writes. |
String |
toString() |
boolean |
updateAtrributes()
Make a best effort to update all the statistics about the drive without
needing to recreate the drive list.
|
public HWDiskStore()
public HWDiskStore(HWDiskStore diskStore)
diskStore - The object to copypublic boolean updateAtrributes()
public String getName()
Getter for the field name.
public String getModel()
Getter for the field model.
public String getSerial()
Getter for the field serial.
public long getSize()
Getter for the field size.
public long getReads()
Getter for the field reads.
public long getReadBytes()
Getter for the field readBytes.
public long getWrites()
Getter for the field writes.
public long getWriteBytes()
Getter for the field writeBytes.
public long getCurrentQueueLength()
Getter for the field currentQueueLength.
public long getTransferTime()
Getter for the field transferTime.
public HWPartition[] getPartitions()
Getter for the field partitions.
public long getTimeStamp()
Getter for the field timeStamp.
public void setName(String name)
Setter for the field name.
name - the name to setpublic void setModel(String model)
Setter for the field model.
model - the model to setpublic void setSerial(String serial)
Setter for the field serial.
serial - the serial to setpublic void setSize(long size)
Setter for the field size.
size - Set size of disk (in bytes)public void setReads(long reads)
Setter for the field reads.
reads - the reads to setpublic void setReadBytes(long readBytes)
Setter for the field readBytes.
readBytes - the bytes read to setpublic void setWrites(long writes)
Setter for the field writes.
writes - the writes to setpublic void setWriteBytes(long writeBytes)
Setter for the field writeBytes.
writeBytes - the bytes written to setpublic void setCurrentQueueLength(long currentQueueLength)
Setter for the field currentQueueLength.
currentQueueLength - the length of the disk queue (#I/O's in progress) to setpublic void setTransferTime(long transferTime)
Setter for the field transferTime.
transferTime - milliseconds spent reading or writing to setpublic void setPartitions(HWPartition[] partitions)
Setter for the field partitions.
partitions - The partitions to set.public void setTimeStamp(long timeStamp)
Setter for the field timeStamp.
timeStamp - The timeStamp to set.public int compareTo(HWDiskStore store)
compareTo in interface Comparable<HWDiskStore>Copyright © 2010–2020 oshi. All rights reserved.