Package oshi.hardware

Interface VirtualMemory

All Known Implementing Classes:
AbstractVirtualMemory, FreeBsdVirtualMemory, LinuxVirtualMemory, MacVirtualMemory, SolarisVirtualMemory, WindowsVirtualMemory

public interface VirtualMemory
The VirtuallMemory class tracks information about the use of a computer's virtual memory (swap file) which temporarily moves rarely accessed information to a disk or other storage device.
  • Method Summary

    Modifier and Type Method Description
    long getSwapPagesIn()
    Number of pages read from paging/swap file(s) to resolve hard page faults.
    long getSwapPagesOut()
    Number of pages written to paging/swap file(s) to free up space in physical memory.
    long getSwapTotal()
    The current size of the paging/swap file(s), in bytes.
    long getSwapUsed()
    The current memory committed to the paging/swap file(s), in bytes
  • Method Details

    • getSwapTotal

      long getSwapTotal()
      The current size of the paging/swap file(s), in bytes. If the paging/swap file can be extended, this is a soft limit.
      Returns:
      Total swap in bytes.
    • getSwapUsed

      long getSwapUsed()
      The current memory committed to the paging/swap file(s), in bytes
      Returns:
      Swap used in bytes
    • getSwapPagesIn

      long getSwapPagesIn()
      Number of pages read from paging/swap file(s) to resolve hard page faults. (Hard page faults occur when a process requires code or data that is not in its working set or elsewhere in physical memory, and must be retrieved from disk.) This property was designed as a primary indicator of the kinds of faults that cause system-wide delays. It includes pages retrieved to satisfy faults in the file system cache (usually requested by applications) and in non-cached mapped memory files.
      Returns:
      Pages swapped in
    • getSwapPagesOut

      long getSwapPagesOut()
      Number of pages written to paging/swap file(s) to free up space in physical memory. Pages are written back to disk only if they are changed in physical memory, so they are likely to hold data, not code. A high rate of pages output might indicate a memory shortage. The operating system writes more pages back to disk to free up space when physical memory is in short supply.
      Returns:
      Pages swapped out