Uses of Interface
oshi.hardware.Baseboard
Packages that use Baseboard
Package
Description
[oshi-common API] Provides cross-platform implementation to retrieve hardware information such as CPU, Memory,
Display, Disks, Network Interfaces, Power Sources, Sensors, and USB Devices
Provides abstract classes for common code
Provides information about hardware such as Memory, Power Sources, and Processor on Mac systems
Provides common Unix hardware implementations shared by JNA and FFM modules.
Provides abstract base classes and pure-Java implementations for FreeBSD hardware, shared by the JNA and FFM modules.
Provides abstract base classes and pure-Java implementations for Solaris/illumos hardware, shared by the JNA and FFM
modules.
Provides common implementations for Windows hardware information shared between JNA and FFM implementations.
Provides information about hardware such as Memory, Power Sources, and Processor on NetBSD systems
Provides information about hardware such as Memory, Power Sources, and Processor on OpenBSD systems
-
Uses of Baseboard in oshi.hardware
Methods in oshi.hardware that return BaseboardModifier and TypeMethodDescriptionComputerSystem.getBaseboard()Get the computer system baseboard/motherboard. -
Uses of Baseboard in oshi.hardware.common
Classes in oshi.hardware.common that implement BaseboardMethods in oshi.hardware.common that return BaseboardModifier and TypeMethodDescriptionprotected abstract BaseboardAbstractComputerSystem.createBaseboard()Instantiates the platform-specificBaseboardobjectAbstractComputerSystem.getBaseboard() -
Uses of Baseboard in oshi.hardware.common.platform.mac
Classes in oshi.hardware.common.platform.mac that implement Baseboard -
Uses of Baseboard in oshi.hardware.common.platform.unix
Classes in oshi.hardware.common.platform.unix that implement BaseboardModifier and TypeClassDescriptionfinal classBaseboard data obtained by a calling class -
Uses of Baseboard in oshi.hardware.common.platform.unix.freebsd
Methods in oshi.hardware.common.platform.unix.freebsd that return Baseboard -
Uses of Baseboard in oshi.hardware.common.platform.unix.solaris
Methods in oshi.hardware.common.platform.unix.solaris that return Baseboard -
Uses of Baseboard in oshi.hardware.common.platform.windows
Classes in oshi.hardware.common.platform.windows that implement Baseboard -
Uses of Baseboard in oshi.hardware.platform.unix.netbsd
Methods in oshi.hardware.platform.unix.netbsd that return Baseboard -
Uses of Baseboard in oshi.hardware.platform.unix.openbsd
Methods in oshi.hardware.platform.unix.openbsd that return Baseboard