Uses of Interface
oshi.hardware.Baseboard
Packages that use Baseboard
Package
Description
[oshi-common API] Provides cross-platform implementation to retrieve hardware information such as CPU, Memory,
Display, Disks, Network Interfaces, Power Sources, Sensors, and USB Devices
Provides abstract classes for common code
Provides information about hardware such as Memory, Power Sources, and Processor on Mac systems
Provides mappings for Unix-based operating systems
Provides information about hardware such as Memory, Power Sources, and Processor on OpenBSD systems
-
Uses of Baseboard in oshi.hardware
Methods in oshi.hardware that return BaseboardModifier and TypeMethodDescriptionComputerSystem.getBaseboard()Get the computer system baseboard/motherboard. -
Uses of Baseboard in oshi.hardware.common
Classes in oshi.hardware.common that implement BaseboardMethods in oshi.hardware.common that return BaseboardModifier and TypeMethodDescriptionprotected abstract BaseboardAbstractComputerSystem.createBaseboard()Instantiates the platform-specificBaseboardobjectAbstractComputerSystem.getBaseboard() -
Uses of Baseboard in oshi.hardware.common.platform.mac
Classes in oshi.hardware.common.platform.mac that implement Baseboard -
Uses of Baseboard in oshi.hardware.platform.unix
Classes in oshi.hardware.platform.unix that implement BaseboardModifier and TypeClassDescriptionfinal classBaseboard data obtained by a calling class -
Uses of Baseboard in oshi.hardware.platform.unix.openbsd
Methods in oshi.hardware.platform.unix.openbsd that return Baseboard