Uses of Interface
oshi.hardware.CentralProcessor
| Package | Description |
|---|---|
| oshi.hardware |
[oshi-core API] Provides cross-platform implementation to retrieve hardware
information such as CPU, Memory, Display, Disks, Network Interfaces, Power
Sources, Sensors, and USB Devices
|
| oshi.hardware.common |
Provides abstract classes for common code
|
| oshi.hardware.platform.linux |
Provides information about hardware such as Memory, Power Sources, and
Processor on Linux systems
|
| oshi.hardware.platform.mac |
Provides information about hardware such as Memory, Power Sources, and
Processor on Mac systems
|
| oshi.hardware.platform.unix.freebsd |
Provides information about hardware such as Memory, Power Sources, and
Processor on FreeBSD systems
|
| oshi.hardware.platform.unix.solaris |
Provides information about hardware such as Memory, Power Sources, and
Processor on Solaris systems
|
| oshi.hardware.platform.windows |
Provides information about hardware such as Memory, Power Sources, and
Processor on Windows systems
|
-
Uses of CentralProcessor in oshi.hardware
Methods in oshi.hardware that return CentralProcessor Modifier and Type Method Description CentralProcessorHardwareAbstractionLayer. getProcessor()Instantiates aCentralProcessorobject. -
Uses of CentralProcessor in oshi.hardware.common
Classes in oshi.hardware.common that implement CentralProcessor Modifier and Type Class Description classAbstractCentralProcessorA CPU.Methods in oshi.hardware.common that return CentralProcessor Modifier and Type Method Description protected abstract CentralProcessorAbstractHardwareAbstractionLayer. createProcessor()Instantiates the platform-specificCentralProcessorobjectCentralProcessorAbstractHardwareAbstractionLayer. getProcessor() -
Uses of CentralProcessor in oshi.hardware.platform.linux
Classes in oshi.hardware.platform.linux that implement CentralProcessor Modifier and Type Class Description classLinuxCentralProcessorA CPU as defined in Linux /proc.Methods in oshi.hardware.platform.linux that return CentralProcessor Modifier and Type Method Description CentralProcessorLinuxHardwareAbstractionLayer. createProcessor()Instantiates the platform-specificCentralProcessorobject -
Uses of CentralProcessor in oshi.hardware.platform.mac
Classes in oshi.hardware.platform.mac that implement CentralProcessor Modifier and Type Class Description classMacCentralProcessorA CPU.Methods in oshi.hardware.platform.mac that return CentralProcessor Modifier and Type Method Description CentralProcessorMacHardwareAbstractionLayer. createProcessor()Instantiates the platform-specificCentralProcessorobject -
Uses of CentralProcessor in oshi.hardware.platform.unix.freebsd
Classes in oshi.hardware.platform.unix.freebsd that implement CentralProcessor Modifier and Type Class Description classFreeBsdCentralProcessorA CPUMethods in oshi.hardware.platform.unix.freebsd that return CentralProcessor Modifier and Type Method Description CentralProcessorFreeBsdHardwareAbstractionLayer. createProcessor()Instantiates the platform-specificCentralProcessorobject -
Uses of CentralProcessor in oshi.hardware.platform.unix.solaris
Classes in oshi.hardware.platform.unix.solaris that implement CentralProcessor Modifier and Type Class Description classSolarisCentralProcessorA CPUMethods in oshi.hardware.platform.unix.solaris that return CentralProcessor Modifier and Type Method Description CentralProcessorSolarisHardwareAbstractionLayer. createProcessor()Instantiates the platform-specificCentralProcessorobject -
Uses of CentralProcessor in oshi.hardware.platform.windows
Classes in oshi.hardware.platform.windows that implement CentralProcessor Modifier and Type Class Description classWindowsCentralProcessorA CPU, representing all of a system's processors.Methods in oshi.hardware.platform.windows that return CentralProcessor Modifier and Type Method Description CentralProcessorWindowsHardwareAbstractionLayer. createProcessor()