Uses of Interface
oshi.hardware.GlobalMemory
| Package | Description |
|---|---|
| oshi.hardware |
[oshi-core API] Provides cross-platform implementation to retrieve hardware
information such as CPU, Memory, Display, Disks, Network Interfaces, Power
Sources, Sensors, and USB Devices
|
| oshi.hardware.common |
Provides abstract classes for common code
|
| oshi.hardware.platform.linux |
Provides information about hardware such as Memory, Power Sources, and
Processor on Linux systems
|
| oshi.hardware.platform.mac |
Provides information about hardware such as Memory, Power Sources, and
Processor on Mac systems
|
| oshi.hardware.platform.unix.freebsd |
Provides information about hardware such as Memory, Power Sources, and
Processor on FreeBSD systems
|
| oshi.hardware.platform.unix.solaris |
Provides information about hardware such as Memory, Power Sources, and
Processor on Solaris systems
|
| oshi.hardware.platform.windows |
Provides information about hardware such as Memory, Power Sources, and
Processor on Windows systems
|
-
Uses of GlobalMemory in oshi.hardware
Methods in oshi.hardware that return GlobalMemory Modifier and Type Method Description GlobalMemoryHardwareAbstractionLayer. getMemory()Instantiates aGlobalMemoryobject. -
Uses of GlobalMemory in oshi.hardware.common
Classes in oshi.hardware.common that implement GlobalMemory Modifier and Type Class Description classAbstractGlobalMemoryMemory info.Methods in oshi.hardware.common that return GlobalMemory Modifier and Type Method Description protected abstract GlobalMemoryAbstractHardwareAbstractionLayer. createMemory()Instantiates the platform-specificGlobalMemoryobjectGlobalMemoryAbstractHardwareAbstractionLayer. getMemory() -
Uses of GlobalMemory in oshi.hardware.platform.linux
Classes in oshi.hardware.platform.linux that implement GlobalMemory Modifier and Type Class Description classLinuxGlobalMemoryMemory obtained by /proc/meminfo and sysinfo.totalramMethods in oshi.hardware.platform.linux that return GlobalMemory Modifier and Type Method Description GlobalMemoryLinuxHardwareAbstractionLayer. createMemory()Instantiates the platform-specificGlobalMemoryobject -
Uses of GlobalMemory in oshi.hardware.platform.mac
Classes in oshi.hardware.platform.mac that implement GlobalMemory Modifier and Type Class Description classMacGlobalMemoryMemory obtained by host_statistics (vm_stat) and sysctl.Methods in oshi.hardware.platform.mac that return GlobalMemory Modifier and Type Method Description GlobalMemoryMacHardwareAbstractionLayer. createMemory()Instantiates the platform-specificGlobalMemoryobject -
Uses of GlobalMemory in oshi.hardware.platform.unix.freebsd
Classes in oshi.hardware.platform.unix.freebsd that implement GlobalMemory Modifier and Type Class Description classFreeBsdGlobalMemoryMemory obtained by sysctl vm.statsMethods in oshi.hardware.platform.unix.freebsd that return GlobalMemory Modifier and Type Method Description GlobalMemoryFreeBsdHardwareAbstractionLayer. createMemory()Instantiates the platform-specificGlobalMemoryobject -
Uses of GlobalMemory in oshi.hardware.platform.unix.solaris
Classes in oshi.hardware.platform.unix.solaris that implement GlobalMemory Modifier and Type Class Description classSolarisGlobalMemoryMemory obtained by kstatMethods in oshi.hardware.platform.unix.solaris that return GlobalMemory Modifier and Type Method Description GlobalMemorySolarisHardwareAbstractionLayer. createMemory()Instantiates the platform-specificGlobalMemoryobject -
Uses of GlobalMemory in oshi.hardware.platform.windows
Classes in oshi.hardware.platform.windows that implement GlobalMemory Modifier and Type Class Description classWindowsGlobalMemoryMemory obtained by Performance Info.Methods in oshi.hardware.platform.windows that return GlobalMemory Modifier and Type Method Description GlobalMemoryWindowsHardwareAbstractionLayer. createMemory()