Uses of Class
oshi.hardware.NetworkIF
| Package | Description |
|---|---|
| oshi.hardware |
[oshi-core API] Provides cross-platform implementation to retrieve hardware
information such as CPU, Memory, Display, Disks, Network Interfaces, Power
Sources, Sensors, and USB Devices
|
| oshi.hardware.common |
Provides abstract classes for common code
|
| oshi.hardware.platform.linux |
Provides information about hardware such as Memory, Power Sources, and
Processor on Linux systems
|
| oshi.hardware.platform.mac |
Provides information about hardware such as Memory, Power Sources, and
Processor on Mac systems
|
| oshi.hardware.platform.unix.freebsd |
Provides information about hardware such as Memory, Power Sources, and
Processor on FreeBSD systems
|
| oshi.hardware.platform.unix.solaris |
Provides information about hardware such as Memory, Power Sources, and
Processor on Solaris systems
|
| oshi.hardware.platform.windows |
Provides information about hardware such as Memory, Power Sources, and
Processor on Windows systems
|
-
Uses of NetworkIF in oshi.hardware
Methods in oshi.hardware that return NetworkIF Modifier and Type Method Description NetworkIF[]HardwareAbstractionLayer. getNetworkIFs()Instantiates an array ofNetworkIFobjects, representing a network interface -
Uses of NetworkIF in oshi.hardware.common
Methods in oshi.hardware.common that return NetworkIF Modifier and Type Method Description NetworkIF[]Networks. getNetworks()Gets the network interfaces on this machine -
Uses of NetworkIF in oshi.hardware.platform.linux
Methods in oshi.hardware.platform.linux that return NetworkIF Modifier and Type Method Description NetworkIF[]LinuxHardwareAbstractionLayer. getNetworkIFs()Methods in oshi.hardware.platform.linux with parameters of type NetworkIF Modifier and Type Method Description static booleanLinuxNetworks. updateNetworkStats(NetworkIF netIF)Updates interface network statistics on the given interface. -
Uses of NetworkIF in oshi.hardware.platform.mac
Methods in oshi.hardware.platform.mac that return NetworkIF Modifier and Type Method Description NetworkIF[]MacHardwareAbstractionLayer. getNetworkIFs()NetworkIF[]MacNetworks. getNetworks()Methods in oshi.hardware.platform.mac with parameters of type NetworkIF Modifier and Type Method Description static booleanMacNetworks. updateNetworkStats(NetworkIF netIF)Updates interface network statistics on the given interface. -
Uses of NetworkIF in oshi.hardware.platform.unix.freebsd
Methods in oshi.hardware.platform.unix.freebsd that return NetworkIF Modifier and Type Method Description NetworkIF[]FreeBsdHardwareAbstractionLayer. getNetworkIFs()Methods in oshi.hardware.platform.unix.freebsd with parameters of type NetworkIF Modifier and Type Method Description static booleanFreeBsdNetworks. updateNetworkStats(NetworkIF netIF)Updates interface network statistics on the given interface. -
Uses of NetworkIF in oshi.hardware.platform.unix.solaris
Methods in oshi.hardware.platform.unix.solaris that return NetworkIF Modifier and Type Method Description NetworkIF[]SolarisHardwareAbstractionLayer. getNetworkIFs()Methods in oshi.hardware.platform.unix.solaris with parameters of type NetworkIF Modifier and Type Method Description static booleanSolarisNetworks. updateNetworkStats(NetworkIF netIF)Updates interface network statistics on the given interface. -
Uses of NetworkIF in oshi.hardware.platform.windows
Methods in oshi.hardware.platform.windows that return NetworkIF Modifier and Type Method Description NetworkIF[]WindowsHardwareAbstractionLayer. getNetworkIFs()Methods in oshi.hardware.platform.windows with parameters of type NetworkIF Modifier and Type Method Description static booleanWindowsNetworks. updateNetworkStats(NetworkIF netIF)Updates interface network statistics on the given interface.