Uses of Enum Class
oshi.hardware.NetworkIF.IfOperStatus
Packages that use NetworkIF.IfOperStatus
Package
Description
[oshi-common API] Provides cross-platform implementation to retrieve hardware information such as CPU, Memory,
Display, Disks, Network Interfaces, Power Sources, Sensors, and USB Devices
Provides common Linux hardware implementations shared by JNA and FFM modules.
Provides information about hardware such as Memory, Power Sources, and Processor on Windows systems
-
Uses of NetworkIF.IfOperStatus in oshi.hardware
Subclasses with type arguments of type NetworkIF.IfOperStatus in oshi.hardwareModifier and TypeClassDescriptionstatic enumThe current operational state of a network interface.Methods in oshi.hardware that return NetworkIF.IfOperStatusModifier and TypeMethodDescriptionstatic NetworkIF.IfOperStatusNetworkIF.IfOperStatus.byValue(int value) Find IfOperStatus by the integer value.default NetworkIF.IfOperStatusNetworkIF.getIfOperStatus()TheifOperStatusas described in RFC 2863.static NetworkIF.IfOperStatusReturns the enum constant of this class with the specified name.static NetworkIF.IfOperStatus[]NetworkIF.IfOperStatus.values()Returns an array containing the constants of this enum class, in the order they are declared. -
Uses of NetworkIF.IfOperStatus in oshi.hardware.common.platform.linux
Methods in oshi.hardware.common.platform.linux that return NetworkIF.IfOperStatusModifier and TypeMethodDescriptionLinuxNetworkIF.getIfOperStatus()protected static NetworkIF.IfOperStatusLinuxNetworkIF.parseIfOperStatus(String operState) Parses the operational status from a sysfs operstate string. -
Uses of NetworkIF.IfOperStatus in oshi.hardware.platform.windows
Methods in oshi.hardware.platform.windows that return NetworkIF.IfOperStatus