| Package | Description |
|---|---|
| oshi.hardware |
[oshi-core API] Provides cross-platform implementation to retrieve hardware
information such as CPU, Memory, Display, Disks, Network Interfaces, Power
Sources, Sensors, and USB Devices
|
| oshi.hardware.common |
Provides abstract classes for common code
|
| oshi.hardware.platform.mac |
Provides information about hardware such as Memory, Power Sources, and
Processor on Mac systems
|
| oshi.hardware.platform.windows |
Provides information about hardware such as Memory, Power Sources, and
Processor on Windows systems
|
| Modifier and Type | Method and Description |
|---|---|
PhysicalMemory[] |
GlobalMemory.getPhysicalMemory()
Physical memory, such as banks of memory.
|
| Modifier and Type | Method and Description |
|---|---|
PhysicalMemory[] |
AbstractGlobalMemory.getPhysicalMemory() |
| Modifier and Type | Method and Description |
|---|---|
PhysicalMemory[] |
MacGlobalMemory.getPhysicalMemory() |
| Modifier and Type | Method and Description |
|---|---|
PhysicalMemory[] |
WindowsGlobalMemory.getPhysicalMemory() |
Copyright © 2010–2020 oshi. All rights reserved.