Uses of Interface
oshi.hardware.PowerSource
Packages that use PowerSource
Package
Description
[oshi-common API] Provides cross-platform implementation to retrieve hardware information such as CPU, Memory,
Display, Disks, Network Interfaces, Power Sources, Sensors, and USB Devices
Provides abstract classes for common code
Provides common Linux hardware implementations shared by JNA and FFM modules.
Native-free Linux hardware implementations using only procfs, sysfs, and command-line utilities.
Provides information about hardware such as Memory, Power Sources, and Processor on Mac systems
Provides abstract base classes and pure-Java implementations for FreeBSD hardware, shared by the JNA and FFM modules.
Provides abstract base classes and pure-Java implementations for OpenBSD hardware, shared by the JNA and FFM modules.
Provides common implementations for Windows hardware information shared between JNA and FFM implementations.
Provides information about hardware such as Memory, Power Sources, and Processor on Linux systems
Provides information about hardware such as Memory, Power Sources, and Processor on Mac systems
Provides information about hardware such as Memory, Power Sources, and Processor on AIX systems
Provides information about hardware such as Memory, Power Sources, and Processor on DragonFly BSD systems
Provides information about hardware such as Memory, Power Sources, and Processor on FreeBSD systems
Provides information about hardware such as Memory, Power Sources, and Processor on NetBSD systems
Provides information about hardware such as Memory, Power Sources, and Processor on OpenBSD systems
Provides information about hardware such as Memory, Power Sources, and Processor on Solaris systems
Provides information about hardware such as Memory, Power Sources, and Processor on Windows systems
-
Uses of PowerSource in oshi.hardware
Methods in oshi.hardware that return types with arguments of type PowerSourceModifier and TypeMethodDescriptionHardwareAbstractionLayer.getPowerSources()Instantiates a list ofPowerSourceobjects, representing batteries, etc. -
Uses of PowerSource in oshi.hardware.common
Classes in oshi.hardware.common that implement PowerSourceMethods in oshi.hardware.common that return types with arguments of type PowerSourceModifier and TypeMethodDescriptionprotected abstract List<PowerSource> AbstractPowerSource.queryPowerSources()Returns a fresh list of power sources for this platform, used byAbstractPowerSource.updateAttributes(). -
Uses of PowerSource in oshi.hardware.common.platform.linux
Classes in oshi.hardware.common.platform.linux that implement PowerSourceMethods in oshi.hardware.common.platform.linux that return types with arguments of type PowerSourceModifier and TypeMethodDescriptionstatic List<PowerSource> LinuxPowerSource.getPowerSources()Gets Battery Informationprotected List<PowerSource> LinuxPowerSource.queryPowerSources() -
Uses of PowerSource in oshi.hardware.common.platform.linux.nativefree
Methods in oshi.hardware.common.platform.linux.nativefree that return types with arguments of type PowerSource -
Uses of PowerSource in oshi.hardware.common.platform.mac
Classes in oshi.hardware.common.platform.mac that implement PowerSource -
Uses of PowerSource in oshi.hardware.common.platform.unix.freebsd
Classes in oshi.hardware.common.platform.unix.freebsd that implement PowerSource -
Uses of PowerSource in oshi.hardware.common.platform.unix.openbsd
Classes in oshi.hardware.common.platform.unix.openbsd that implement PowerSourceMethods in oshi.hardware.common.platform.unix.openbsd that return types with arguments of type PowerSourceModifier and TypeMethodDescriptionstatic List<PowerSource> OpenBsdPowerSource.getPowerSources()Gets Battery Informationprotected List<PowerSource> OpenBsdPowerSource.queryPowerSources() -
Uses of PowerSource in oshi.hardware.common.platform.windows
Classes in oshi.hardware.common.platform.windows that implement PowerSource -
Uses of PowerSource in oshi.hardware.platform.linux
Classes in oshi.hardware.platform.linux that implement PowerSourceModifier and TypeClassDescriptionfinal classJNA-based Linux power source implementation.Methods in oshi.hardware.platform.linux that return types with arguments of type PowerSourceModifier and TypeMethodDescriptionLinuxHardwareAbstractionLayerJNA.getPowerSources()static List<PowerSource> LinuxPowerSourceJNA.getPowerSources()Gets Battery Informationprotected List<PowerSource> LinuxPowerSourceJNA.queryPowerSources() -
Uses of PowerSource in oshi.hardware.platform.mac
Classes in oshi.hardware.platform.mac that implement PowerSourceMethods in oshi.hardware.platform.mac that return types with arguments of type PowerSourceModifier and TypeMethodDescriptionMacHardwareAbstractionLayerJNA.getPowerSources()static List<PowerSource> MacPowerSourceJNA.getPowerSources()Gets Battery Information.protected List<PowerSource> MacPowerSourceJNA.queryPowerSources() -
Uses of PowerSource in oshi.hardware.platform.unix.aix
Classes in oshi.hardware.platform.unix.aix that implement PowerSourceMethods in oshi.hardware.platform.unix.aix that return types with arguments of type PowerSourceModifier and TypeMethodDescriptionAixHardwareAbstractionLayer.getPowerSources()static List<PowerSource> AixPowerSource.getPowerSources()Gets Battery Information.protected List<PowerSource> AixPowerSource.queryPowerSources() -
Uses of PowerSource in oshi.hardware.platform.unix.dragonflybsd
Methods in oshi.hardware.platform.unix.dragonflybsd that return types with arguments of type PowerSource -
Uses of PowerSource in oshi.hardware.platform.unix.freebsd
Classes in oshi.hardware.platform.unix.freebsd that implement PowerSourceMethods in oshi.hardware.platform.unix.freebsd that return types with arguments of type PowerSourceModifier and TypeMethodDescriptionFreeBsdHardwareAbstractionLayerJNA.getPowerSources()static List<PowerSource> FreeBsdPowerSourceJNA.getPowerSources()Gets Battery Informationprotected List<PowerSource> FreeBsdPowerSourceJNA.queryPowerSources() -
Uses of PowerSource in oshi.hardware.platform.unix.netbsd
Classes in oshi.hardware.platform.unix.netbsd that implement PowerSourceMethods in oshi.hardware.platform.unix.netbsd that return types with arguments of type PowerSourceModifier and TypeMethodDescriptionNetBsdHardwareAbstractionLayer.getPowerSources()static List<PowerSource> NetBsdPowerSource.getPowerSources()Gets Battery Informationprotected List<PowerSource> NetBsdPowerSource.queryPowerSources() -
Uses of PowerSource in oshi.hardware.platform.unix.openbsd
Methods in oshi.hardware.platform.unix.openbsd that return types with arguments of type PowerSource -
Uses of PowerSource in oshi.hardware.platform.unix.solaris
Classes in oshi.hardware.platform.unix.solaris that implement PowerSourceMethods in oshi.hardware.platform.unix.solaris that return types with arguments of type PowerSourceModifier and TypeMethodDescriptionSolarisHardwareAbstractionLayer.getPowerSources()static List<PowerSource> SolarisPowerSource.getPowerSources()Gets Battery Informationprotected List<PowerSource> SolarisPowerSource.queryPowerSources() -
Uses of PowerSource in oshi.hardware.platform.windows
Classes in oshi.hardware.platform.windows that implement PowerSourceModifier and TypeClassDescriptionfinal classJNA-based Windows power source implementation.Methods in oshi.hardware.platform.windows that return types with arguments of type PowerSourceModifier and TypeMethodDescriptionWindowsHardwareAbstractionLayerJNA.getPowerSources()static List<PowerSource> WindowsPowerSourceJNA.getPowerSources()Gets Battery Information.protected List<PowerSource> WindowsPowerSourceJNA.queryPowerSources()