Uses of Interface
oshi.hardware.PowerSource
| Package | Description |
|---|---|
| oshi.hardware |
[oshi-core API] Provides cross-platform implementation to retrieve hardware
information such as CPU, Memory, Display, Disks, Network Interfaces, Power
Sources, Sensors, and USB Devices
|
| oshi.hardware.common |
Provides abstract classes for common code
|
| oshi.hardware.platform.linux |
Provides information about hardware such as Memory, Power Sources, and
Processor on Linux systems
|
| oshi.hardware.platform.mac |
Provides information about hardware such as Memory, Power Sources, and
Processor on Mac systems
|
| oshi.hardware.platform.unix.freebsd |
Provides information about hardware such as Memory, Power Sources, and
Processor on FreeBSD systems
|
| oshi.hardware.platform.unix.solaris |
Provides information about hardware such as Memory, Power Sources, and
Processor on Solaris systems
|
| oshi.hardware.platform.windows |
Provides information about hardware such as Memory, Power Sources, and
Processor on Windows systems
|
-
Uses of PowerSource in oshi.hardware
Methods in oshi.hardware that return PowerSource Modifier and Type Method Description PowerSource[]HardwareAbstractionLayer. getPowerSources()Instantiates an array ofPowerSourceobjects, representing batteries, etc. -
Uses of PowerSource in oshi.hardware.common
Classes in oshi.hardware.common that implement PowerSource Modifier and Type Class Description classAbstractPowerSourceA Power Source -
Uses of PowerSource in oshi.hardware.platform.linux
Classes in oshi.hardware.platform.linux that implement PowerSource Modifier and Type Class Description classLinuxPowerSourceA Power SourceMethods in oshi.hardware.platform.linux that return PowerSource Modifier and Type Method Description PowerSource[]LinuxHardwareAbstractionLayer. getPowerSources()static PowerSource[]LinuxPowerSource. getPowerSources()Gets Battery Information -
Uses of PowerSource in oshi.hardware.platform.mac
Classes in oshi.hardware.platform.mac that implement PowerSource Modifier and Type Class Description classMacPowerSourceA Power SourceMethods in oshi.hardware.platform.mac that return PowerSource Modifier and Type Method Description PowerSource[]MacHardwareAbstractionLayer. getPowerSources()static PowerSource[]MacPowerSource. getPowerSources()Gets Battery Information. -
Uses of PowerSource in oshi.hardware.platform.unix.freebsd
Classes in oshi.hardware.platform.unix.freebsd that implement PowerSource Modifier and Type Class Description classFreeBsdPowerSourceA Power SourceMethods in oshi.hardware.platform.unix.freebsd that return PowerSource Modifier and Type Method Description PowerSource[]FreeBsdHardwareAbstractionLayer. getPowerSources()static PowerSource[]FreeBsdPowerSource. getPowerSources()Gets Battery Information -
Uses of PowerSource in oshi.hardware.platform.unix.solaris
Classes in oshi.hardware.platform.unix.solaris that implement PowerSource Modifier and Type Class Description classSolarisPowerSourceA Power SourceMethods in oshi.hardware.platform.unix.solaris that return PowerSource Modifier and Type Method Description PowerSource[]SolarisHardwareAbstractionLayer. getPowerSources()static PowerSource[]SolarisPowerSource. getPowerSources()Gets Battery Information -
Uses of PowerSource in oshi.hardware.platform.windows
Classes in oshi.hardware.platform.windows that implement PowerSource Modifier and Type Class Description classWindowsPowerSourceA Power SourceMethods in oshi.hardware.platform.windows that return PowerSource Modifier and Type Method Description PowerSource[]WindowsHardwareAbstractionLayer. getPowerSources()static PowerSource[]WindowsPowerSource. getPowerSources()Gets Battery Information.