| Package | Description |
|---|---|
| oshi.hardware |
[oshi-core API] Provides cross-platform implementation to retrieve hardware
information such as CPU, Memory, Display, Disks, Network Interfaces, Power
Sources, Sensors, and USB Devices
|
| oshi.hardware.common |
Provides abstract classes for common code
|
| oshi.hardware.platform.linux |
Provides information about hardware such as Memory, Power Sources, and
Processor on Linux systems
|
| oshi.hardware.platform.mac |
Provides information about hardware such as Memory, Power Sources, and
Processor on Mac systems
|
| oshi.hardware.platform.unix.freebsd |
Provides information about hardware such as Memory, Power Sources, and
Processor on FreeBSD systems
|
| oshi.hardware.platform.unix.solaris |
Provides information about hardware such as Memory, Power Sources, and
Processor on Solaris systems
|
| oshi.hardware.platform.windows |
Provides information about hardware such as Memory, Power Sources, and
Processor on Windows systems
|
| Modifier and Type | Method and Description |
|---|---|
SoundCard[] |
HardwareAbstractionLayer.getSoundCards()
Instantiates an array of
SoundCard objects,
representing the Sound cards. |
| Modifier and Type | Class and Description |
|---|---|
class |
AbstractSoundCard
An abstract Sound Card
|
| Modifier and Type | Class and Description |
|---|---|
class |
LinuxSoundCard
Sound card data obtained via /proc/asound directory
|
| Modifier and Type | Method and Description |
|---|---|
SoundCard[] |
LinuxHardwareAbstractionLayer.getSoundCards()
Instantiates an array of
SoundCard objects,
representing the Sound cards. |
| Modifier and Type | Class and Description |
|---|---|
class |
MacSoundCard
Sound card data obtained via system_profiler
|
| Modifier and Type | Method and Description |
|---|---|
SoundCard[] |
MacHardwareAbstractionLayer.getSoundCards()
Instantiates an array of
SoundCard objects,
representing the Sound cards. |
| Modifier and Type | Class and Description |
|---|---|
class |
FreeBsdSoundCard
FreeBSD soundcard.
|
| Modifier and Type | Method and Description |
|---|---|
SoundCard[] |
FreeBsdHardwareAbstractionLayer.getSoundCards()
Instantiates an array of
SoundCard objects,
representing the Sound cards. |
| Modifier and Type | Method and Description |
|---|---|
static List<SoundCard> |
FreeBsdSoundCard.getSoundCards()
getSoundCards.
|
| Modifier and Type | Class and Description |
|---|---|
class |
SolarisSoundCard
Solaris Sound Card.
|
| Modifier and Type | Method and Description |
|---|---|
SoundCard[] |
SolarisHardwareAbstractionLayer.getSoundCards()
Instantiates an array of
SoundCard objects,
representing the Sound cards. |
| Modifier and Type | Class and Description |
|---|---|
class |
WindowsSoundCard
Sound Card data obtained from registry
|
| Modifier and Type | Method and Description |
|---|---|
SoundCard[] |
WindowsHardwareAbstractionLayer.getSoundCards()
Instantiates an array of
SoundCard objects,
representing the Sound cards. |
Copyright © 2010–2020 oshi. All rights reserved.