Uses of Interface
oshi.hardware.UsbDevice
| Package | Description |
|---|---|
| oshi.hardware |
[oshi-core API] Provides cross-platform implementation to retrieve hardware
information such as CPU, Memory, Display, Disks, Network Interfaces, Power
Sources, Sensors, and USB Devices
|
| oshi.hardware.common |
Provides abstract classes for common code
|
| oshi.hardware.platform.linux |
Provides information about hardware such as Memory, Power Sources, and
Processor on Linux systems
|
| oshi.hardware.platform.mac |
Provides information about hardware such as Memory, Power Sources, and
Processor on Mac systems
|
| oshi.hardware.platform.unix.freebsd |
Provides information about hardware such as Memory, Power Sources, and
Processor on FreeBSD systems
|
| oshi.hardware.platform.unix.solaris |
Provides information about hardware such as Memory, Power Sources, and
Processor on Solaris systems
|
| oshi.hardware.platform.windows |
Provides information about hardware such as Memory, Power Sources, and
Processor on Windows systems
|
-
Uses of UsbDevice in oshi.hardware
Methods in oshi.hardware that return UsbDevice Modifier and Type Method Description UsbDevice[]UsbDevice. getConnectedDevices()Other devices connected to this hubUsbDevice[]HardwareAbstractionLayer. getUsbDevices(boolean tree)Instantiates an array ofUsbDeviceobjects, representing devices connected via a usb port (including internal devices). -
Uses of UsbDevice in oshi.hardware.common
Classes in oshi.hardware.common that implement UsbDevice Modifier and Type Class Description classAbstractUsbDeviceA USB deviceFields in oshi.hardware.common declared as UsbDevice Modifier and Type Field Description protected UsbDevice[]AbstractUsbDevice. connectedDevicesMethods in oshi.hardware.common that return UsbDevice Modifier and Type Method Description UsbDevice[]AbstractUsbDevice. getConnectedDevices()Methods in oshi.hardware.common with parameters of type UsbDevice Modifier and Type Method Description intAbstractUsbDevice. compareTo(UsbDevice usb)Constructors in oshi.hardware.common with parameters of type UsbDevice Constructor Description AbstractUsbDevice(java.lang.String name, java.lang.String vendor, java.lang.String vendorId, java.lang.String productId, java.lang.String serialNumber, java.lang.String uniqueDeviceId, UsbDevice[] connectedDevices)Constructor for AbstractUsbDevice. -
Uses of UsbDevice in oshi.hardware.platform.linux
Classes in oshi.hardware.platform.linux that implement UsbDevice Modifier and Type Class Description classLinuxUsbDeviceLinuxUsbDevice class.Methods in oshi.hardware.platform.linux that return UsbDevice Modifier and Type Method Description UsbDevice[]LinuxHardwareAbstractionLayer. getUsbDevices(boolean tree)Instantiates an array ofUsbDeviceobjects, representing devices connected via a usb port (including internal devices).static UsbDevice[]LinuxUsbDevice. getUsbDevices(boolean tree)Constructors in oshi.hardware.platform.linux with parameters of type UsbDevice Constructor Description LinuxUsbDevice(java.lang.String name, java.lang.String vendor, java.lang.String vendorId, java.lang.String productId, java.lang.String serialNumber, java.lang.String uniqueDeviceId, UsbDevice[] connectedDevices)Constructor for LinuxUsbDevice. -
Uses of UsbDevice in oshi.hardware.platform.mac
Classes in oshi.hardware.platform.mac that implement UsbDevice Modifier and Type Class Description classMacUsbDeviceMacUsbDevice class.Methods in oshi.hardware.platform.mac that return UsbDevice Modifier and Type Method Description UsbDevice[]MacHardwareAbstractionLayer. getUsbDevices(boolean tree)Instantiates an array ofUsbDeviceobjects, representing devices connected via a usb port (including internal devices).static UsbDevice[]MacUsbDevice. getUsbDevices(boolean tree)Constructors in oshi.hardware.platform.mac with parameters of type UsbDevice Constructor Description MacUsbDevice(java.lang.String name, java.lang.String vendor, java.lang.String vendorId, java.lang.String productId, java.lang.String serialNumber, java.lang.String uniqueDeviceId, UsbDevice[] connectedDevices)Constructor for MacUsbDevice. -
Uses of UsbDevice in oshi.hardware.platform.unix.freebsd
Classes in oshi.hardware.platform.unix.freebsd that implement UsbDevice Modifier and Type Class Description classFreeBsdUsbDeviceFreeBsdUsbDevice class.Methods in oshi.hardware.platform.unix.freebsd that return UsbDevice Modifier and Type Method Description UsbDevice[]FreeBsdHardwareAbstractionLayer. getUsbDevices(boolean tree)Instantiates an array ofUsbDeviceobjects, representing devices connected via a usb port (including internal devices).static UsbDevice[]FreeBsdUsbDevice. getUsbDevices(boolean tree)Constructors in oshi.hardware.platform.unix.freebsd with parameters of type UsbDevice Constructor Description FreeBsdUsbDevice(java.lang.String name, java.lang.String vendor, java.lang.String vendorId, java.lang.String productId, java.lang.String serialNumber, java.lang.String uniqueDeviceId, UsbDevice[] connectedDevices) -
Uses of UsbDevice in oshi.hardware.platform.unix.solaris
Classes in oshi.hardware.platform.unix.solaris that implement UsbDevice Modifier and Type Class Description classSolarisUsbDeviceSolarisUsbDevice class.Methods in oshi.hardware.platform.unix.solaris that return UsbDevice Modifier and Type Method Description UsbDevice[]SolarisHardwareAbstractionLayer. getUsbDevices(boolean tree)Instantiates an array ofUsbDeviceobjects, representing devices connected via a usb port (including internal devices).static UsbDevice[]SolarisUsbDevice. getUsbDevices(boolean tree)Constructors in oshi.hardware.platform.unix.solaris with parameters of type UsbDevice Constructor Description SolarisUsbDevice(java.lang.String name, java.lang.String vendor, java.lang.String vendorId, java.lang.String productId, java.lang.String serialNumber, java.lang.String uniqueDeviceId, UsbDevice[] connectedDevices)Constructor for SolarisUsbDevice. -
Uses of UsbDevice in oshi.hardware.platform.windows
Classes in oshi.hardware.platform.windows that implement UsbDevice Modifier and Type Class Description classWindowsUsbDeviceWindowsUsbDevice class.Methods in oshi.hardware.platform.windows that return UsbDevice Modifier and Type Method Description UsbDevice[]WindowsHardwareAbstractionLayer. getUsbDevices(boolean tree)static UsbDevice[]WindowsUsbDevice. getUsbDevices(boolean tree)Constructors in oshi.hardware.platform.windows with parameters of type UsbDevice Constructor Description WindowsUsbDevice(java.lang.String name, java.lang.String vendor, java.lang.String vendorId, java.lang.String productId, java.lang.String serialNumber, java.lang.String uniqueDeviceId, UsbDevice[] connectedDevices)