Uses of Interface
oshi.hardware.VirtualMemory
| Package | Description |
|---|---|
| oshi.hardware |
[oshi-core API] Provides cross-platform implementation to retrieve hardware
information such as CPU, Memory, Display, Disks, Network Interfaces, Power
Sources, Sensors, and USB Devices
|
| oshi.hardware.common |
Provides abstract classes for common code
|
| oshi.hardware.platform.linux |
Provides information about hardware such as Memory, Power Sources, and
Processor on Linux systems
|
| oshi.hardware.platform.mac |
Provides information about hardware such as Memory, Power Sources, and
Processor on Mac systems
|
| oshi.hardware.platform.unix.freebsd |
Provides information about hardware such as Memory, Power Sources, and
Processor on FreeBSD systems
|
| oshi.hardware.platform.unix.solaris |
Provides information about hardware such as Memory, Power Sources, and
Processor on Solaris systems
|
| oshi.hardware.platform.windows |
Provides information about hardware such as Memory, Power Sources, and
Processor on Windows systems
|
-
Uses of VirtualMemory in oshi.hardware
Methods in oshi.hardware that return VirtualMemory Modifier and Type Method Description VirtualMemoryGlobalMemory. getVirtualMemory()Virtual memory, such as a swap file. -
Uses of VirtualMemory in oshi.hardware.common
Classes in oshi.hardware.common that implement VirtualMemory Modifier and Type Class Description classAbstractVirtualMemoryVirtual Memory info. -
Uses of VirtualMemory in oshi.hardware.platform.linux
Classes in oshi.hardware.platform.linux that implement VirtualMemory Modifier and Type Class Description classLinuxVirtualMemoryMemory obtained by /proc/meminfo and /proc/vmstatMethods in oshi.hardware.platform.linux that return VirtualMemory Modifier and Type Method Description VirtualMemoryLinuxGlobalMemory. getVirtualMemory() -
Uses of VirtualMemory in oshi.hardware.platform.mac
Classes in oshi.hardware.platform.mac that implement VirtualMemory Modifier and Type Class Description classMacVirtualMemoryMemory obtained by host_statistics (vm_stat) and sysctl.Methods in oshi.hardware.platform.mac that return VirtualMemory Modifier and Type Method Description VirtualMemoryMacGlobalMemory. getVirtualMemory() -
Uses of VirtualMemory in oshi.hardware.platform.unix.freebsd
Classes in oshi.hardware.platform.unix.freebsd that implement VirtualMemory Modifier and Type Class Description classFreeBsdVirtualMemoryMemory obtained by swapinfoMethods in oshi.hardware.platform.unix.freebsd that return VirtualMemory Modifier and Type Method Description VirtualMemoryFreeBsdGlobalMemory. getVirtualMemory() -
Uses of VirtualMemory in oshi.hardware.platform.unix.solaris
Classes in oshi.hardware.platform.unix.solaris that implement VirtualMemory Modifier and Type Class Description classSolarisVirtualMemoryMemory obtained by kstat and swapMethods in oshi.hardware.platform.unix.solaris that return VirtualMemory Modifier and Type Method Description VirtualMemorySolarisGlobalMemory. getVirtualMemory() -
Uses of VirtualMemory in oshi.hardware.platform.windows
Classes in oshi.hardware.platform.windows that implement VirtualMemory Modifier and Type Class Description classWindowsVirtualMemoryMemory obtained from WMIMethods in oshi.hardware.platform.windows that return VirtualMemory Modifier and Type Method Description VirtualMemoryWindowsGlobalMemory. getVirtualMemory()