| Package | Description |
|---|---|
| oshi.hardware |
[oshi-core API] Provides cross-platform implementation to retrieve hardware
information such as CPU, Memory, Display, Disks, Network Interfaces, Power
Sources, Sensors, and USB Devices
|
| oshi.hardware.common |
Provides abstract classes for common code
|
| oshi.hardware.platform.linux |
Provides information about hardware such as Memory, Power Sources, and
Processor on Linux systems
|
| oshi.hardware.platform.mac |
Provides information about hardware such as Memory, Power Sources, and
Processor on Mac systems
|
| oshi.hardware.platform.unix.freebsd |
Provides information about hardware such as Memory, Power Sources, and
Processor on FreeBSD systems
|
| oshi.hardware.platform.unix.solaris |
Provides information about hardware such as Memory, Power Sources, and
Processor on Solaris systems
|
| oshi.hardware.platform.windows |
Provides information about hardware such as Memory, Power Sources, and
Processor on Windows systems
|
| Modifier and Type | Method and Description |
|---|---|
VirtualMemory |
GlobalMemory.getVirtualMemory()
Virtual memory, such as a swap file.
|
| Modifier and Type | Class and Description |
|---|---|
class |
AbstractVirtualMemory
Virtual Memory info.
|
| Modifier and Type | Class and Description |
|---|---|
class |
LinuxVirtualMemory
Memory obtained by /proc/meminfo and /proc/vmstat
|
| Modifier and Type | Method and Description |
|---|---|
VirtualMemory |
LinuxGlobalMemory.getVirtualMemory() |
| Modifier and Type | Class and Description |
|---|---|
class |
MacVirtualMemory
Memory obtained by host_statistics (vm_stat) and sysctl.
|
| Modifier and Type | Method and Description |
|---|---|
VirtualMemory |
MacGlobalMemory.getVirtualMemory() |
| Modifier and Type | Class and Description |
|---|---|
class |
FreeBsdVirtualMemory
Memory obtained by swapinfo
|
| Modifier and Type | Method and Description |
|---|---|
VirtualMemory |
FreeBsdGlobalMemory.getVirtualMemory() |
| Modifier and Type | Class and Description |
|---|---|
class |
SolarisVirtualMemory
Memory obtained by kstat and swap
|
| Modifier and Type | Method and Description |
|---|---|
VirtualMemory |
SolarisGlobalMemory.getVirtualMemory() |
| Modifier and Type | Class and Description |
|---|---|
class |
WindowsVirtualMemory
Memory obtained from WMI
|
| Modifier and Type | Method and Description |
|---|---|
VirtualMemory |
WindowsGlobalMemory.getVirtualMemory() |
Copyright © 2010–2020 oshi. All rights reserved.