Package oshi.hardware.common
Class AbstractNetworks
java.lang.Object
oshi.hardware.common.AbstractNetworks
- All Implemented Interfaces:
Networks
- Direct Known Subclasses:
FreeBsdNetworks,LinuxNetworks,MacNetworks,SolarisNetworks,WindowsNetworks
public abstract class AbstractNetworks extends java.lang.Object implements Networks
Network interfaces implementation.
-
Constructor Summary
Constructors Constructor Description AbstractNetworks() -
Method Summary
Modifier and Type Method Description protected java.net.NetworkInterface[]getNetworkInterfaces()Returns network interfaces that are not Loopback, and have a hardware address.NetworkIF[]getNetworks()Get network interfaces on this machine
-
Constructor Details
-
AbstractNetworks
public AbstractNetworks()
-
-
Method Details
-
getNetworks
Description copied from interface:NetworksGet network interfaces on this machine- Specified by:
getNetworksin interfaceNetworks- Returns:
- Array of
NetworkIFobjects
-
getNetworkInterfaces
protected java.net.NetworkInterface[] getNetworkInterfaces()Returns network interfaces that are not Loopback, and have a hardware address.- Returns:
- An array of network interfaces
-