Uses of Class
oshi.hardware.common.AbstractComputerSystem
Packages that use AbstractComputerSystem
Package
Description
Provides information about hardware such as Memory, Power Sources, and Processor on Mac systems
Provides abstract base classes and pure-Java implementations for FreeBSD hardware, shared by the JNA and FFM modules.
Provides abstract base classes and pure-Java implementations for Solaris/illumos hardware, shared by the JNA and FFM
modules.
Provides common implementations for Windows hardware information shared between JNA and FFM implementations.
Provides information about hardware such as Memory, Power Sources, and Processor on FreeBSD systems
Provides information about hardware such as Memory, Power Sources, and Processor on NetBSD systems
Provides information about hardware such as Memory, Power Sources, and Processor on OpenBSD systems
-
Uses of AbstractComputerSystem in oshi.hardware.common.platform.mac
Subclasses of AbstractComputerSystem in oshi.hardware.common.platform.mac -
Uses of AbstractComputerSystem in oshi.hardware.common.platform.unix.freebsd
Subclasses of AbstractComputerSystem in oshi.hardware.common.platform.unix.freebsd -
Uses of AbstractComputerSystem in oshi.hardware.common.platform.unix.solaris
Subclasses of AbstractComputerSystem in oshi.hardware.common.platform.unix.solaris -
Uses of AbstractComputerSystem in oshi.hardware.common.platform.windows
Subclasses of AbstractComputerSystem in oshi.hardware.common.platform.windows -
Uses of AbstractComputerSystem in oshi.hardware.platform.unix.freebsd
Subclasses of AbstractComputerSystem in oshi.hardware.platform.unix.freebsdModifier and TypeClassDescriptionclassJNA-backed FreeBSD computer system. -
Uses of AbstractComputerSystem in oshi.hardware.platform.unix.netbsd
Subclasses of AbstractComputerSystem in oshi.hardware.platform.unix.netbsd -
Uses of AbstractComputerSystem in oshi.hardware.platform.unix.openbsd
Subclasses of AbstractComputerSystem in oshi.hardware.platform.unix.openbsdModifier and TypeClassDescriptionclassOpenBSD ComputerSystem implementation