Uses of Class
oshi.hardware.common.AbstractNetworkIF
Packages that use AbstractNetworkIF
Package
Description
Provides common Linux hardware implementations shared by JNA and FFM modules.
Native-free Linux hardware implementations using only procfs, sysfs, and command-line utilities.
Provides information about hardware such as Memory, Power Sources, and Processor on Mac systems
Provides information about hardware such as Memory, Power Sources, and Processor on Linux systems
Provides information about hardware such as Memory, Power Sources, and Processor on Mac systems
Provides mappings for Unix-based operating systems
Provides information about hardware such as Memory, Power Sources, and Processor on AIX systems
Provides information about hardware such as Memory, Power Sources, and Processor on Solaris systems
Provides information about hardware such as Memory, Power Sources, and Processor on Windows systems
-
Uses of AbstractNetworkIF in oshi.hardware.common.platform.linux
Subclasses of AbstractNetworkIF in oshi.hardware.common.platform.linux -
Uses of AbstractNetworkIF in oshi.hardware.common.platform.linux.nativefree
Subclasses of AbstractNetworkIF in oshi.hardware.common.platform.linux.nativefreeModifier and TypeClassDescriptionfinal classNative-free Linux network interface implementation. -
Uses of AbstractNetworkIF in oshi.hardware.common.platform.mac
Subclasses of AbstractNetworkIF in oshi.hardware.common.platform.macModifier and TypeClassDescriptionclassBase class for macOS NetworkIF implementations. -
Uses of AbstractNetworkIF in oshi.hardware.platform.linux
Subclasses of AbstractNetworkIF in oshi.hardware.platform.linuxModifier and TypeClassDescriptionfinal classJNA-based Linux network interface implementation. -
Uses of AbstractNetworkIF in oshi.hardware.platform.mac
Subclasses of AbstractNetworkIF in oshi.hardware.platform.mac -
Uses of AbstractNetworkIF in oshi.hardware.platform.unix
Subclasses of AbstractNetworkIF in oshi.hardware.platform.unixModifier and TypeClassDescriptionfinal classBsdNetworkIF applicable to FreeBSD and OpenBSD. -
Uses of AbstractNetworkIF in oshi.hardware.platform.unix.aix
Subclasses of AbstractNetworkIF in oshi.hardware.platform.unix.aix -
Uses of AbstractNetworkIF in oshi.hardware.platform.unix.solaris
Subclasses of AbstractNetworkIF in oshi.hardware.platform.unix.solaris -
Uses of AbstractNetworkIF in oshi.hardware.platform.windows
Subclasses of AbstractNetworkIF in oshi.hardware.platform.windows