Uses of Package
oshi.hardware.common
Packages that use oshi.hardware.common
Package
Description
Provides common Linux hardware implementations shared by JNA and FFM modules.
Native-free Linux hardware implementations using only procfs, sysfs, and command-line utilities.
Provides information about hardware such as Memory, Power Sources, and Processor on Mac systems
Provides common Unix hardware implementations shared by JNA and FFM modules.
Provides information about hardware such as Memory, Power Sources, and Processor on AIX systems
Provides abstract base classes and pure-Java implementations for FreeBSD hardware, shared by the JNA and FFM modules.
Provides information about hardware such as Memory, Power Sources, and Processor on NetBSD systems
Provides abstract base classes and pure-Java implementations for OpenBSD hardware, shared by the JNA and FFM modules.
Provides abstract base classes and pure-Java implementations for Solaris/illumos hardware, shared by the JNA and FFM
modules.
Provides common implementations for Windows hardware information shared between JNA and FFM implementations.
Provides information about hardware such as Memory, Power Sources, and Processor on Linux systems
Provides information about hardware such as Memory, Power Sources, and Processor on Mac systems
Provides mappings for Unix-based operating systems
Provides JNA-backed hardware implementations for AIX.
Provides information about hardware such as Memory, Power Sources, and Processor on DragonFly BSD systems
Provides information about hardware such as Memory, Power Sources, and Processor on FreeBSD systems
Provides information about hardware such as Memory, Power Sources, and Processor on OpenBSD systems
Provides information about hardware such as Memory, Power Sources, and Processor on Solaris systems
Provides information about hardware such as Memory, Power Sources, and Processor on Windows systems
-
Classes in oshi.hardware.common used by oshi.hardware.common.platform.linuxClassDescriptionAbstract base class for BluetoothDevice implementations.A CPU.Memory info.An abstract Graphics CardCommon fields or methods used by platform-specific implementations of HardwareAbstractionLayerCommon methods for platform HWDiskStore classesCommon implementations for LogicalVolumeGroup.Network interfaces implementation.A Power SourceA USB device
-
Classes in oshi.hardware.common used by oshi.hardware.common.platform.linux.nativefreeClassDescriptionA CPU.Common fields or methods used by platform-specific implementations of HardwareAbstractionLayerCommon methods for platform HWDiskStore classesNetwork interfaces implementation.A USB device
-
Classes in oshi.hardware.common used by oshi.hardware.common.platform.macClassDescriptionBaseboard dataAbstract base class for BluetoothDevice implementations.A CPU.Computer System data.Firmware data.Memory info.An abstract Graphics CardCommon fields or methods used by platform-specific implementations of HardwareAbstractionLayerCommon methods for platform HWDiskStore classesCommon implementations for LogicalVolumeGroup.Network interfaces implementation.A Power SourceAn abstract Sound CardA USB deviceVirtual Memory info.
-
Classes in oshi.hardware.common used by oshi.hardware.common.platform.unixClassDescriptionBaseboard dataA CPU.A DisplayAn abstract Graphics CardNetwork interfaces implementation.A Power SourceAbstract base class for Printer implementations.Sensors from WMI or Open Hardware MonitorAn abstract Sound CardA USB device
-
Classes in oshi.hardware.common used by oshi.hardware.common.platform.unix.aixClassDescriptionBaseboard dataA CPU.Computer System data.Firmware data.Memory info.An abstract Graphics CardCommon methods for platform HWDiskStore classesNetwork interfaces implementation.A Power SourceSensors from WMI or Open Hardware MonitorAn abstract Sound CardA USB deviceVirtual Memory info.
-
Classes in oshi.hardware.common used by oshi.hardware.common.platform.unix.freebsdClassDescriptionA CPU.Computer System data.Firmware data.Memory info.An abstract Graphics CardCommon methods for platform HWDiskStore classesA Power SourceSensors from WMI or Open Hardware MonitorAn abstract Sound CardA USB deviceVirtual Memory info.
-
Classes in oshi.hardware.common used by oshi.hardware.common.platform.unix.netbsdClassDescriptionA CPU.Computer System data.Firmware data.Common fields or methods used by platform-specific implementations of HardwareAbstractionLayerCommon methods for platform HWDiskStore classesNetwork interfaces implementation.
-
Classes in oshi.hardware.common used by oshi.hardware.common.platform.unix.openbsdClassDescriptionA CPU.Firmware data.Memory info.Common methods for platform HWDiskStore classesVirtual Memory info.
-
Classes in oshi.hardware.common used by oshi.hardware.common.platform.unix.solarisClassDescriptionA CPU.Computer System data.Firmware data.Memory info.An abstract Graphics CardCommon methods for platform HWDiskStore classesNetwork interfaces implementation.A Power SourceSensors from WMI or Open Hardware MonitorAn abstract Sound CardA USB deviceVirtual Memory info.
-
Classes in oshi.hardware.common used by oshi.hardware.common.platform.windowsClassDescriptionBaseboard dataA CPU.Computer System data.Firmware data.Memory info.Common methods for platform HWDiskStore classesA Power SourceAbstract base class for Printer implementations.Sensors from WMI or Open Hardware Monitor
-
Classes in oshi.hardware.common used by oshi.hardware.platform.linuxClassDescriptionCommon fields or methods used by platform-specific implementations of HardwareAbstractionLayerCommon methods for platform HWDiskStore classesNetwork interfaces implementation.A Power SourceA USB device
-
Classes in oshi.hardware.common used by oshi.hardware.platform.macClassDescriptionCommon fields or methods used by platform-specific implementations of HardwareAbstractionLayerCommon methods for platform HWDiskStore classesNetwork interfaces implementation.A Power SourceA USB device
-
Classes in oshi.hardware.common used by oshi.hardware.platform.unix
-
Classes in oshi.hardware.common used by oshi.hardware.platform.unix.aixClassDescriptionCommon fields or methods used by platform-specific implementations of HardwareAbstractionLayerCommon methods for platform HWDiskStore classesNetwork interfaces implementation.
-
Classes in oshi.hardware.common used by oshi.hardware.platform.unix.dragonflybsdClassDescriptionA CPU.Common fields or methods used by platform-specific implementations of HardwareAbstractionLayer
-
Classes in oshi.hardware.common used by oshi.hardware.platform.unix.freebsdClassDescriptionA CPU.Computer System data.Memory info.Common fields or methods used by platform-specific implementations of HardwareAbstractionLayerCommon methods for platform HWDiskStore classesA Power SourceSensors from WMI or Open Hardware Monitor
-
Classes in oshi.hardware.common used by oshi.hardware.platform.unix.openbsdClassDescriptionA CPU.Computer System data.Common fields or methods used by platform-specific implementations of HardwareAbstractionLayerCommon methods for platform HWDiskStore classes
-
Classes in oshi.hardware.common used by oshi.hardware.platform.unix.solarisClassDescriptionCommon fields or methods used by platform-specific implementations of HardwareAbstractionLayerCommon methods for platform HWDiskStore classesNetwork interfaces implementation.A Power Source
-
Classes in oshi.hardware.common used by oshi.hardware.platform.windowsClassDescriptionAbstract base class for BluetoothDevice implementations.Common fields or methods used by platform-specific implementations of HardwareAbstractionLayerCommon methods for platform HWDiskStore classesNetwork interfaces implementation.A Power SourceA USB device