Uses of Package
oshi.hardware.common
| Package | Description |
|---|---|
| oshi.hardware.platform.linux |
Provides information about hardware such as Memory, Power Sources, and
Processor on Linux systems
|
| oshi.hardware.platform.mac |
Provides information about hardware such as Memory, Power Sources, and
Processor on Mac systems
|
| oshi.hardware.platform.unix.freebsd |
Provides information about hardware such as Memory, Power Sources, and
Processor on FreeBSD systems
|
| oshi.hardware.platform.unix.solaris |
Provides information about hardware such as Memory, Power Sources, and
Processor on Solaris systems
|
| oshi.hardware.platform.windows |
Provides information about hardware such as Memory, Power Sources, and
Processor on Windows systems
|
-
Classes in oshi.hardware.common used by oshi.hardware.platform.linux Class Description AbstractCentralProcessor A CPU.AbstractDisplay A DisplayAbstractGlobalMemory Memory info.AbstractHardwareAbstractionLayer Common fields or methods used by platform-specific implementations of HardwareAbstractionLayerAbstractNetworks Network interfaces implementation.AbstractPowerSource A Power SourceAbstractSensors Sensor info.AbstractSoundCard An abstract Sound CardAbstractUsbDevice A USB deviceAbstractVirtualMemory Virtual Memory info. -
Classes in oshi.hardware.common used by oshi.hardware.platform.mac Class Description AbstractCentralProcessor A CPU.AbstractDisplay A DisplayAbstractGlobalMemory Memory info.AbstractHardwareAbstractionLayer Common fields or methods used by platform-specific implementations of HardwareAbstractionLayerAbstractNetworks Network interfaces implementation.AbstractPowerSource A Power SourceAbstractSensors Sensor info.AbstractSoundCard An abstract Sound CardAbstractUsbDevice A USB deviceAbstractVirtualMemory Virtual Memory info. -
Classes in oshi.hardware.common used by oshi.hardware.platform.unix.freebsd Class Description AbstractCentralProcessor A CPU.AbstractDisplay A DisplayAbstractGlobalMemory Memory info.AbstractHardwareAbstractionLayer Common fields or methods used by platform-specific implementations of HardwareAbstractionLayerAbstractNetworks Network interfaces implementation.AbstractPowerSource A Power SourceAbstractSensors Sensor info.AbstractSoundCard An abstract Sound CardAbstractUsbDevice A USB deviceAbstractVirtualMemory Virtual Memory info. -
Classes in oshi.hardware.common used by oshi.hardware.platform.unix.solaris Class Description AbstractCentralProcessor A CPU.AbstractDisplay A DisplayAbstractGlobalMemory Memory info.AbstractHardwareAbstractionLayer Common fields or methods used by platform-specific implementations of HardwareAbstractionLayerAbstractNetworks Network interfaces implementation.AbstractPowerSource A Power SourceAbstractSensors Sensor info.AbstractSoundCard An abstract Sound CardAbstractUsbDevice A USB deviceAbstractVirtualMemory Virtual Memory info. -
Classes in oshi.hardware.common used by oshi.hardware.platform.windows Class Description AbstractCentralProcessor A CPU.AbstractDisplay A DisplayAbstractGlobalMemory Memory info.AbstractHardwareAbstractionLayer Common fields or methods used by platform-specific implementations of HardwareAbstractionLayerAbstractNetworks Network interfaces implementation.AbstractPowerSource A Power SourceAbstractSensors Sensor info.AbstractSoundCard An abstract Sound CardAbstractUsbDevice A USB deviceAbstractVirtualMemory Virtual Memory info.