Enum Class LinuxPowerSource.Prop
- All Implemented Interfaces:
Serializable, Comparable<LinuxPowerSource.Prop>, Constable
- Enclosing class:
LinuxPowerSource
Power supply uevent properties from sysfs.
-
Nested Class Summary
Nested classes/interfaces inherited from class Enum
Enum.EnumDesc<E> -
Enum Constant Summary
Enum ConstantsEnum ConstantDescriptionRemaining capacity percentage.Full charge capacity in microamp-hours.Design charge capacity in microamp-hours.Current charge in microamp-hours.Current draw in microamps.Battery cycle count.Full energy capacity in microwatt-hours.Design energy capacity in microwatt-hours.Current energy in microwatt-hours.Manufacture day.Manufacture month.Manufacture year.Manufacturer name.Model name.Power supply name.Whether the power supply is online.Current power draw in microwatts.Whether the power supply is present.Serial number.Power supply status (Charging, Discharging, etc.).Battery technology/chemistry.Temperature in tenths of degrees Celsius.Estimated time to empty in seconds.Estimated time to full in seconds.Current voltage in microvolts. -
Method Summary
Modifier and TypeMethodDescriptionstatic LinuxPowerSource.PropReturns the enum constant of this class with the specified name.static LinuxPowerSource.Prop[]values()Returns an array containing the constants of this enum class, in the order they are declared.
-
Enum Constant Details
-
POWER_SUPPLY_NAME
Power supply name. -
POWER_SUPPLY_STATUS
Power supply status (Charging, Discharging, etc.). -
POWER_SUPPLY_CAPACITY
Remaining capacity percentage. -
POWER_SUPPLY_PRESENT
Whether the power supply is present. -
POWER_SUPPLY_ONLINE
Whether the power supply is online. -
POWER_SUPPLY_ENERGY_NOW
Current energy in microwatt-hours. -
POWER_SUPPLY_CHARGE_NOW
Current charge in microamp-hours. -
POWER_SUPPLY_ENERGY_FULL
Full energy capacity in microwatt-hours. -
POWER_SUPPLY_CHARGE_FULL
Full charge capacity in microamp-hours. -
POWER_SUPPLY_ENERGY_FULL_DESIGN
Design energy capacity in microwatt-hours. -
POWER_SUPPLY_CHARGE_FULL_DESIGN
Design charge capacity in microamp-hours. -
POWER_SUPPLY_VOLTAGE_NOW
Current voltage in microvolts. -
POWER_SUPPLY_POWER_NOW
Current power draw in microwatts. -
POWER_SUPPLY_CURRENT_NOW
Current draw in microamps. -
POWER_SUPPLY_CYCLE_COUNT
Battery cycle count. -
POWER_SUPPLY_TECHNOLOGY
Battery technology/chemistry. -
POWER_SUPPLY_MODEL_NAME
Model name. -
POWER_SUPPLY_MANUFACTURER
Manufacturer name. -
POWER_SUPPLY_SERIAL_NUMBER
Serial number. -
POWER_SUPPLY_TEMP
Temperature in tenths of degrees Celsius. -
POWER_SUPPLY_TIME_TO_EMPTY_NOW
Estimated time to empty in seconds. -
POWER_SUPPLY_TIME_TO_FULL_NOW
Estimated time to full in seconds. -
POWER_SUPPLY_MANUFACTURE_YEAR
Manufacture year. -
POWER_SUPPLY_MANUFACTURE_MONTH
Manufacture month. -
POWER_SUPPLY_MANUFACTURE_DAY
Manufacture day.
-
-
Method Details
-
values
Returns an array containing the constants of this enum class, in the order they are declared.- Returns:
- an array containing the constants of this enum class, in the order they are declared
-
valueOf
Returns the enum constant of this class with the specified name. The string must match exactly an identifier used to declare an enum constant in this class. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum class has no constant with the specified nameNullPointerException- if the argument is null
-