Enum Class LinuxPowerSource.Prop

java.lang.Object
java.lang.Enum<LinuxPowerSource.Prop>
oshi.hardware.common.platform.linux.LinuxPowerSource.Prop
All Implemented Interfaces:
Serializable, Comparable<LinuxPowerSource.Prop>, Constable
Enclosing class:
LinuxPowerSource

protected static enum LinuxPowerSource.Prop extends Enum<LinuxPowerSource.Prop>
  • Enum Constant Details

  • Method Details

    • values

      public static LinuxPowerSource.Prop[] values()
      Returns an array containing the constants of this enum class, in the order they are declared.
      Returns:
      an array containing the constants of this enum class, in the order they are declared
    • valueOf

      public static LinuxPowerSource.Prop valueOf(String name)
      Returns the enum constant of this class with the specified name. The string must match exactly an identifier used to declare an enum constant in this class. (Extraneous whitespace characters are not permitted.)
      Parameters:
      name - the name of the enum constant to be returned.
      Returns:
      the enum constant with the specified name
      Throws:
      IllegalArgumentException - if this enum class has no constant with the specified name
      NullPointerException - if the argument is null