public class LinuxHardwareAbstractionLayer extends AbstractHardwareAbstractionLayer
LinuxHardwareAbstractionLayer class.
| Constructor and Description |
|---|
LinuxHardwareAbstractionLayer() |
| Modifier and Type | Method and Description |
|---|---|
ComputerSystem |
createComputerSystem()
Instantiates the platform-specific
ComputerSystem object |
GlobalMemory |
createMemory()
Instantiates the platform-specific
GlobalMemory object |
CentralProcessor |
createProcessor()
Instantiates the platform-specific
CentralProcessor object |
Sensors |
createSensors()
Instantiates the platform-specific
Sensors object |
HWDiskStore[] |
getDiskStores()
Instantiates an array of
HWDiskStore objects,
representing a physical hard disk or other similar storage device |
Display[] |
getDisplays()
Instantiates an array of
Display objects, representing
monitors or other video output devices. |
NetworkIF[] |
getNetworkIFs()
Instantiates an array of
NetworkIF objects,
representing a network interface |
PowerSource[] |
getPowerSources()
Instantiates an array of
PowerSource objects,
representing batteries, etc. |
SoundCard[] |
getSoundCards()
Instantiates an array of
SoundCard objects,
representing the Sound cards. |
UsbDevice[] |
getUsbDevices(boolean tree)
Instantiates an array of
UsbDevice objects,
representing devices connected via a usb port (including internal devices). |
getComputerSystem, getMemory, getProcessor, getSensorspublic ComputerSystem createComputerSystem()
ComputerSystem objectcreateComputerSystem in class AbstractHardwareAbstractionLayerComputerSystem objectpublic GlobalMemory createMemory()
GlobalMemory objectcreateMemory in class AbstractHardwareAbstractionLayerGlobalMemory objectpublic CentralProcessor createProcessor()
CentralProcessor objectcreateProcessor in class AbstractHardwareAbstractionLayerCentralProcessor objectpublic Sensors createSensors()
Sensors objectcreateSensors in class AbstractHardwareAbstractionLayerSensors objectpublic PowerSource[] getPowerSources()
PowerSource objects,
representing batteries, etc.public HWDiskStore[] getDiskStores()
HWDiskStore objects,
representing a physical hard disk or other similar storage devicepublic Display[] getDisplays()
Display objects, representing
monitors or other video output devices.public NetworkIF[] getNetworkIFs()
NetworkIF objects,
representing a network interfacepublic UsbDevice[] getUsbDevices(boolean tree)
UsbDevice objects,
representing devices connected via a usb port (including internal devices).
If the value of tree is true, the top level devices returned from this method are the USB Controllers; connected hubs and devices in its device tree share that controller's bandwidth. If the value of tree is false, USB devices (not controllers) are listed in a single flat array.
tree - Whether to display devices in a nested tree format from their
controllersCopyright © 2010–2020 oshi. All rights reserved.