Class LinuxPowerSourceJNA
java.lang.Object
oshi.hardware.common.AbstractPowerSource
oshi.hardware.common.platform.linux.LinuxPowerSource
oshi.hardware.platform.linux.LinuxPowerSourceJNA
- All Implemented Interfaces:
PowerSource
JNA-based Linux power source implementation.
-
Nested Class Summary
Nested classes/interfaces inherited from class LinuxPowerSource
LinuxPowerSource.PropModifier and TypeClassDescriptionprotected static enumPower supply uevent properties from sysfs.Nested classes/interfaces inherited from interface PowerSource
PowerSource.CapacityUnitsModifier and TypeInterfaceDescriptionstatic enumUnits of Battery Capacity -
Method Summary
Modifier and TypeMethodDescriptionstatic List<PowerSource> Gets Battery Informationprotected List<PowerSource> Returns a fresh list of power sources for this platform, used byAbstractPowerSource.updateAttributes().Methods inherited from class LinuxPowerSource
buildPowerSourceModifier and TypeMethodDescriptionprotected static LinuxPowerSourcebuildPowerSource(String name, Map<LinuxPowerSource.Prop, String> props) Builds a LinuxPowerSource from parsed uevent properties.Methods inherited from class AbstractPowerSource
getAmperage, getCapacityUnits, getChemistry, getCurrentCapacity, getCycleCount, getDesignCapacity, getDeviceName, getManufactureDate, getManufacturer, getMaxCapacity, getName, getPowerUsageRate, getRemainingCapacityPercent, getSerialNumber, getTemperature, getTimeRemainingEstimated, getTimeRemainingInstant, getVoltage, isCharging, isDischarging, isPowerOnLine, toString, updateAttributesModifier and TypeMethodDescriptiondoubleAmperage of the battery, in milliAmperes (mA).Reports =the units ofPowerSource.getCurrentCapacity(),PowerSource.getMaxCapacity(), andPowerSource.getDesignCapacity()The battery chemistry (e.g., Lithium Ion).intThe current (remaining) capacity of the battery.intThe cycle count of the battery, if known.intThe design (original) capacity of the battery.Name of the power source at the device level.The battery's date of manufacture.The name of the battery's manufacturer.intThe maximum capacity of the battery.getName()Name of the power source at the Operating System level.doublePower Usage Rate of the battery, in milliWatts (mW).doubleEstimated remaining capacity as a fraction of max capacity.The battery's serial number.doubleThe battery's temperature, in degrees Celsius.doubleEstimated time remaining on the power source, in seconds, as reported by the operating system.doubleEstimated time remaining on the power source, in seconds, as reported by the battery.doubleVoltage of the battery, in Volts.booleanReports whether the battery is charging.booleanReports whether the battery is discharging.booleanReports whether the device is plugged in to an external power source.toString()booleanUpdates statistics on this battery.
-
Method Details
-
queryPowerSources
Description copied from class:AbstractPowerSourceReturns a fresh list of power sources for this platform, used byAbstractPowerSource.updateAttributes(). Each concrete subclass implements this by delegating to its own staticgetPowerSources()factory method.- Overrides:
queryPowerSourcesin classLinuxPowerSource- Returns:
- A list of PowerSource objects representing batteries, etc.
-
getPowerSources
Gets Battery Information- Returns:
- A list of PowerSource objects representing batteries, etc.
-