Package oshi.jna.platform.windows
Interface IPHlpAPI
- All Superinterfaces:
com.sun.jna.platform.win32.IPHlpAPI,com.sun.jna.Library
public interface IPHlpAPI
extends com.sun.jna.platform.win32.IPHlpAPI
-
Nested Class Summary
Nested Classes Modifier and Type Interface Description static classIPHlpAPI.MIB_TCP6ROW_OWNER_PIDContains information that describes an IPv6 TCP connection.static classIPHlpAPI.MIB_TCP6TABLE_OWNER_PIDContains a table of IPv6 TCP connections on the local computer.static classIPHlpAPI.MIB_TCPROW_OWNER_PIDContains information that describes an IPv4 TCP connection.static classIPHlpAPI.MIB_TCPTABLE_OWNER_PIDContains a table of IPv4 TCP connections on the local computer.static classIPHlpAPI.MIB_UDP6ROW_OWNER_PIDContains information that describes an IPv6 UDP connection.static classIPHlpAPI.MIB_UDP6TABLE_OWNER_PIDContains a table of IPv6 UDP connections on the local computer.static classIPHlpAPI.MIB_UDPROW_OWNER_PIDContains information that describes an IPv6 UDP connection.static classIPHlpAPI.MIB_UDPTABLE_OWNER_PIDContains a table of IPv6 UDP connections on the local computer.Nested classes/interfaces inherited from interface com.sun.jna.platform.win32.IPHlpAPI
com.sun.jna.platform.win32.IPHlpAPI.FIXED_INFO, com.sun.jna.platform.win32.IPHlpAPI.IP_ADDR_STRING, com.sun.jna.platform.win32.IPHlpAPI.IP_ADDRESS_STRING, com.sun.jna.platform.win32.IPHlpAPI.MIB_IF_ROW2, com.sun.jna.platform.win32.IPHlpAPI.MIB_IFROW, com.sun.jna.platform.win32.IPHlpAPI.MIB_TCPSTATS, com.sun.jna.platform.win32.IPHlpAPI.MIB_UDPSTATSNested classes/interfaces inherited from interface com.sun.jna.Library
com.sun.jna.Library.Handler -
Field Summary
Fields Modifier and Type Field Description static IPHlpAPIINSTANCEstatic intTCP_TABLE_OWNER_PID_ALLstatic intUDP_TABLE_OWNER_PIDFields inherited from interface com.sun.jna.platform.win32.IPHlpAPI
AF_BTH, AF_INET, AF_INET6, AF_IPX, AF_IRDA, AF_NETBIOS, AF_UNSPEC, IF_MAX_PHYS_ADDRESS_LENGTH, IF_MAX_STRING_SIZE, MAX_DOMAIN_NAME_LEN, MAX_HOSTNAME_LEN, MAX_INTERFACE_NAME_LEN, MAX_SCOPE_ID_LEN, MAXLEN_IFDESCR, MAXLEN_PHYSADDRFields inherited from interface com.sun.jna.Library
OPTION_ALLOW_OBJECTS, OPTION_CALLING_CONVENTION, OPTION_CLASSLOADER, OPTION_FUNCTION_MAPPER, OPTION_INVOCATION_MAPPER, OPTION_OPEN_FLAGS, OPTION_STRING_ENCODING, OPTION_STRUCTURE_ALIGNMENT, OPTION_TYPE_MAPPER -
Method Summary
Modifier and Type Method Description intGetExtendedTcpTable(com.sun.jna.Pointer pTcpTable, com.sun.jna.ptr.IntByReference pdwSize, boolean bOrder, int ulAf, int TableClass, int Reserved)Retrieves a table that contains a list of TCP endpoints available to the application.intGetExtendedUdpTable(com.sun.jna.Pointer pUdpTable, com.sun.jna.ptr.IntByReference pdwSize, boolean bOrder, int ulAf, int TableClass, int Reserved)Retrieves a table that contains a list of UDP endpoints available to the application.Methods inherited from interface com.sun.jna.platform.win32.IPHlpAPI
GetIfEntry, GetIfEntry2, GetNetworkParams, GetTcpStatistics, GetTcpStatisticsEx, GetUdpStatistics, GetUdpStatisticsEx
-
Field Details
-
INSTANCE
-
UDP_TABLE_OWNER_PID
static final int UDP_TABLE_OWNER_PID- See Also:
- Constant Field Values
-
TCP_TABLE_OWNER_PID_ALL
static final int TCP_TABLE_OWNER_PID_ALL- See Also:
- Constant Field Values
-
-
Method Details
-
GetExtendedTcpTable
int GetExtendedTcpTable(com.sun.jna.Pointer pTcpTable, com.sun.jna.ptr.IntByReference pdwSize, boolean bOrder, int ulAf, int TableClass, int Reserved)Retrieves a table that contains a list of TCP endpoints available to the application.- Parameters:
pTcpTable- A pointer to the table structure that contains the filtered TCP endpoints available to the application.pdwSize- The estimated size of the structure returned in pTcpTable, in bytes. If this value is set too small,ERROR_INSUFFICIENT_BUFFERis returned by this function, and this field will contain the correct size of the structure.bOrder- A value that specifies whether the TCP connection table should be sorted. If this parameter is set to TRUE, the TCP endpoints in the table are sorted in ascending order, starting with the lowest local IP address. If this parameter is set to FALSE, the TCP endpoints in the table appear in the order in which they were retrieved. The following values are compared (as listed) when ordering the TCP endpoints: Local IP address, Local scope ID (applicable when the ulAf parameter is set to AF_INET6), Local TCP port, Remote IP address, Remote scope ID (applicable when the ulAf parameter is set to AF_INET6), Remote TCP port.ulAf- The version of IP used by the TCP endpoints.TableClass- The type of the TCP table structure to retrieve. This parameter can be one of the values from theTCP_TABLE_CLASSenumeration.Reserved- Reserved. This value must be zero.- Returns:
- If the function succeeds, the return value is
NO_ERROR. If the function fails, the return value is an error code.
-
GetExtendedUdpTable
int GetExtendedUdpTable(com.sun.jna.Pointer pUdpTable, com.sun.jna.ptr.IntByReference pdwSize, boolean bOrder, int ulAf, int TableClass, int Reserved)Retrieves a table that contains a list of UDP endpoints available to the application.- Parameters:
pUdpTable- A pointer to the table structure that contains the filtered UDP endpoints available to the application.pdwSize- The estimated size of the structure returned in pTcpTable, in bytes. If this value is set too small,ERROR_INSUFFICIENT_BUFFERis returned by this function, and this field will contain the correct size of the structure.bOrder- A value that specifies whether the TCP connection table should be sorted. If this parameter is set to TRUE, the TCP endpoints in the table are sorted in ascending order, starting with the lowest local IP address. If this parameter is set to FALSE, the TCP endpoints in the table appear in the order in which they were retrieved. The following values are compared (as listed) when ordering the TCP endpoints: Local IP address, Local scope ID (applicable when the ulAf parameter is set toAF_INET6), Local TCP port, Remote IP address, Remote scope ID (applicable when the ulAf parameter is set toAF_INET6), Remote TCP port.ulAf- The version of IP used by the UDP endpoints.TableClass- The type of the TCP table structure to retrieve. This parameter can be one of the values from theTCP_TABLE_CLASSenumeration.Reserved- Reserved. This value must be zero.- Returns:
- If the function succeeds, the return value is
NO_ERROR. If the function fails, the return value is an error code.
-