Interface IPHlpAPI

All Superinterfaces:
com.sun.jna.platform.win32.IPHlpAPI, com.sun.jna.Library

public interface IPHlpAPI
extends com.sun.jna.platform.win32.IPHlpAPI
  • Nested Class Summary

    Nested Classes 
    Modifier and Type Interface Description
    static class  IPHlpAPI.MIB_TCPSTATS
    The MIB_TCPSTATS structure contains statistics for the TCP protocol running on the local computer.
    static class  IPHlpAPI.MIB_UDPSTATS
    The MIB_UDPSTATS structure contains statistics for the User Datagram Protocol (UDP) running on the local computer.

    Nested classes/interfaces inherited from interface com.sun.jna.platform.win32.IPHlpAPI

    com.sun.jna.platform.win32.IPHlpAPI.FIXED_INFO, com.sun.jna.platform.win32.IPHlpAPI.IP_ADDR_STRING, com.sun.jna.platform.win32.IPHlpAPI.IP_ADDRESS_STRING, com.sun.jna.platform.win32.IPHlpAPI.MIB_IF_ROW2, com.sun.jna.platform.win32.IPHlpAPI.MIB_IFROW

    Nested classes/interfaces inherited from interface com.sun.jna.Library

    com.sun.jna.Library.Handler
  • Field Summary

    Fields 
    Modifier and Type Field Description
    static int AF_INET  
    static int AF_INET6  
    static IPHlpAPI INSTANCE  

    Fields inherited from interface com.sun.jna.platform.win32.IPHlpAPI

    IF_MAX_PHYS_ADDRESS_LENGTH, IF_MAX_STRING_SIZE, MAX_DOMAIN_NAME_LEN, MAX_HOSTNAME_LEN, MAX_INTERFACE_NAME_LEN, MAX_SCOPE_ID_LEN, MAXLEN_IFDESCR, MAXLEN_PHYSADDR

    Fields inherited from interface com.sun.jna.Library

    OPTION_ALLOW_OBJECTS, OPTION_CALLING_CONVENTION, OPTION_CLASSLOADER, OPTION_FUNCTION_MAPPER, OPTION_INVOCATION_MAPPER, OPTION_OPEN_FLAGS, OPTION_STRING_ENCODING, OPTION_STRUCTURE_ALIGNMENT, OPTION_TYPE_MAPPER
  • Method Summary

    Modifier and Type Method Description
    int GetTcpStatistics​(IPHlpAPI.MIB_TCPSTATS Statistics)
    The GetTcpStatistics function retrieves the TCP statistics for the local computer.
    int GetTcpStatisticsEx​(IPHlpAPI.MIB_TCPSTATS Statistics, int Family)
    The GetTcpStatisticsEx function retrieves the Transmission Control Protocol (TCP) statistics for the current computer.
    int GetUdpStatistics​(IPHlpAPI.MIB_UDPSTATS Stats)
    The GetUdpStatistics function retrieves the User Datagram Protocol (UDP) statistics for the local computer.
    int GetUdpStatisticsEx​(IPHlpAPI.MIB_UDPSTATS Statistics, int Family)
    The GetUdpStatisticsEx function retrieves the User Datagram Protocol (UDP) statistics for the current computer.

    Methods inherited from interface com.sun.jna.platform.win32.IPHlpAPI

    GetIfEntry, GetIfEntry2, GetNetworkParams
  • Field Details

  • Method Details

    • GetTcpStatistics

      int GetTcpStatistics​(IPHlpAPI.MIB_TCPSTATS Statistics)
      The GetTcpStatistics function retrieves the TCP statistics for the local computer.
      Parameters:
      Statistics - A IPHlpAPI.MIB_TCPSTATS structure that receives the TCP statistics for the local computer.
      Returns:
      If the function succeeds, the return value is WinError.NO_ERROR.
    • GetTcpStatisticsEx

      int GetTcpStatisticsEx​(IPHlpAPI.MIB_TCPSTATS Statistics, int Family)
      The GetTcpStatisticsEx function retrieves the Transmission Control Protocol (TCP) statistics for the current computer. The GetTcpStatisticsEx function differs from the GetTcpStatistics(oshi.jna.platform.windows.IPHlpAPI.MIB_TCPSTATS) function in that GetTcpStatisticsEx also supports the Internet Protocol version 6 (IPv6) protocol family.
      Parameters:
      Statistics - A IPHlpAPI.MIB_TCPSTATS structure that receives the TCP statistics for the local computer.
      Family - The protocol family for which to retrieve statistics. This parameter must be AF_INET or AF_INET6.
      Returns:
      If the function succeeds, the return value is WinError.NO_ERROR.
    • GetUdpStatistics

      int GetUdpStatistics​(IPHlpAPI.MIB_UDPSTATS Stats)
      The GetUdpStatistics function retrieves the User Datagram Protocol (UDP) statistics for the local computer.
      Parameters:
      Stats - A IPHlpAPI.MIB_UDPSTATS structure that receives the UDP statistics for the local computer.
      Returns:
      If the function succeeds, the return value is WinError.NO_ERROR.
    • GetUdpStatisticsEx

      int GetUdpStatisticsEx​(IPHlpAPI.MIB_UDPSTATS Statistics, int Family)
      The GetUdpStatisticsEx function retrieves the User Datagram Protocol (UDP) statistics for the current computer. The GetUdpStatisticsEx function differs from the GetUdpStatistics(oshi.jna.platform.windows.IPHlpAPI.MIB_UDPSTATS) function in that GetUdpStatisticsEx also supports the Internet Protocol version 6 (IPv6) protocol family.
      Parameters:
      Statistics - A IPHlpAPI.MIB_UDPSTATS structure that receives the UDP statistics for the local computer.
      Family - The protocol family for which to retrieve statistics. This parameter must be AF_INET or AF_INET6.
      Returns:
      If the function succeeds, the return value is WinError.NO_ERROR.