Package oshi.jna.platform.windows
Interface IPHlpAPI
- All Superinterfaces:
com.sun.jna.platform.win32.IPHlpAPI,com.sun.jna.Library
public interface IPHlpAPI
extends com.sun.jna.platform.win32.IPHlpAPI
-
Nested Class Summary
Nested Classes Modifier and Type Interface Description static classIPHlpAPI.MIB_TCPSTATSThe MIB_TCPSTATS structure contains statistics for the TCP protocol running on the local computer.static classIPHlpAPI.MIB_UDPSTATSThe MIB_UDPSTATS structure contains statistics for the User Datagram Protocol (UDP) running on the local computer.Nested classes/interfaces inherited from interface com.sun.jna.platform.win32.IPHlpAPI
com.sun.jna.platform.win32.IPHlpAPI.FIXED_INFO, com.sun.jna.platform.win32.IPHlpAPI.IP_ADDR_STRING, com.sun.jna.platform.win32.IPHlpAPI.IP_ADDRESS_STRING, com.sun.jna.platform.win32.IPHlpAPI.MIB_IF_ROW2, com.sun.jna.platform.win32.IPHlpAPI.MIB_IFROW -
Field Summary
Fields Modifier and Type Field Description static intAF_INETstatic intAF_INET6static IPHlpAPIINSTANCE -
Method Summary
Modifier and Type Method Description intGetTcpStatistics(IPHlpAPI.MIB_TCPSTATS Statistics)The GetTcpStatistics function retrieves the TCP statistics for the local computer.intGetTcpStatisticsEx(IPHlpAPI.MIB_TCPSTATS Statistics, int Family)The GetTcpStatisticsEx function retrieves the Transmission Control Protocol (TCP) statistics for the current computer.intGetUdpStatistics(IPHlpAPI.MIB_UDPSTATS Stats)The GetUdpStatistics function retrieves the User Datagram Protocol (UDP) statistics for the local computer.intGetUdpStatisticsEx(IPHlpAPI.MIB_UDPSTATS Statistics, int Family)The GetUdpStatisticsEx function retrieves the User Datagram Protocol (UDP) statistics for the current computer.
-
Field Details
-
INSTANCE
-
AF_INET
static final int AF_INET- See Also:
- Constant Field Values
-
AF_INET6
static final int AF_INET6- See Also:
- Constant Field Values
-
-
Method Details
-
GetTcpStatistics
The GetTcpStatistics function retrieves the TCP statistics for the local computer.- Parameters:
Statistics- AIPHlpAPI.MIB_TCPSTATSstructure that receives the TCP statistics for the local computer.- Returns:
- If the function succeeds, the return value is
WinError.NO_ERROR.
-
GetTcpStatisticsEx
The GetTcpStatisticsEx function retrieves the Transmission Control Protocol (TCP) statistics for the current computer. The GetTcpStatisticsEx function differs from theGetTcpStatistics(oshi.jna.platform.windows.IPHlpAPI.MIB_TCPSTATS)function in that GetTcpStatisticsEx also supports the Internet Protocol version 6 (IPv6) protocol family.- Parameters:
Statistics- AIPHlpAPI.MIB_TCPSTATSstructure that receives the TCP statistics for the local computer.Family- The protocol family for which to retrieve statistics. This parameter must beAF_INETorAF_INET6.- Returns:
- If the function succeeds, the return value is
WinError.NO_ERROR.
-
GetUdpStatistics
The GetUdpStatistics function retrieves the User Datagram Protocol (UDP) statistics for the local computer.- Parameters:
Stats- AIPHlpAPI.MIB_UDPSTATSstructure that receives the UDP statistics for the local computer.- Returns:
- If the function succeeds, the return value is
WinError.NO_ERROR.
-
GetUdpStatisticsEx
The GetUdpStatisticsEx function retrieves the User Datagram Protocol (UDP) statistics for the current computer. The GetUdpStatisticsEx function differs from theGetUdpStatistics(oshi.jna.platform.windows.IPHlpAPI.MIB_UDPSTATS)function in that GetUdpStatisticsEx also supports the Internet Protocol version 6 (IPv6) protocol family.- Parameters:
Statistics- AIPHlpAPI.MIB_UDPSTATSstructure that receives the UDP statistics for the local computer.Family- The protocol family for which to retrieve statistics. This parameter must beAF_INETorAF_INET6.- Returns:
- If the function succeeds, the return value is
WinError.NO_ERROR.
-