Uses of Class
oshi.software.common.AbstractOperatingSystem
Packages that use AbstractOperatingSystem
Package
Description
Provides common (native-free) Linux operating system implementations shared by JNA and FFM modules.
Provides information about Software and OS on macOS
Provides common implementations for Windows operating system information shared between JNA and FFM implementations.
Provides information about Software and OS on Linux
Provides information about Software and OS on macOS
Provides information about Software and OS on AIX
Provides information about Software and OS on FreeBSD
Provides information about Software and OS on OpenBSD
Provides information about Software and OS on Solaris
Provides information about Software and OS on Windows
-
Uses of AbstractOperatingSystem in oshi.software.common.os.linux
Subclasses of AbstractOperatingSystem in oshi.software.common.os.linuxModifier and TypeClassDescriptionclassLinux is a family of open source Unix-like operating systems based on the Linux kernel, an operating system kernel first released on September 17, 1991, by Linus Torvalds. -
Uses of AbstractOperatingSystem in oshi.software.common.os.mac
Subclasses of AbstractOperatingSystem in oshi.software.common.os.macModifier and TypeClassDescriptionclassmacOS, previously Mac OS X and later OS X) is a series of proprietary graphical operating systems developed and marketed by Apple Inc. since 2001. -
Uses of AbstractOperatingSystem in oshi.software.common.os.windows
Subclasses of AbstractOperatingSystem in oshi.software.common.os.windowsModifier and TypeClassDescriptionclassCommon base class for Windows operating system implementations. -
Uses of AbstractOperatingSystem in oshi.software.os.linux
Subclasses of AbstractOperatingSystem in oshi.software.os.linuxModifier and TypeClassDescriptionclassJNA-based Linux operating system implementation. -
Uses of AbstractOperatingSystem in oshi.software.os.mac
Subclasses of AbstractOperatingSystem in oshi.software.os.macModifier and TypeClassDescriptionclassmacOS, previously Mac OS X and later OS X) is a series of proprietary graphical operating systems developed and marketed by Apple Inc. since 2001. -
Uses of AbstractOperatingSystem in oshi.software.os.unix.aix
Subclasses of AbstractOperatingSystem in oshi.software.os.unix.aixModifier and TypeClassDescriptionclassAIX (Advanced Interactive eXecutive) is a series of proprietary Unix operating systems developed and sold by IBM for several of its computer platforms. -
Uses of AbstractOperatingSystem in oshi.software.os.unix.freebsd
Subclasses of AbstractOperatingSystem in oshi.software.os.unix.freebsdModifier and TypeClassDescriptionclassFreeBSD is a free and open-source Unix-like operating system descended from the Berkeley Software Distribution (BSD), which was based on Research Unix. -
Uses of AbstractOperatingSystem in oshi.software.os.unix.openbsd
Subclasses of AbstractOperatingSystem in oshi.software.os.unix.openbsdModifier and TypeClassDescriptionclassOpenBsd is a free and open-source Unix-like operating system descended from the Berkeley Software Distribution (BSD), which was based on Research Unix. -
Uses of AbstractOperatingSystem in oshi.software.os.unix.solaris
Subclasses of AbstractOperatingSystem in oshi.software.os.unix.solarisModifier and TypeClassDescriptionclassSolaris is a non-free Unix operating system originally developed by Sun Microsystems. -
Uses of AbstractOperatingSystem in oshi.software.os.windows
Subclasses of AbstractOperatingSystem in oshi.software.os.windowsModifier and TypeClassDescriptionclassMicrosoft Windows, commonly referred to as Windows, is a group of several proprietary graphical operating system families, all of which are developed and marketed by Microsoft.