Class LinuxOperatingSystem
java.lang.Object
oshi.software.common.AbstractOperatingSystem
oshi.software.common.os.linux.LinuxOperatingSystem
- All Implemented Interfaces:
OperatingSystem
- Direct Known Subclasses:
LinuxOperatingSystemJNA, LinuxOperatingSystemNF
Linux is a family of open source Unix-like operating systems based on the Linux kernel, an operating system kernel
first released on September 17, 1991, by Linus Torvalds. Linux is typically packaged in a Linux distribution.
-
Nested Class Summary
Nested classes/interfaces inherited from interface OperatingSystem
OperatingSystem.OSVersionInfo, OperatingSystem.ProcessFiltering, OperatingSystem.ProcessSortingModifier and TypeInterfaceDescriptionstatic classA class representing the Operating System version details.static final classConstants which may be used to filter Process lists inOperatingSystem.getProcesses(Predicate, Comparator, int),OperatingSystem.getChildProcesses(int, Predicate, Comparator, int), andOperatingSystem.getDescendantProcesses(int, Predicate, Comparator, int).static final classConstants which may be used to sort Process lists inOperatingSystem.getProcesses(Predicate, Comparator, int),OperatingSystem.getChildProcesses(int, Predicate, Comparator, int), andOperatingSystem.getDescendantProcesses(int, Predicate, Comparator, int). -
Field Summary
Fields inherited from class AbstractOperatingSystem
USE_WHO_COMMANDModifier and TypeFieldDescriptionprotected static final booleanWhether to use the 'who' command for session queries. -
Constructor Summary
ConstructorsModifierConstructorDescriptionprotectedConstructor for LinuxOperatingSystem. -
Method Summary
Modifier and TypeMethodDescriptionprotected abstract OSProcesscreateOSProcess(int pid) Creates an OS process for the given PID.static longGets the system boot time in seconds since the epoch.Retrieves cgroup information for the current process.Makes a best effort to get the current thread.abstract longgetHz()Gets Jiffies per second, useful for converting ticks to milliseconds and vice versa.Retrieves a list of installed applications on the system.Instantiates aInternetProtocolStatsobject.abstract longGets Page Size, for converting memory stats from pages to bytesgetParentPidsFromProcFiles(File[] pidFiles) Gets parent PIDs from proc filesystem files.intGet the number of processes currently runningprotected static StringLooks for a collection of possible distrib-release filenamesGets the all services on the system.longGet Unix time of boot.longGet the System up time (time since boot).Queries all processes on the system.protected intqueryBitness(int jvmBitness) Backup OS-specific query to determine bitness if previous checks failqueryChildProcesses(int parentPid) Queries the children of a process.queryDescendantProcesses(int parentPid) Queries the descendants of a process.Queries the OS family and version info.Queries the OS manufacturer.Methods inherited from class AbstractOperatingSystem
getBitness, getChildProcesses, getChildrenOrDescendants, getChildrenOrDescendants, getDescendantProcesses, getDesktopWindows, getFamily, getManufacturer, getProcesses, getSessions, getVersionInfo, isElevated, toStringModifier and TypeMethodDescriptionintGets the bitness (32 or 64) of the operating system.getChildProcesses(int parentPid, Predicate<OSProcess> filter, Comparator<OSProcess> sort, int limit) Gets currently running child processes of provided parent PID, optionally filtering, sorting, and limited to the top "N".getChildrenOrDescendants(Collection<OSProcess> allProcs, int parentPid, boolean allDescendants) Utility method for subclasses to take a full process list as input and return the children or descendants of a particular process.getChildrenOrDescendants(Map<Integer, Integer> parentPidMap, int parentPid, boolean allDescendants) Utility method for subclasses to take a map of pid to parent as input and return the children or descendants of a particular process.getDescendantProcesses(int parentPid, Predicate<OSProcess> filter, Comparator<OSProcess> sort, int limit) Gets currently running processes of provided parent PID's descendants, including their children, the children's children, etc., optionally filtering, sorting, and limited to the top "N".getDesktopWindows(boolean visibleOnly) Gets windows on the operating system's GUI desktop.Get the Operating System family.Get the Operating System manufacturer.getProcesses(Predicate<OSProcess> filter, Comparator<OSProcess> sort, int limit) Gets currently running processes, optionally filtering, sorting, and limited to the top "N".Gets currently logged in users.Get Operating System version information.booleanDetermine whether the current process has elevated permissions such as sudo / AdministratortoString()Methods inherited from class Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface OperatingSystem
getCurrentProcess, getFileSystem, getNetworkParams, getProcess, getProcesses, getProcesses, getProcessId, getThreadCount, getThreadIdModifier and TypeMethodDescriptiondefault OSProcessGets the current process.Instantiates aFileSystemobject.Instantiates aNetworkParamsobject.getProcess(int pid) Gets information on a currently running processGets currently running processes.getProcesses(Collection<Integer> pids) Gets information on aCollectionof currently running processes.intGets the current process ID (PID).intGet the number of threads currently runningintMakes a best effort to get the current thread ID (TID).
-
Constructor Details
-
LinuxOperatingSystem
protected LinuxOperatingSystem()Constructor for LinuxOperatingSystem.
-
-
Method Details
-
queryManufacturer
Description copied from class:AbstractOperatingSystemQueries the OS manufacturer.- Specified by:
queryManufacturerin classAbstractOperatingSystem- Returns:
- the manufacturer string
-
queryFamilyVersionInfo
Description copied from class:AbstractOperatingSystemQueries the OS family and version info.- Specified by:
queryFamilyVersionInfoin classAbstractOperatingSystem- Returns:
- a pair of family string and OS version info
-
queryBitness
protected int queryBitness(int jvmBitness) Description copied from class:AbstractOperatingSystemBackup OS-specific query to determine bitness if previous checks fail- Specified by:
queryBitnessin classAbstractOperatingSystem- Parameters:
jvmBitness- The bitness of the JVM- Returns:
- The operating system bitness
-
getInternetProtocolStats
Description copied from interface:OperatingSystemInstantiates aInternetProtocolStatsobject.- Returns:
- a
InternetProtocolStatsobject.
-
queryAllProcesses
Description copied from class:AbstractOperatingSystemQueries all processes on the system.- Specified by:
queryAllProcessesin classAbstractOperatingSystem- Returns:
- a list of all OS processes
-
queryChildProcesses
Description copied from class:AbstractOperatingSystemQueries the children of a process.- Specified by:
queryChildProcessesin classAbstractOperatingSystem- Parameters:
parentPid- the parent process ID- Returns:
- a list of child processes (including the parent itself)
-
queryDescendantProcesses
Description copied from class:AbstractOperatingSystemQueries the descendants of a process.- Specified by:
queryDescendantProcessesin classAbstractOperatingSystem- Parameters:
parentPid- the parent process ID- Returns:
- a list of descendant processes (including the parent itself)
-
createOSProcess
Creates an OS process for the given PID.- Parameters:
pid- the process ID- Returns:
- the OS process
-
getParentPidsFromProcFiles
-
getProcessCount
public int getProcessCount()Description copied from interface:OperatingSystemGet the number of processes currently running- Returns:
- The number of processes running
-
getCurrentThread
Description copied from interface:OperatingSystemMakes a best effort to get the current thread. May not be useful in a multithreaded environment. The thread returned may have been short lived and no longer exist.On macOS, returns the oldest thread in the calling process.
- Returns:
- the current thread if known; an invalid thread otherwise.
-
getSystemUptime
public long getSystemUptime()Description copied from interface:OperatingSystemGet the System up time (time since boot).- Returns:
- Number of seconds since boot.
-
getSystemBootTime
public long getSystemBootTime()Description copied from interface:OperatingSystemGet Unix time of boot.- Returns:
- The approximate time at which the system booted, in seconds since the Unix epoch.
-
getInstalledApplications
Description copied from interface:OperatingSystemRetrieves a list of installed applications on the system.This method is implemented per OS. If the OS does not support this feature, it returns an empty list.
- Returns:
- A list of installed applications or an empty list if unsupported.
-
getCgroupInfo
Description copied from interface:OperatingSystemRetrieves cgroup information for the current process.On Linux, this returns detailed cgroup resource limits and usage metrics. On non-Linux platforms, this returns a no-op instance where
CgroupInfo.isContainerized()returnsfalse.- Returns:
- A
CgroupInfoobject representing cgroup information.
-
getReleaseFilename
Looks for a collection of possible distrib-release filenames- Returns:
- The first valid matching filename
-
getServices
Description copied from interface:OperatingSystemGets the all services on the system. The definition of what is a service is platform-dependent.- Returns:
- An array of
OSServiceobjects
-
getHz
public abstract long getHz()Gets Jiffies per second, useful for converting ticks to milliseconds and vice versa.- Returns:
- Jiffies per second.
-
getPageSize
public abstract long getPageSize()Gets Page Size, for converting memory stats from pages to bytes- Returns:
- Page Size
-
getBootTime
public static long getBootTime()Gets the system boot time in seconds since the epoch.- Returns:
- Boot time in seconds since the epoch.
-