Class LinuxOperatingSystemNF
java.lang.Object
oshi.software.common.AbstractOperatingSystem
oshi.software.common.os.linux.LinuxOperatingSystem
oshi.software.common.os.linux.nativefree.LinuxOperatingSystemNF
- All Implemented Interfaces:
OperatingSystem
Native-free Linux operating system implementation. Extends
LinuxOperatingSystem, providing implementations
that require no native access.-
Nested Class Summary
Nested classes/interfaces inherited from interface OperatingSystem
OperatingSystem.OSVersionInfo, OperatingSystem.ProcessFiltering, OperatingSystem.ProcessSortingModifier and TypeInterfaceDescriptionstatic classA class representing the Operating System version details.static final classConstants which may be used to filter Process lists inOperatingSystem.getProcesses(Predicate, Comparator, int),OperatingSystem.getChildProcesses(int, Predicate, Comparator, int), andOperatingSystem.getDescendantProcesses(int, Predicate, Comparator, int).static final classConstants which may be used to sort Process lists inOperatingSystem.getProcesses(Predicate, Comparator, int),OperatingSystem.getChildProcesses(int, Predicate, Comparator, int), andOperatingSystem.getDescendantProcesses(int, Predicate, Comparator, int). -
Field Summary
Fields inherited from class AbstractOperatingSystem
USE_WHO_COMMANDModifier and TypeFieldDescriptionprotected static final booleanWhether to use the 'who' command for session queries. -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionprotected OSProcesscreateOSProcess(int pid) Creates an OS process for the given PID.Instantiates aFileSystemobject.longgetHz()Gets Jiffies per second, useful for converting ticks to milliseconds and vice versa.Instantiates aNetworkParamsobject.longGets Page Size, for converting memory stats from pages to bytesgetProcess(int pid) Gets information on a currently running processintGets the current process ID (PID).intGet the number of threads currently runningintMakes a best effort to get the current thread ID (TID).static longhz()Gets Jiffies per second.static longpageSize()Gets Page Size in bytes.Methods inherited from class LinuxOperatingSystem
getBootTime, getCgroupInfo, getCurrentThread, getInstalledApplications, getInternetProtocolStats, getParentPidsFromProcFiles, getProcessCount, getReleaseFilename, getServices, getSystemBootTime, getSystemUptime, queryAllProcesses, queryBitness, queryChildProcesses, queryDescendantProcesses, queryFamilyVersionInfo, queryManufacturerModifier and TypeMethodDescriptionstatic longGets the system boot time in seconds since the epoch.Retrieves cgroup information for the current process.Makes a best effort to get the current thread.Retrieves a list of installed applications on the system.Instantiates aInternetProtocolStatsobject.getParentPidsFromProcFiles(File[] pidFiles) Gets parent PIDs from proc filesystem files.intGet the number of processes currently runningprotected static StringLooks for a collection of possible distrib-release filenamesGets the all services on the system.longGet Unix time of boot.longGet the System up time (time since boot).Queries all processes on the system.protected intqueryBitness(int jvmBitness) Backup OS-specific query to determine bitness if previous checks failqueryChildProcesses(int parentPid) Queries the children of a process.queryDescendantProcesses(int parentPid) Queries the descendants of a process.Queries the OS family and version info.Queries the OS manufacturer.Methods inherited from class AbstractOperatingSystem
getBitness, getChildProcesses, getChildrenOrDescendants, getChildrenOrDescendants, getDescendantProcesses, getDesktopWindows, getFamily, getManufacturer, getProcesses, getSessions, getVersionInfo, isElevated, toStringModifier and TypeMethodDescriptionintGets the bitness (32 or 64) of the operating system.getChildProcesses(int parentPid, Predicate<OSProcess> filter, Comparator<OSProcess> sort, int limit) Gets currently running child processes of provided parent PID, optionally filtering, sorting, and limited to the top "N".getChildrenOrDescendants(Collection<OSProcess> allProcs, int parentPid, boolean allDescendants) Utility method for subclasses to take a full process list as input and return the children or descendants of a particular process.getChildrenOrDescendants(Map<Integer, Integer> parentPidMap, int parentPid, boolean allDescendants) Utility method for subclasses to take a map of pid to parent as input and return the children or descendants of a particular process.getDescendantProcesses(int parentPid, Predicate<OSProcess> filter, Comparator<OSProcess> sort, int limit) Gets currently running processes of provided parent PID's descendants, including their children, the children's children, etc., optionally filtering, sorting, and limited to the top "N".getDesktopWindows(boolean visibleOnly) Gets windows on the operating system's GUI desktop.Get the Operating System family.Get the Operating System manufacturer.getProcesses(Predicate<OSProcess> filter, Comparator<OSProcess> sort, int limit) Gets currently running processes, optionally filtering, sorting, and limited to the top "N".Gets currently logged in users.Get Operating System version information.booleanDetermine whether the current process has elevated permissions such as sudo / AdministratortoString()Methods inherited from class Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface OperatingSystem
getCurrentProcess, getProcesses, getProcessesModifier and TypeMethodDescriptiondefault OSProcessGets the current process.Gets currently running processes.getProcesses(Collection<Integer> pids) Gets information on aCollectionof currently running processes.
-
Constructor Details
-
LinuxOperatingSystemNF
public LinuxOperatingSystemNF()
-
-
Method Details
-
hz
public static long hz()Gets Jiffies per second.- Returns:
- Jiffies per second.
-
pageSize
public static long pageSize()Gets Page Size in bytes.- Returns:
- Page Size in bytes.
-
getHz
public long getHz()Description copied from class:LinuxOperatingSystemGets Jiffies per second, useful for converting ticks to milliseconds and vice versa.- Specified by:
getHzin classLinuxOperatingSystem- Returns:
- Jiffies per second.
-
getPageSize
public long getPageSize()Description copied from class:LinuxOperatingSystemGets Page Size, for converting memory stats from pages to bytes- Specified by:
getPageSizein classLinuxOperatingSystem- Returns:
- Page Size
-
getFileSystem
Description copied from interface:OperatingSystemInstantiates aFileSystemobject.- Returns:
- A
FileSystemobject.
-
getNetworkParams
Description copied from interface:OperatingSystemInstantiates aNetworkParamsobject.- Returns:
- A
NetworkParamsobject.
-
getProcess
Description copied from interface:OperatingSystemGets information on a currently running process- Parameters:
pid- A process ID- Returns:
- An
OSProcessobject for the specified process id if it is running; null otherwise
-
createOSProcess
Description copied from class:LinuxOperatingSystemCreates an OS process for the given PID.- Specified by:
createOSProcessin classLinuxOperatingSystem- Parameters:
pid- the process ID- Returns:
- the OS process
-
getProcessId
public int getProcessId()Description copied from interface:OperatingSystemGets the current process ID (PID).- Returns:
- the Process ID of the current process
-
getThreadId
public int getThreadId()Description copied from interface:OperatingSystemMakes a best effort to get the current thread ID (TID). May not be useful in a multithreaded environment. The thread ID returned may have been short lived and no longer exist.Thread IDs on macOS are not correlated with any other Operating System output.
- Returns:
- the Thread ID of the current thread if known, 0 otherwise.
-
getThreadCount
public int getThreadCount()Description copied from interface:OperatingSystemGet the number of threads currently running- Returns:
- The number of threads running
-