Class SolarisFileSystem
java.lang.Object
oshi.software.common.AbstractFileSystem
oshi.software.common.os.unix.solaris.SolarisFileSystem
- All Implemented Interfaces:
FileSystem
- Direct Known Subclasses:
SolarisFileSystemJNA
The Solaris File System contains
OSFileStores which are a storage pool, device, partition,
volume, concrete file system or other implementation specific means of file storage. In Solaris, these are found in
the /proc/mount filesystem, excluding temporary and kernel mounts.
The mount-table and inode parsing is shared; the kstat-based file-descriptor counts (getOpenFile...,
getMaxFile...) are native and implemented by the JNA and FFM subclasses.
-
Field Summary
FieldsModifier and TypeFieldDescriptionstatic final Stringstatic final Stringstatic final Stringstatic final StringFields inherited from class AbstractFileSystem
NETWORK_FS_TYPES, PSEUDO_FS_TYPESModifier and TypeFieldDescriptionFileSystem types which are network-based and should be excluded from local-only listsFileSystem types which are pseudo-filesystems and should be excluded from local-only lists -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptiongetFileStores(boolean localOnly) Get file stores on this machine Instantiates a list ofOSFileStoreobjects, representing a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage.longThe maximum number of open file descriptors per process.Methods inherited from class AbstractFileSystem
getFileStoresModifier and TypeMethodDescriptionGet file stores on this machine Instantiates a list ofOSFileStoreobjects, representing a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage.Methods inherited from class Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, waitMethods inherited from interface FileSystem
getMaxFileDescriptors, getOpenFileDescriptorsModifier and TypeMethodDescriptionlongThe maximum number of open file descriptors.longThe current number of open file descriptors.
-
Field Details
-
OSHI_SOLARIS_FS_PATH_EXCLUDES
- See Also:
-
OSHI_SOLARIS_FS_PATH_INCLUDES
- See Also:
-
OSHI_SOLARIS_FS_VOLUME_EXCLUDES
- See Also:
-
OSHI_SOLARIS_FS_VOLUME_INCLUDES
- See Also:
-
-
Constructor Details
-
SolarisFileSystem
public SolarisFileSystem()
-
-
Method Details
-
getFileStores
Description copied from interface:FileSystemGet file stores on this machine Instantiates a list ofOSFileStoreobjects, representing a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage.- Parameters:
localOnly- If true, filters the list to only local file stores. On Windows, also excluded CD-ROM drives.- Returns:
- A list of
OSFileStoreobjects or an empty array if none are present.
-
getMaxFileDescriptorsPerProcess
public long getMaxFileDescriptorsPerProcess()Description copied from interface:FileSystemThe maximum number of open file descriptors per process. This returns the upper limit which applies to each process. The actual limit of a process may be lower if configured.- Returns:
- The maximum number of file descriptors of each process if available, 0 otherwise.
-