Class WindowsOperatingSystem
java.lang.Object
oshi.software.common.AbstractOperatingSystem
oshi.software.common.os.windows.WindowsOperatingSystem
- All Implemented Interfaces:
OperatingSystem
- Direct Known Subclasses:
WindowsOperatingSystemJNA
Common base class for Windows operating system implementations.
-
Nested Class Summary
Nested classes/interfaces inherited from interface OperatingSystem
OperatingSystem.OSVersionInfo, OperatingSystem.ProcessFiltering, OperatingSystem.ProcessSorting -
Field Summary
FieldsFields inherited from class AbstractOperatingSystem
USE_WHO_COMMAND -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionprotected static StringparseCodeName(int suiteMask) Gets suites available on the system and return as a codename.protected StringMethods inherited from class AbstractOperatingSystem
getBitness, getChildProcesses, getChildrenOrDescendants, getChildrenOrDescendants, getDescendantProcesses, getDesktopWindows, getFamily, getManufacturer, getProcesses, getSessions, getVersionInfo, isElevated, queryAllProcesses, queryBitness, queryChildProcesses, queryDescendantProcesses, queryFamilyVersionInfo, toStringMethods inherited from class Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface OperatingSystem
getCgroupInfo, getCurrentProcess, getCurrentThread, getFileSystem, getInstalledApplications, getInternetProtocolStats, getNetworkParams, getProcess, getProcessCount, getProcesses, getProcesses, getProcessId, getServices, getSystemBootTime, getSystemUptime, getThreadCount, getThreadId
-
Field Details
-
USE_PROCSTATE_SUSPENDED
protected static final boolean USE_PROCSTATE_SUSPENDED
-
-
Constructor Details
-
WindowsOperatingSystem
public WindowsOperatingSystem()
-
-
Method Details
-
queryManufacturer
- Specified by:
queryManufacturerin classAbstractOperatingSystem
-
parseCodeName
Gets suites available on the system and return as a codename.- Parameters:
suiteMask- The suite mask bitmask- Returns:
- Suites
-