Uses of Interface
oshi.software.os.OSProcess
Packages that use OSProcess
Package
Description
Provides abstract classes for common code
Provides common (native-free) Linux operating system implementations shared by JNA and FFM modules.
Native-free Linux operating system implementations using only procfs, sysfs, and command-line utilities.
Provides information about Software and OS on macOS
Provides abstract base classes and pure-Java implementations for the FreeBSD operating system, shared by the JNA and
FFM modules.
Provides abstract base classes and pure-Java implementations for the OpenBSD operating system, shared by the JNA and
FFM modules.
Provides common implementations for Windows operating system information shared between JNA and FFM implementations.
[oshi-common API] Provides cross-platform common API to retrieve OS, FileSystem, and Process information
Provides information about Software and OS on Linux
Provides information about Software and OS on macOS
Provides information about Software and OS on AIX
Provides information about Software and OS on DragonFly BSD
Provides information about Software and OS on FreeBSD
Provides information about Software and OS on NetBSD
Provides information about Software and OS on OpenBSD
Provides information about Software and OS on Solaris
Provides information about Software and OS on Windows
-
Uses of OSProcess in oshi.software.common
Classes in oshi.software.common that implement OSProcessModifier and TypeClassDescriptionclassA process is an instance of a computer program that is being executed.Methods in oshi.software.common that return types with arguments of type OSProcessModifier and TypeMethodDescriptionAbstractOperatingSystem.getChildProcesses(int parentPid, Predicate<OSProcess> filter, Comparator<OSProcess> sort, int limit) AbstractOperatingSystem.getDescendantProcesses(int parentPid, Predicate<OSProcess> filter, Comparator<OSProcess> sort, int limit) AbstractOperatingSystem.getProcesses(Predicate<OSProcess> filter, Comparator<OSProcess> sort, int limit) AbstractOperatingSystem.queryAllProcesses()Queries all processes on the system.AbstractOperatingSystem.queryChildProcesses(int parentPid) Queries the children of a process.AbstractOperatingSystem.queryDescendantProcesses(int parentPid) Queries the descendants of a process.Methods in oshi.software.common with parameters of type OSProcessModifier and TypeMethodDescriptiondoubleAbstractOSProcess.getProcessCpuLoadBetweenTicks(OSProcess priorSnapshot) Method parameters in oshi.software.common with type arguments of type OSProcessModifier and TypeMethodDescriptionAbstractOperatingSystem.getChildProcesses(int parentPid, Predicate<OSProcess> filter, Comparator<OSProcess> sort, int limit) AbstractOperatingSystem.getChildProcesses(int parentPid, Predicate<OSProcess> filter, Comparator<OSProcess> sort, int limit) AbstractOperatingSystem.getChildrenOrDescendants(Collection<OSProcess> allProcs, int parentPid, boolean allDescendants) Utility method for subclasses to take a full process list as input and return the children or descendants of a particular process.AbstractOperatingSystem.getDescendantProcesses(int parentPid, Predicate<OSProcess> filter, Comparator<OSProcess> sort, int limit) AbstractOperatingSystem.getDescendantProcesses(int parentPid, Predicate<OSProcess> filter, Comparator<OSProcess> sort, int limit) AbstractOperatingSystem.getProcesses(Predicate<OSProcess> filter, Comparator<OSProcess> sort, int limit) AbstractOperatingSystem.getProcesses(Predicate<OSProcess> filter, Comparator<OSProcess> sort, int limit) -
Uses of OSProcess in oshi.software.common.os.linux
Classes in oshi.software.common.os.linux that implement OSProcessMethods in oshi.software.common.os.linux that return OSProcessModifier and TypeMethodDescriptionprotected abstract OSProcessLinuxOperatingSystem.createOSProcess(int pid) Creates an OS process for the given PID.Methods in oshi.software.common.os.linux that return types with arguments of type OSProcessModifier and TypeMethodDescriptionLinuxOperatingSystem.queryAllProcesses()LinuxOperatingSystem.queryChildProcesses(int parentPid) LinuxOperatingSystem.queryDescendantProcesses(int parentPid) -
Uses of OSProcess in oshi.software.common.os.linux.nativefree
Classes in oshi.software.common.os.linux.nativefree that implement OSProcessModifier and TypeClassDescriptionclassNative-free Linux OS process implementation.Methods in oshi.software.common.os.linux.nativefree that return OSProcessModifier and TypeMethodDescriptionprotected OSProcessLinuxOperatingSystemNF.createOSProcess(int pid) LinuxOperatingSystemNF.getProcess(int pid) -
Uses of OSProcess in oshi.software.common.os.mac
Methods in oshi.software.common.os.mac that return types with arguments of type OSProcessModifier and TypeMethodDescriptionMacOperatingSystem.queryChildProcesses(int parentPid) MacOperatingSystem.queryDescendantProcesses(int parentPid) -
Uses of OSProcess in oshi.software.common.os.unix.freebsd
Classes in oshi.software.common.os.unix.freebsd that implement OSProcess -
Uses of OSProcess in oshi.software.common.os.unix.openbsd
Classes in oshi.software.common.os.unix.openbsd that implement OSProcess -
Uses of OSProcess in oshi.software.common.os.windows
Classes in oshi.software.common.os.windows that implement OSProcessModifier and TypeClassDescriptionclassCommon base class for Windows OS process implementations, containing shared fields, getters, and non-native methods. -
Uses of OSProcess in oshi.software.os
Fields in oshi.software.os with type parameters of type OSProcessModifier and TypeFieldDescriptionOperatingSystem.ProcessFiltering.ALL_PROCESSESNo filtering.OperatingSystem.ProcessFiltering.BITNESS_32Only include 32-bit processes.OperatingSystem.ProcessFiltering.BITNESS_64Only incude 64-bit processes.static final Comparator<OSProcess> OperatingSystem.ProcessSorting.CPU_DESCSort by decreasing cumulative CPU percentagestatic final Comparator<OSProcess> OperatingSystem.ProcessSorting.NAME_ASCSort by Process Name (case insensitive)OperatingSystem.ProcessFiltering.NO_PARENTExclude child processes.static final Comparator<OSProcess> OperatingSystem.ProcessSorting.NO_SORTINGNo sortingstatic final Comparator<OSProcess> OperatingSystem.ProcessSorting.PARENTPID_ASCSort by Parent Process Idstatic final Comparator<OSProcess> OperatingSystem.ProcessSorting.PID_ASCSort by Process Idstatic final Comparator<OSProcess> OperatingSystem.ProcessSorting.PRIVATE_RSS_DESCSort by decreasing private resident memory sizestatic final Comparator<OSProcess> OperatingSystem.ProcessSorting.RSS_DESCSort by decreasing Resident Set Size (RSS)static final Comparator<OSProcess> OperatingSystem.ProcessSorting.UPTIME_ASCSort by up time, newest processes firststatic final Comparator<OSProcess> OperatingSystem.ProcessSorting.UPTIME_DESCSort by up time, oldest processes firstOperatingSystem.ProcessFiltering.VALID_PROCESSExclude processes withOSProcess.State.INVALIDprocess state.Methods in oshi.software.os that return OSProcessModifier and TypeMethodDescriptiondefault OSProcessOperatingSystem.getCurrentProcess()Gets the current process.OperatingSystem.getProcess(int pid) Gets information on a currently running processMethods in oshi.software.os that return types with arguments of type OSProcessModifier and TypeMethodDescriptionOperatingSystem.getChildProcesses(int parentPid, Predicate<OSProcess> filter, Comparator<OSProcess> sort, int limit) Gets currently running child processes of provided parent PID, optionally filtering, sorting, and limited to the top "N".OperatingSystem.getDescendantProcesses(int parentPid, Predicate<OSProcess> filter, Comparator<OSProcess> sort, int limit) Gets currently running processes of provided parent PID's descendants, including their children, the children's children, etc., optionally filtering, sorting, and limited to the top "N".OperatingSystem.getProcesses()Gets currently running processes.OperatingSystem.getProcesses(Collection<Integer> pids) Gets information on aCollectionof currently running processes.OperatingSystem.getProcesses(Predicate<OSProcess> filter, Comparator<OSProcess> sort, int limit) Gets currently running processes, optionally filtering, sorting, and limited to the top "N".Methods in oshi.software.os with parameters of type OSProcessModifier and TypeMethodDescriptiondoubleOSProcess.getProcessCpuLoadBetweenTicks(OSProcess proc) Gets CPU usage of this process since a previous snapshot of the same process, provided as a parameter.Method parameters in oshi.software.os with type arguments of type OSProcessModifier and TypeMethodDescriptionOperatingSystem.getChildProcesses(int parentPid, Predicate<OSProcess> filter, Comparator<OSProcess> sort, int limit) Gets currently running child processes of provided parent PID, optionally filtering, sorting, and limited to the top "N".OperatingSystem.getChildProcesses(int parentPid, Predicate<OSProcess> filter, Comparator<OSProcess> sort, int limit) Gets currently running child processes of provided parent PID, optionally filtering, sorting, and limited to the top "N".OperatingSystem.getDescendantProcesses(int parentPid, Predicate<OSProcess> filter, Comparator<OSProcess> sort, int limit) Gets currently running processes of provided parent PID's descendants, including their children, the children's children, etc., optionally filtering, sorting, and limited to the top "N".OperatingSystem.getDescendantProcesses(int parentPid, Predicate<OSProcess> filter, Comparator<OSProcess> sort, int limit) Gets currently running processes of provided parent PID's descendants, including their children, the children's children, etc., optionally filtering, sorting, and limited to the top "N".OperatingSystem.getProcesses(Predicate<OSProcess> filter, Comparator<OSProcess> sort, int limit) Gets currently running processes, optionally filtering, sorting, and limited to the top "N".OperatingSystem.getProcesses(Predicate<OSProcess> filter, Comparator<OSProcess> sort, int limit) Gets currently running processes, optionally filtering, sorting, and limited to the top "N". -
Uses of OSProcess in oshi.software.os.linux
Classes in oshi.software.os.linux that implement OSProcessMethods in oshi.software.os.linux that return OSProcessModifier and TypeMethodDescriptionprotected OSProcessLinuxOperatingSystemJNA.createOSProcess(int pid) LinuxOperatingSystemJNA.getProcess(int pid) -
Uses of OSProcess in oshi.software.os.mac
Classes in oshi.software.os.mac that implement OSProcessMethods in oshi.software.os.mac that return OSProcessMethods in oshi.software.os.mac that return types with arguments of type OSProcess -
Uses of OSProcess in oshi.software.os.unix.aix
Classes in oshi.software.os.unix.aix that implement OSProcessMethods in oshi.software.os.unix.aix that return OSProcessMethods in oshi.software.os.unix.aix that return types with arguments of type OSProcessModifier and TypeMethodDescriptionAixOperatingSystem.queryAllProcesses()AixOperatingSystem.queryChildProcesses(int parentPid) AixOperatingSystem.queryDescendantProcesses(int parentPid) -
Uses of OSProcess in oshi.software.os.unix.dragonflybsd
Classes in oshi.software.os.unix.dragonflybsd that implement OSProcessMethods in oshi.software.os.unix.dragonflybsd that return OSProcessMethods in oshi.software.os.unix.dragonflybsd that return types with arguments of type OSProcessModifier and TypeMethodDescriptionDragonFlyBsdOperatingSystem.queryAllProcesses()DragonFlyBsdOperatingSystem.queryChildProcesses(int parentPid) DragonFlyBsdOperatingSystem.queryDescendantProcesses(int parentPid) -
Uses of OSProcess in oshi.software.os.unix.freebsd
Classes in oshi.software.os.unix.freebsd that implement OSProcessMethods in oshi.software.os.unix.freebsd that return OSProcessMethods in oshi.software.os.unix.freebsd that return types with arguments of type OSProcessModifier and TypeMethodDescriptionFreeBsdOperatingSystemJNA.queryAllProcesses()FreeBsdOperatingSystemJNA.queryChildProcesses(int parentPid) FreeBsdOperatingSystemJNA.queryDescendantProcesses(int parentPid) -
Uses of OSProcess in oshi.software.os.unix.netbsd
Classes in oshi.software.os.unix.netbsd that implement OSProcessMethods in oshi.software.os.unix.netbsd that return OSProcessMethods in oshi.software.os.unix.netbsd that return types with arguments of type OSProcessModifier and TypeMethodDescriptionNetBsdOperatingSystem.queryAllProcesses()NetBsdOperatingSystem.queryChildProcesses(int parentPid) NetBsdOperatingSystem.queryDescendantProcesses(int parentPid) -
Uses of OSProcess in oshi.software.os.unix.openbsd
Classes in oshi.software.os.unix.openbsd that implement OSProcessMethods in oshi.software.os.unix.openbsd that return OSProcessMethods in oshi.software.os.unix.openbsd that return types with arguments of type OSProcessModifier and TypeMethodDescriptionOpenBsdOperatingSystem.queryAllProcesses()OpenBsdOperatingSystem.queryChildProcesses(int parentPid) OpenBsdOperatingSystem.queryDescendantProcesses(int parentPid) -
Uses of OSProcess in oshi.software.os.unix.solaris
Classes in oshi.software.os.unix.solaris that implement OSProcessMethods in oshi.software.os.unix.solaris that return OSProcessMethods in oshi.software.os.unix.solaris that return types with arguments of type OSProcessModifier and TypeMethodDescriptionSolarisOperatingSystem.queryAllProcesses()SolarisOperatingSystem.queryChildProcesses(int parentPid) SolarisOperatingSystem.queryDescendantProcesses(int parentPid) -
Uses of OSProcess in oshi.software.os.windows
Classes in oshi.software.os.windows that implement OSProcessModifier and TypeClassDescriptionclassJNA-based Windows OS process implementation.Methods in oshi.software.os.windows that return OSProcessMethods in oshi.software.os.windows that return types with arguments of type OSProcessModifier and TypeMethodDescriptionWindowsOperatingSystemJNA.getProcesses(Collection<Integer> pids) WindowsOperatingSystemJNA.queryAllProcesses()WindowsOperatingSystemJNA.queryChildProcesses(int parentPid) WindowsOperatingSystemJNA.queryDescendantProcesses(int parentPid)