Uses of Enum Class
oshi.software.os.OSProcess.State
Packages that use OSProcess.State
Package
Description
Provides functions to query Mac info
Provides common (native-free) Linux operating system implementations shared by JNA and FFM modules.
Provides information about Software and OS on macOS
Provides abstract base classes and pure-Java implementations for the FreeBSD operating system, shared by the JNA and
FFM modules.
Provides abstract base classes and pure-Java implementations for the OpenBSD operating system, shared by the JNA and
FFM modules.
Provides common implementations for Windows operating system information shared between JNA and FFM implementations.
[oshi-common API] Provides cross-platform common API to retrieve OS, FileSystem, and Process information
Provides information about Software and OS on macOS
Provides information about Software and OS on AIX
Provides information about Software and OS on DragonFly BSD
Provides information about Software and OS on FreeBSD
Provides information about Software and OS on NetBSD
Provides information about Software and OS on OpenBSD
Provides information about Software and OS on Solaris
Provides non-native Linux driver utilities for querying the
/proc filesystem.-
Uses of OSProcess.State in oshi.driver.common.mac
Methods in oshi.driver.common.mac that return OSProcess.State -
Uses of OSProcess.State in oshi.software.common.os.linux
Methods in oshi.software.common.os.linux that return OSProcess.State -
Uses of OSProcess.State in oshi.software.common.os.mac
Methods in oshi.software.common.os.mac that return OSProcess.StateConstructors in oshi.software.common.os.mac with parameters of type OSProcess.StateModifierConstructorDescriptionMacOSThread(int pid, int threadId, OSProcess.State state, long kernelTime, long userTime, long startTime, long upTime, int priority) Creates a MacOSThread with full parameters. -
Uses of OSProcess.State in oshi.software.common.os.unix.freebsd
Methods in oshi.software.common.os.unix.freebsd that return OSProcess.State -
Uses of OSProcess.State in oshi.software.common.os.unix.openbsd
Methods in oshi.software.common.os.unix.openbsd that return OSProcess.State -
Uses of OSProcess.State in oshi.software.common.os.windows
Methods in oshi.software.common.os.windows that return OSProcess.StateMethods in oshi.software.common.os.windows with parameters of type OSProcess.StateModifier and TypeMethodDescriptionprotected voidWindowsOSProcess.setState(OSProcess.State state) Sets the process state. -
Uses of OSProcess.State in oshi.software.os
Subclasses with type arguments of type OSProcess.State in oshi.software.osMethods in oshi.software.os that return OSProcess.StateModifier and TypeMethodDescriptionOSProcess.getState()Gets the process state.OSThread.getState()Gets the execution state of the task/thread.static OSProcess.StateReturns the enum constant of this class with the specified name.static OSProcess.State[]OSProcess.State.values()Returns an array containing the constants of this enum class, in the order they are declared. -
Uses of OSProcess.State in oshi.software.os.mac
Methods in oshi.software.os.mac that return OSProcess.State -
Uses of OSProcess.State in oshi.software.os.unix.aix
Methods in oshi.software.os.unix.aix that return OSProcess.State -
Uses of OSProcess.State in oshi.software.os.unix.dragonflybsd
Methods in oshi.software.os.unix.dragonflybsd that return OSProcess.State -
Uses of OSProcess.State in oshi.software.os.unix.freebsd
Methods in oshi.software.os.unix.freebsd that return OSProcess.State -
Uses of OSProcess.State in oshi.software.os.unix.netbsd
Methods in oshi.software.os.unix.netbsd that return OSProcess.State -
Uses of OSProcess.State in oshi.software.os.unix.openbsd
Methods in oshi.software.os.unix.openbsd that return OSProcess.State -
Uses of OSProcess.State in oshi.software.os.unix.solaris
Methods in oshi.software.os.unix.solaris that return OSProcess.State -
Uses of OSProcess.State in oshi.util.driver.linux.proc
Methods in oshi.util.driver.linux.proc that return OSProcess.StateModifier and TypeMethodDescriptionstatic OSProcess.StateProcessStat.getState(char stateValue) Returns Enum STATE for the state value obtained from status file of any process/thread.