Uses of Interface
oshi.software.os.OperatingSystem

Packages that use OperatingSystem
Package
Description
[oshi-core API] Provides a cross-platform implementation to retrieve Operating System and Hardware Information, such as OS version, memory, CPU, disk, devices, sensors, etc.
Provides abstract classes for common code
Provides common (native-free) Linux operating system implementations shared by JNA and FFM modules.
Provides information about Software and OS on macOS
Provides common implementations for Windows operating system information shared between JNA and FFM implementations.
Provides information about Software and OS on Linux
Provides information about Software and OS on macOS
Provides information about Software and OS on AIX
Provides information about Software and OS on FreeBSD
Provides information about Software and OS on OpenBSD
Provides information about Software and OS on Solaris
Provides information about Software and OS on Windows
Provides utilities for parsing, formatting, and other access