Package oshi.software.os.mac
Class MacOperatingSystem
java.lang.Object
oshi.software.common.AbstractOperatingSystem
oshi.software.os.mac.MacOperatingSystem
- All Implemented Interfaces:
OperatingSystem
public class MacOperatingSystem extends AbstractOperatingSystem
MacOperatingSystem class.
-
Nested Class Summary
Nested classes/interfaces inherited from class oshi.software.common.AbstractOperatingSystem
AbstractOperatingSystem.FamilyVersionInfoNested classes/interfaces inherited from interface oshi.software.os.OperatingSystem
OperatingSystem.OSVersionInfo, OperatingSystem.ProcessSort -
Field Summary
-
Constructor Summary
Constructors Constructor Description MacOperatingSystem()Constructor for MacOperatingSystem. -
Method Summary
Modifier and Type Method Description OSProcess[]getChildProcesses(int parentPid, int limit, OperatingSystem.ProcessSort sort)Gets currently running child processes of provided PID.FileSystemgetFileSystem()Instantiates aFileSystemobject.NetworkParamsgetNetworkParams()Instantiates aNetworkParamsobject.OSProcessgetProcess(int pid, boolean slowFields)Gets information on a currently running processlonggetProcessAffinityMask(int processId)Retrieves the process affinity mask for the specified process.intgetProcessCount()Get the number of processes currently runningOSProcess[]getProcesses(int limit, OperatingSystem.ProcessSort sort, boolean slowFields)Gets currently running processes.intgetProcessId()Gets the current process IDOSService[]getServices()Gets the all services on the system.longgetSystemBootTime()Get Unix time of boot.longgetSystemUptime()Get the System up time (time since boot).intgetThreadCount()Get the number of threads currently runningprotected intqueryBitness(int jvmBitness)Backup OS-specific query to determine bitness if previous checks failprotected booleanqueryElevated()AbstractOperatingSystem.FamilyVersionInfoqueryFamilyVersionInfo()java.lang.StringqueryManufacturer()Methods inherited from class oshi.software.common.AbstractOperatingSystem
getBitness, getFamily, getManufacturer, getProcess, getProcesses, getProcesses, getProcesses, getProcesses, getVersion, getVersionInfo, isElevated, processSort, toString
-
Constructor Details
-
MacOperatingSystem
public MacOperatingSystem()Constructor for MacOperatingSystem.
-
-
Method Details
-
queryManufacturer
public java.lang.String queryManufacturer()- Specified by:
queryManufacturerin classAbstractOperatingSystem
-
queryFamilyVersionInfo
- Specified by:
queryFamilyVersionInfoin classAbstractOperatingSystem
-
queryBitness
protected int queryBitness(int jvmBitness)Description copied from class:AbstractOperatingSystemBackup OS-specific query to determine bitness if previous checks fail- Specified by:
queryBitnessin classAbstractOperatingSystem- Parameters:
jvmBitness- The bitness of the JVM- Returns:
- The operating system bitness
-
queryElevated
protected boolean queryElevated()- Specified by:
queryElevatedin classAbstractOperatingSystem
-
getFileSystem
Description copied from interface:OperatingSystemInstantiates aFileSystemobject.- Returns:
- A
FileSystemobject.
-
getProcesses
Description copied from interface:OperatingSystemGets currently running processes. If a positive limit is specified, returns only that number of processes; zero will return all processes. The order may be specified by the sort parameter, for example, to return the top cpu or memory consuming processes; if null, no order is guaranteed.- Parameters:
limit- Max number of results to return, or 0 to return all resultssort- If not null, determines sorting of resultsslowFields- If false, skipOSProcessfields that are slow to retrieve (e.g., group information on Windows, open files on Unix and Linux). If true, include all fields, regardless of how long it takes to retrieve the data.- Returns:
- An array of
OSProcessobjects for the specified number (or all) of currently running processes, sorted as specified. The array may contain null elements if a process terminates during iteration.
-
getProcess
Description copied from interface:OperatingSystemGets information on a currently running process- Parameters:
pid- A process IDslowFields- If false, skipOSProcessfields that are slow to retrieve (e.g., group information on Windows, open files on Unix and Linux). If true, include all fields, regardless of how long it takes to retrieve the data.- Returns:
- An
OSProcessobject for the specified process id if it is running; null otherwise
-
getChildProcesses
Description copied from interface:OperatingSystemGets currently running child processes of provided PID. If a positive limit is specified, returns only that number of processes; zero will return all processes. The order may be specified by the sort parameter, for example, to return the top cpu or memory consuming processes; if null, no order is guaranteed.- Parameters:
parentPid- A process IDlimit- Max number of results to return, or 0 to return all resultssort- If not null, determines sorting of results- Returns:
- An array of
OSProcessobjects presenting the specified number (or all) of currently running child processes of the provided PID, sorted as specified. The array may contain null elements if a process terminates during iteration.
-
getProcessAffinityMask
public long getProcessAffinityMask(int processId)Description copied from interface:OperatingSystemRetrieves the process affinity mask for the specified process.On Windows systems with more than 64 processors, if the threads of the calling process are in a single processor group, returns the process affinity mask for that group (which may be zero if the specified process is running in a different group). If the calling process contains threads in multiple groups, returns zero.
If the Operating System fails to retrieve an affinity mask (e.g., the process has terminated), returns zero.
- Parameters:
processId- The process ID for which to retrieve the affinity.- Returns:
- a bit vector in which each bit represents the processors that a process is allowed to run on.
-
getProcessId
public int getProcessId()Description copied from interface:OperatingSystemGets the current process ID- Returns:
- the Process ID of the current process
-
getProcessCount
public int getProcessCount()Description copied from interface:OperatingSystemGet the number of processes currently running- Returns:
- The number of processes running
-
getThreadCount
public int getThreadCount()Description copied from interface:OperatingSystemGet the number of threads currently running- Returns:
- The number of threads running
-
getSystemUptime
public long getSystemUptime()Description copied from interface:OperatingSystemGet the System up time (time since boot).- Returns:
- Number of seconds since boot.
-
getSystemBootTime
public long getSystemBootTime()Description copied from interface:OperatingSystemGet Unix time of boot.- Returns:
- The approximate time at which the system booted, in seconds since the Unix epoch.
-
getNetworkParams
Description copied from interface:OperatingSystemInstantiates aNetworkParamsobject.- Returns:
- A
NetworkParamsobject.
-
getServices
Description copied from interface:OperatingSystemGets the all services on the system. The definition of what is a service is platform-dependent.- Specified by:
getServicesin interfaceOperatingSystem- Overrides:
getServicesin classAbstractOperatingSystem- Returns:
- An array of
OSServiceobjects
-