Package oshi.software.os

[oshi-core API] Provides cross-platform implementation to retrieve OS, FileSystem, and Process information
  • Interface Summary 
    Interface Description
    FileSystem
    The File System is a logical arrangement, usually in a hierarchial tree, where files are placed for storage and retrieval.
    NetworkParams
    NetworkParams presents network parameters of running OS, such as DNS, host name etc.
    OperatingSystem
    An operating system (OS) is the software on a computer that manages the way different programs use its hardware, and regulates the ways that a user controls the computer.
    OperatingSystemVersion Deprecated.
  • Class Summary 
    Class Description
    OperatingSystem.OSVersionInfo  
    OSFileStore
    A File Store is a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage.
    OSProcess
    A process is an instance of a computer program that is being executed.
    OSService
    Operating system services are responsible for the management of platform resources, including the processor, memory, files, and input and output.
  • Enum Summary 
    Enum Description
    OperatingSystem.ProcessSort
    Controls sorting of Process output
    OSProcess.State
    Process Execution States
    OSService.State
    Service Execution States