| Package | Description |
|---|---|
| oshi |
[oshi-core API] Provides a cross-platform implementation to retrieve
Operating System and Hardware Information, such as OS version, memory, CPU,
disk, devices, sensors, etc.
|
| oshi.software.common |
Provides abstract classes for common code
|
| oshi.software.os |
[oshi-core API] Provides cross-platform implementation to retrieve OS,
FileSystem, and Process information
|
| oshi.software.os.linux |
Provides information about Software and OS on Linux
|
| oshi.software.os.mac |
Provides information about Software and OS on Mac OS X
|
| oshi.software.os.unix.freebsd |
Provides information about Software and OS on FreeBSD
|
| oshi.software.os.unix.solaris |
Provides information about Software and OS on Solaris
|
| oshi.software.os.windows |
Provides information about Software and OS on Windows
|
| Class and Description |
|---|
| OperatingSystem
An operating system (OS) is the software on a computer that manages the way
different programs use its hardware, and regulates the ways that a user
controls the computer.
|
| Class and Description |
|---|
| NetworkParams
NetworkParams presents network parameters of running OS, such as DNS, host
name etc.
|
| OperatingSystem
An operating system (OS) is the software on a computer that manages the way
different programs use its hardware, and regulates the ways that a user
controls the computer.
|
| OperatingSystem.OSVersionInfo |
| OperatingSystem.ProcessSort
Controls sorting of Process output
|
| OperatingSystemVersion
Deprecated.
|
| OSProcess
A process is an instance of a computer program that is being executed.
|
| OSService
Operating system services are responsible for the management of platform
resources, including the processor, memory, files, and input and output.
|
| Class and Description |
|---|
| FileSystem
The File System is a logical arrangement, usually in a hierarchial tree,
where files are placed for storage and retrieval.
|
| NetworkParams
NetworkParams presents network parameters of running OS, such as DNS, host
name etc.
|
| OperatingSystem
An operating system (OS) is the software on a computer that manages the way
different programs use its hardware, and regulates the ways that a user
controls the computer.
|
| OperatingSystem.OSVersionInfo |
| OperatingSystem.ProcessSort
Controls sorting of Process output
|
| OperatingSystemVersion
Deprecated.
|
| OSFileStore
A File Store is a storage pool, device, partition, volume, concrete file
system or other implementation specific means of file storage.
|
| OSProcess
A process is an instance of a computer program that is being executed.
|
| OSProcess.State
Process Execution States
|
| OSService
Operating system services are responsible for the management of platform
resources, including the processor, memory, files, and input and output.
|
| OSService.State
Service Execution States
|
| Class and Description |
|---|
| FileSystem
The File System is a logical arrangement, usually in a hierarchial tree,
where files are placed for storage and retrieval.
|
| NetworkParams
NetworkParams presents network parameters of running OS, such as DNS, host
name etc.
|
| OperatingSystem
An operating system (OS) is the software on a computer that manages the way
different programs use its hardware, and regulates the ways that a user
controls the computer.
|
| OperatingSystem.ProcessSort
Controls sorting of Process output
|
| OperatingSystemVersion
Deprecated.
|
| OSFileStore
A File Store is a storage pool, device, partition, volume, concrete file
system or other implementation specific means of file storage.
|
| OSProcess
A process is an instance of a computer program that is being executed.
|
| OSService
Operating system services are responsible for the management of platform
resources, including the processor, memory, files, and input and output.
|
| OSUser
OSUser class.
|
| Class and Description |
|---|
| FileSystem
The File System is a logical arrangement, usually in a hierarchial tree,
where files are placed for storage and retrieval.
|
| NetworkParams
NetworkParams presents network parameters of running OS, such as DNS, host
name etc.
|
| OperatingSystem
An operating system (OS) is the software on a computer that manages the way
different programs use its hardware, and regulates the ways that a user
controls the computer.
|
| OperatingSystem.ProcessSort
Controls sorting of Process output
|
| OperatingSystemVersion
Deprecated.
|
| OSFileStore
A File Store is a storage pool, device, partition, volume, concrete file
system or other implementation specific means of file storage.
|
| OSProcess
A process is an instance of a computer program that is being executed.
|
| OSService
Operating system services are responsible for the management of platform
resources, including the processor, memory, files, and input and output.
|
| Class and Description |
|---|
| FileSystem
The File System is a logical arrangement, usually in a hierarchial tree,
where files are placed for storage and retrieval.
|
| NetworkParams
NetworkParams presents network parameters of running OS, such as DNS, host
name etc.
|
| OperatingSystem
An operating system (OS) is the software on a computer that manages the way
different programs use its hardware, and regulates the ways that a user
controls the computer.
|
| OperatingSystem.ProcessSort
Controls sorting of Process output
|
| OperatingSystemVersion
Deprecated.
|
| OSFileStore
A File Store is a storage pool, device, partition, volume, concrete file
system or other implementation specific means of file storage.
|
| OSProcess
A process is an instance of a computer program that is being executed.
|
| OSService
Operating system services are responsible for the management of platform
resources, including the processor, memory, files, and input and output.
|
| Class and Description |
|---|
| FileSystem
The File System is a logical arrangement, usually in a hierarchial tree,
where files are placed for storage and retrieval.
|
| NetworkParams
NetworkParams presents network parameters of running OS, such as DNS, host
name etc.
|
| OperatingSystem
An operating system (OS) is the software on a computer that manages the way
different programs use its hardware, and regulates the ways that a user
controls the computer.
|
| OperatingSystem.ProcessSort
Controls sorting of Process output
|
| OperatingSystemVersion
Deprecated.
|
| OSFileStore
A File Store is a storage pool, device, partition, volume, concrete file
system or other implementation specific means of file storage.
|
| OSProcess
A process is an instance of a computer program that is being executed.
|
| OSService
Operating system services are responsible for the management of platform
resources, including the processor, memory, files, and input and output.
|
| Class and Description |
|---|
| FileSystem
The File System is a logical arrangement, usually in a hierarchial tree,
where files are placed for storage and retrieval.
|
| NetworkParams
NetworkParams presents network parameters of running OS, such as DNS, host
name etc.
|
| OperatingSystem
An operating system (OS) is the software on a computer that manages the way
different programs use its hardware, and regulates the ways that a user
controls the computer.
|
| OperatingSystem.ProcessSort
Controls sorting of Process output
|
| OperatingSystemVersion
Deprecated.
|
| OSFileStore
A File Store is a storage pool, device, partition, volume, concrete file
system or other implementation specific means of file storage.
|
| OSProcess
A process is an instance of a computer program that is being executed.
|
| OSService
Operating system services are responsible for the management of platform
resources, including the processor, memory, files, and input and output.
|
Copyright © 2010–2020 oshi. All rights reserved.