Class WindowsOSFileStoreJNA
java.lang.Object
oshi.software.common.AbstractOSFileStore
oshi.software.common.os.windows.WindowsOSFileStore
oshi.software.os.windows.WindowsOSFileStoreJNA
- All Implemented Interfaces:
OSFileStore
JNA-based Windows OSFileStore implementation.
-
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionbooleanMake a best effort to update all the statistics about the file store without needing to recreate the file store list.Methods inherited from class WindowsOSFileStore
getDescription, getFreeInodes, getFreeSpace, getLogicalVolume, getTotalInodes, getTotalSpace, getType, getUsableSpace, updateFrom, updateSpaceMethods inherited from class AbstractOSFileStore
getLabel, getMount, getName, getOptions, getUUID, getVolume, isLocal, toString
-
Constructor Details
-
WindowsOSFileStoreJNA
-
-
Method Details
-
updateAttributes
public boolean updateAttributes()Description copied from interface:OSFileStoreMake a best effort to update all the statistics about the file store without needing to recreate the file store list. This method provides for more frequent periodic updates of file store statistics.- Returns:
- True if the update was (probably) successful, false if the disk was not found
-