Class WindowsOSThreadJNA
java.lang.Object
oshi.software.common.AbstractOSThread
oshi.software.common.os.windows.WindowsOSThread
oshi.software.os.windows.WindowsOSThreadJNA
- All Implemented Interfaces:
OSThread
JNA-based Windows OS thread implementation.
-
Nested Class Summary
Nested classes/interfaces inherited from interface OSThread
OSThread.ThreadFiltering -
Constructor Summary
ConstructorsConstructorDescriptionWindowsOSThreadJNA(int pid, int tid, String procName, ThreadPerfCounterBlock pcb) -
Method Summary
Modifier and TypeMethodDescriptionbooleanAttempts to updates process attributes.Methods inherited from class WindowsOSThread
getContextSwitches, getKernelTime, getName, getPriority, getProcName, getStartMemoryAddress, getStartTime, getState, getThreadId, getUpTime, getUserTime, updateAttributesMethods inherited from class AbstractOSThread
getOwningProcessId, getThreadCpuLoadBetweenTicks, getThreadCpuLoadCumulative, toStringMethods inherited from class Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface OSThread
getMajorFaults, getMinorFaults
-
Constructor Details
-
WindowsOSThreadJNA
-
-
Method Details
-
updateAttributes
public boolean updateAttributes()Description copied from interface:OSThreadAttempts to updates process attributes. Returns false if the update fails, which will occur if the process no longer exists. Not implemented for macOS, as thread ID is simply an index and not unique.- Returns:
trueif the update was successful, false if the update failed. In addition, on a failed update the thread state will be changed toOSProcess.State.INVALID.
-