Interface ExceptionUtil.ThrowingRunnable
- Enclosing class:
ExceptionUtil
- Functional Interface:
- This is a functional interface and can therefore be used as the assignment target for a lambda expression or method reference.
A runnable that may throw any
Throwable.-
Method Summary
-
Method Details
-
run
-