Package oshi.util.driver.linux.proc
package oshi.util.driver.linux.proc
Provides non-native Linux driver utilities for querying the
/proc filesystem.-
ClassDescriptionConstants and shared logic for the Linux auxiliary vector (
/proc/self/auxv).Reads a native-long value from aByteBufferand returns it as a Javalong.Utility to read CPU info from/proc/cpuinfoUtility to read CPU statistics from/proc/statUtility to read disk statistics from/proc/diskstatsEnum corresponding to the fields in the output of/proc/diskstatsUtility to read process statistics from/proc/[pid]/statEnum corresponding to the fields in the output of/proc/[pid]/statEnum corresponding to the fields in the output of/proc/[pid]/statmUtility to read system uptime from/proc/uptime