Class DevPath
java.lang.Object
oshi.util.linux.DevPath
Provides constants for paths in the
/dev filesystem on Linux.
If the user desires to configure a custom /dev path, it must be declared in the OSHI configuration file or
updated in the GlobalConfig class prior to initializing this class.
-
Field Summary
FieldsModifier and TypeFieldDescriptionstatic final StringThe /dev filesystem location.static final StringPath to disk-by-uuid directory.static final StringPath prefix for device-mapper devices.static final StringPath prefix for loop devices.static final StringPath prefix for device-mapper mapped names.static final StringPath prefix for RAM disk devices. -
Method Summary
-
Field Details
-
DEV
The /dev filesystem location. -
DISK_BY_UUID
Path to disk-by-uuid directory. -
DM
Path prefix for device-mapper devices. -
LOOP
Path prefix for loop devices. -
MAPPER
Path prefix for device-mapper mapped names. -
RAM
Path prefix for RAM disk devices.
-