Class SysPath
java.lang.Object
oshi.util.linux.SysPath
Provides constants for paths in the
/sys filesystem on Linux.
If the user desires to configure a custom /sys path, it must be declared in the OSHI configuration file or
updated in the GlobalConfig class prior to initializing this class.
-
Field Summary
FieldsModifier and TypeFieldDescriptionstatic final StringPath to cgroup filesystem.static final StringPath to CPU devices.static final StringPath to DMI identification.static final StringPath to DRM (Direct Rendering Manager) class.static final StringPath to hardware monitoring.static final StringPath to device tree model.static final StringPath to network interfaces.static final StringPath to power supply class.static final StringThe /sys filesystem location.static final StringPath to thermal class. -
Method Summary
-
Field Details
-
SYS
The /sys filesystem location. -
CPU
Path to CPU devices. -
DMI_ID
Path to DMI identification. -
NET
Path to network interfaces. -
MODEL
Path to device tree model. -
POWER_SUPPLY
Path to power supply class. -
HWMON
Path to hardware monitoring. -
THERMAL
Path to thermal class. -
CGROUP
Path to cgroup filesystem. -
DRM
Path to DRM (Direct Rendering Manager) class.
-